using System.Collections.Generic;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Enum.CommentEnum;

namespace WingInterfaceLibrary.DTO.Comment
{
    public class DiagnosisPerImageDTO : AIDiagnosisPerImageDTO
    {
        /// <summary>
        /// 扫查图像编码
        /// </summary>
        /// <value></value>
        public string RemedicalCode { get; set; }

        /// <summary>
        /// 文件类型
        /// </summary>
        /// <value></value>
        public RemedicalFileDataTypeEnum DataType { get; set; }

        public double Pixel { get; set; }

        public string RemedicalFileToken { get; set; }

        public string AIFileToken { get; set; }

        public string AIPreviewFileToken { get; set; }

        public string PerImageJson { get; set; }

        /// <summary>
        /// AI诊断结论
        /// </summary>
        /// <value></value>
        public DiagnosisConclusionEnum DiagnosisConclusion { get; set; }

        /// <summary>
        /// AI识别的器官
        /// </summary>
        /// <value></value>
        public List<DiagnosisOrganEnum> DiagnosisOrgans { get; set; } = new List<DiagnosisOrganEnum>();

    }


    public class AIDiagnosisPerImageDTO
    {
        public int Index { get; set; }
        public float PriorityScore { get; set; }
        public List<AIDiagnosisResultPerOrgan> DiagResultsForEachOrgan { get; set; } = new List<AIDiagnosisResultPerOrgan>();
    }

    public class AIDiagnosisResultPerOrgan
    {
        public DiagnosisOrganEnum Organ { get; set; }
        public AIDiagnosisRect OrganBoundBox { get; set; }
        public List<AIDiagnosisPoint2D> OrganContours { get; set; }
        public List<AIDiagnosisDescription> OrganDescriptions { get; set; }
        public List<AIDetectedObject> DetectedObjects { get; set; }
    }

    public class AIDiagnosisRect
    {
        public int Right { get; set; }
        public int Bottom { get; set; }
        public int Left { get; set; }
        public int Top { get; set; }
        public int Width { get; set; }
        public int Height { get; set; }
    }

    /// <summary>
    /// 病灶轮廓坐标点
    /// </summary>
    public class AIDiagnosisPoint2D
    {
        /// <summary>
        /// 2维点坐标的X坐标
        /// </summary>
        /// <value></value>
        public int X { get; set; }

        /// <summary>
        /// 2维点坐标的Y坐标
        /// </summary>
        /// <value></value>
        public int Y { get; set; }
    }

    public class AIDetectedObject
    {
        public int Label { get; set; }
        public float Confidence { get; set; }
        public AIDiagnosisRect BoundingBox { get; set; }
        public List<AIDiagnosisPoint2D> Contours { get; set; }
        public List<AIDiagnosisDescription> Descriptions { get; set; }
    }

    public class AIDiagnosisDescription
    {
        public DiagnosisDescriptionEnum Type { get; set; }

        public string Value { get; set; }
    }

    /// <summary>
    /// 轮廓的横纵径测量值
    /// </summary>
    public class AIDiagnosisLesionSize
    {
        /// <summary>
        /// 横径的起点
        /// </summary>
        /// <value></value>
        public AIDiagnosisPoint2D HorizontalPoint1 { get; set; }

        /// <summary>
        /// 横径的终点
        /// </summary>
        /// <value></value>
        public AIDiagnosisPoint2D HorizontalPoint2 { get; set; }

        /// <summary>
        /// 纵径的起点
        /// </summary>
        /// <value></value>
        public AIDiagnosisPoint2D VerticalPoint1 { get; set; }

        /// <summary>
        /// 纵径的终点
        /// </summary>
        /// <value></value>
        public AIDiagnosisPoint2D VerticalPoint2 { get; set; }

        /// <summary>
        /// 横径的长度（在图像上的像素长度）
        /// </summary>
        /// <value></value>
        public int HorizontalLengthInPixel { get; set; }

        /// <summary>
        /// 纵径的长度（在图像上的像素长度）
        /// </summary>
        /// <value></value>
        public int VerticalLengthInPixel { get; set; }
    }
}