using System;
namespace WingInterfaceLibrary.DTO.Common
{
    /// <summary>
    /// License信息实体
    /// </summary>
    public class LicenseInfoDTO
    {
        /// <summary>
        /// LicenseId
        /// </summary>
        /// <value></value>
        public string LicenseId { get; set; }

        /// <summary>
        /// 类型：0-试用；1-正式
        /// </summary>
        public int LicenseType { get; set; }

        /// <summary>
        /// 最大账号数
        /// </summary>
        public long MaxAccountCount { get; set; }

        /// <summary>
        /// 最大超声机数
        /// </summary>
        public long MaxUsCount { get; set; }
       
        /// <summary>
        /// 过期时间 utc时间, 可以和当前时间比较，
        /// </summary>
        public DateTime ExpirationUtcDate { get; set; }

        /// <summary>
        /// 是否已过期
        /// </summary>
        public bool IsExpired { get; set; }

        /// <summary>
        /// 物理唯一码
        /// </summary>
        /// <value></value>
        public string MachineId { get; set; }

        /// <summary>
        /// 是否识别到dongle并获取到license
        /// </summary>
        /// <value></value>
        public bool IsDongleOn { get; set; } = false;

        /// <summary>
        /// 权限字符串
        /// </summary>
        /// <value></value>
        public string AuthorityInfos { get; set; }

    }

    /// <summary>
    /// License基础信息实体
    /// </summary>
    public class LicenseInfoBasicDTO : BaseDTO
    {
        /// <summary>
        /// dbLicense code
        /// </summary>
        /// <value></value>
        public string Code  { get; set; }

        /// <summary>
        /// 工具生成的LicenseId
        /// </summary>
        /// <value></value>
        public string LicenseId { get; set; }

        /// <summary>
        /// 使用方名称【使用机构名称】
        /// </summary>
        /// <value></value>
        public string AgencyName { get; set; }

        /// <summary>
        /// 加密的license内容
        /// </summary>
        /// <value></value>
        public string LicenseContent { get; set; }

    }

    /// <summary>
    /// License信息详情实体
    /// </summary>
    public class LicenseDetailInfoDTO : LicenseInfoBasicDTO
    {
        /// <summary>
        /// 类型：0-试用；1-正式
        /// </summary>
        public int LicenseType { get; set; }

        /// <summary>
        /// Functional Item Value
        /// </summary>
        public string FunctionalItemValue { get; set; }

        /// <summary>
        /// 有效期
        /// </summary>
        /// <value></value>
        public DateTime ExpiredTime { get; set; }

        /// <summary>
        /// 绑定物理地址
        /// </summary>
        /// <value></value>
        public string BindMachinePhyAddress { get; set; }
    }

    /// <summary>
    /// Dongle信息实体
    /// </summary>
    public class DongleInfoDTO : BaseDTO
    {        
        /// <summary>
        /// db dongle code
        /// </summary>
        /// <value></value>
        public string Code  { get; set; }

        /// <summary>
        /// dongle类型：1- software;2-customer
        /// </summary>
        /// <value></value>
        public int DongleType { get; set; }

        /// <summary>
        /// LicenseId
        /// </summary>
        /// <value></value>
        public string LicenseId { get; set; }

        /// <summary>
        /// DongleId
        /// </summary>
        /// <value></value>
        public string DongleId { get; set; }

        /// <summary>
        /// 加密的Dongle内容
        /// </summary>
        /// <value></value>
        public string DongleContent { get; set; }

    }

    /// <summary>
    /// Dongle详情信息实体
    /// </summary>
    public class DongleDetailInfoDTO : DongleInfoDTO
    {        
        /// <summary>
        /// dongle 绑定名称
        /// </summary>
        /// <value></value>
        public string Name { get; set; }

        /// <summary>
        /// 使用方名称【使用机构名称】
        /// </summary>
        /// <value></value>
        public string AgencyName { get; set; }

        /// <summary>
        /// 有效期
        /// </summary>
        /// <value></value>
        public DateTime ExpiredTime { get; set; }

        /// <summary>
        /// 绑定物理地址
        /// </summary>
        /// <value></value>
        public string BindMachinePhyAddress { get; set; }

    }
}