using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using WingInterfaceLibrary.DTO.Common;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.DTO.Consultation
{
    /// <summary>
    /// 会诊列表信息
    /// </summary>
    public class ConsultationPageDTO
    {
        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;

        /// <summary>
        /// 会诊状态
        /// </summary>
        /// <value>1</value>
        public TransactionStatusEnum ConsultationStatus { get; set; } = TransactionStatusEnum.Applied;

        /// <summary>
        /// 患者姓名
        /// </summary>
        /// <value>	马丽</value>
        public string PatientName { get; set; } = string.Empty;

        /// <summary>
        /// 患者手机号
        /// </summary>
        /// <value>138xxxxxxxx</value>
        public string Phone { get; set; } = string.Empty;

        /// <summary>
        /// 患者性别
        /// </summary>
        /// <value>Female</value>
        public string Sex { get; set; } = "Female";

        /// <summary>
        /// 患者年龄
        /// </summary>
        /// <value>2岁</value>
        public string PatientAge { get; set; } = "";

        /// <summary>
        /// 申请医院名称
        /// </summary>
        /// <value>申请医院</value>
        public string ApplyOrganizationName { get; set; } = string.Empty;

        /// <summary>
        /// 会诊开始时间
        /// </summary>
        /// <value>2022-09-30T14:00:00Z</value>
        public DateTime ConsultationTime { get; set; }

        /// <summary>
        /// 会诊结束时间
        /// </summary>
        /// <value>2022-09-30T14:00:00Z</value>
        public DateTime ConsultationTimeEnd { get; set; }

        /// <summary>
        /// 会诊专家名称
        /// </summary>
        /// <value>菲儿</value>
        public string ExpertUserName { get; set; } = string.Empty;

        /// <summary>
        /// 会诊评价
        /// </summary>
        /// <value>好评</value>
        public EvaluateGradeEnum ConsultationEvaluate { get; set; }

        /// <summary>
        /// 是否急诊标识
        /// </summary>
        /// <value></value>
        public bool IsEmergency { get; set; }

        /// <summary>
        /// 急诊code
        /// </summary>
        /// <value></value>
        public string EmergencyCode { get; set; }

        /// <summary>
        /// 质控状态枚举
        /// </summary>
        /// <value></value>
        public QualityType QualityType { get; set; } = QualityType.None;

        /// <summary>
        /// 质控合格状态
        /// </summary>
        /// <value></value>
        public QualifiedState QualifiedState { get; set; } = QualifiedState.UnSet;

    }

    /// <summary>
    /// 导出会诊数据
    /// </summary>
    public class ExportConsultationDataResult
    {

        /// <summary>
        /// 会诊记录列表
        /// </summary>
        /// <value></value>
        public List<ConsultationExportData> ConsultationList { get; set; } = new List<ConsultationExportData>();

        /// <summary>
        /// 报告列表
        /// </summary>
        /// <value></value>
        public List<ConsultationReportData> ReportList { get; set; } = new List<ConsultationReportData>();

        /// <summary>
        /// 图像列表
        /// </summary>
        /// <value></value>
        public List<ConsultationFileData> ConsultationFileDatalList { get; set; } = new List<ConsultationFileData>();

    }

    /// <summary>
    /// 会诊导出数据实体
    /// </summary>
    public class ConsultationExportData
    {
        /// <summary>
        /// 病人名字
        /// </summary>
        /// <value>张三</value>
        public string PatientName { get; set; }

        /// <summary>
        /// 病人编号
        /// </summary>
        /// <value>xxx</value>
        public string PatientCode { get; set; }

        /// <summary>
        /// 会诊明细列表
        /// </summary>
        /// <value></value>
        public List<ConsultationItem> ConsultationItemList { get; set; } = new List<ConsultationItem>();
    }

    /// <summary>
    /// 导出会诊明细实体
    /// </summary>
    public class ConsultationItem
    {
        /// <summary>
        /// 病人姓名
        /// </summary>
        /// <value></value>
        public string PatientName { get; set; }

        /// <summary>
        /// 病人性别
        /// </summary>
        /// <value></value>
        public string Sex { get; set; }

        /// <summary>
        /// 病人年龄
        /// </summary>
        /// <value></value>
        public string Age { get; set; }

        /// <summary>
        /// 申请医院名称
        /// </summary>
        /// <value>申请医院</value>
        public string ApplyOrganizationName { get; set; } = string.Empty;

        /// <summary>
        /// 申请医生名称
        /// </summary>
        /// <value>刘医师/value>
        public string ApplyUserName { get; set; } = string.Empty;

        /// <summary>
        /// 会诊医院名称
        /// </summary>
        /// <value>上级医院</value>
        public string ExpertOrganizationName { get; set; } = string.Empty;

        /// <summary>
        /// 会诊专家名称
        /// </summary>
        /// <value>菲儿</value>
        public string ExpertUserName { get; set; } = string.Empty;

        /// <summary>
        /// 会诊开始时间
        /// </summary>
        /// <value>2022-09-30 14:00:00</value>
        public DateTime ConsultationTime { get; set; }

        /// <summary>
        /// 会诊截止时间
        /// </summary>
        /// <value></value>
        public DateTime ConsultationTimeEnd { get; set; }

        /// <summary>
        /// 疾病名称
        /// </summary>
        /// <value></value>
        public string Diseases { get; set; }

        /// <summary>
        /// 初步诊断
        /// </summary>
        /// <value>初步诊断结论</value>   
        public string PrimaryDiagnosis { get; set; } = string.Empty;

        /// <summary>
        /// 会诊状态
        /// </summary>
        /// <value>1</value>
        public TransactionStatusEnum ConsultationStatus { get; set; } = TransactionStatusEnum.Applied;

        /// <summary>
        /// 检查部位
        /// </summary>
        /// <value>肝脏 附件</value>        
        /// <code>0</code>
        public List<string> ScanPositions { get; set; }
    }

    /// <summary>
    /// 报告数据
    /// </summary>
    public class ConsultationReportData
    {
        /// <summary>
        /// 病人名字
        /// </summary>
        /// <value>张三</value>
        public string PatientName { get; set; }

        /// <summary>
        /// 病人编号
        /// </summary>
        /// <value>xxx</value>
        public string PatientCode { get; set; }

        /// <summary>
        /// 报告列表
        /// </summary>
        /// <value></value>
        public List<ConsultationReportItem> ReportItemList { get; set; } = new List<ConsultationReportItem>();


    }

    /// <summary>
    /// 报告明细
    /// </summary>
    public class ConsultationReportItem
    {
        /// <summary>
        /// 对应会诊记录
        /// </summary>
        /// <value></value>
        public string ConsultationCode { get; set; }

        /// <summary>
        /// 报告fileToken
        /// </summary>
        /// <value></value>
        public string FileToken { get; set; }

        /// <summary>
        /// 提交时间
        /// </summary>
        /// <value></value>
        public DateTime SubmissionTime { get; set; }
    }

    /// <summary>
    /// 图像
    /// </summary>
    public class ConsultationFileData
    {
        public string PatientName { get; set; }

        public string PatientCode { get; set; }

        /// <summary>
        /// 图像列表
        /// </summary>
        /// <value></value>
        public List<ConsultationFileItem> ConsultationFileItemList { get; set; } = new List<ConsultationFileItem>();

    }

    /// <summary>
    /// 图像明细
    /// </summary>
    public class ConsultationFileItem
    {
        /// <summary>
        /// 对应会诊记录
        /// </summary>
        /// <value></value>
        public string ConsultationCode { get; set; }

        /// <summary>
        /// 扫查图像fileToken
        /// </summary>
        /// <value></value>
        public string FileToken { get; set; }

        /// <summary>
        /// 文件数据类型
        /// </summary>
        /// <value>0</value>
        public RemedicalFileDataTypeEnum FileDataType { get; set; }

        /// <summary>
        /// 会诊图像操作类型枚举
        /// </summary>
        /// <value></value>
        public ConsultationFileTypeEnum ConsultationFileType { get; set; }

        /// <summary>
        /// 提交时间
        /// </summary>
        /// <value></value>
        public DateTime SubmissionTime { get; set; }
    }
}