using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Enum.CourseEnum;

namespace WingInterfaceLibrary.DTO.Courses
{
    /// <summary>
    /// 课程专辑详情
    /// </summary>
    public class CourseAlbumDetailDTO : CourseAlbumDTO
    {
        /// <summary>
        /// 关联课程编码信息
        /// </summary>
        public IList<CourseInfoDetailDTO> CourseInfos { get; set; }

        /// <summary>
        /// 已报名数量
        /// </summary>
        /// <value></value>
        public int StudentCount { get; set; }
    }

    /// <summary>
    /// 课程专辑详情
    /// </summary>
    public class CourseAlbumExtendDTO : BaseCourseAlbumDTO
    {
        /// <summary>
        /// 关联课程编码信息
        /// </summary>
        public IList<CourseInfoDetailDTO> CourseInfos { get; set; }

        /// <summary>
        /// 已报名数量
        /// </summary>
        /// <value></value>
        public int SignInCount { get; set; }

        /// <summary>
        /// 专辑封面
        /// </summary>
        public string Cover { get; set; }

        /// <summary>
        /// 关联课程编码信息
        /// </summary>
        public IList<string> CourseCodes { get; set; }

        /// <summary>
        /// 专辑简介
        /// </summary>
        /// <value></value>
        public string Introduction { get; set; }

        /// <summary>
        /// 课程标签列表
        /// </summary>
        public IList<string> CourseLabelCodes { get; set; }

        /// <summary>
        /// 课程标签名称列表
        /// </summary>
        public IList<string> CourseLabelNames { get; set; }

        /// <summary>
        /// 教师Code
        /// </summary>
        public string TeacherCode { get; set; }

        /// <summary>
        /// 教师名称
        /// </summary>
        public string TeacherName { get; set; }

        /// <summary>
        /// 可见范围：国内，国外，或者两者兼有 TODO
        /// </summary>
        public CourseViewRangeEnum ViewRange { get; set; }

        /// <summary>
        /// 专辑价格 TODO
        /// </summary>
        public decimal Price { get; set; }

        /// <summary>
        /// 创建时间 
        /// </summary>
        public DateTime CreateTime { get; set; }

        /// <summary>
        /// 排序
        /// </summary>
        /// <value></value>
        public int Sort { get; set; }

        /// <summary>
        /// 是否置顶
        /// </summary>
        /// <value></value>
        public bool IsStick { get; set; }

        /// <summary>
        /// 学生对于专辑的状态
        /// </summary>
        ///  <value>0</value>
        public StudentCourseStatusEnum SignCourseStatus { get; set; }

        /// <summary>
        /// 学生是否支付：是-支付；否-未支付
        /// </summary>
        public bool IsPay { get; set; }
    }

    /// <summary>
    ///  课程专辑信息
    /// </summary>
    public class CourseAlbumDTO : BaseCourseAlbumDTO
    {
        /// <summary>
        /// 专辑封面
        /// </summary>
        public string Cover { get; set; }

        /// <summary>
        /// 关联课程编码信息
        /// </summary>
        public IList<string> CourseCodes { get; set; }

        /// <summary>
        /// 专辑简介
        /// </summary>
        /// <value></value>
        public string Introduction { get; set; }

        /// <summary>
        /// 课程标签列表
        /// </summary>
        public IList<string> CourseLabelCodes { get; set; }

        /// <summary>
        /// 教师Code
        /// </summary>
        public string TeacherCode { get; set; }

        /// <summary>
        /// 教师名称
        /// </summary>
        public string TeacherName { get; set; }

        /// <summary>
        /// 可见范围：国内，国外，或者两者兼有 TODO
        /// </summary>
        public CourseViewRangeEnum ViewRange { get; set; }

        /// <summary>
        /// 专辑价格 TODO
        /// </summary>
        public decimal Price { get; set; }

        /// <summary>
        /// 创建时间 
        /// </summary>
        public DateTime CreateTime { get; set; }

        /// <summary>
        /// 更新时间 
        /// </summary>
        public DateTime UpdateTime { get; set; }

        /// <summary>
        /// 排序
        /// </summary>
        /// <value></value>
        public int Sort { get; set; }

        /// <summary>
        /// 是否置顶
        /// </summary>
        /// <value></value>
        public bool IsStick { get; set; }

        /// <summary>
        /// 语言
        /// </summary>
        /// <value>zh-CN</value>
        public string LanguageCode { get; set; }
    }

    /// <summary>
    /// 课程专辑基础信息表
    /// </summary>
    public class BaseCourseAlbumDTO
    {
        /// <summary>
        /// 课程或专辑编码
        /// </summary>
        public string Code { get; set; }

        /// <summary>
        /// 课程或专辑名称
        /// </summary>
        public string Name { get; set; }

    }
}