using System.Collections.Generic;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Enum.CourseEnum;
using System;
using WingInterfaceLibrary.DTO.Education;
using WingInterfaceLibrary.DTO.LiveRoom;

namespace WingInterfaceLibrary.DTO.Courses
{
    /// <summary>
    /// 课程详细信息
    /// </summary>
    public class CourseInfoDetailDTO : BaseCourseInfoDTO
    {
        /// <summary>
        /// 病例标签
        /// </summary>
        /// <value></value>
        public IList<BaseLabelInfoDTO> CaseLabels { get; set; }

        /// <summary>
        /// 课程标签列表
        /// </summary>
        /// <value></value>
        public IList<BaseLabelInfoDTO> CourseLabels { get; set; }

        /// <summary>
        /// 【班级List】
        /// </summary>
        /// <value></value>
        public IList<BaseUserGroupDTO> UserGroups { get; set; }

        /// <summary>
        /// 教培视频列表
        /// </summary>
        /// <value></value>
        public IList<VideoInfoDTO> CourseVideos { get; set; }

        /// <summary>
        /// 课程资料
        /// </summary>
        /// <value></value>
        public IList<VideoInfoDTO> CourseMaterials { get; set; }

        /// <summary>
        /// 所属专辑信息
        /// </summary>
        /// <value></value>
        public IList<BaseCourseAlbumDTO> CourseAlbums { get; set; }

        /// <summary>
        /// 课程是否需要支付
        /// </summary>
        /// <value></value>
        public bool NeedPay { get { return Price > 0; } }

        /// <summary>
        /// 学生对于课程的状态
        /// </summary>
        ///  <value>0</value>
        public StudentCourseStatusEnum SignCourseStatus { get; set; }

        /// <summary>
        /// 学生是否支付：是-支付；否-未支付
        /// </summary>
        ///  <value>false</value>
        public bool IsPay { get; set; }

        /// <summary>
        /// 是否参与专家
        /// </summary>
        /// <value></value>
        public bool IsParticipant { get; set; } = false;

        /// <summary>
        /// 是否助教
        /// </summary>
        /// <value></value>
        public bool IsAssistant { get; set; } = false;

        /// <summary>
        /// 直播播放地址
        /// </summary>
        ///  <value>http://192.168.6.117:8080/open/school/#/video_course_player/B86CAC597ED84A18B7B3F19684187E74</value>
        public string CourseLiveUrl { get; set; }

        /// <summary>
        /// 课程分享地址
        /// </summary>
        ///  <value>http://192.168.6.117:8080/open/school/#/detail/B86CAC597ED84A18B7B3F19684187E74/course</value>
        public string CourseShareUrl { get; set; }
    }

    /// <summary>
    /// 基础课程信息对象
    /// </summary>
    public class BaseCourseInfoDTO
    {
        /// <summary>
        ///  课程编码
        /// </summary>
        /// <value>12334e</value>
        public string Code { get; set; }

        /// <summary>
        /// 课程名称
        /// </summary>
        /// <value>TestCourse</value>
        public string Name { get; set; }

        /// <summary>
        /// 课程简介
        /// </summary>
        ///  <value>Test course dec</value>
        public string CourseIntro { get; set; }

        /// <summary>
        /// 教师编码
        /// </summary>
        /// <value>04669519BF9544489E4DB547E1C01322</value>
        public string TeacherCode { get; set; }

        /// <summary>
        /// 教师名称
        /// </summary>
        /// <value>Test teacher name</value>
        public string TeacherName { get; set; }

        /// <summary>
        /// 封面图，课程海报
        /// </summary>
        /// <value>https://flyinsono-bj-1300984704.cos.ap-beijing.myqcloud.com/0B7B494B7A7044F3ADE0FCF8C0422700.png</value>
        public string Cover { get; set; }

        /// <summary>
        /// 课程预计开始时间
        /// </summary>
        /// <value>2022-03-15T12:53:29.889Z</value>
        public DateTime StartTime { get; set; }

        /// <summary>
        /// 课程时长【单位秒】
        /// </summary>
        /// <value>120</value>
        public int Duration { get; set; }

        /// <summary>
        /// 课程时间开始时间
        /// </summary>
        /// <value>2022-03-15T12:53:29.889Z</value>
        public DateTime ActualStartTime { get; set; }

        /// <summary>
        /// 课程实际结束时间
        /// </summary>
        /// <value>2022-03-15T12:53:29.889Z</value>
        public DateTime ActualEndTime { get; set; }

        /// <summary>
        /// 课程分类
        /// </summary>
        /// <value>1</value>
        public CourseTypeEnum CourseType { get; set; }

        /// <summary>
        /// 课程规模类型
        /// </summary>
        /// <value>1</value>
        public CourseAudienceTypeEnum AudienceType { get; set; }

        /// <summary>
        /// 课件地址
        /// </summary>
        /// <value>https://flyinsono-bj-1300984704.cos.ap-beijing.myqcloud.com/0B7B494B7A7044F3ADE0FCF8C0422700.png</value>
        public string CoursewareToken { get; set; }

        /// <summary>
        /// 课程状态
        /// </summary>
        /// <value>1</value>
        public CourseStatusEnum Status { get; set; }

        /// <summary>
        /// 课程可见范围，默认所有
        /// </summary>
        /// <value>0</value>
        public CourseViewRangeEnum ViewRange { get; set; }

        /// <summary>
        /// 创建人
        /// </summary>
        /// <value>12345</value>
        public string CreatorCode { get; set; }

        /// <summary>
        /// 创建机构code
        /// </summary>
        /// <value>1234</value>
        public string OrganizationCode { get; set; }

        /// <summary>
        /// 创建时间
        /// </summary>
        /// <value>2022-01-15T12:53:29.889Z</value>
        public DateTime CreateTime { get; set; }

        /// <summary>
        /// 更新时间
        /// </summary>
        /// <value>2022-01-15T12:53:29.889Z</value>
        public DateTime UpdateTime { get; set; }

        /// <summary>
        /// 课程价格
        /// </summary>
        /// <value>10.0</value>
        public decimal Price { get; set; }

        /// <summary>
        /// 课程标签列表
        /// </summary>
        /// <value>'12334e','12334e'</value>
        public IList<string> CourseLabelCodes { get; set; }

        /// <summary>
        /// 病例标签
        /// </summary>
        /// <value>'12334e','12334e'</value>
        public IList<string> CaseLabelCodes { get; set; }

        /// <summary>
        /// 班级CodeList
        /// </summary>
        /// <value>'12334e','12334e'</value>
        public IList<string> UserGroupCodes { get; set; }

        /// <summary>
        /// 教培视频Code列表
        /// </summary>
        /// <value>'12334e','12334e'</value>
        public IList<string> CourseVideoCodes { get; set; }

        /// <summary>
        /// 课程资料
        /// </summary>
        /// <value>'12334e','12334e'</value>
        public IList<string> CourseMaterialCodes { get; set; }

        /// <summary>
        /// 绑定试卷集合
        /// </summary>
        /// <value></value>     
        public IList<CourseExaminationDTO> BindExams { get; set; }

        /// <summary>
        /// 是否小班化
        /// </summary>
        /// <value></value>
        public bool IsSmallClass { get; set; }

        /// <summary>
        /// 助教列表
        /// </summary>
        /// <value></value>
        public IList<StudentInfoDTO> Assistants { get; set; } = new List<StudentInfoDTO>();

        /// <summary>
        /// 参与专家列表
        /// </summary>
        /// <value></value>
        public IList<StudentInfoDTO> Experts { get; set; } = new List<StudentInfoDTO>();

        /// <summary>
        /// 是否代理商课程
        /// </summary>
        /// <value>false</value>
        public bool IsAgentCourse { get; set; }

        /// <summary>
        /// 所属专辑
        /// </summary>
        /// <value></value>
        public IList<string> CourseAlbumCodes { get; set; }

        /// <summary>
        /// 课程呈现类型
        /// </summary>
        /// <value></value>
        public CourseAppearTypeEnum CourseAppearType { get; set; }

        /// <summary>
        /// 是否置顶
        /// </summary>
        /// <value></value>
        public bool IsStick { get; set; }

        /// <summary>
        /// 推荐星级
        /// </summary>
        /// <value></value>
        public int Sort { get; set; }

        /// <summary>
        /// 播放量
        /// </summary>
        /// <value>1</value>
        public int PlayCount { get; set; }

        /// <summary>
        /// 报名数量
        /// </summary>
        /// <value>1</value>
        public int SignInCount { get; set; }

        /// <summary>
        /// 默认播放地址
        /// </summary>
        /// <value>https://flyinsono-bj-1300984704.cos.ap-beijing.myqcloud.com/0221119072812.MP4</value>
        public string DefaultVideoToken { get; set; }

        /// <summary>
        /// 课程分享直播信息
        /// </summary>
        /// <value></value>
        public LiveDataDTO CourseChannel { get; set; }

        /// <summary>
        /// 其他互动人员共享屏幕直播信息
        /// </summary>
        /// <value></value>
        public LiveDataDTO OthersScreenSharingChannel { get; set; }

        /// <summary>
        /// 桌面共享RTC信息
        /// </summary>
        /// <value></value>
        public ScreenSharingChannelDTO RtcScreenSharingChannel { get; set; }

        /// <summary>
        /// 语言
        /// </summary>
        /// <value>zh-CN</value>
        public string LanguageCode { get; set; }

        /// <summary>
        /// 是否仅为视频课
        /// </summary>
        /// <value>false</value>  
        public bool IsJustVideoCourse { get; set; }

        /// <summary>
        /// 是否禁言：true-禁言；false-不禁言
        /// </summary>
        /// <value>false</value>
        public bool IsProhibition { get; set; }

        // /// <summary>
        // /// 统计信息
        // /// </summary>
        // /// <value>false</value>
        // public CourseStatisticsInfoDTO StatisticsInfo { get; set; }
    }

    // /// <summary>
    // /// 课程观看人数统计信息
    // /// </summary>
    // public class CourseStatisticsInfoDTO
    // {
    //     /// <summary>
    //     /// 报名人数
    //     /// </summary>
    //     /// <value>false</value>
    //     public int SignCount { get; set; }
        
    //     /// <summary>
    //     /// 观看数量
    //     /// </summary>
    //     /// <value>false</value>
    //     public int BrwosedCount { get; set; }
        
    //     /// <summary>
    //     /// 最多在线人数
    //     /// </summary>
    //     /// <value>false</value>
    //     public int MaxOnlineCount { get; set; }

    //     /// <summary>
    //     /// 统计详情信息
    //     /// </summary>
    //     /// <value>false</value>
    //     public List<CourseStatisticsOnlineDetailDTO> StatisticsDetailInfos { get; set; }
    // }

    // /// <summary>
    // /// 在线课程在线统计详情信息
    // /// </summary>
    // public class CourseStatisticsOnlineDetailDTO 
    // {
    //     /// <summary>
    //     /// 当前时间
    //     /// </summary>
    //     public DateTime CurrentTime { get; set; }

    //     /// <summary>
    //     /// 当前时间最多在线人数
    //     /// </summary>
    //     public int MaxOnlineCount { get; set; }
    // }


    public class ScreenSharingChannelDTO
    {
        /// <summary>
        /// RTC房间号
        /// </summary>
        public int RtcRoomId { get; set; }

        /// <summary>
        /// SdkAppId
        /// </summary>
        public int SdkAppId { get; set; }

        /// <summary>
        /// 直播用户唯一码
        /// </summary>
        public string UserCode { get; set; }

        /// <summary>
        /// 用户签名
        /// </summary>
        public string UserSign { get; set; }

        /// <summary>
        /// 直播推拉流信息
        /// </summary>
        /// <value></value>
        public LiveDataDTO LiveData { get; set; }
    }
}