using System;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Education;
using WingInterfaceLibrary.DTO.Report;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.DTO.DataCenter
{
    /// <summary>
    /// 数据中心试卷信息
    /// </summary>
    public class ExamPaperDTO : BaseDTO
    {
        /// <summary>
        /// 试卷编码
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 名称
        /// </summary>
        /// <value></value>
        public string Name { get; set; }

        /// <summary>
        /// 总分
        /// </summary>
        /// <value></value>
        public double TotalScore { get; set; }

        /// <summary>
        /// 题目列表
        /// </summary>
        /// <value></value>
        public IList<ExamQuestionView> QuestionList { get; set; }

        /// <summary>
        /// 病例标签
        /// </summary>
        /// <value></value>
        public IList<CourseLabelDTO> CaseLabels { get; set; }

        /// <summary>
        /// 课程标签
        /// </summary>
        /// <value></value>
        public IList<CourseLabelDTO> CourseLabels { get; set; }

        /// <summary>
        /// 学生答题情况
        /// </summary>
        /// <value></value>
        public IList<StudentExaminationDTO> StudentExaminationInfos { get; set; }

        /// <summary>
        /// Description
        /// </summary>
        public string Description { get; set; }

        /// <summary>
        /// exam start time
        /// </summary>
        public DateTime StarTime { get; set; }

        /// <summary>
        /// exam end time
        /// </summary>
        public DateTime EndTime { get; set; }

        /// <summary>
        /// LimitCount
        /// </summary>
        public int LimitCount { get; set; }

        /// <summary>
        /// Result
        /// </summary>
        public string Result { get; set; }

        /// <summary>
        ///  Examiners user ids
        /// </summary>
        public ICollection<UserView> Examiners { get; set; }

        /// <summary>
        ///  Examiners group ids
        /// </summary>
        public ICollection<GroupView> ExaminerUserGroups { get; set; }

        /// <summary>
        /// ExaminationAvailability
        /// </summary>
        public ExaminationAvailabilityEnum ExaminationAvailability { get; set; }

        /// <summary>
        ///  Examiners class ids
        /// </summary>
        public ICollection<ClassView> Classes { get; set; }

        /// <summary>
        /// Exam Creator UserId(or AdminId)
        /// </summary>
        public string CreatorId { get; set; }

        /// <summary>
        /// Exam Creator UserId(or AdminId)
        /// </summary>
        public string CreatorName { get; set; }

        /// <summary>
        /// ExamType
        /// </summary>
        public ExamTypeEnum ExamType { get; set; }

        /// <summary>
        /// Has pass score
        /// </summary>
        public bool HasPassScore { get; set; }

        /// <summary>
        /// Pass score
        /// </summary>
        public double PassScore { get; set; }

        /// <summary>
        /// Exam video info
        /// </summary>
        public List<ExamVideoView> ExamVideoInfos { get; set; }

        public IList<ExamScoreView> ExamScoreInfos { get; set; }


        /// <summary>
        /// 考试模板
        /// </summary>
        public ExamTemplateView ExamTemplate { get; set; }

        /// <summary>
        ///是否考题回顾 显示隐藏正确答案
        /// </summary>
        public bool IsDisplayAnswer { get; set; }
    }

    public class ExamQuestionView
    {
        /// <summary>
        /// 试题编码
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 题干
        /// </summary>
        /// <value></value>
        public string Stem { get; set; }

        /// <summary>
        /// 题目类型
        /// </summary>
        /// <value></value>
        public QuestionTypeEnum QuestionType { get; set; }

        /// <summary>
        /// 选择题选项
        /// </summary>
        /// <value></value>
        public IList<QuestionOptionDTO> QuestionOptionList { get; set; } = new List<QuestionOptionDTO>();

        /// <summary>
        /// 图像列表
        /// </summary>
        /// <value></value>
        public IList<QuestionFileDTO> FileList { get; set; }

        /// <summary>
        /// 病例标签
        /// </summary>
        /// <value></value>
        public IList<string> CaseLabelCodes { get; set; }

        /// <summary>
        /// 课程标签
        /// </summary>
        /// <value></value>
        public IList<string> CourseLabelCodes { get; set; }

        /// <summary>
        /// 判断题对错
        /// </summary>
        /// <value></value>
        public bool TrueOrFalse { get; set; } = false;

        /// <summary>
        /// 分值
        /// </summary>
        /// <value></value>
        public double Score { get; set; }
    }

    public class ExamTemplateView
    {
        /// <summary>
        /// 考题模板编码
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// Subjects
        /// </summary>
        public List<SubjectInfoView> Subjects { get; set; }

        /// <summary>
        /// is delete status
        /// </summary>
        public bool IsDeleted { get; set; }

        /// <summary>
        /// template name
        /// </summary>
        public string Name { get; set; }
    }

    public class SubjectInfoView
    {
        /// <summary>
        /// Subject id
        /// </summary>
        public string Id { get; set; }

        /// <summary>
        /// Subject
        /// </summary>
        public string Subject { get; set; }

        /// <summary>
        /// Images
        /// </summary>
        public List<string> Images { get; set; }

        /// <summary>
        /// Videos
        /// </summary>
        public List<VideoInfoView> Videos { get; set; }

        /// <summary>
        /// Score
        /// </summary>
        public double Score { get; set; }

        /// <summary>
        /// Index
        /// </summary>
        public int Index { get; set; }

        /// <summary>
        /// SubjectType
        /// </summary>
        public QuestionTypeEnum SubjectType { get; set; }

        /// <summary>
        /// Subject Items
        /// </summary>
        public List<SubjectItemView> Items { get; set; }
    }

    public class SubjectItemView
    {
        /// <summary>
        /// Content
        /// </summary>
        public string Content { get; set; }

        /// <summary>
        /// Index
        /// </summary>
        public int Index { get; set; }

        /// <summary>
        /// IsAnswer
        /// </summary>
        public bool IsAnswer { get; set; }
    }

    public class VideoInfoView
    {
        /// <summary>
        /// VideoToken
        /// </summary>
        public string VideoToken { get; set; }
        /// <summary>
        /// VideoImageToken
        /// </summary>
        public string VideoImageToken { get; set; }

    }

    public class ExamScoreView
    {

        /// <summary>
        /// Total Score
        /// </summary>
        public double TotalScore { get; set; }

        /// <summary>
        /// Correct Count
        /// </summary>
        public int CorrectCount { get; set; }

        /// <summary>
        /// Submit Count
        /// </summary>
        public int SubmitCount { get; set; }

        /// <summary>
        /// Max score Count
        /// </summary>
        public int MaxScore { get; set; }

        /// <summary>
        /// 自己答题的答案
        /// </summary>
        public List<MyExamAnswerView> MyExamAnswers { get; set; } = new List<MyExamAnswerView>();
    }

    /// <summary>
    /// 自己考试答案
    /// </summary>
    public class MyExamAnswerView
    {
        /// <summary>
        /// 题号Id
        /// </summary>
        public string SubjectId { get; set; }
        /// <summary>
        /// 自己答题得答案 Index
        /// </summary>
        public List<string> Answers { get; set; } = new List<string>();
    }

    public class ExamVideoView
    {
        /// <summary>
        /// Gets or sets the id
        /// </summary>
        public string Id { get; set; }

        /// <summary>
        /// Gets or sets the video name
        /// </summary>
        public string VideoName { get; set; }
     
        /// <summary>
        /// Gets or sets the create time
        /// </summary>
        public DateTime CreateTime { get; set; }

        /// <summary>
        ///gets or set video display poster Token
        /// </summary>
        public string PosterToken { get; set; }
        /// <summary>
        /// video player time duration 
        /// </summary>
        public int Duration { get; set; }
        /// <summary>
        /// gets or set Video size ,(uint :M)
        /// </summary>
        public int Size { get; set; }

        public string Description { get; set; }

        /// <summary>
        ///  gets or set palye Video 
        /// </summary>
        public string Url { get; set; }

    }

}