using System;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Common;
using WingInterfaceLibrary.DTO.Consultation;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.LiveConsultation.Enums;
using WingInterfaceLibrary.Request.DBCopy;

namespace WingInterfaceLibrary.DTO.DataCenter
{
    /// <summary>
    /// 数据中心实时会诊
    /// </summary>
    public class LiveConsultationDTO : BaseDTO
    {
        /// <summary>
        /// 实时会诊编码
        /// </summary>
        /// <value></value>
        public string Code { get; set; }
        /// <summary>
        /// 基层医师信息
        /// </summary>
        /// <value></value>
        public UserView DoctorInfo { get; set; }
        /// <summary>
        /// 会诊专家信息
        /// </summary>
        /// <value></value>
        public UserView ExpertInfo { get; set; }
        /// <summary>
        /// 病人信息
        /// </summary>
        /// <value></value>
        public PatientView PatientInfo { get; set; }
        /// <summary>
        /// 基层机构信息
        /// </summary>
        /// <value></value>
        public OrganizationView PrimaryHosptial { get; set; }
        /// <summary>
        /// 会诊机构信息
        /// </summary>
        /// <value></value>
        public OrganizationView CentralHospital { get; set; }
        /// <summary>
        /// 会诊设备信息
        /// </summary>
        /// <value></value>
        public DeviceView DeviceInfo { get; set; }

        public string CheckPoint { get; set; }

        public ConsultationState State { get; set; }

        public string ConsultationNumber { get; set; }

        public string QueuingNumber { get; set; }

        public QualityType QualityType { get; set; }

        /// <summary>
        /// 随访记录状态
        /// </summary>
        public FollowUpVisitStatusEnum FollowUpVisitStatus { get; set; }

        /// <summary>
        /// 是否需要随访
        /// </summary>
        public bool IsNeedFollowUpVisit { get; set; }

        /// <summary>
        /// 会诊评价满意度
        /// </summary>
        public EvaluateGradeEnum EvaluateGrade { get; set; }

        /// <summary>
        /// 图像集合
        /// </summary>
        public ICollection<LiveConsultationFileView> FileInfos { get; set; }

        public ICollection<ReportConclusionView> ReportConclusionInfos { get; set; }

        /// <summary>
        /// 病人信息
        /// </summary>
        /// <value></value>
        public IList<DataItemDTO> PatientDatas { get; set; } = new List<DataItemDTO>();

        /// <summary>
        /// 服务对象：人用、兽用
        /// </summary>
        /// <value>0</value>
        public OrganizationPatientTypeEnum PatientType { get; set; }

        /// <summary>
        /// 检查部位
        /// </summary>
        /// <value>肝脏 附件</value>        
        /// <code>0</code>
        public List<string> ScanPositions { get; set; }

        /// <summary>
        /// 扫查医生
        /// </summary>
        /// <value>0</value>
        public string ScanUserCode { get; set; }

        /// <summary>
        /// 扫查医生
        /// </summary>
        /// <value>0</value>
        public string ScanUserName { get; set; }

        /// <summary>
        /// 操作人
        /// </summary>
        /// <value>0</value>
        public string OperateUserCode { get; set; }

        /// <summary>
        /// 操作人
        /// </summary>
        /// <value>0</value>
        public string OperateUserName { get; set; }

        /// <summary>
        /// 会诊开始时间
        /// </summary>
        /// <value>0</value>
        public DateTime ConsultationTime { get; set; }

        /// <summary>
        /// 会诊截止时间
        /// </summary>
        /// <value></value>
        public DateTime ConsultationTimeEnd { get; set; }

        /// <summary>
        /// 会诊状态
        /// </summary>
        /// <value>0</value>
        public TransactionStatusEnum ConsultationStatus { get; set; }

        /// <summary>
        /// 拒绝申请会诊原因
        /// </summary>
        /// <value></value>
        public string RejectReason { get; set; } = string.Empty;

        /// <summary>
        /// 地点
        /// </summary>
        /// <value></value>
        public string Location { get; set; }

        /// <summary>
        /// 会诊参与方对象列表
        /// </summary>
        /// <value></value>
        public List<ConsultationMemberDTO> ConsultationMembers { get; set; }

        /// <summary>
        /// 会诊描述
        /// </summary>
        /// <value></value>
        public string Description { get; set; }

        /// <summary>
        /// 会诊提醒集合
        /// </summary>
        /// <value></value>
        public List<ConsultationReminderDTO> ConsultationReminders { get; set; }

        /// <summary>
        /// 审核人编码
        /// </summary>
        /// <value></value>
        public string ApproverCode { get; set; }

        /// <summary>
        /// 报告方式
        /// </summary>
        /// <value></value>
        public ConsultationReportMode ReportMode { get; set; }

        /// <summary>
        /// 疾病名称
        /// </summary>
        /// <value></value>
        public string Diseases { get; set; }

        /// <summary>
        /// 初步诊断
        /// </summary>
        /// <value>初步诊断</value>
        public string PrimaryDiagnosis { get; set; }

        /// <summary>
        /// 发起人编码
        /// </summary>
        /// <value></value>
        public string InitiatorCode { get; set; }

        /// <summary>
        /// 是否急诊标识
        /// </summary>
        /// <value></value>
        public bool IsEmergency { get; set; }

        /// <summary>
        /// 急诊code
        /// </summary>
        /// <value></value>
        public string EmergencyCode { get; set; }

        /// <summary>
        /// 评价
        /// </summary>
        /// <value>0</value>
        public SyncEvaluatesRequest Evaluates { get; set; } 

        /// <summary>
        /// 随访记录列表
        /// </summary>
        /// <value>0</value>
        public IList<SyncFollowUpVisitRequest> SyncFollowUpVisitList { get; set; }
    }
}