using System;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Education;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Enum.CourseEnum;

namespace WingInterfaceLibrary.DTO.DataCenter
{
    /// <summary>
    /// 数据中心在线培训
    /// </summary>
    public class OnlineTrainingDTO : BaseDTO
    {
        /// <summary>
        /// 在线培训编码
        /// </summary>
        /// <value></value>
        public string Code { get; set; }
        
        /// <summary>
        /// 课程名称
        /// </summary>
        public string Name { get; set; }

        /// <summary>
        /// 教师Code
        /// </summary>
        public string TeacherCode { get; set; }

        /// <summary>
        ///教师名称
        /// </summary>
        public string TeacherName { get; set; }

        /// <summary>
        /// 课程时长【单位分钟】
        /// </summary>
        public int Duration { get; set; }

        /// <summary>
        /// 课程状态
        /// </summary>
        public CourseStatusEnum Status { get; set; }

        /// <summary>
        /// 可见范围：国内，国外，或者两者兼有
        /// </summary>
        public CourseViewRangeEnum ViewRange { get; set; }

        /// <summary>
        /// 课程价格
        /// </summary>
        public decimal Price { get; set; }

        /// <summary>
        /// 课程简介
        /// </summary>
        public string CourseIntro { get; set; }

        /// <summary>
        /// 面向类型
        /// </summary>
        public CourseAudienceTypeEnum AudienceType { get; set; }

        /// <summary>
        /// 封面图，课程海报
        /// </summary>
        public string Poster { get; set; }

        /// <summary>
        /// 创建人
        /// </summary>
        public string CreatorCode { get; set; }

        /// <summary>
        /// 创建机构code
        /// </summary>
        public string OrganizationCode { get; set; }

        /// <summary>
        /// 课程预计开始时间
        /// </summary>
        public DateTime StartTime { get; set; } = DateTime.UtcNow;

        /// <summary>
        /// 课程结束签到时间
        /// </summary>
        public DateTime Deadline { get; set; } = DateTime.UtcNow;

        /// <summary>
        /// 实际开始时间
        /// </summary>
        public DateTime ActualStartTime { get; set; } = DateTime.UtcNow;

        /// <summary>
        /// 实际结束时间
        /// </summary>
        public DateTime ActualEndTime { get; set; } = DateTime.UtcNow;

        /// <summary>
        /// 病例标签
        /// </summary>
        public IList<CourseLabelView> CaseLabelInfos { get; set; }

        // /// <summary>
        // /// 直播通道数据
        // /// </summary>
        // public IList<ChannelDataInfoEntity> ChannelDatas { get;private set; }

        /// <summary>
        /// 课程地址，邀请码
        /// </summary>
        public string CourseToken { get; set; }

        /// <summary>
        /// 课件地址
        /// </summary>
        public string CoursewareToken { get; set; }

        /// <summary>
        /// 用户组（班级）
        /// </summary>
        public IList<GroupView> UserGroupInfos { get; set; }

        /// <summary>
        /// 课程分类
        /// </summary>
        public CourseTypeEnum CourseType { get; set; }

        /// <summary>
        /// 报名学生列表
        /// </summary>
        public IList<SignStudentView> Students { get; set; } = new List<SignStudentView>();

        /// <summary>
        /// 助教列表
        /// </summary>
        public IList<SignStudentView> Assistants { get; set; } = new List<SignStudentView>();

        /// <summary>
        /// 参与互动专家
        /// </summary>
        public IList<SignStudentView> Experts { get; set; } = new List<SignStudentView>();

        /// <summary>
        /// 课程标签列表
        /// </summary>
        public IList<CourseLabelView> CourseLabelInfos { get; set; }

        /// <summary>
        /// 是否代理商课程
        /// </summary>
        public bool IsAgentCourse { get; set; }

        /// <summary>
        /// 是否置顶
        /// </summary>
        public bool IsStick { get; set; }

        /// <summary>
        /// 排序
        /// </summary>
        public int Sort { get; set; }

        /// <summary>
        /// 绑定试卷
        /// </summary>
        public IList<CourseExaminationView> BindExams { get; set; }

        /// <summary>
        /// 教培素材Code列表
        /// </summary>
        public IList<string> CourseVideoCodes { get; set; }

        /// <summary>
        /// 课程呈现类型
        /// </summary>
        /// <value></value>
        public CourseAppearTypeEnum CourseAppearType { get; set; }

        /// <summary>
        /// 所属专辑
        /// </summary>
        /// <value></value>
        public IList<string> CourseAlbumCodes { get;set;}

        /// <summary>
        /// 播放量
        /// </summary>
        /// <value>1</value>
        public int PlayCount { get; set; }

        /// <summary>
        /// 课程资料
        /// </summary>
        /// <value>1</value>
        public IList<string> CourseMaterialCodes { get; set; }

        /// <summary>
        /// teacher apply course state,is Reject or passed
        /// </summary>
        public ApplyStateEnum ApplyState { get; set; }

        /// <summary>
        /// conversation id
        /// </summary>
        public string ConversationId { get; set; }

        /// <summary>
        /// channel data infos,which is applied from NE
        /// </summary>
        public ICollection<ChannelDataView> ChannelDatas { get; set; }        

        /// <summary>
        /// Create admin info
        /// </summary>
        public AdminView CreateAdmin { get; set; }

        /// <summary>
        /// admin owner list
        /// </summary>
        public ICollection<AdminView> Owners { get; set; }

        /// <summary>
        /// teacher state
        /// </summary>
        public bool TeacherOnlineState { get; set; }

        /// <summary>
        /// start course in advance true or false
        /// </summary>
        public bool StartCourseInAdvance { get; set; }

        /// <summary>
        /// 助教ID
        /// </summary>
        public List<UserView> AssistantInfos { get; set; }

        /// <summary>
        /// 嘉宾ID
        /// </summary>
        public List<UserView> GuestInfos { get; set; }

        /// <summary>
        /// 邀请码
        /// </summary>
        public string CredentialCode { get; set; }

        /// <summary>
        /// 课程公告
        /// </summary>
        public string CourseNotice { get; set; }

        /// <summary>
        /// 小班化培训 参与者Ids
        /// </summary>
        public List<UserView> MeetingMemberInfos { get; set; }

    }
    
    public class CourseExaminationView
    {
        /// <summary>
        /// 编码
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 名称
        /// </summary>
        /// <value></value>
        public string Name { get; set; }

        /// <summary>
        /// 总分
        /// </summary>
        /// <value></value>
        public double TotalScore { get; set; }

        /// <summary>
        /// 题目列表
        /// </summary>
        /// <value></value>
        public List<CourseExaminationQuestionView> QuestionList { get; set; }

        /// <summary>
        /// 提交次数
        /// </summary>
        /// <value></value>
        public int SubmitLimitCount { get; set; }

        /// <summary>
        /// 是否已发布
        /// </summary>
        /// <value></value>
        public bool IsRelease { get; set; }

        /// <summary>
        /// 考试试卷类型
        /// </summary>
        /// <value></value>
        public CourseExaminationTypeEnum ExaminationType { get; set; }

        /// <summary>
        /// 考试开始时间
        /// </summary>
        /// <value></value>
        public DateTime StartTime { get; set; }

        /// <summary>
        /// 考试时长（分钟）
        /// </summary>
        /// <value></value>
        public int ExamDuration { get; set; }

        /// <summary>
        /// 及格分数
        /// </summary>
        /// <value></value>
        public double PassingScore { get; set; }


    }

    public class SignStudentView
    {
        /// <summary>
        /// 学生编码
        /// </summary>
        public string StudentCode { get; set; }

        /// <summary>
        /// 学生编码
        /// </summary>
        public string StudentName { get; set; }

        /// <summary>
        /// 呈现类型
        /// </summary>
        /// <value></value>
        public CourseAppearTypeEnum CourseAppearType { get; set; }

        /// <summary>
        /// 是否支付
        /// </summary>
        /// <value></value>
        public bool IsPay { get; set; }

        /// <summary>
        /// 学生对于课程的状态
        /// </summary>
        ///  <value>0</value>
        public StudentCourseStatusEnum SignCourseStatus { get; set; }

        public bool IsNoSpeaking { get; set; }

        public bool IsAssistant { get; set; }

        public byte[] SmallHeadImage { get; set; }
    }

    
    /// <summary>
    /// 课程考试
    /// </summary>
    public class CourseExaminationQuestionView
    {
        /// <summary>
        /// 题目Code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 题干
        /// </summary>
        /// <value></value>
        public string Stem { get; set; }

        /// <summary>
        /// 题目类型
        /// </summary>
        /// <value></value>
        public QuestionTypeEnum QuestionType { get; set; }

        /// <summary>
        /// 题目选项
        /// </summary>
        /// <value></value>
        public IList<QuestionOptionDTO> QuestionOptionList { get; set; }

        /// <summary>
        /// 图像列表
        /// </summary>
        /// <value></value>
        public IList<QuestionFileDTO> FileList { get; set; }

        /// <summary>
        /// 判断题对错
        /// </summary>
        /// <value></value>
        public bool TrueOrFalse { get; set; } = false;

        /// <summary>
        /// 题目分数
        /// </summary>
        /// <value></value>
        public double Score { get; set; }
    }
}