using System.Collections.Generic;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.DTO.DataCenter
{
    /// <summary>
    /// 教培素材信息
    /// </summary>
    public class OnlineVideoDTO : BaseDTO
    {
        /// <summary>
        /// 教培素材编码
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 素材名称
        /// </summary>
        public string Name { get; set; }

        /// <summary>
        /// 素材上传人Code
        /// </summary>
        public string CreatorCode { get; set; }
        /// <summary>
        /// 素材上传人
        /// </summary>
        public string CreatorName { get; set; }

        /// <summary>
        /// 素材分类：视频、图片、文件
        /// </summary>
        public UploadFileTypeEnum FodderType { get; set; } 

        /// <summary>
        /// 素材使用：公开的、私有的
        /// </summary>
        public bool IsPublic { get; set; } = true;

        /// <summary>
        /// 可见范围：国内，国外，或者两者兼有 todo
        /// </summary>
        public CourseViewRangeEnum ViewRange { get; set; }

        /// <summary>
        /// 视频地址
        /// </summary>
        public string VideoToken { get; set; }

        /// <summary>
        /// Vod云点播文件Id
        /// </summary>
        public string VodFileId { get; set; }

        /// <summary>
        /// 封面图
        /// </summary>
        public string Poster { get; set; }

        /// <summary>
        /// 视频时长【分钟】
        /// </summary>
        public int Duration { get; set; }

        /// <summary>
        /// 视频大小【MB】
        /// </summary>
        public double VideoSize { get; set; }

        /// <summary>
        /// 播放量
        /// </summary>
        /// <value>1</value>
        public int PlayCount { get; set; }

        /// <summary>
        /// 原始文件地址
        /// </summary>
        /// <value></value>
        public string SrcFileToken { get; set; }

        public string Description { get; set; }
        /// <summary>
        /// gets or set enum video importance
        /// </summary>
        public VideoImportanceEnum Importance { get; set; }
        /// <summary>
        /// gets or set video permissions (enum:Public, Private, LinkToCourse)
        /// </summary>
        public VideoPermissionsEnum Permissions { get; set; }
        /// <summary>
        /// 可以观看视频用户的id
        /// </summary>
        public List<UserView> Users { get; set; }
        /// <summary>
        /// 可以观看视频用户组的id
        /// </summary>
        public List<GroupView> UserGroups { get; set; }
        /// <summary>
        /// 可以观看视频 班级id
        /// </summary>
        public List<ClassView> ClassInfos { get; set; }
        /// <summary>
        /// gets or set  this video link vcloud course info list
        /// </summary>
        public List<OnlineTrainingDTO> Courses { get; set; }
        /// <summary>
        /// 标签 课程不可录制、课程不可快进、同步教学文档
        /// </summary>
        public List<VideoLabelEnum> Labels { get; set; } = new List<VideoLabelEnum>();
        /// <summary>
        /// 教学文档名称
        /// </summary>
        public string TeachingDocumentName { get; set; } = string.Empty;
        /// <summary>
        /// 教学文档
        /// </summary>
        public string TeachingDocument { get; set; } = string.Empty;

        public int RealBrowsedCount { get; set; }

        public int BaseBrowsedCount { get; set; }
        /// <summary>
        /// 学生已完成学习记录列表
        /// </summary>
        public List<UserView> FinishedUsers { get; set; }
    }
}