using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Common;
using WingInterfaceLibrary.DTO.Record;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.DTO.DataCenter
{
    /// <summary>
    /// 数据中心分时会诊
    /// </summary>
    public class RemoteDiagnosisDTO : BaseDTO
    {
        /// <summary>
        /// 分时会诊编码
        /// </summary>
        /// <value></value>
        public string Code { get; set; }
        /// <summary>
        /// 设备检查编码
        /// </summary>
        /// <value></value>
        public string ExamId { get; set; }
        /// <summary>
        /// 机构信息
        /// </summary>
        /// <value></value>
        public OrganizationView OrganizationInfo { get; set; }
        /// <summary>
        /// 设备信息
        /// </summary>
        /// <value></value>
        public DeviceView DeviceInfo { get; set; }
        /// <summary>
        /// 病人信息
        /// </summary>
        /// <value></value>
        public PatientView PatientInfo { get; set; }
        /// <summary>
        /// 截图版信息
        /// </summary>
        /// <value></value>
        public ScreenshotView ScreenshotInfo { get; set; }
        /// <summary>
        /// 质控信息
        /// </summary>
        /// <value></value>
        public QualifiedView QualifiedInfo { get; set; }
        /// <summary>
        /// AI诊断信息
        /// </summary>
        /// <value></value>
        public List<DiagnosisView> DiagnosisInfos { get; set; }
        /// <summary>
        /// 分享用户集合
        /// </summary>
        /// <value></value>
        public List<string> ShareUserCodes { get; set; }
        /// <summary>
        /// 自定义医生名称用于手动输入 默认是空
        /// </summary>
        public string CustomDoctor { get; set; }
        /// <summary>
        /// 自定义医院名称用于手动输入
        /// </summary>
        public string CustomOrganzation { get; set; }
        /// <summary>
        /// 设备上传标识
        /// </summary>
        public string EquipmentSN { get; set; }
        /// <summary>
        /// 图像集合
        /// </summary>
        /// <value></value>
        public List<RemoteDiagnosisFileView> FileInfos { get; set; }

        /// <summary>
        /// 已完成用户列表
        /// </summary>
        /// <value>"test01","test02"</value>
        public List<string> CompletedUsers { get; set; } = new List<string>();

        /// <summary>
        /// 检查状态
        /// </summary>
        public RecordStatusEnum RecordStatus { get; set; }

        /// <summary>
        /// 检查医生
        /// </summary>
        /// <value></value>
        public string CreatorCode { get; set; }

        /// <summary>
        /// 处理标识，用来做特殊处理标识
        /// </summary>
        public string Tags { get; set; }

        /// <summary>
        /// 创建方式
        /// </summary>
        /// <value></value>
        public RecordCreateTypeEnum CreateType { get; set; }

        /// <summary>
        /// 病人信息
        /// </summary>
        public List<DataItemDTO> PatientDataInfo { get; set; }

        /// <summary>
        /// 病人检查信息列表
        /// </summary>
        /// <value></value>
        public List<PatientInfoExt> PatientInfoExtList { get; set; }

        /// <summary>
        /// 类型
        /// </summary>
        /// <value>Person、Animals</value>
        public string PatientType { get; set; }

        /// <summary>
        /// 已读用户列表
        /// </summary>
        /// <value>"test01","test02"</value>
        public List<string> ReadUsers { get; set; } = new List<string>();

        /// <summary>
        /// 关联的超声机本地上传的检查code
        /// </summary>
        /// <value></value>
        public List<string> AssociatedExamCodes { get; set; } = new List<string>();

    }
}