using System;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Report;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.DTO.DataCenter
{
    /// <summary>
    /// 数据中心报告信息
    /// </summary>
    public class ReportInfoResultDTO : BaseDTO
    {
        /// <summary>
        /// 报告编码
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 机构编码
        /// </summary>
        /// <value></value>
        public string OrganizationCode { get; set; } = string.Empty;

        /// <summary>
        /// 机构名称
        /// </summary>
        /// <value></value>
        public string OrganizationName { get; set; } = string.Empty;

        /// <summary>
        /// 检查编码
        /// </summary>
        /// <value></value>
        public string RecordCode { get; set; } = string.Empty;

        /// <summary>
        /// 报告医生编码
        /// </summary>
        /// <value></value>
        public string ReportUserCode { get; set; } = string.Empty;

        /// <summary>
        /// 报告医生
        /// </summary>
        /// <value></value>
        public string ReportUserName { get; set; } = string.Empty;

        /// <summary>
        /// 设备信息
        /// </summary>
        public DeviceView DeviceInfo { get; set; }

        /// <summary>
        /// 病人Code
        /// </summary>
        public string PatientCode { get; set; } = string.Empty;

        /// <summary>
        /// 病人Id
        /// </summary>
        public string PatientId { get; set; } = string.Empty;

        /// <summary>
        /// 报告模板Json
        /// </summary>
        public string ReportTemplateJson { get; set; } = string.Empty;

        /// <summary>
        /// 报告内容Json
        /// </summary>
        public string ReportDatasJson { get; set; } = string.Empty;

        /// <summary>
        /// 病人姓名
        /// </summary>
        public string PatientName { get; set; } = string.Empty;

        /// <summary>
        /// 报告标签
        /// </summary>
        public List<string> ReportLabels { get; set; } = new List<string>();

        /// <summary>
        /// 来源标签
        /// </summary>
        public List<string> PlatformLabels { get; set; } = new List<string>();

        /// <summary>
        /// 诊断标签
        /// </summary>
        public List<string> DiagnosisLabels { get; set; } = new List<string>();

        /// <summary>
        /// 检查器官
        /// </summary>
        /// <value>2</value>
        public DiagnosisOrganEnum ReportOrgan { get; set; }

        /// <summary>
        /// 报告预览图
        /// </summary>
        public List<ReportPreviewDTO> ReportPreviewList { get; set; } = new List<ReportPreviewDTO>();

        /// <summary>
        /// 转诊记录编码
        /// </summary>
        public string ReferralRecordCode { get; set; } = string.Empty;

        /// <summary>
        /// 业务类型
        /// </summary>
        /// <value>0</value>
        public ReportTypeEnum ReportType { get; set; } = ReportTypeEnum.RemoteDiagnosis;

        public string  ElementCollectionJson { get; set; }

        public string MeasureElementCollectionJson { get; set; }
        public string PatientPerfPhysician { get; set; }
        public string PatientRefPhysician { get; set; }

        public ICollection<ReportImageInfo> PreviewImages { get; set; }
        public ICollection<CustomLabelView> CustomLabels { get; set; }
        /// <summary>
        /// 质控状态
        /// </summary>
        public QualifiedState QualifiedState { get; set; }
        /// <summary>
        /// 质控类型
        /// </summary>
        public QualityType QualityType { get; set; }
        /// <summary>
        /// 报告pdf
        /// </summary>
        public string ReportPreviewPdf { get; set; }

        /// <summary>
        /// 报告质控内容
        /// </summary>
        public ICollection<QualityControlDataView> QualityControlDatas { get; set; }
    }

    public class ReportImageInfo
    {
        public string Name { get; set; }
        public ImageTypeEnum Type { get; set; }

        public string ExamDataId { get; set; }

    }

    public class QualityControlDataView
    {
        /// <summary>
        /// 质控人Id
        /// </summary>
        public string ControlPersonId { get; set; }

        /// <summary>
        /// 质控人
        /// </summary>
        public string ControlPersonName { get; set; }

        /// <summary>
        /// 质控意见
        /// </summary>
        public string Opinion { get; set; }

        /// <summary>
        /// 总评分
        /// </summary>
        public double Score { get; set; }

        /// <summary>
        /// 指控评分项
        /// </summary>
        public List<QualityControlScoreItemView> ScoreItems { get; set; }

        /// <summary>
        /// 质控时间
        /// </summary>
        public DateTime ControlTime { get; set; }
    }

    /// <summary>
    /// 指控评分项
    /// </summary>
    public class QualityControlScoreItemView
    { 
        /// <summary>
        /// 评分项顺序
        /// </summary>
        public int Sort { get; set; }
        
        /// <summary>
        /// 评分
        /// </summary>
        public double Score { get; set; }
    }

    /// <summary>
    /// 自定义标签
    /// </summary>
    public class CustomLabelView
    {
        /// <summary>
        /// Name
        /// </summary>
        public string Name { get; set; }

        /// <summary>
        /// Code
        /// </summary>
        public string Code { get; set; }

        /// <summary>
        /// Description
        /// </summary>
        public string Description { get; set; }

        /// <summary>
        /// Father Code
        /// </summary>
        public string FatherCode { get; set; }

        /// <summary>
        /// Label Type
        /// </summary>
        public CustomLabelTypeEnum LabelType { get; set; }

        /// <summary>
        /// Is show
        /// </summary>
        public bool IsShow { get; set; }

        /// <summary>
        /// user id array
        /// </summary>
        public List<string> UserIds { get; set; } = new List<string>();
    }

    
}