using System.Collections.Generic;
using WingInterfaceLibrary.Enum.CourseEnum;

namespace WingInterfaceLibrary.DTO.DataCenter
{
    /// <summary>
    /// 用户信息
    /// </summary>
    public class UserView
    {
        /// <summary>
        /// 用户编码
        /// </summary>
        /// <value></value>
        public string Code { get; set; }
        /// <summary>
        /// 用户姓名
        /// </summary>
        /// <value></value>
        public string Name { get; set; }
        /// <summary>
        /// 机构编码
        /// </summary>
        /// <value></value>
        public string OrganizationCode { get; set; }
        /// <summary>
        /// 所属机构
        /// </summary>
        /// <value></value>
        public string OrganizationName { get; set; }
    }

    /// <summary>
    /// 教师信息
    /// </summary>
    public class TeacherView : UserView
    {
        /// <summary>
        /// teacher introduction
        /// </summary>
        public string Introduction { get; set; }

        /// <summary>
        /// teacher small avatar
        /// </summary>
        public byte[] SmallAvatar { get; set; }
    }

    /// <summary>
    /// 学生信息
    /// </summary>
    public class StudentView : UserView
    {
        public bool IsNoSpeaking { get; set; }

        public bool IsAssistant { get; set; }

        public byte[] SmallHeadImage { get; set; }

        /// <summary>
        /// 是否支付：是-支付；否-未支付
        /// </summary>
        public bool IsPay { get; set; }

        /// <summary>
        /// 学生对于课程的状态
        /// </summary>
        ///  <value>0</value>
        public StudentCourseStatusEnum SignCourseStatus { get; set; }
    }

    /// <summary>
    /// 观众信息
    /// </summary>
    public class AudienceView : UserView
    {
        /// <summary>
        /// 合计观看时间（分钟）
        /// </summary>
        public int TotalMinutes { get; set; }
        /// <summary>
        /// 用户组
        /// </summary>
        public List<GroupView> GroupInfos { get; set; }
    }
}