using System;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Common;
using WingInterfaceLibrary.DTO.Dictionary;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.LiveConsultation;

namespace WingInterfaceLibrary.DTO.Device
{
    /// <summary>
    /// 设备信息响应实体
    /// </summary>
    public class DeviceInfoDTO : BaseDTO
    {
        /// <summary>
        /// 设备编码
        /// </summary>
        /// <value>test0122</value>
        public string DeviceCode { get; set; }

        /// <summary>
        /// 设备物理唯一码
        /// </summary>
        /// <value>test010122</value>
        public string SerialNumber { get; set; }

        /// <summary>
        /// 设备密码
        /// </summary>
        /// <value>ABC123</value>
        public string Password { get; set; }

        /// <summary>
        /// 设备名称
        /// </summary>
        /// <value>测试设备0122</value>
        public string Name { get; set; }

        /// <summary>
        /// 备注
        /// </summary>
        /// <value>测试Description22</value>
        public string Description { get; set; }

        /// <summary>
        /// 设备型号
        /// </summary>
        /// <value>M001</value>
        public string DeviceModel { get; set; }

        /// <summary>
        /// 设备类型
        /// </summary>
        /// <value>X00001</value>
        public string DeviceType { get; set; }

        /// <summary>
        /// 设备头图
        /// </summary>
        /// <value>http://192.168.6.117:9001/Storage/B1154C6500E4F174249224B41284498E_7_0_0_0.PNG</value>
        public string HeadPicUrl { get; set; }

        /// <summary>
        /// 设备软件版本
        /// </summary>
        /// <value>1.11.0</value>
        public string DeviceSoftwareVersion { get; set; }

        /// <summary>
        /// 设备SDK版本
        /// </summary>
        /// <value>1.11.1</value>
        public string SDKSoftwareVersion { get; set; }

        /// <summary>
        /// 设备所属组织
        /// </summary>
        /// <value>Organization_2022012520473430DnW3</value>
        public string OrganizationCode { get; set; }

        /// <summary>
        /// 组织下属科室
        /// </summary>
        /// <value>Organization_2022012520473430DnW32</value>
        public string DepartmentCode { get; set; }

        /// <summary>
        /// 超声机动态唯一码
        /// </summary>
        /// <value>test01010122</value>
        public string ShortCode { get; set; }

        /// <summary>
        /// 是否设备自动分享
        /// </summary>
        /// <value>true</value>
        public bool IsAutoShared { get; set; }

        /// <summary>
        /// 敏感信息加密显示
        /// </summary>
        /// <value>true</value>
        public bool IsEncryptedShow { get; set; }
        /// <summary>
        /// 最近登录时间
        /// </summary>
        /// <value>2022-02-28T09:21:38.861Z</value>
        public DateTime LastLoginTime { get; set; } = DateTime.UtcNow;

        /// <summary>
        /// 系统版本
        /// </summary>
        /// <value>2.2.27.5</value>
        public string SystemVersion { get; set; } = string.Empty;

        /// <summary>
        /// CPU型号
        /// </summary>
        /// <value>I5-10400</value>
        public string CPUModel { get; set; } = string.Empty;

        /// <summary>
        /// 系统语言
        /// </summary>
        /// <value>Chinese</value>
        public string SystemLanguage { get; set; } = string.Empty;

        /// <summary>
        /// AI应用集合
        /// </summary>
        public List<string> DiagnosisModules { get; set; } = new List<string>();

        /// <summary>
        /// 报告转发配置集合
        /// </summary>
        public List<string> ReportPosterCodes { get; set; } = new List<string>();

        /// <summary>
        /// 是否把多路视屏合流
        /// </summary>
        /// <value></value>
        public bool MergedChannel { get; set; }

        /// <summary>
        /// 合流的画面宽度
        /// </summary>
        /// <value></value>
        public int MergedVideoOutputWidth { get; set; }

        /// <summary>
        /// 合流的画面高度
        /// </summary>
        /// <value></value>
        public int MergedVideoOutputHeight { get; set; }

        /// <summary>
        /// 视屏设备画面信息
        /// </summary>
        /// <value></value>
        public IList<VideoDeviceDTO> VideoDeviceInfos { get; set; } = new List<VideoDeviceDTO>();

        /// <summary>
        /// 设置下载模式
        /// </summary>
        /// <value></value>
        public DownloadModeSettingEnum DownloadModeSetting { get; set; }

        /// <summary>
        /// 直播开关，true=开启，false=关闭
        /// </summary>
        /// <value></value>
        public bool LiveOpened { get; set; }

        /// <summary>
        /// 是否支持Rtc
        /// </summary>
        /// <value></value>
        public bool SupportRtc { get; set; }

        /// <summary>
        /// 设备展示名称
        /// </summary>
        /// <value></value>
        public string DisplayName
        {
            get
            {
                var displayName = Description;
                if (string.IsNullOrWhiteSpace(displayName))
                {
                    displayName = Name;
                }
                return displayName;
            }
        }

        /// <summary>
        /// 魔盒类型
        /// </summary>
        /// <value></value>
        public SonopostVersionEnum SonopostVersion { get; set; }

        /// <summary>
        /// 设备属性列表
        /// </summary>
        /// <value></value>
        public string DeviceAttributes { get; set; }

        /// <summary>
        /// 设备耗材属性列表 json数据格式，
        /// </summary>
        /// <value></value>
        public string DeviceConsumableAttributes { get; set; }

        /// <summary>
        /// 是否连接
        /// </summary>
        /// <value></value>
        public bool IsOnline { get; set; }

        /// <summary>
        /// 是否活动
        /// </summary>
        /// <value></value>
        public bool IsActive { get; set; }

        /// <summary>
        /// 是否活动
        /// </summary>
        /// <value></value>
        public List<DictionaryLanguageConfigDTO> LanguageConfigs { get; set; }

        /// <summary>
        /// iot设备升级指定版本
        /// </summary>
        /// <value></value>
        public string UpgradeVersionCode { get; set; }
    }

    /// <summary>
    /// 视频设备实体
    /// </summary>
    public class VideoDeviceDTO
    {
        /// <summary>
        /// 设备Id（比如超声机唯一码，用来表示这是超声机画面）
        /// </summary>
        /// <value></value>
        public string VideoDeviceId { get; set; }

        /// <summary>
        /// 视屏画面设备来源的类型（设备主屏或摄像头）
        /// </summary>
        /// <value></value>
        public VideoDeviceSourceTypeEnum VideoDeviceSourceType { get; set; }

        /// <summary>
        /// 设备设置的画面宽度，上报值
        /// </summary>
        /// <value></value>
        public int Width { get; set; }

        /// <summary>
        /// 设备设置的画面高度，上报值
        /// </summary>
        /// <value></value>
        public int Height { get; set; }

        /// <summary>
        /// 设备设置的画面宽度
        /// </summary>
        /// <value></value>
        public int OutputWidth { get; set; }

        /// <summary>
        /// 设备设置的画面高度
        /// </summary>
        /// <value></value>
        public int OutputHeight { get; set; }

        /// <summary>
        /// 帧率
        /// </summary>
        /// <value></value>
        public int VideoFps { get; set; } = 20;

        /// <summary>
        /// 码率
        /// </summary>
        /// <value></value>
        public int VideoBitrate { get; set; } = 2000;

        /// <summary>
        /// 最小码率
        /// </summary>
        /// <value></value>
        public int MinVideoBitrate { get; set; } = 1000;
    }

    /// <summary>
    /// 设备输出配置
    /// </summary>
    public class DeviceOutputConfigDTO
    {
        /// <summary>
        /// 编码
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 名称
        /// </summary>
        /// <value></value>
        public string Name { get; set; }

        /// <summary>
        /// 设备视频输出类型
        /// </summary>
        /// <value></value>
        public DeviceVideoOutputTypeEnum DeviceVideoOutputType { get; set; }

        /// <summary>
        /// 画面宽度
        /// </summary>
        /// <value></value>
        public int VideoWidth { get; set; }

        /// <summary>
        /// 画面高度
        /// </summary>
        /// <value></value>
        public int VideoHeight { get; set; }
    }

    /// <summary>
    /// 品牌型号输出配置
    /// </summary>
    public class BrandModelOutputConfigDTO
    {
        /// <summary>
        /// 是否选中
        /// </summary>
        /// <value></value>
        public bool IsSelect { get; set; }

        /// <summary>
        /// 画面宽度
        /// </summary>
        /// <value></value>
        public int VideoWidth { get; set; }

        /// <summary>
        /// 画面高度
        /// </summary>
        /// <value></value>
        public int VideoHeight { get; set; }
    }

    /// <summary>
    /// 品牌型号信息
    /// </summary>
    public class BrandModelDetailDTO
    {
        /// <summary>
        /// 品牌型号编码
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 品牌名称
        /// </summary>
        /// <value></value>
        public string Brand { get; set; }

        /// <summary>
        /// 设备型号
        /// </summary>
        /// <value></value>
        public string Model { get; set; }

        /// <summary>
        /// 分辨率列表
        /// </summary>
        /// <value></value>
        public List<ResolutionDTO> Resolutions { get; set; }
    }

    /// <summary>
    /// 分辨率信息
    /// </summary>
    public class ResolutionDTO
    {
        /// <summary>
        /// 设备唯一码
        /// </summary>
        /// <value></value>
        public string ShortCode { get; set; }

        /// <summary>
        /// 画面宽度
        /// </summary>
        /// <value></value>
        public int VideoWidth { get; set; }

        /// <summary>
        /// 画面高度
        /// </summary>
        /// <value></value>
        public int VideoHeight { get; set; }
    }

    /// <summary>
    /// 急诊设备信息
    /// </summary>
    public class EmergencyDeviceInfoDTO : DeviceInfoDTO
    {
        /// <summary>
        /// 是否被占用
        /// </summary>
        /// <value></value>
        public bool IsOccupied { get; set; }

        /// <summary>
        ///如果被占用，占用模块
        /// </summary>
        /// <value></value>
        public BusinessModuleEnum OccupiedModuleEnum { get; set; }
    }
}