using System;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.DTO.Device
{
    /// <summary>
    /// 设备人员使用记录实体
    /// </summary>
    public class IOTDeviceUseRecordDTO : IOTDeviceUseRecordBaseDTO
    {
  
    }

    /// <summary>
    /// 设备人员使用基础实体
    /// </summary>
    public class IOTDeviceUseRecordBaseDTO : BaseDTO
    {
        /// <summary>
        /// 绑定code
        /// </summary>
        public string Code {get; set;}

        /// <summary>
        /// iot设备用户code
        /// </summary>
        public string UserCode { get; set; }

        /// <summary>
        /// iot设备编号
        /// </summary>
        public string DeviceCode { get; set; }

        /// <summary>
        /// 设备SN号
        /// </summary>
        public string DeviceSN { get; set; }

        /// <summary>
        /// 设备mac地址
        /// </summary>
        public string DeviceMAC { get; set; }

        /// <summary>
        /// 数据文件列表
        /// </summary>
        public IList<IOTDeviceDataFolderDTO> FolderList { get; set; }
    }


    /// <summary>
    /// 设备数据文件夹记录实体
    /// </summary>
    public class IOTDeviceDataFolderDTO
    {
        /// <summary>
        /// The unique database table id
        /// </summary>
        /// <returns></returns>
        public string Id { get; set; } = Guid.NewGuid().ToString("N");

        /// <summary>
        /// 文件夹名称
        /// </summary>
        /// <returns></returns>
        public string FolderName { get; set; }

        /// <summary>
        /// 数据文件列表
        /// </summary>
        public IList<IOTDeviceFileDataRecordDTO> DataFileList { get; set; }

        /// <summary>
        /// Create time
        /// </summary>
        public DateTime CreateTime { get; set; } = DateTime.UtcNow;
    }

    /// <summary>
    /// 设备数据文件详情实体
    /// </summary>
    public class IOTDeviceFileDataRecordDTO
    {
        /// <summary>
        /// The unique database table id
        /// </summary>
        /// <returns></returns>
        public string Id { get; set; } = Guid.NewGuid().ToString("N");

        /// <summary>
        /// Create time
        /// </summary>
        public DateTime CreateTime { get; set; } = DateTime.UtcNow;

        /// <summary>
        /// 治疗时间
        /// </summary>
        public DateTime TreatTime { get; set; } = DateTime.UtcNow;

        /// <summary>
        /// 数据类型分类
        /// </summary>
        public int DataFileType { get; set; }

        /// <summary>
        /// 数据类型描述
        /// </summary>
        public string DataDesc { get; set; }

        /// <summary>
        /// 原始文件名，带后缀
        /// </summary>
        public string OriginalFileName { get; set; }

        /// <summary>
        /// 文件地址，会重命名
        /// </summary>
        public string FileToken { get; set; }
        
        /// <summary>
        /// 是否完成
        /// </summary>
        public bool IsCompleted { get; set; }
    }

    /// <summary>
    /// 设备查看数据响应实体
    /// </summary>
    public class IOTDeviceUserInfoDTO : IOTDeviceUseRecordBaseDTO
    {
        /// <summary>
        /// 设备模式类型枚举
        /// </summary>
        public ModeType Mode { get; set; }

        /// <summary>
        /// 姓名
        /// </summary>
        public string Name { get; set; }

        /// <summary>
        /// 性别
        /// </summary>
        /// <value></value>
        public string Sex { get; set; }

        /// <summary>
        /// 年龄
        /// </summary>
        public int Age { get; set; }

        /// <summary>
        /// 生日
        /// </summary>
        public DateTime Birthday { get; set; }

        /// <summary>
        /// 身高，厘米
        /// </summary>
        public int Height { get; set; }

        /// <summary>
        /// 体重 kg
        /// </summary>
        public double Weight { get; set; }

        /// <summary>
        /// 颈围 厘米
        /// </summary>
        public double Neck { get; set; }

        /// <summary>
        /// 体重指数
        /// </summary>
        public double BMI { get; set; }
    }

    /// <summary>
    /// 设备绑定用户列表数据实体
    /// </summary>
    public class IOTDeviceUserListDTO : BaseDTO
    {
        /// <summary>
        /// 绑定code
        /// </summary>
        public string Code {get; set;}

        /// <summary>
        /// iot设备编号
        /// </summary>
        public string DeviceCode { get; set; }

        /// <summary>
        /// 设备SN号
        /// </summary>
        public string DeviceSN { get; set; }

        /// <summary>
        /// 设备mac地址
        /// </summary>
        public string DeviceMAC { get; set; }

        /// <summary>
        /// 数据文件列表
        /// </summary>
        public IList<IOTDeviceUserExtendInfoDTO> UserDataList { get; set; }
    }

    /// <summary>
    /// 设备绑定用户详情信息实体
    /// </summary>
    public class IOTDeviceUserExtendInfoDTO
    {
        /// <summary>
        /// iot设备用户code
        /// </summary>
        public string UserCode { get; set; }

        /// <summary>
        /// 设备模式类型枚举
        /// </summary>
        public ModeType Mode { get; set; }

        /// <summary>
        /// 姓名
        /// </summary>
        public string Name { get; set; }

        /// <summary>
        /// 性别
        /// </summary>
        /// <value></value>
        public string Sex { get; set; }

        /// <summary>
        /// 性别：0-未知；1-男；2-女
        /// </summary>
        /// <value></value>
        public int Gender { get; set; }

        /// <summary>
        /// 年龄
        /// </summary>
        public int Age { get; set; }

        /// <summary>
        /// 生日
        /// </summary>
        public DateTime Birthday { get; set; }

        /// <summary>
        /// 身高，厘米
        /// </summary>
        public int Height { get; set; }

        /// <summary>
        /// 体重 kg
        /// </summary>
        public double Weight { get; set; }

        /// <summary>
        /// 颈围 厘米
        /// </summary>
        public double Neck { get; set; }

        /// <summary>
        /// 体重指数
        /// </summary>
        public double BMI { get; set; }

        /// <summary>
        /// 数据文件列表
        /// </summary>
        public IList<IOTDeviceDataFolderDTO> FolderList { get; set; }
    }
}