﻿using System;
using System.Collections.Generic;
using System.Runtime.Serialization;
using System.Xml.Serialization;

namespace WingInterfaceLibrary.DTO.Device
{
    /// <summary>
    /// Represents system settings and related data.
    /// </summary>
    public class SystemSettingInfoDTO
    {
        // The key of the selected list page.
        public string SelectedListPageKey { get; set; }

        // The key of the selected group.
        public string SelectedGroupKey { get; set; }

        // A collection of list pages.
        public List<ListPageSettingInfoDTO> ListPages { get; set; }

        // The result message of applying a license.
        public string ApplyLicenseResult { get; set; }
    }

    /// <summary>
    /// Represents a named item with a key.
    /// </summary>
    public class NameItemSettingInfoDTO
    {
        // The name of the item.
        public string Name { get; set; }

        // The unique key of the item.
        public string Key { get; set; }
    }

    /// <summary>
    /// Represents a command setting with a description.
    /// </summary>
    public class CommandSettingInfoDTO : NameItemSettingInfoDTO
    {
        // A brief description of the command.
        public string CommandDescription { get; set; }
    }

    /// <summary>
    /// Represents an extended version of a command setting with additional information.
    /// </summary>
    public class ExtendCommandSettingInfoDTO : CommandSettingInfoDTO
    {
        // Additional description for this command.
        public string AdditionalDescription { get; set; }

        // Value associated with this command.
        public string Value { get; set; }
    }

    /// <summary>
    /// Represents the result of a command.
    /// </summary>
    public class CommandResultInfoDTO : NameItemSettingInfoDTO
    {
        // The result of the command execution.
        public string Result { get; set; }
    }

    /// <summary>
    /// Represents a feature item with details and status information.
    /// </summary>
    [Serializable]
    public class FeatureItemInfoDTO : NameItemSettingInfoDTO
    {
        // Detailed description of the feature.
        public string Details { get; set; }

        // Status of the feature (e.g., enabled, disabled, etc.).
        public string Status { get; set; }
    }

    /// <summary>
    /// Represents information about applying a license.
    /// </summary>
    public class ApplyLicenseInfoDTO : NameItemSettingInfoDTO
    {
        // Description of the applied license.
        public string ApplyLicenseDescription { get; set; }
    }

    /// <summary>
    /// Represents a boolean parameter with a name and key.
    /// </summary>
    public class BoolParameterInfoDTO : NameItemSettingInfoDTO
    {
        // Value of the boolean parameter.
        public bool Value { get; set; }
    }

    /// <summary>
    /// Represents a string parameter with a name and key.
    /// </summary>
    public class StringParameterInfoDTO : NameItemSettingInfoDTO
    {
        // Value of the string parameter.
        public string Value { get; set; }
    }

    /// <summary>
    /// Represents a choice parameter with a name, key, selected value, and list of possible choices.
    /// </summary>
    public class ChoiceParameterInfoDTO : NameItemSettingInfoDTO
    {
        // Selected value of the choice parameter.
        public string Value { get; set; }

        // List of available choices for this parameter.
        public List<string> Items { get; set; }
    }

    /// <summary>
    /// Represents a group of named items with a name and key.
    /// </summary>
    public class GroupSettingInfoDTO : NameItemSettingInfoDTO
    {
        // Collection of named items in the group.
        public List<NameItemSettingInfoDTO> Items { get; set; }
    }

    /// <summary>
    /// Represents a list page consisting of groups of named items with a name and key.
    /// </summary>
    public class ListPageSettingInfoDTO : NameItemSettingInfoDTO
    {
        // Collection of groups within the list page.
        public List<GroupSettingInfoDTO> Groups { get; set; }
    }

    /// <summary>
    /// Represents a command result page containing information about the command execution and related settings.
    /// </summary>
    public class CommandResultPageSettingInfoDTO : ListPageSettingInfoDTO
    {
        // The result of the command execution.
        public string Result { get; set; }
    }
}