using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.DTO.Education
{
    /// <summary>
    /// 题目
    /// </summary>
    public class ExaminationQuestionDTO : BaseDTO
    {
        /// <summary>
        /// 是否删除
        /// </summary>
        /// <value>false</value>
        public bool IsDelete { get; set; }
        /// <summary>
        /// 题目Code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 题干
        /// </summary>
        /// <value></value>
        public string Stem { get; set; }

        /// <summary>
        /// 题目类型
        /// </summary>
        /// <value></value>
        public QuestionTypeEnum QuestionType { get; set; }

        /// <summary>
        /// 题目选项
        /// </summary>
        /// <value></value>
        public IList<QuestionOptionDTO> QuestionOptionList { get; set; }

        /// <summary>
        /// 图像列表
        /// </summary>
        /// <value></value>
        public IList<QuestionFileDTO> FileList { get; set; }

        /// <summary>
        /// 病例标签
        /// </summary>
        /// <value></value>
        public IList<string> CaseLabelCodes { get; set; }

        /// <summary>
        /// 课程标签
        /// </summary>
        /// <value></value>
        public IList<string> CourseLabelCodes { get; set; }

        /// <summary>
        /// 判断题对错
        /// </summary>
        /// <value></value>
        public bool TrueOrFalse { get; set; } = false;
    }

    /// <summary>
    /// 选择题选项
    /// </summary>
    public class QuestionOptionDTO
    {
        /// <summary>
        /// code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }
        /// <summary>
        /// 内容
        /// </summary>
        /// <value></value>
        public string Content { get; set; }

        /// <summary>
        /// 是否正确
        /// </summary>
        /// <value></value>
        public bool TrueOrFalse { get; set; } = false;
    }


    /// <summary>
    /// 题目图像
    /// </summary>
    public class QuestionFileDTO
    {
        /// <summary>
        /// 源文件地址
        /// </summary>
        /// <value>http://****</value>
        public string SourceUrl { get; set; } = string.Empty;

        /// <summary>
        /// 缩略图地址
        /// </summary>
        /// <value>http://****</value>
        public string PreviewImageUrl { get; set; } = string.Empty;

        /// <summary>
        /// 海报图地址
        /// </summary>
        /// <value>http://****</value>
        public string CoverImageUrl { get; set; } = string.Empty;
        /// <summary>
        /// 创建时间
        /// </summary>
        /// <value></value>
        public DateTime CreateTime { get; set; }
        /// <summary>
        /// 创建人
        /// </summary>
        /// <value></value>
        public string CreatorCode { get; set; }
        /// <summary>
        /// 文件数据类型
        /// </summary>
        /// <value>0</value>
        public RemedicalFileDataTypeEnum FileDataType { get; set; }
    }
}