using System.Collections.Generic;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Enum.CourseEnum;
namespace WingInterfaceLibrary.DTO.Education
{
    /// <summary>
    /// 用户组信息
    /// </summary>
    public class UserGroupDTO : BaseUserGroupDTO
    {
        /// <summary>
        /// 最大人数
        /// </summary>
        /// <value>50</value>
        public int MaxPeople { get; set; }

        /// <summary>
        /// 创建人Code
        /// </summary>
        /// <value>20220324085918O01i7T</value>
        public string CreatorCode { get; set; }

        /// <summary>
        /// 创建人名称
        /// </summary>
        /// <value>张三</value>
        public string CreatorName { get; set; }

        /// <summary>
        /// 学生列表
        /// </summary>
        /// <value></value>
        public IList<StudentInfoDTO> Students { get; set; }

        /// <summary>
        /// 课程数量
        /// </summary>
        /// <value></value>
        public int CourseCount { get; set; }

        /// <summary>
        /// 练习数量
        /// </summary>
        /// <value></value>
        public int PracticeCount { get; set; }

        /// <summary>
        /// 考试数量
        /// </summary>
        /// <value></value>
        public int ExamCount { get; set; }

        /// <summary>
        /// 学生数量
        /// </summary>
        /// <value></value>
        public int StudentCount { get; set; }

        /// <summary>
        /// 是否代理商，后台可以维护和创建
        /// </summary>
        /// <value>false</value>
        public bool IsAgent { get; set; } = false;

        /// <summary>
        /// 是否老平台数据
        /// </summary>
        /// <value></value>
        public bool IsOldPlatformData { get; set; }

        /// <summary>
        /// 用户组类型，默认：班级-0
        /// </summary>
        /// <value></value>
        public UserGroupEnum UserGroupType { get; set; }

        /// <summary>
        /// 用户列表
        /// </summary>
        public IList<string> UserCodes { get; set; }

        /// <summary>
        /// 设备列表
        /// </summary>
        public IList<string> DeviceCodes { get; set; }
    }

    /// <summary>
    /// 用户组基础信息
    /// </summary>
    public class BaseUserGroupDTO : BaseDTO
    {
        /// <summary>
        /// 用户组Code
        /// </summary>
        /// <value>20220324085918O01i7T</value>
        public string Code { get; set; }

        /// <summary>
        /// 用户组名称
        /// </summary>
        /// <value>张老师用户组</value>
        public string Name { get; set; }

        /// <summary>
        /// 短码班级
        /// </summary>
        public string ShortCode { get; set; }

        /// <summary>
        /// 用户组描述
        /// </summary>
        public string Description { get; set; }
    }

    /// <summary>
    /// 学生基础信息
    /// </summary>
    public class StudentInfoDTO
    {
        /// <summary>
        /// 用户Code
        /// </summary>
        /// <value>20220324085918O01i7T</value>
        public string Code { get; set; }

        /// <summary>
        /// 用户名称
        /// </summary>
        /// <value>XX学生</value>
        public string Name { get; set; }

        /// <summary>
        /// 手机号
        /// </summary>
        /// <value>13301543825</value>
        public string Phone { get; set; } = string.Empty;

        /// <summary>
        /// 是否支付：是-支付；否-未支付
        /// </summary>
        /// <value>false</value>
        public bool IsPay { get; set; }

        /// <summary>
        /// 学生对于课程的状态
        /// </summary>
        ///  <value>0</value>
        public StudentCourseStatusEnum SignCourseStatus { get; set; }

        /// <summary>
        /// 学员对于班级状态枚举
        /// </summary>
        public LearnerStatusEnum LearnerStatus { get; set; } = LearnerStatusEnum.NoApproval;
    }
}