using System;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Role;
using WingInterfaceLibrary.DTO.User;

namespace WingInterfaceLibrary.DTO.Management
{
    /// <summary>
    /// 管理员信息
    /// </summary>
    public class AdminInfoDTO : BaseDTO
    {
        /// <summary>
        /// 管理员编码
        /// </summary>
        public string AdminCode { get; set; }

        /// <summary>
        /// 对应父级管理员编码
        /// </summary>
        public string FatherCode { get; set; }

        /// <summary>
        /// 管理员名称
        /// </summary>
        public string AdminName { get; set; }

        /// <summary>
        /// 姓名
        /// </summary>
        public string FullName { get; set; }

        /// <summary>
        /// 密码
        /// </summary>
        public string SecretPassword { get; set; }

        /// <summary>
        /// 头像url地址
        /// </summary>
        public string HeadImageToken { get; set; }

        /// <summary>
        /// 管理授权码
        /// </summary>
        public string LicenseKey { get; set; }

        /// <summary>
        /// 最后登录IP地址
        /// </summary>
        public string LastIP { get; set; }

        /// <summary>
        /// 管理员联系电话
        /// </summary>
        public string Phone { get; set; }

        /// <summary>
        /// 管理员邮箱
        /// </summary>
        public string Email { get; set; }

        /// <summary>
        /// 后台角色列表
        /// </summary>
        /// <value></value>
        public List<string> RoleCodes { get; set; } = new List<string>();

        /// <summary>
        /// 登录失败信息 
        /// </summary>
        /// <value></value>
        public LoginLockInfoDTO LoginLockInfo { get; set; }
        
        /// <summary>
        /// password update time
        /// </summary>
        public DateTime PasswordUpdateTime { get; set; }

        /// <summary>
        /// 密码记录列表
        /// </summary>
        public List<string> PasswordRecords { get; set; } = new List<string>();

        /// <summary>
        /// 清理日志实体列表
        /// </summary>
        public IList<ClearLogOperateDTO> ClearLogOperateList { get; set; } = new List<ClearLogOperateDTO>();

        /// <summary>
        ///分配的医院列表
        /// </summary>
        /// <value></value>
        public List<string> AssignedOrganizations { get; set; }

        /// <summary>
        /// 绑定用户
        /// </summary>
        public string BindUserCode { get; set; }
        
        /// <summary>
        /// 绑定用户名称
        /// </summary>
        public string BindUserName  { get; set; }
    }

    /// <summary>
    /// 清理日志实体
    /// </summary>
    public class ClearLogOperateDTO
    {
        /// <summary>
        /// 目标服务器
        /// </summary>
        public string ServerHost { get; set; }

        /// <summary>
        /// 上次日志清理时间【可以根据daysAgo计算出来】
        /// </summary>
        public DateTime LastClearTime { get; set; }

        /// <summary>
        /// 上次清理操作时间
        /// </summary>
        public DateTime LastClearOperateTime { get; set; }
    }

    /// <summary>
    /// 管理员扩展信息
    /// </summary>
    public class AdminExtendInfoDTO : AdminInfoDTO
    {
        /// <summary>
        /// 后台角色名称列表
        /// </summary>
        /// <value></value>
        public List<string> RoleNames { get; set; } = new List<string>();

        /// <summary>
        /// 后台默认角色编码
        /// </summary>
        /// <value></value>
        public string DefaultRoleCode { get; set; }

        /// <summary>
        /// 后台默认角色名称
        /// </summary>
        /// <value></value>
        public string DefaultRoleName { get; set; }
        /// <summary>
        /// 账号是否锁定
        /// </summary>
        /// <value></value>
        public bool IsLocked { get; set; }
    }
}