using System;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Common;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.DTO.Patient
{
    /// <summary>
    /// 患者基础信息响应实体
    /// </summary>
    public class PatientInfoBaseDTO : BaseDTO
    {
        /// <summary>
        /// 病人编码
        /// </summary>
        /// <value>PatientInfoDO_20220315125334n5j3A2</value>
        public string PatientCode { get; set; }
        /// <summary>
        /// 病人姓名
        /// </summary>
        /// <value>病人1</value>
        public string Name { get; set; }
        /// <summary>
        /// 联系电话
        /// </summary>
        /// <value>18550415531</value>
        public string Phone { get; set; }
        /// <summary>
        /// 身份证号码
        /// </summary>
        /// <value>323258195538821585</value>
        public string IdentityCard { get; set; }
        /// <summary>
        /// 保险编号
        /// </summary>
        /// <value></value>
        public string InsuranceCode { get; set; }
        /// <summary>
        /// 年龄 -废弃
        /// </summary>
        /// <value>41</value>
        /// <code>0</code>
        public string Age { get; set; }
        /// <summary>
        /// 性别
        /// </summary>
        /// <value>1</value>
        public int Gender { get; set; }
        /// <summary>
        /// 是否已登记确认
        /// </summary>
        /// <value>true</value>
        public bool IsValid { get; set; }
        /// <summary>
        /// 机构编码
        /// </summary>
        /// <value>Org_20220315125334n5j3A</value>
        public string OrganizationCode { get; set; }
        /// <summary>
        /// 医院机构编码
        /// </summary>
        /// <value>Org_20220315125334n5j3A</value>
        public string RootOrganizationCode { get; set; }
        /// <summary>
        /// 分配用户code集合
        /// </summary>
        /// <value>"uc_code01","uc_code02"</value>
        public List<string> AssignmentUserCodes { get; set; }

        /// <summary>
        /// 病人信息字段 json 集合
        /// </summary>
        /// <value></value>
        public List<DataItemDTO> PatientData { get; set; }

        /// <summary>
        /// 未读病例数量
        /// </summary>
        /// <value>0</value>
        public int UnReadRecordCount { get; set; } = 0;

        /// <summary>
        /// 病人/宠物头像
        /// </summary>
        public string HeadImgUrl { get; set; }

        /// <summary>
        /// 类型
        /// </summary>
        /// <value>Person、Animals</value>
        public string PatientType { get; set; }

        /// <summary>
        /// 是否转诊
        /// </summary>
        /// <value>false</value>
        public bool IsReferral { get; set; }

        /// <summary>
        /// 设备病人ID
        /// </summary>
        public List<string> DevicePatientIDs { get; set; } = new List<string>();

        /// <summary>
        /// 是否dicom上传
        /// </summary>
        public bool IsFromDicom { get; set; } = false;

        /// <summary>
        /// 所属科研项目
        /// </summary>
        /// <value></value>
        public string ProjectCode { get; set; }

        /// <summary>
        /// 是否URM
        /// </summary>
        public bool IsUrm { get; set; }
    }
}