using System;
using System.Collections.Generic;
using System.Linq;
using WingInterfaceLibrary.DTO.LiveRoom;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.LiveConsultation.Consultation;

namespace WingInterfaceLibrary.DTO.RTC
{
    /// <summary>
    /// 直播房间实体
    /// </summary>
    public class LiveRoomInfoDTO
    {
        /// <summary>
        /// The module unique id
        /// </summary>
        /// <value></value>
        public string RoomId { get; set; }

        /// <summary>
        /// The diagnosis room No
        /// </summary>
        /// <value></value>
        public int RoomNo { get; set; }

        /// <summary>
        /// The diagnosis room No
        /// </summary>
        /// <value></value>
        public string MsgQueueId { get; set; }

        /// <summary>
        /// 直播成员数据列表
        /// </summary>
        /// <value></value>
        public IList<LiveMemberDTO> Members { get; set; } = new List<LiveMemberDTO>();

        /// <summary>
        /// 直播观众列表
        /// </summary>
        /// <value></value>
        public IList<LiveViewerDTO> ViewerInfos { get; set; } = new List<LiveViewerDTO>();

        /// <summary>
        /// 直播发起者
        /// </summary>
        /// <value></value>
        public LiveMemberDTO Initiator
        {
            get
            {
                return Members.FirstOrDefault();
            }
        }

        /// <summary>
        /// 用户成员列表
        /// </summary>
        /// <value></value>
        public IEnumerable<LiveMemberDTO> UserInfos
        {
            get
            {
                return Members.Where(x => x.MemberType == LiveMemberEnum.User);
            }
        }

        /// <summary>
        /// divce members
        /// </summary>
        /// <value></value>
        public IEnumerable<LiveMemberDTO> DeviceInfos
        {
            get
            {
                return Members.Where(x => x.MemberType == LiveMemberEnum.Device);
            }
        }

        /// <summary>
        /// main user members包括专家列表
        /// </summary>
        /// <value></value>
        public IEnumerable<LiveMemberDTO> ExpertUserInfos 
        {             
            get
            {
                return Members;
            }
         }

        /// <summary>
        /// 助理列表
        /// </summary>
        /// <value></value>
        public IEnumerable<LiveMemberDTO> AssistantsInfos 
        {             
            get
            {
                return Members;
            }
         }

        /// <summary>
        /// The diagnosis room status
        /// </summary>
        /// <value>0</value>
        public LiveRoomStatus Status { get; set; }

        /// <summary>
        /// 名称[可以是病人名称、课程名称]
        /// </summary>
        /// <value>XXXXX</value>
        public string Name { get; set; }

        /// <summary>
        /// 直播时间
        /// </summary>
        /// <value>2023-02-28T09:21:38.861Z</value>
        public DateTime LiveTime { get; set; }

        /// <summary>
        /// 通用直播项目状态
        /// </summary>
        /// <value>0</value>
        public int LiveStatus { get; set; }

        /// <summary>
        /// 白板数据集合
        /// </summary>
        /// <value></value>
        public IList<InteractiveBoardDataDTO> InteractiveBoardDatas { get; set; } = new List<InteractiveBoardDataDTO>();
    }
}