using System;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Common;
using WingInterfaceLibrary.DTO.Report;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Result.Record;

namespace WingInterfaceLibrary.DTO.Record
{
    public class RecordInfoDTO : BaseDTO
    {
        /// <summary>
        /// 检查编码
        /// </summary>
        /// <value></value>
        public string RecordCode { get; set; }

        /// <summary>
        /// 病人编码
        /// </summary>
        public string PatientCode { get; set; }

        /// <summary>
        /// 设备编码
        /// </summary>
        public string DeviceCode { get; set; }

        /// <summary>
        /// 检查状态
        /// </summary>
        public RecordStatusEnum RecordStatus { get; set; }

        /// <summary>
        /// 检查医生
        /// </summary>
        /// <value></value>
        public string CreatorCode { get; set; }

        /// <summary>
        /// 处理标识，用来做特殊处理标识
        /// </summary>
        public string Tags { get; set; }

        /// <summary>
        /// 创建方式
        /// </summary>
        /// <value></value>
        public RecordCreateTypeEnum CreateType { get; set; }

        /// <summary>
        /// 病人信息
        /// </summary>
        /// <code>0</code>
        public List<DataItemDTO> PatientInfo { get; set; }

        /// <summary>
        /// 病人额外信息列表
        /// </summary>
        /// <value></value>
        public List<PatientInfoExt> PatientInfoExtList { get; set; }

        /// <summary>
        /// 设备病人ID
        /// </summary>
        /// <value></value>
        public string DevicePatientID { get; set; }

        /// <summary>
        /// 类型
        /// </summary>
        /// <value>Person、Animals</value>
        public string PatientType { get; set; }

        /// <summary>
        /// 已读用户列表
        /// </summary>
        /// <value>"test01","test02"</value>
        public List<string> ReadUsers { get; set; } = new List<string>();

        /// <summary>
        /// 根组织
        /// </summary>
        /// <value></value>
        public string RootOrganizationCode { get; set; }

        /// <summary>
        /// 组织
        /// </summary>
        /// <value></value>
        public string OrganizationCode { get; set; }

        /// <summary>
        /// 关联的超声机本地上传的检查code
        /// </summary>
        /// <value></value>
        public List<string> AssociatedExamCodes { get; set; } = new List<string>();

        /// <summary>
        /// AI诊断状态
        /// </summary>
        /// <value>2</value>
        public DiagnosisStatusEnum DiagnosisStatus { get; set; }

        /// <summary>
        /// AI诊断结果
        /// </summary>
        /// <value></value>
        public List<DiagnosisInfoDTO> DiagnosisInfos { get; set; } = new List<DiagnosisInfoDTO>();

        /// <summary>
        /// 是否采图中
        /// </summary>
        /// <value></value>
        public bool IsCollecting { get; set; }

        /// <summary>
        /// 开始采图时间
        /// </summary>
        /// <value></value>
        public DateTime StartCollectingTime { get; set; }

        /// <summary>
        /// 是否医生出了诊断报告
        /// </summary>
        /// <value></value>
        public bool IsUserReport { get; set; }

        /// <summary>
        /// 是否转出
        /// </summary>
        /// <value></value>
        public bool IsReferral { get; set; }

        /// <summary>
        /// 是否dicom上传
        /// </summary>
        public bool IsFromDicom { get; set; } = false;

        /// <summary>
        /// 国家脑卒中项目，掌超上传医生
        /// </summary>
        /// <value></value>
        public string CustomDoctor { get; set; }

        /// <summary>
        /// 国家脑卒中项目，掌超上传医院
        /// </summary>
        /// <value></value>
        public string CustomOrganzation { get; set; }

        /// <summary>
        /// 国家脑卒中项目，掌超上传设备SN
        /// </summary>
        /// <value></value>
        public string EquipmentSN { get; set; }

        /// <summary>
        /// 检查时间
        /// </summary>
        /// <value></value>
        public DateTime? ExamTime { get; set; }

        /// <summary>
        /// 设备端ExamId
        /// </summary>
        /// <value></value>
        public string DeviceExamId { get; set; }

        /// <summary>
        /// 图像是否已质控
        /// </summary>
        /// <value></value>
        public bool IsImgQualityControlled { get; set; } = false;

        /// <summary>
        /// 报告是否已质控
        /// </summary>
        /// <value></value>
        public bool IsReportQualityControlled { get; set; } = false;

        /// <summary>
        /// 图像质控分
        /// </summary>
        /// <value></value>
        public double ImgScore { get; set; }

        /// <summary>
        /// 报告质控分
        /// </summary>
        /// <value></value>
        public double ReportScore { get; set; }

        /// <summary>
        /// 是否已质控（有一个即算）
        /// </summary>
        /// <value></value>
        public bool IsQualityControlled
        {
            get
            {
                return IsReportQualityControlled || IsImgQualityControlled;
            }
        }

        /// <summary>
        /// 质控总分
        /// </summary>
        /// <value></value>
        public double Score
        {
            get
            {
                return ImgScore + ReportScore;
            }
        }

        /// <summary>
        /// 体检机构编码
        /// </summary>
        /// <value></value>
        public string VitalOrganizationCode { get; set; }


        /// <summary>
        /// 所属科研项目
        /// </summary>
        /// <value></value>
        public string ProjectCode { get; set; }
    }

    /// <summary>
    /// 转诊数据
    /// </summary>
    public class ReferralData : BaseDTO
    {
        /// <summary>
        /// 病人姓名
        /// </summary>
        /// <value></value>
        public string PatientName { get; set; }

        /// <summary>
        /// code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 检查code
        /// </summary>
        /// <value></value>
        public string RecordCode { get; set; }

        /// <summary>
        /// 转出医生
        /// </summary>
        /// <value></value>
        public string ReferralOutUserCode { get; set; }

        /// <summary>
        /// 转出医院
        /// </summary>
        /// <value></value>
        public string ReferralOutOrganizationCode { get; set; }

        /// <summary>
        /// 转入医生
        /// </summary>
        /// <value></value>
        public string ReferralInUserCode { get; set; }

        /// <summary>
        /// 转入医院
        /// </summary>
        /// <value></value>
        public string ReferralInOrganizationCode { get; set; }

        /// <summary>
        /// 转诊状态
        /// </summary>
        /// <value></value>
        public RecordReferralStatusEnum ReferralStatus { get; set; }

        /// <summary>
        /// 转诊时间
        /// </summary>
        /// <value></value>
        public DateTime ReferralTime { get; set; }

        /// <summary>
        /// 转诊事由
        /// </summary>
        /// <value></value>
        public string SubjectMatter { get; set; }
    }


    /// <summary>
    /// 检查额外信息
    /// </summary>
    public class PatientInfoExt
    {
        /// <summary>
        ///检查扫查类型
        /// </summary>
        /// <value>Routine</value>
        public string PatientScanType { get; set; }

        /// <summary>
        /// 检查额外信息内容
        /// </summary>
        /// <code>0</code>
        public List<DataItemDTO> Content { get; set; }
    }

    /// <summary>
    /// AI诊断结论
    /// </summary>
    public class DiagnosisInfoDTO
    {
        /// <summary>
        /// AI识别器官
        /// </summary>
        /// <value></value>
        public DiagnosisOrganEnum DiagnosisOrgan { get; set; }
        /// <summary>
        /// 诊断结论
        /// </summary>
        /// <value></value>
        public DiagnosisConclusionEnum Conclusion { get; set; }
        /// <summary>
        /// 报告状态
        /// </summary>
        /// <value></value>
        public DiagnosisReportStatusEnum ReportStatus { get; set; }
    }


    /// <summary>
    /// 大列表记录实体
    /// </summary>
    public class SimpleRecordInfoDTO : BaseDTO
    {
        /// <summary>
        /// 检查编码
        /// </summary>
        /// <value></value>
        public string RecordCode { get; set; }

        /// <summary>
        /// 检查状态
        /// </summary>
        public RecordStatusEnum RecordStatus { get; set; }

        /// <summary>
        //  转诊状态 0-普通，1-转出，2-转入
        /// </summary>
        /// <value></value>
        public ReferralTypeEnum ReferralType { get; set; }

        /// <summary>
        /// 病人编码
        /// </summary>
        public string PatientCode { get; set; }

        /// <summary>
        /// 病人名称
        /// </summary>
        /// <value></value>
        public string PatientName { get; set; }

        /// <summary>
        /// 年龄
        /// </summary>
        /// <value></value>
        public string Age { get; set; }

        /// <summary>
        /// 性别
        /// </summary>
        /// <value></value>
        public string Sex { get; set; }


        /// <summary>
        /// 设备病人ID
        /// </summary>
        /// <value></value>
        public string DevicePatientID { get; set; }

        /// <summary>
        /// 设备编码
        /// </summary>
        public string DeviceCode { get; set; }

        /// <summary>
        /// 设备名称
        /// </summary>
        /// <value></value>
        public string DeviceName { get; set; }

        /// <summary>
        /// 设备头图
        /// </summary>
        /// <value></value>
        public string DeviceHeadPicUrl { get; set; }

        /// <summary>
        /// 医院code
        /// </summary>
        /// <value></value>
        public string RootOrganizationCode { get; set; }

        /// <summary>
        /// 医院名称
        /// </summary>
        /// <value></value>
        public string RootOrganizationName { get; set; }

        /// <summary>
        /// 语言 en-US
        /// </summary>
        /// <value></value>
        public string Languge { get; set; } = "en-US";

        /// <summary>
        /// 是否可以创建报告
        /// </summary>
        /// <value></value>
        public bool CanCreateReport { get; set; }

        /// <summary>
        /// 是否采图中
        /// </summary>
        /// <value>true</value>
        public bool IsCollecting { get; set; }

        /// <summary>
        /// 是否可采图
        /// </summary>
        /// <value>true</value>
        public bool CanCollcetImg { get; set; }

        /// <summary>
        /// 国家脑卒中项目，掌超上传医生
        /// </summary>
        /// <value></value>
        public string CustomDoctor { get; set; }

        /// <summary>
        /// 国家脑卒中项目，掌超上传医院
        /// </summary>
        /// <value></value>
        public string CustomOrganzation { get; set; }

        /// <summary>
        /// 国家脑卒中项目，掌超上传设备SN
        /// </summary>
        /// <value></value>
        public string EquipmentSN { get; set; }

        /// <summary>
        /// AI诊断结果
        /// </summary>
        /// <value></value>
        public List<DiagnosisInfoDTO> DiagnosisInfos { get; set; } = new List<DiagnosisInfoDTO>();

        /// <summary>
        /// 是否已质控（有一个即算）
        /// </summary>
        /// <value></value>
        public bool IsQualityControlled { get; set; }


        /// <summary>
        /// 质控总分
        /// </summary>
        /// <value></value>
        public double Score { get; set; }

        /// <summary>
        /// 是否可以截图版采图
        /// </summary>
        /// <value>true</value>
        public bool CanScreenshot { get; set; }

    }

    /// <summary>
    /// 健康体检-远程超声详情
    /// </summary>
    public class VitalRecordInfoDTO
    {
        /// <summary>
        /// 检查编码
        /// </summary>
        /// <value></value>
        public string RecordCode { get; set; }

        /// <summary>
        /// 检查状态
        /// </summary>
        public RecordStatusEnum RecordStatus { get; set; }

        /// <summary>
        /// 设备编码
        /// </summary>
        public string DeviceCode { get; set; }

        /// <summary>
        /// 设备名称
        /// </summary>
        /// <value></value>
        public string DeviceName { get; set; }

        /// <summary>
        /// 语言 en-US
        /// </summary>
        /// <value></value>
        public string Languge { get; set; } = "en-US";

        public RemedicalListResult RemedicalListResult { get; set; }

        public List<ReportDTO> ReportInfos { get; set; }

    }
}