using System;
using System.Collections.Generic;
using System.Text.RegularExpressions;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.DTO.User
{
    /// <summary>
    /// 用户信息响应实体
    /// </summary>
    public class UserDTO : UserBaseDTO
    {
        /// <summary>
        /// 用户昵称
        /// </summary>
        /// <value>打到伏地魔</value>
        public string NickName { get; set; } = string.Empty;

        /// <summary>
        /// 所属组织【废弃】
        /// </summary>
        /// <value>Org000001</value>
        public string OrganizationCode { get; set; } = string.Empty;

        /// <summary>
        /// 所属组织名称【废弃】
        /// </summary>
        /// <value>组织00001</value>
        public string OrganizationName { get; set; } = string.Empty;

        /// <summary>
        /// 科室Code【未绑定则为空】
        /// </summary>
        /// <value>Dep000001</value>
        public string DepartmentCode { get; set; } = string.Empty;

        /// <summary>
        /// 科室名称【未绑定则为空】
        /// </summary>
        /// <value>科室00001</value>
        public string DepartmentName { get; set; } = string.Empty;

        /// <summary>
        /// 科室短码
        /// </summary>
        /// <value>TDDU43</value>
        public string DepartmentShortCode { get; set; } = string.Empty;

        /// <summary>
        /// 所属顶级组织【机构Code】
        /// </summary>
        /// <value>RootOrg000001</value>
        public string RootOrganizationCode { get; set; } = string.Empty;

        /// <summary>
        /// 所属顶级组织名称【机构名称】
        /// </summary>
        /// <value>机构00001</value>
        public string RootOrganizationName { get; set; } = string.Empty;

        /// <summary>
        /// 所属权限组
        /// </summary>
        /// <value>"权限1","权限1"</value>
        public List<string> AuthorityGroups { get; set; } = new List<string>();

        /// <summary>
        /// 绑定设备列表
        /// </summary>
        /// <value>"设备1","设备2"</value>
        public List<string> BindDevices { get; set; } = new List<string>();

        /// <summary>
        /// 绑定设备机构列表
        /// </summary>
        /// <value>"机构1","机构2"</value>
        public IList<string> BindDeviceOrganizations { get; set; } = new List<string>();

        /// <summary>
        /// 最后使用IP地址
        /// </summary>
        /// <value>127.0.0.1</value>
        public string LastIP { get; set; }

        /// <summary>
        /// 登录次数
        /// </summary>
        /// <value></value>
        /// <value>0</value>
        public int Logintimes { get; set; }

        /// <summary>
        /// 用户状态
        /// </summary>
        /// <value>1</value>
        public UserInfoStateEnum UserState { get; set; } = UserInfoStateEnum.Activated;

        /// <summary>
        /// 用户角色列表
        /// </summary>
        /// <value>"角色1","角色2"</value>
        public List<string> RoleCodes { get; set; } = new List<string>();

        /// <summary>
        /// 用户职称列表
        /// </summary>
        /// <value>"职称1","职称2"</value>
        public List<string> RankCodes { get; set; } = new List<string>();

        /// <summary>
        /// 岗位身份列表
        /// </summary>
        /// <value>"岗位1","岗位2"</value>
        public List<string> PositionCodes { get; set; } = new List<string>();

        /// <summary>
        /// 申请状态
        /// </summary>
        /// <value>1</value>
        public ApplyStateEnum ApplyState { get; set; }

        /// <summary>
        /// 用户职称名称
        /// </summary>
        /// <value></value>
        /// <value>Rank0001</value>
        public string RankName { get; set; } = string.Empty;

        /// <summary>
        /// 岗位身份名称
        /// </summary>
        /// <value></value>
        /// <value>role0001</value>
        public string PositionName { get; set; } = string.Empty;

        /// <summary>
        /// 是否机构负责人
        /// </summary>
        /// <value></value>
        public bool IsDirector { get; set; } = false;

        /// <summary>
        /// 擅长领域
        /// </summary>
        /// <value>"test1","test2"</value>
        public List<string> FieldList { get; set; } = new List<string>();

        /// <summary>
        /// 删除的病人code集合
        /// </summary>
        /// <value>"PatientInfoDO_202205120238579oWImY","PatientInfoDO_202205120238579oWGb4"</value>
        public List<string> DeletePatientCodes { get; set; } = new List<string>();

        /// <summary>
        /// 是否开启分时诊断数据批量导出
        /// </summary>
        /// <value>false</value>
        public bool IsBatchExportDiagnoseData { get; set; }

        /// <summary>
        /// 助理用户编码
        /// </summary>
        /// <value></value>
        public string BindAssistantUserCode { get; set; }

        /// <summary>
        /// 助理医师用户编码
        /// </summary>
        /// <value></value>
        public string BindAssistantDoctorUserCode { get; set; }

        /// <summary>
        /// 登录锁定信息
        /// </summary>
        /// <value></value>
        public LoginLockInfoDTO LoginLockInfo { get; set; }

        /// <summary>
        /// 签名
        /// </summary>
        public string Signature { get; set; }

        /// <summary>
        /// 语言
        /// </summary>
        public string Language { get; set; }

        /// <summary>
        /// 报告标签
        /// </summary>
        /// <value></value>
        public bool EnableReportLabel { get; set; }

        /// <summary>
        /// 第三方关联信息
        /// </summary>
        /// <value></value>
        public List<AssociatedInfoDTO> AssociatedInfos { get; set; }

        /// <summary>
        /// 公共平台用户ID
        /// </summary>
        /// <value></value>
        public string CommonPlatformUserId { get; set; }

        /// <summary>
        /// 急诊设备编码
        /// </summary>
        /// <value></value>
        public string BindEmergencyDeviceCode { get; set; }

        /// <summary>
        /// 急诊专家编码
        /// </summary>
        /// <value></value>
        public string BindEmergencyExpertCode { get; set; }

        /// <summary>
        /// 配置Dashboard查询医院编码集合
        /// </summary>
        /// <value></value>
        public List<string> DashboardOrgCodes { get; set; }

        /// <summary>
        /// 所属组织短码【废弃】
        /// </summary>
        /// <value>TSD0X1</value>
        public string OrganizationShortCode { get; set; } = string.Empty;

        /// <summary>
        /// 顶级组织短码
        /// </summary>
        /// <value>TSD0X1</value>
        public string RootOrganizationShortCode { get; set; } = string.Empty;

        /// <summary>
        /// 是否代理商
        /// </summary>
        /// <value></value>
        public bool IsOldAgent { get; set; }

        /// <summary>
        /// 是否科研用户
        /// </summary>
        /// <value></value>
        public bool IsResearchProjectUser { get; set; }

        /// <summary>
        /// 用户绑定权限列表
        /// </summary>
        /// <value></value>
        public List<string> UserFeatureCodes { get; set; }

        /// <summary>
        /// 微信OpenId
        /// </summary>
        /// <value></value>
        public string OpenId { get; set; }

        /// <summary>
        /// 生日
        /// </summary>
        /// <value></value>
        public string Birthday { get; set; }

        /// <summary>
        /// 出生年月
        /// </summary>
        /// <value></value>
        public DateTime? BirthDate { get; set; } = DateTime.MinValue;

        /// <summary>
        /// 性别：0-未知；1-男；2-女
        /// </summary>
        /// <value></value>
        public int Gender { get; set; }

        /// <summary>
        /// 颈围 
        /// </summary>
        /// <value></value>
        public float NeckGirth { get; set; }
        /// <summary>
        /// 身高 
        /// </summary>
        /// <value></value>
        public float Height { get; set; }
        /// <summary>
        /// 体重 
        /// </summary>
        /// <value></value>
        public float Weight { get; set; }
        /// <summary>
        /// 体脂数 
        /// </summary>
        /// <value></value>
        public float BMI { get; set; }
        
        /// <summary>
        /// 科研项目Dongle 
        /// </summary>
        /// <value></value>
        public string LabDongle { get; set; }

        /// <summary>
        /// 用户绑定计费信息列表
        /// </summary>
        public List<BindChargeResourcePackageDTO> BindChargeResourcePackages { get; set; }

        /// <summary>
        /// 用户绑定计费信息列表历史记录表
        /// </summary>
        /// <value></value>
        public List<BindChargeResourcePackageDTO> BindChargeResourcePackageRecords { get; set; }

        /// <summary>
        /// 是否试用过 
        /// </summary>
        /// <value></value>
        public bool IsProbationChargeResourcePackage { get; set; }
    }

    /// <summary>
    /// 用户信息响应实体
    /// </summary>
    public class UserBaseDTO : BaseDTO
    {
        /// <summary>
        /// 手机号
        /// </summary>
        /// <value>13301543825</value>
        public string Phone { get; set; } = string.Empty;

        /// <summary>
        /// 邮箱地址
        /// </summary>
        /// <value>warr.qian@vinno.com</value>
        public string Email { get; set; } = string.Empty;

        /// <summary>
        /// 用户编码
        /// </summary>
        /// <value>4914352a75f645279f6b4ad6764cc288</value>
        public string UserCode { get; set; }

        /// <summary>
        /// 用户名
        /// </summary>
        /// <value>User_20220107104236xiP0nz</value>
        public string UserName { get; set; }

        /// <summary>
        /// 用户姓名
        /// </summary>
        /// <value>哈利波特</value>
        public string FullName { get; set; } = string.Empty;

        /// <summary>
        /// 头像
        /// </summary>
        /// <value>http://192.168.6.91:9001/Storage/f5ca4b07ffd312gd2f042d88fb6bbda13c61fa6_7_0.PNG</value>
        public string HeadImageUrl { get; set; } = string.Empty;

        /// <summary>
        /// 统一名字展示字段
        /// </summary>
        /// <value></value>
        public string DisplayName
        {
            get
            {
                var name = string.IsNullOrWhiteSpace(FullName) ? UserName : FullName;
                if(Regex.IsMatch(name,"[0-9A-Z]{32}") && !string.IsNullOrWhiteSpace(Phone))
                {
                    name = Phone;
                }
                if(Regex.IsMatch(name,"[0-9A-Z]{32}") && !string.IsNullOrWhiteSpace(Email))
                {
                    name = Email;
                }
                return name;
            }
        }
    }

    public class UserInfoByCodeDTO : UserDTO
    {
        /// <summary>
        /// 助理用户名称
        /// </summary>
        /// <value></value>
        public string BindAssistantUserName { get; set; }

        /// <summary>
        /// 助理医师用户名称
        /// </summary>
        /// <value></value>
        public string BindAssistantDoctorUserName { get; set; }
    }


    /// <summary>
    /// 第三方关联信息
    /// </summary>
    public class AssociatedInfoDTO
    {
        /// <summary>
        /// Id
        /// </summary>
        /// <value></value>
        public string Id { get; set; }

        /// <summary>
        /// 关联用户名
        /// </summary>
        /// <value></value>
        public string RelationName { get; set; }

        /// <summary>
        /// 标题
        /// </summary>
        /// <value></value>
        public string Title { get; set; }

        /// <summary>
        /// 标题
        /// </summary>
        /// <value></value>
        public string CTitle { get; set; }

        /// <summary>
        /// 标题
        /// </summary>
        /// <value></value>
        public string ETitle { get; set; }

        /// <summary>
        /// Ico
        /// </summary>
        /// <value></value>
        public string Icon { get; set; }

        /// <summary>
        /// 描述
        /// </summary>
        /// <value></value>
        public string Description { get; set; }

        /// <summary>
        /// 系统地址
        /// </summary>
        /// <value></value>
        public string Url { get; set; }

        /// <summary>
        /// 索引号
        /// </summary>
        /// <value></value>
        public int Index { get; set; }
    }

    /// <summary>
    /// 第三方关联信息
    /// </summary>
    public class AssociatedFeatureInfoDTO : AssociatedInfoDTO
    {
        /// <summary>
        /// FeatureCode
        /// </summary>
        /// <value></value>
        public string FeatureCode { get; set; }

        /// <summary>
        /// 位置
        /// </summary>
        /// <value></value>
        public string AssociatedPosition { get; set; }
    }

    /// <summary>
    /// 用户绑定计费资源信息实体 
    /// </summary>
    /// <value></value>
    public class BindChargeResourcePackageDTO
    {
        /// <summary>
        /// 绑定资源包列code 
        /// </summary>
        /// <value></value>
        public string ResourcePackageCode { get; set; }

        /// <summary>
        /// 业务类型code 
        /// </summary>
        /// <value></value>
        public string BussinessCode { get; set; }

        /// <summary>
        /// 计费资源包类型
        /// </summary>
        /// <value></value>
        public ChargeResourcePackageTypeEnum ResourcePackageType { get; set; }

        /// <summary>
        /// 资源包名称 
        /// </summary>
        /// <value></value>
        public string ResourcePackageName { get; set; }

        /// <summary>
        /// 数量 
        /// </summary>
        /// <value></value>
        public int Count { get; set; }
        
        /// <summary>
        /// 开始时间 
        /// </summary>
        /// <value></value>
        public DateTime BeginTime { get; set; }
        
        /// <summary>
        /// 结束时间 
        /// </summary>
        /// <value></value>
        public DateTime EndTime { get; set; }
    }

}