using System;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Common;

namespace WingInterfaceLibrary.DTO.Vital
{
    /// <summary>
    /// 县级健康平台（密山县市）
    /// </summary>
    public class CountyHealthPlatformStatisticsDTO : BaseDTO
    {
        /// <summary>
        /// 签约统计数据
        /// </summary>
        /// <value></value>
        public SignStatisticsBasicDTO SignStatisticsData { get; set; }

        /// <summary>
        /// 人群分类占比统计
        /// </summary>
        /// <value></value>
        public IList<DataItemDTO> PopulationClassificationPercentageStatisticsData { get; set; }

        /// <summary>
        /// 乡镇档案统计数据（包括签约量、医生数量、档案数量）
        /// </summary>
        /// <value></value>
        public ArchivesStatisticsDTO TownArchivesStatisticsData { get; set; }

        /// <summary>
        /// 人群分类数量统计(map town级别)
        /// </summary>
        /// <value></value>
        public IList<MapCommonStatisticsDTO> TownPopulationClassificationStatisticsData { get; set; }

        /// <summary>
        /// 健康管理效果统计数据
        /// </summary>
        /// <value></value>
        public HealthManagerEffectSubordinateStatisticsDTO HealthManagerEffectStatisticsData { get; set; }

        /// <summary>
        /// 乡镇数据统计列表
        /// </summary>
        /// <value></value>
        public IList<PlatformStatisticsDTO> TownStatisticsList { get; set; }

        /// <summary>
        /// 高血压患者数据统计
        /// </summary>
        /// <value></value>
        public PopulationControlStatisticsDTO HypertensionStatisticsData { get; set; }

        /// <summary>
        /// 2型糖尿病患者数据统计
        /// </summary>
        /// <value></value>
        public PopulationControlStatisticsDTO DiabetesStatisticsData { get; set; }

        /// <summary>
        /// 肺结核患者数据统计
        /// </summary>
        /// <value></value>
        public PopulationFinishStatisticsDTO PhthisisPatientStatisticsData { get; set; }

        /// <summary>
        /// 严重精神障碍患者数据统计
        /// </summary>
        /// <value></value>
        public PopulationFinishStatisticsDTO MentalPatientsStatisticsData { get; set; }

        /// <summary>
        /// 孕产妇数据统计
        /// </summary>
        /// <value></value>
        public PopulationFinishStatisticsDTO MaternalStatisticsData { get; set; }

        /// <summary>
        /// 老年人数据统计
        /// </summary>
        /// <value></value>
        public PopulationFinishStatisticsDTO OldPeopleStatisticsData { get; set; }

        /// <summary>
        /// 0-6岁儿童数据统计
        /// </summary>
        /// <value></value>
        public PopulationFinishStatisticsDTO ChildrenStatisticsData { get; set; }

        /// <summary>
        /// 版本号，如果版本号没变化，则不更新浏览器缓存数据
        /// </summary>
        /// <value></value>
        public string Version { get; set; }

        /// <summary>
        /// 当前县级统计平台名称
        /// </summary>
        /// <value></value>
        public string CountyName { get; set; }

        /// <summary>
        /// 当前县级Code
        /// </summary>
        /// <value></value>
        public string CountyCode { get; set; }
    }

    /// <summary>
    /// 乡镇数据统计实体
    /// </summary>
    public class TownStatisticsDTO
    {
        /// <summary>
        /// 乡镇code
        /// </summary>
        /// <value></value>
        public string TownCode { get; set; }

        /// <summary>
        /// 乡镇姓名
        /// </summary>
        /// <value></value>
        public string TownName { get; set; }

        /// <summary>
        /// 档案数量
        /// </summary>
        /// <value></value>
        public int ArchivesCount { get; set; }

        /// <summary>
        /// 签约数量
        /// </summary>
        /// <value></value>
        public int SignCount { get; set; }

        /// <summary>
        /// 今日建档数
        /// </summary>
        /// <value></value>
        public int TodayArchivesCount { get; set; }

        /// <summary>
        /// 签约率
        /// </summary>
        /// <value></value>
        public double SignPercentage { get; set; }
    }

    /// <summary>
    /// 乡镇档案统计实体
    /// </summary>
    public class ArchivesStatisticsDTO
    {
        /// <summary>
        /// 签约数量
        /// </summary>
        public int SignCount { get; set; }
        /// <summary>
        /// 医生数量
        /// </summary>
        public int DoctorCount { get; set; }
        /// <summary>
        /// 团队数量
        /// </summary>
        public int TeamCount { get; set; }
        /// <summary>
        /// 乡镇数量
        /// </summary>
        public int TownCount { get; set; }
        /// <summary>
        /// 机构数量
        /// </summary>
        public int OrganizationCount { get; set; }
        /// <summary>
        /// 档案数量
        /// </summary>
        public int ArchivesCount { get; set; }

        /// <summary>
        /// 完成服务数（服务包）
        /// </summary>
        /// <value></value>
        public int ServiceCompletedNum { get; set; }
        /// <summary>
        /// 合格档案数
        /// </summary>
        /// <value></value>
        public int QualifiedArchivesNum { get; set; }
        /// <summary>
        /// 签约居民档案合格数量
        /// </summary>
        /// <value></value>
        public int SignQualifiedArchivesNum { get; set; }
        /// <summary>
        /// 续约人数
        /// </summary>
        /// <value></value>
        public int RenewalsNum { get; set; }
        /// <summary>
        /// 重点人群签约人数
        /// </summary>
        /// <value></value>
        public int KeyPeopleSignNum { get; set; }
        /// <summary>
        /// 重点人群续约人数
        /// </summary>
        /// <value></value>
        public int KeyPeopleRenewalsNum { get; set; }
        /// <summary>
        /// 重点人群数量
        /// </summary>
        /// <value></value>
        public int KeyPeopleNum { get; set; }
        /// <summary>
        /// 有档案更新的最新日期的当天建档人数
        /// </summary>
        /// <value></value>
        public int ThatDayArchivesNum { get; set; }
        /// <summary>
        /// 有档案更新的最新日期
        /// </summary>
        /// <value></value>
        public DateTime ThatDay { get; set; }
    }

    
    /// <summary>
    /// 签约统计实体
    /// </summary>
    public class SignStatisticsBasicDTO
    {
        /// <summary>
        /// 签约覆盖率
        /// </summary>
        /// <value></value>
        public double SignCoverageRate { get; set; }

        /// <summary>
        /// 重点人群签约覆盖率
        /// </summary>
        /// <value></value>
        public double KeyPopulationSignCoverageRate { get; set; }

        /// <summary>
        /// 签约人群服务器完成率
        /// </summary>
        /// <value></value>
        public double SignPopulationServiceCompletionRate { get; set; }

        /// <summary>
        /// 签约居民电子健康档案合格率
        /// </summary>
        /// <value></value>
        public double SignPopulationEHRQualifiedRRate { get; set; }
    }

    /// <summary>
    /// 乡镇地图地图统计实体
    /// </summary>
    public class MapCommonStatisticsDTO : DataItemDTO
    {
        /// <summary>
        /// 描述
        /// </summary>
        /// <value></value>
        public string Desc { get; set; }

        /// <summary>
        /// 地图上区域对应db的code
        /// </summary>
        /// <value></value>
        public string ServerAreaCode { get; set; }

        /// <summary>
        /// 地图上区域的code
        /// </summary>
        /// <value></value>
        public string MapAreaCode { get; set; }
    }

}