using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum.VitalEnum;

namespace WingInterfaceLibrary.DTO.Vital
{
    public class DiagnosisDTO : BaseDTO
    {
        /// <summary>
        /// 编码
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 键
        /// </summary>
        /// <value></value>
        public string Key { get; set; }
        /// <summary>
        /// 居民代码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }
        /// <summary>
        /// 医生代码
        /// </summary>
        /// <value></value>
        public string DoctorCode { get; set; }

        /// <summary>
        /// 诊疗数据
        /// </summary>
        /// <value></value>
        public string DiagnosisData { get; set; }

		/// <summary>
		/// 诊疗时间
		/// </summary>
		/// <value></value>
        public DateTime DiagnosisTime { get; set; }

        /// <summary>
        /// 医生名称
        /// </summary>
        /// <value></value>
        public string DoctorName { get; set; }

        /// <summary>
        /// 居民名称
        /// </summary>
        /// <value></value>
        public string PatientName { get; set; }

        /// <summary>
        /// 居民性别
        /// </summary>
        /// <value></value>
        public GenderEnum PatientGender { get; set; }
        /// <summary>
        /// 电话
        /// </summary>
        /// <value></value>
        public string Phone { get; set; }

        /// <summary>
        /// 证件编号
        /// </summary>
        /// <value></value>
        public string CardNo { get; set; }

        /// <summary>
        /// 生日
        /// </summary>
        /// <value></value>
        public DateTime Birthday { get; set; }

        /// <summary>
        /// 居民地址
        /// </summary>
        /// <value></value>
        public string PatientAddress { get; set; }

        /// <summary>
        /// 人群标签
        /// </summary>
        /// <value></value>
        public List<string> CrowdLabels { get; set; }

        /// <summary>
        /// 标签名称
        /// </summary>
        /// <value></value>
        public List<string> LabelNames { get; set; }

        /// <summary>
        /// 机构名称
        /// </summary>
        /// <value></value>
        public string OrganizationName { get; set; }

        /// <summary>
        /// 客户端本地数据Id，用于数据分组
        /// </summary>
        /// <value></value>
        public string AppDataId { get; set; }

        /// <summary>
        /// 民族
        /// </summary>
        /// <value></value>
        public string National { get; set; }

        /// <summary>
        /// 体检号(健康体检专用)
        /// </summary>
        /// <value></value>
        public string PhysicalExamNumber { get; set; }

        /// <summary>
        /// 检查code
        /// </summary>
        /// <value></value>
        public string ExamCode { get; set; }

    }

    public class DiagnosisAggregationRecord
    {
        /// <summary>
        /// 居民代码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }
        /// <summary>
        /// 医生代码
        /// </summary>
        /// <value></value>
        public string DoctorCode { get; set; }

        /// <summary>
        /// 医生名称
        /// </summary>
        /// <value></value>
        public string DoctorName { get; set; }

        /// <summary>
        /// 居民名称
        /// </summary>
        /// <value></value>
        public string PatientName { get; set; }

        /// <summary>
        /// 居民性别
        /// </summary>
        /// <value></value>
        public GenderEnum PatientGender { get; set; }
        /// <summary>
        /// 电话
        /// </summary>
        /// <value></value>
        public string Phone { get; set; }

        /// <summary>
        /// 证件编号
        /// </summary>
        /// <value></value>
        public string CardNo { get; set; }

        /// <summary>
        /// 生日
        /// </summary>
        /// <value></value>
        public DateTime Birthday { get; set; }

        /// <summary>
        /// 居民地址
        /// </summary>
        /// <value></value>
        public string PatientAddress { get; set; }

        /// <summary>
        /// 人群标签
        /// </summary>
        /// <value></value>
        public List<string> CrowdLabels { get; set; }

        /// <summary>
        /// 机构名称
        /// </summary>
        /// <value></value>
        public string OrganizationName { get; set; }

        /// <summary>
        /// 客户端本地数据Id，用于数据分组
        /// </summary>
        /// <value></value>
        public string AppDataId { get; set; }

        /// <summary>
		/// 诊疗时间（最新时间）
		/// </summary>
		/// <value></value>
        public DateTime DiagnosisTime { get; set; }

        /// <summary>
		/// 更新时间
		/// </summary>
		/// <value></value>
        public DateTime UpdateTime { get; set; }

        /// <summary>
		/// 注册时间
		/// </summary>
		/// <value></value>
        public DateTime RegistTime { get; set; }

        /// <summary>
        /// 聚合后的诊疗数据
        /// </summary>
        /// <value></value>
        public List<DiagnosisAggregationData> DiagnosisAggregationData { get; set; }

        /// <summary>
        /// 民族
        /// </summary>
        /// <value></value>
        public string National { get; set; }
    }

    public class DiagnosisAggregationData
    {
        /// <summary>
        /// 键
        /// </summary>
        /// <value></value>
        public string Key { get; set; }

        /// <summary>
        /// 诊疗数据
        /// </summary>
        /// <value></value>
        public string DiagnosisData { get; set; }
    }
}