using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum.VitalEnum;

namespace WingInterfaceLibrary.DTO.Vital
{
    /// <summary>
    /// 体检数据
    /// </summary>
    public class ExamDTO : BaseDTO
    {
        /// <summary>
        /// 编码
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 键
        /// </summary>
        /// <value></value>
        public string Key { get; set; }
        /// <summary>
        /// 居民代码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }
        /// <summary>
        /// 已签约医生
        /// </summary>
        /// <value></value>
        public string ContractedDoctor { get; set; }
        /// <summary>
        /// 检查数据
        /// </summary>
        /// <value></value>
        public string ExamData { get; set; }
        /// <summary>
        /// 居民姓名
        /// </summary>
        /// <value></value>
        public string PatientName { get; set; }
        /// <summary>
        /// 证件号码
        /// </summary>
        /// <value></value>
        public string CardNo { get; set; }
        /// <summary>
        /// 居民性别
        /// </summary>
        /// <value></value>
        public GenderEnum PatientGender { get; set; }
        /// <summary>
        /// 居民地址
        /// </summary>
        /// <value></value>
        public string PatientAddress { get; set; }
        /// <summary>
        /// 生日
        /// </summary>
        /// <value></value>
        public DateTime Birthday { get; set; }
        /// <summary>
        /// 体检状态
        /// </summary>
        /// <value></value>
        public ExamStateEnum ExamState { get; set; }
        /// <summary>
        /// 检查时间
        /// </summary>
        /// <value></value>
        public DateTime ExamTime { get; set; }
        /// <summary>
        /// 模版编码
        /// </summary>
        /// <value></value>
        public string TemplateCode { get; set; }

        /// <summary>
        /// 体检医生
        /// </summary>
        /// <value></value>
        public string ExamDoctor { get; set; }

        /// <summary>
        /// 体检签名
        /// </summary>
        /// <value></value>
        public string ExamSign { get; set; }

        /// <summary>
        /// 批次号
        /// </summary>
        /// <value></value>
        public string BatchNumber { get; set; }

        /// <summary>
        /// 体检号(健康体检专用)
        /// </summary>
        /// <value></value>
        public string PhysicalExamNumber { get; set; }

        /// <summary>
        /// 创建团队
        /// </summary>
        /// <value></value>
        public string CreatedTeamCode { get; set; }

        /// <summary>
        /// 创建医生
        /// </summary>
        /// <value></value>
        public string CreatedDoctor { get; set; }

        /// <summary>
        /// 创建机构编码
        /// </summary>
        /// <value></value>
        public string CreatedOrgCode { get; set; }

        /// <summary>
        /// 更新时间
        /// </summary>
        /// <value></value>
        public DateTime UpdateTime { get; set; }

        /// <summary>
        /// 体检医生姓名
        /// </summary>
        /// <value></value>
        public string ExamDoctorName { get; set; }
    }

    /// <summary>
    /// 体检记录模版数据
    /// </summary>
    public class ExamRecordDataDTO
    {
        /// <summary>
        /// 键
        /// </summary>
        /// <value></value>
        public string Key { get; set; }

        /// <summary>
        /// 检查编码
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 检查数据
        /// </summary>
        /// <value></value>
        public string ExamData { get; set; }

        /// <summary>
        /// 模版编码
        /// </summary>
        /// <value></value>
        public string TemplateCode { get; set; }
    }

    /// <summary>
    /// 体检记录数据
    /// </summary>
    public class ExamRecordDTO
    {
        /// <summary>
        /// 批次号
        /// </summary>
        /// <value></value>
        public string BatchNumber { get; set; }

        /// <summary>
        /// 已签约医生
        /// </summary>
        /// <value></value>
        public string ContractedDoctor { get; set; }
        /// <summary>
        /// 居民姓名
        /// </summary>
        /// <value></value>
        public string PatientName { get; set; }
        /// <summary>
        /// 证件号码
        /// </summary>
        /// <value></value>
        public string CardNo { get; set; }
        /// <summary>
        /// 居民性别
        /// </summary>
        /// <value></value>
        public GenderEnum PatientGender { get; set; }
        /// <summary>
        /// 居民地址
        /// </summary>
        /// <value></value>
        public string PatientAddress { get; set; }
        /// <summary>
        /// 生日
        /// </summary>
        /// <value></value>
        public DateTime Birthday { get; set; }
        /// <summary>
        /// 体检状态
        /// </summary>
        /// <value></value>
        public ExamStateEnum ExamState { get; set; }
        /// <summary>
        /// 检查时间
        /// </summary>
        /// <value></value>
        public DateTime ExamTime { get; set; }
        /// <summary>
        /// 体检医生
        /// </summary>
        /// <value></value>
        public string ExamDoctor { get; set; }
        /// <summary>
        /// 体检数据
        /// </summary>
        /// <value></value>
        public List<ExamRecordDataDTO> ExamRecordDatas { get; set; }

        /// <summary>
        /// 更新时间
        /// </summary>
        /// <value></value>
        public DateTime UpdateTime { get; set; }
    }

    /// <summary>
    /// 体检记录结果实体
    /// </summary>
    public class ExamConclusionDTO : ExamDTO
    {
        /// <summary>
        /// 中医体质结果 Ping_Score:平和质;Qi_Score:气虚质;Qiyu_Score:气郁质;Shi_Score:湿热质;Tan_Score:痰湿质;Te_Score:特禀质;Xue_Score:血瘀质;Yang_Score:阳虚质;Yin_Score:阴虚质
        /// </summary>
        /// <value></value>
        public string TcmConclusion { get; set; }
    }

    /// <summary>
    /// 体检平铺结果实体
    /// </summary>
    public class ExamTileConslusionDTO : ExamConclusionDTO
    {
        /// <summary>
        /// 中医保健指导 1:情志调摄;2:饮食调养;3:起居调摄;4:运动保健;5:穴位保健;6:其他;
        /// </summary>
        /// <value></value>
        public List<string> HealthGuidance { get; set; } = new List<string>();
        
        /// <summary>
        /// 评分 0:可自理;1:可自理;2:轻度依赖;3:中度依赖;4:不能自理;
        /// </summary>
        /// <value></value>
        public string SelfCareScore { get; set; }

        /// <summary>
        /// 平和质结论
        /// </summary>
        /// <value></value>
        public string Ping_Score { get; set; }

        /// <summary>
        /// 气虚质结论
        /// </summary>
        /// <value></value>
        public string Qi_Score { get; set; }

        /// <summary>
        /// 阴虚质结论
        /// </summary>
        /// <value></value>
        public string Yin_Score { get; set; }

        /// <summary>
        /// 痰湿质结论
        /// </summary>
        /// <value></value>
        public string Tan_Score { get; set; }

        /// <summary>
        /// 湿热质结论
        /// </summary>
        /// <value></value>
        public string Shi_Score { get; set; }

        /// <summary>
        /// 阳虚质结论
        /// </summary>
        /// <value></value>
        public string Yang_Score { get; set; }

        /// <summary>
        /// 特禀质结论
        /// </summary>
        /// <value></value>
        public string Te_Score { get; set; }

        /// <summary>
        /// 气郁质结论
        /// </summary>
        /// <value></value>
        public string Qiyu_Score { get; set; }

        /// <summary>
        /// 血瘀质结论
        /// </summary>
        /// <value></value>
        public string Xue_Score { get; set; }

        /// <summary>
        /// Question
        /// </summary>
        /// <value></value>
        public string Question1 { get; set; }

        /// <summary>
        /// Question
        /// </summary>
        /// <value></value>
        public string Question2 { get; set; }

        /// <summary>
        /// Question
        /// </summary>
        /// <value></value>
        public string Question3 { get; set; }

        /// <summary>
        /// Question
        /// </summary>
        /// <value></value>
        public string Question4 { get; set; }

        /// <summary>
        /// Question
        /// </summary>
        /// <value></value>
        public string Question5 { get; set; }

        /// <summary>
        /// Question
        /// </summary>
        /// <value></value>
        public string Question6 { get; set; }

        /// <summary>
        /// Question
        /// </summary>
        /// <value></value>
        public string Question7 { get; set; }

        /// <summary>
        /// Question
        /// </summary>
        /// <value></value>
        public string Question8 { get; set; }

        /// <summary>
        /// Question
        /// </summary>
        /// <value></value>
        public string Question9 { get; set; }

        /// <summary>
        /// Question
        /// </summary>
        /// <value></value>
        public string Question10 { get; set; }

        /// <summary>
        /// Question
        /// </summary>
        /// <value></value>
        public string Question11 { get; set; }

        /// <summary>
        /// Question
        /// </summary>
        /// <value></value>
        public string Question12 { get; set; }

        /// <summary>
        /// Question
        /// </summary>
        /// <value></value>
        public string Question13 { get; set; }

        /// <summary>
        /// Question
        /// </summary>
        /// <value></value>
        public string Question14 { get; set; }

        /// <summary>
        /// Question
        /// </summary>
        /// <value></value>
        public string Question15 { get; set; }

        /// <summary>
        /// Question
        /// </summary>
        /// <value></value>
        public string Question16 { get; set; }

        /// <summary>
        /// Question
        /// </summary>
        /// <value></value>
        public string Question17 { get; set; }

        /// <summary>
        /// Question
        /// </summary>
        /// <value></value>
        public string Question18 { get; set; }

        /// <summary>
        /// Question
        /// </summary>
        /// <value></value>
        public string Question19 { get; set; }

        /// <summary>
        /// Question
        /// </summary>
        /// <value></value>
        public string Question20 { get; set; }

        /// <summary>
        /// Question
        /// </summary>
        /// <value></value>
        public string Question21 { get; set; }

        /// <summary>
        /// Question
        /// </summary>
        /// <value></value>
        public string Question22 { get; set; }

        /// <summary>
        /// Question
        /// </summary>
        /// <value></value>
        public string Question23 { get; set; }

        /// <summary>
        /// Question
        /// </summary>
        /// <value></value>
        public string Question24 { get; set; }

        /// <summary>
        /// Question
        /// </summary>
        /// <value></value>
        public string Question25 { get; set; }

        /// <summary>
        /// Question
        /// </summary>
        /// <value></value>
        public string Question26 { get; set; }

        /// <summary>
        /// Question
        /// </summary>
        /// <value></value>
        public string Question27 { get; set; }

        /// <summary>
        /// Question
        /// </summary>
        /// <value></value>
        public string Question28 { get; set; }

        /// <summary>
        /// Question
        /// </summary>
        /// <value></value>
        public string Question29 { get; set; }

        /// <summary>
        /// Question
        /// </summary>
        /// <value></value>
        public string Question30 { get; set; }

        /// <summary>
        /// Question
        /// </summary>
        /// <value></value>
        public string Question31 { get; set; }

        /// <summary>
        /// Question
        /// </summary>
        /// <value></value>
        public string Question32 { get; set; }

        /// <summary>
        /// Question
        /// </summary>
        /// <value></value>
        public string Question33 { get; set; }
    }
}