using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum.VitalEnum;

namespace WingInterfaceLibrary.DTO.Vital
{
    public class FollowUpDTO : BaseDTO
    {
        /// <summary>
        /// 编码
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 键
        /// </summary>
        /// <value></value>
        public string Key { get; set; }
        /// <summary>
        /// 居民代码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }
        /// <summary>
        /// 已签约医生编码
        /// </summary>
        /// <value></value>
        public string ContractedDoctorCode { get; set; }
        /// <summary>
        /// 已签约医生
        /// </summary>
        /// <value></value>
        public string ContractedDoctor { get; set; }
        /// <summary>
        /// 跟进更新数据
        /// </summary>
        /// <value></value>
        public string FollowUpData { get; set; }
        /// <summary>
        /// 居民姓名
        /// </summary>
        /// <value></value>
        public string PatientName { get; set; }
        /// <summary>
        /// 证件号码
        /// </summary>
        /// <value></value>
        public string CardNo { get; set; }
        /// <summary>
        /// 居民性别
        /// </summary>
        /// <value></value>
        public GenderEnum PatientGender { get; set; }
        /// <summary>
        /// 居民地址
        /// </summary>
        /// <value></value>
        public string PatientAddress { get; set; }
        /// <summary>
        /// 生日
        /// </summary>
        /// <value></value>
        public DateTime Birthday { get; set; }
        /// <summary>
        /// 随访状态
        /// </summary>
        /// <value></value>
        public FollowUpStateEnum FollowUpState { get; set; }
        /// <summary>
        /// 模版编码
        /// </summary>
        /// <value></value>
        public string TemplateCode { get; set; }
        /// <summary>
        /// 本次随访时间
        /// </summary>
        /// <value></value>
        public DateTime? FollowUpTime { get; set; } = null;
        /// <summary>
        /// 下次随访时间
        /// </summary>
        /// <value></value>
        public DateTime? NextFollowUpTime { get; set; } = null;
        /// <summary>
        /// 随访方式
        /// </summary>
        /// <value></value>
        public FollowUpModeEnum? FollowUpMode { get; set; } = null;

        /// <summary>
        /// 随访照片
        /// </summary>
        /// <value></value>
        public List<string> FollowUpPhotos { get; set; }

        /// <summary>
        /// 体检医生编码
        /// </summary>
        /// <value></value>
        public string FollowUpDoctorCode { get; set; }

        /// <summary>
        /// 体检医生
        /// </summary>
        /// <value></value>
        public string FollowUpDoctor { get; set; }

        /// <summary>
        /// 体检号(健康体检专用)
        /// </summary>
        /// <value></value>
        public string PhysicalExamNumber { get; set; }
    }

    /// <summary>
    /// 随访记录模版数据
    /// </summary>
    public class FollowUpRecordDataDTO
    {
        /// <summary>
        /// 键
        /// </summary>
        /// <value></value>
        public string Key { get; set; }

        /// <summary>
        /// 随访编码
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 随访数据
        /// </summary>
        /// <value></value>
        public string FollowUpData { get; set; }

        /// <summary>
        /// 模版编码
        /// </summary>
        /// <value></value>
        public string TemplateCode { get; set; }

        /// <summary>
        /// 本次随访时间
        /// </summary>
        /// <value></value>
        public DateTime? FollowUpTime { get; set; } = null;

        /// <summary>
        /// 下次随访时间
        /// </summary>
        /// <value></value>
        public DateTime? NextFollowUpTime { get; set; } = null;

        /// <summary>
        /// 随访方式
        /// </summary>
        /// <value></value>
        public FollowUpModeEnum? FollowUpMode { get; set; } = null;

        /// <summary>
        /// 体检状态
        /// </summary>
        /// <value></value>
        public FollowUpStateEnum FollowUpState { get; set; }

        /// <summary>
        /// 随访医生
        /// </summary>
        /// <value></value>
        public string FollowUpDoctor { get; set; }
        /// <summary>
        /// 体检医生编码
        /// </summary>
        /// <value></value>
        public string FollowUpDoctorCode { get; set; }
        /// <summary>
        /// 随访照片
        /// </summary>
        /// <value></value>
        public List<string> FollowUpPhotos { get; set; }
        /// <summary>
        /// 随访医生签名
        /// </summary>
        /// <value></value>
        public string FollowUpDoctorSignature { get; set; }
    }

    /// <summary>
    /// 随访记录数据
    /// </summary>
    public class FollowUpRecordDTO
    {
        /// <summary>
        /// 已签约医生
        /// </summary>
        /// <value></value>
        public string ContractedDoctor { get; set; }
        /// <summary>
        /// 已签约医生编码
        /// </summary>
        /// <value></value>
        public string ContractedDoctorCode { get; set; }
        /// <summary>
        /// 居民姓名
        /// </summary>
        /// <value></value>
        public string PatientName { get; set; }
        /// <summary>
        /// 证件号码
        /// </summary>
        /// <value></value>
        public string CardNo { get; set; }
        /// <summary>
        /// 居民性别
        /// </summary>
        /// <value></value>
        public GenderEnum PatientGender { get; set; }
        /// <summary>
        /// 居民地址
        /// </summary>
        /// <value></value>
        public string PatientAddress { get; set; }
        /// <summary>
        /// 生日
        /// </summary>
        /// <value></value>
        public DateTime Birthday { get; set; }
        /// <summary>
        /// 随访数据
        /// </summary>
        /// <value></value>
        public List<FollowUpRecordDataDTO> FollowUpRecordDatas { get; set; }
    }
}