using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.DTO.Vital
{
    /// <summary>
    /// 健康体检预约信息
    /// </summary>
    public class HealthExamBookingDTO : BaseDTO
    {
        /// <summary>
        /// 体检记录编码
        /// </summary>
        public string Code { get; set; }

        /// <summary>
        /// 预约类型
        /// </summary>
        public BookingTypeEnum BookingType { get; set; }

        /// <summary>
        /// 体检名称
        /// </summary>
        public string Name { get; set; }

        /// <summary>
        /// 体检地点
        /// </summary>
        public string Location { get; set; }

        /// <summary>
        /// 体检开始日期
        /// </summary>
        /// <value></value>
        public DateTime StartDate { get; set; }

        /// <summary>
        /// 体检结束日期
        /// </summary>
        /// <value></value>
        public DateTime EndDate { get; set; }

        /// <summary>
        /// 体检对象
        /// </summary>
        /// <value></value>
        public string Subject { get; set; }

        /// <summary>
        /// 体检说明
        /// </summary>
        /// <value></value>
        public string Description { get; set; }

        /// <summary>
        /// 发起人编码
        /// </summary>
        /// <value></value>
        public string InitiatorCode { get; set; }

        /// <summary>
        /// 发起人机构编码
        /// </summary>
        /// <value></value>
        public string OrgCode { get; set; }

        /// <summary>
        /// 预约状态（待提交、已预约、已取消）
        /// </summary>
        /// <value></value>
        public BookingStatusEnum Status { get; set; }

        /// <summary>
        /// 体检人员集合
        /// </summary>
        /// <typeparam name="HealthExamPersonEntity"></typeparam>
        /// <returns></returns>
        public List<HealthExamPersonDTO> Persons { get; set; } = new List<HealthExamPersonDTO>();

        /// <summary>
        /// 检查项目
        /// </summary>
        /// <typeparam name="HealthExamPersonEntity"></typeparam>
        /// <returns></returns>
        public List<HealthExamItemDTO> ExamItems { get; set; } = new List<HealthExamItemDTO>();

        /// <summary>
        /// 分享地址
        /// </summary>
        public string ShareUrl { get; set; }
    }

    public class HealthExamPersonDTO
    {
        /// <summary>
        /// 姓名
        /// </summary>
        /// <value></value>
        public string Name { get; set; }

        /// <summary>
        /// 性别
        /// </summary>
        /// <value></value>
        public PatientGenderEnum Gender { get; set; }

        /// <summary>
        /// 证件号
        /// </summary>
        /// <value></value>
        public string IdentityCard { get; set; }

        /// <summary>
        /// 手机号
        /// </summary>
        /// <value></value>
        public string Phone { get; set; }
    }

    public class HealthExamItemDTO
    {
        /// <summary>
        /// 检查项目
        /// </summary>
        /// <value></value>
        public string Name { get; set; }

        /// <summary>
        /// 描述
        /// </summary>
        /// <value></value>
        public string Content { get; set; }

        /// <summary>
        /// 检查项目
        /// </summary>
        /// <value></value>
        public string Code { get; set; }
    }

    /// <summary>
    /// 检查标签实体
    /// </summary>
    public class HealthExamLabelDTO
    {
        /// <summary>
        /// 检查类型
        /// </summary>
        /// <value></value>
        public string Type { get; set; }

        /// <summary>
        /// 标签名
        /// </summary>
        /// <value></value>
        public string Title { get; set; }

        /// <summary>
        /// 标签编号
        /// </summary>
        /// <value></value>
        public string UniquedCode { get; set; }

        /// <summary>
        /// 是否有效
        /// </summary>
        /// <value></value>
        public bool Valid { get; set; }

        /// <summary>
        /// 使用检测编号
        /// </summary>
        /// <value></value>
        public bool ForceExamNumber { get; set; }
    }
}