using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Enum.VitalEnum;

namespace WingInterfaceLibrary.DTO.Vital
{
    /// <summary>
    /// 居民档案信息
    /// </summary>
    public class PatientDTO : BaseDTO
    {
        /// <summary>
        /// 编码
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 档案编号
        /// </summary>
        public string RecordNo { get; set; }

        /// <summary>
        /// 居民姓名
        /// </summary>
        /// <value></value>
        public string PatientName { get; set; }
        /// <summary>
        /// 电话
        /// </summary>
        /// <value></value>
        public string Phone { get; set; }

        /// <summary>
        /// 联系人姓名
        /// </summary>
        /// <value></value>
        public string EmergencyName { get; set; }

        /// <summary>
        /// 紧急联系人手机号
        /// </summary>
        public string EmergencyPhone { get; set; }

        /// <summary>
        /// 证件编号
        /// </summary>
        /// <value></value>
        public string CardNo { get; set; }

        /// <summary>
        /// 民族
        /// </summary>
        /// <value></value>
        public string Nationality { get; set; }

        /// <summary>
        /// 生日
        /// </summary>
        /// <value></value>
        public DateTime Birthday { get; set; }

        /// <summary>
        /// 人群标签
        /// </summary>
        /// <value></value>
        public List<string> CrowdLabels { get; set; }
        /// <summary>
        /// 卡片类型
        /// </summary>
        /// <value></value>
        public CardTypeEnum CardType { get; set; }

        /// <summary>
        /// 居民性别
        /// </summary>
        /// <value></value>
        public GenderEnum PatientGender { get; set; }

        /// <summary>
        /// 居民地址
        /// </summary>
        /// <value></value>
        public string PatientAddress { get; set; }

        /// <summary>
        /// 永久村/小区地址
        /// </summary>
        /// <value></value>
        public string PermanentResidenceAddress { get; set; }

        /// <summary>
        /// 团队区域代码
        /// </summary>
        /// <value></value>
        public string TeamRegionCode { get; set; }

        /// <summary>
        /// 建档人
        /// </summary>
        /// <value></value>
        public string CreatedDoctor { get; set; }

        /// <summary>
        /// 已签约医生
        /// </summary>
        /// <value></value>
        public string ContractedDoctor { get; set; }

        /// <summary>
        /// 人群分类名称（只用于显示不做编辑）
        /// </summary>
        public List<string> LabelNames { get; set; }

        /// <summary>
        /// 建档人姓名 
        /// </summary>
        /// <value></value>
        public string CreatedDoctorName { get; set; }

        /// <summary>
        /// 建档机构名称(实际是归档机构名称)
        /// </summary>
        /// <value></value>
        public string CreatedOrgName { get; set; }

        /// <summary>
        /// 建档团队名称(实际是归档团队名称)
        /// </summary>
        /// <value></value>
        public string CreatedTeamName { get; set; }

        /// <summary>
        /// 建档状态
        /// </summary>
        /// <value>0</value>
        public PatientStatusEnum Status { get; set; }

        /// <summary>
        /// 建档机构编码
        /// </summary>
        /// <value></value>
        public string CreatedOrgCode { get; set; }

        /// <summary>
        /// 建档团队编码
        /// </summary>
        /// <value></value>
        public string CreatedTeamCode { get; set; }

        /// <summary>
        /// 归属团队编码
        /// </summary>
        /// <value></value>
        public string CurrentTeamCode { get; set; }

        /// <summary>
        /// 归属机构编码
        /// </summary>
        /// <value></value>
        public string CurrentOrgCode { get; set; }

        /// <summary>
        /// 签约医生姓名
        /// </summary>
        public string ContractedDoctorName { get; set; }

        /// <summary>
        /// 合约状态
        /// </summary>
        /// <value></value>
        public ContractStateEnum ContractState { get; set; }

        /// <summary>
        /// 照片
        /// </summary>
        /// <value></value>
        public List<string> Photos { get; set; }

        /// <summary>
        /// 归档医生姓名
        /// </summary>
        /// <value></value>
        public string ArchivedDoctorName { get; set; }

        /// <summary>
        /// 服务开始时间
        /// </summary>
        /// <value></value>
        public DateTime ServiceStartDate { get; set; }  
        
        /// <summary>
        /// 服务结束时间
        /// </summary>
        /// <value></value>
        public DateTime ServiceEndDate { get; set; }
    }

    /// <summary>
    /// 居民档案统计信息
    /// </summary>
    public class PatientStatisticDTO
    {
        /// <summary>
        /// 建档总数
        /// </summary>
        /// <value></value>
        public int Count { get; set; }

        /// <summary>
        /// 当日建档数
        /// </summary>
        /// <value></value>
        public int TodayCount { get; set; }
    }

    /// <summary>
    /// 居民基本信息
    /// </summary>
    public class PatientBaseDTO
    {
        /// <summary>
        /// 是否识别成功
        /// </summary>
        /// <value></value>
        public bool IsSuccess { get; set; } = false;

        /// <summary>
        /// 是否识别成功
        /// </summary>
        /// <value></value>
        public FaceScanErrorTypeEnum FaceScanErrorType { get; set; }

        /// <summary>
        /// 错误信息
        /// </summary>
        /// <value></value>
        public string ErrorMessage { get; set; }

        /// <summary>
        /// 证件编号
        /// </summary>
        /// <value></value>
        public string CardNo { get; set; }

        /// <summary>
        /// 居民姓名
        /// </summary>
        /// <value></value>
        public string PatientName { get; set; }

        /// <summary>
        /// 民族
        /// </summary>
        /// <value></value>
        public string Nationality { get; set; }

        /// <summary>
        /// 生日
        /// </summary>
        /// <value></value>
        public DateTime Birthday { get; set; }

        /// <summary>
        /// 居民性别
        /// </summary>
        /// <value></value>
        public GenderEnum PatientGender { get; set; }

        /// <summary>
        /// 居民地址
        /// </summary>
        /// <value></value>
        public string PatientAddress { get; set; }

        /// <summary>
        /// 手机号
        /// </summary>
        /// <value></value>
        public string Phone { get; set; }

        /// <summary>
        /// 建档人
        /// </summary>
        /// <value></value>
        public string CreatedDoctor { get; set; }

        /// <summary>
        /// 建档人姓名 
        /// </summary>
        /// <value></value>
        public string CreatedDoctorName { get; set; }

        /// <summary>
        /// 建档机构编码
        /// </summary>
        /// <value></value>
        public string CreatedOrgCode { get; set; }

        /// <summary>
        /// 建档机构名称(实际是归档机构名称)
        /// </summary>
        /// <value></value>
        public string CreatedOrgName { get; set; }

        /// <summary>
        /// 归属机构编码
        /// </summary>
        /// <value></value>
        public string CurrentOrgCode { get; set; }

        /// <summary>
        /// 建档团队编码
        /// </summary>
        /// <value></value>
        public string CreatedTeamCode { get; set; }

        /// <summary>
        /// 建档团队名称(实际是归档团队名称)
        /// </summary>
        /// <value></value>
        public string CreatedTeamName { get; set; }

        /// <summary>
        /// 归属团队编码
        /// </summary>
        /// <value></value>
        public string CurrentTeamCode { get; set; }
    }

    /// <summary>
    /// 添人员搜索 响应
    /// </summary>
    public class SearchPersonsResult
    {
        /// <summary>
        /// 是否完成识别
        /// </summary>
        /// <value></value>
        public bool IsSearchSuccess { get; set; }

        /// <summary>
        /// 错误原因，当IsSearchSuccess为false时具体的失败原因
        /// </summary>
        /// <value></value>
        public string ErrMessage { get; set; }

        /// <summary>
        /// 是否识别到人员，当IsSearchSuccess为true时使用
        /// </summary>
        /// <value></value>
        public bool HasPerson { get; set; }

        /// <summary>
        /// 人员信息
        /// </summary>
        /// <value></value>
        public RecognitionPersonDTO PersonInfo { get; set; }

        /// <summary>
        /// 人脸ID
        /// </summary>
        /// <value></value>
        public List<RecognitionPersonDTO> Persons { get; set; }
    }

    /// <summary>
    /// 人员信息
    /// </summary>
    public class RecognitionPersonDTO
    {
        /// <summary>
        /// 人员ID
        /// </summary>
        /// <value></value>
        public string PersonId { get; set; }

        /// <summary>
        /// 人脸ID
        /// </summary>
        /// <value></value>
        public string FaceId { get; set; }

        /// <summary>
        /// 相似度，一般80分左右可适用大部分场景
        /// </summary>
        /// <value>80</value>
        public float Score { get; set; }
    }

    /// <summary>
    /// 识别结果
    /// </summary>
    public class RecognitionResult
    {
        /// <summary>
        /// 响应码
        /// </summary>
        /// <value></value>
        public IDCardRecognitionStatusEnum StatusCode { get; set; }

        /// <summary>
        /// 是否成功
        /// </summary>
        /// <value></value>
        public bool IsSuccess { get; set; }

        /// <summary>
        /// 识别结果
        /// </summary>
        /// <value></value>
        public IDCardInfoResult IDCardData { get; set; }
    }

    /// <summary>
    /// 身份证识别结果
    /// </summary>
    public class IDCardInfoResult
    {
        /// <summary>
        /// 姓名
        /// </summary>
        /// <value></value>
        public string Name { get; set; }

        /// <summary>
        /// 身份证号
        /// </summary>
        /// <value></value>
        public string IdCardNo { get; set; }

        /// <summary>
        /// 性别
        /// </summary>
        /// <value></value>
        public string Gender { get; set; }

        /// <summary>
        /// 民族
        /// </summary>
        /// <value></value>
        public string Nation { get; set; }

        /// <summary>
        /// 出生年月
        /// </summary>
        /// <value></value>
        public string BirthDay { get; set; }

        /// <summary>
        /// 地址
        /// </summary>
        /// <value></value>
        public string Address { get; set; }
    }

    /// <summary>
    /// 保存人员信息 请求
    /// </summary>
    public class SavePersonDTO
    {
        /// <summary>
        /// 是否成功
        /// </summary>
        /// <value></value>
        public bool Success { get; set; }

        /// <summary>
        /// 已绑定的证件号
        /// </summary>
        /// <value></value>
        public string BindCardNo { get; set; }

        /// <summary>
        /// 错误原因
        /// </summary>
        /// <value></value>
        public string ErrMessage { get; set; }
    }

    /// <summary>
    /// 删除人员信息 请求
    /// </summary>
    public class DeletePersonDTO
    {
        /// <summary>
        /// 是否成功
        /// </summary>
        /// <value></value>
        public bool Success { get; set; }

        /// <summary>
        /// 错误原因
        /// </summary>
        /// <value></value>
        public string ErrMessage { get; set; }
    }
}