using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.DTO.Vital
{
    /// <summary>
    /// 登记人员基本信息
    /// </summary>

    public class PersonInfoByFaceImageDTO : PersonInfoBaseDTO
    {

        /// <summary>
        /// 是否识别成功
        /// </summary>
        /// <value></value>
        public bool IsSuccess { get; set; } = false;

        /// <summary>
        /// 是否识别成功
        /// </summary>
        /// <value></value>
        public FaceScanErrorTypeEnum FaceScanErrorType { get; set; }

        /// <summary>
        /// 错误信息
        /// </summary>
        /// <value></value>
        public string ErrorMessage { get; set; }

    }


    /// <summary>
    /// 登记人员基本信息
    /// </summary>

    public class PersonInfoBaseDTO
    {

        /// <summary>
        /// 姓名
        /// </summary>
        /// <value></value>
        public string Name { get; set; }

        /// <summary>
        /// 照片
        /// </summary>
        /// <value></value>
        public string HeadImg { get; set; }

        /// <summary>
        /// 性别
        /// </summary>
        /// <value></value>
        public PatientGenderEnum Sex { get; set; }

        /// <summary>
        /// 年龄
        /// </summary>
        /// <value></value>
        public string Age { get; set; }

        /// <summary>
        /// 身份证号
        /// </summary>
        /// <value></value>
        public string CardID { get; set; }

        /// <summary>
        /// 备注
        /// </summary>
        /// <value></value>
        public string Remarks { get; set; }

        /// <summary>
        /// 登记人员code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }
        
        /// <summary>
        /// 机构
        /// </summary>
        /// <value></value>
        public string Organization { get; set; }

        /// <summary>
        /// 经纬度
        /// </summary>
        /// <value></value>
        public string Nautical { get; set; }

        /// <summary>
        /// 卫生机构
        /// </summary>
        /// <value></value>
        public string Government { get; set; }
    }

    /// <summary>
    /// 人员信息（含历史登记记录）
    /// </summary>
    public class PersonInfoFullDTO : PersonInfoBaseDTO
    {
        /// <summary>
        /// 历史登记状态
        /// </summary>
        /// <value></value>
        public List<PersonRegisterDTO> PersonRegisterRecordList { get; set; }

    }

    public class PersonRegisterDTO
    {
        /// <summary>
        /// 健康状态是否正常
        /// </summary>
        /// <value></value>
        public bool IsNormal { get; set; }

        /// <summary>
        /// 登记时间
        /// </summary>
        /// <value></value>
        public DateTime RegisterTime { get; set; }

        /// <summary>
        /// 机构
        /// </summary>
        /// <value></value>
        public string Organization { get; set; }

        /// <summary>
        /// 经纬度
        /// </summary>
        /// <value></value>
        public string Nautical { get; set; }
    }
}