using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Common;

namespace WingInterfaceLibrary.DTO.Vital
{
    /// <summary>
    /// 乡镇健康平台（八五一农产）
    /// </summary>
    public class TownHealthPlatformStatisticsDTO : BaseDTO
    {
        /// <summary>
        /// 签约统计数据
        /// </summary>
        /// <value></value>
        public SignStatisticsBasicDTO SignStatisticsData { get; set; }

        /// <summary>
        /// 人群分类占比统计
        /// </summary>
        /// <value></value>
        public IList<DataItemDTO> PopulationClassificationPercentageStatisticsData { get; set; }

        /// <summary>
        /// 乡镇档案统计数据（包括签约量、医生数量、档案数量）
        /// </summary>
        /// <value></value>
        public ArchivesStatisticsDTO VillageArchivesStatisticsData { get; set; }

        /// <summary>
        /// 人群分类数量统计（柱状图，村级）
        /// </summary>
        /// <value></value>
        public IList<DataItemDTO> VillagePopulationClassificationStatisticsData { get; set; }

        /// <summary>
        /// 健康管理效果统计数据
        /// </summary>
        /// <value></value>
        public HealthManagerEffectSubordinateStatisticsDTO HealthManagerEffectSubordinateStatisticsData { get; set; }

        /// <summary>
        /// 村级数据统计列表
        /// </summary>
        /// <value></value>
        public IList<PlatformStatisticsDTO> VillageStatisticsList { get; set; }

        /// <summary>
        /// 高血压患者数据统计
        /// </summary>
        /// <value></value>
        public PopulationControlStatisticsDTO HypertensionStatisticsData { get; set; }

        /// <summary>
        /// 2型糖尿病患者数据统计
        /// </summary>
        /// <value></value>
        public PopulationControlStatisticsDTO DiabetesStatisticsData { get; set; }

        /// <summary>
        /// 肺结核患者数据统计
        /// </summary>
        /// <value></value>
        public PopulationFinishStatisticsDTO PhthisisPatientStatisticsData{ get; set; }

        /// <summary>
        /// 严重精神障碍患者数据统计
        /// </summary>
        /// <value></value>
        public PopulationFinishStatisticsDTO MentalPatientsStatisticsData { get; set; }

        /// <summary>
        /// 孕产妇数据统计
        /// </summary>
        /// <value></value>
        public PopulationFinishStatisticsDTO MaternalStatisticsData { get; set; }

        /// <summary>
        /// 老年人数据统计
        /// </summary>
        /// <value></value>
        public PopulationFinishStatisticsDTO OldPeopleStatisticsData { get; set; }

        /// <summary>
        /// 0-6岁儿童数据统计
        /// </summary>
        /// <value></value>
        public PopulationFinishStatisticsDTO ChildrenStatisticsData { get; set; }

        /// <summary>
        /// 版本号，如果版本号没变化，则不更新浏览器缓存数据
        /// </summary>
        /// <value></value>
        public string Version { get; set; }

        /// <summary>
        /// 当前乡镇统计平台名称
        /// </summary>
        /// <value></value>
        public string TownName { get; set; }

        /// <summary>
        /// 当前乡镇Code
        /// </summary>
        /// <value></value>
        public string TownCode { get; set; }

        /// <summary>
        /// 父级县级Code
        /// </summary>
        /// <value></value>
        public string CountyCode { get; set; }
    }

    /// <summary>
    /// 健康管理效果下级统计实体
    /// </summary>
    public class HealthManagerEffectSubordinateStatisticsDTO
    {
        /// <summary>
        /// 互联网+签约率
        /// </summary>
        /// <value></value>
        public double InternetPlusSignRate { get; set; }

        /// <summary>
        /// 签约居民续约率
        /// </summary>
        /// <value></value>
        public double SignedResidentRenewalRate { get; set; }

        /// <summary>
        /// 重点人群续约率
        /// </summary>
        /// <value></value>
        public double KeepPeopleRenewalRate { get; set; }

        /// <summary>
        /// 重点人群服务完成率
        /// </summary>
        /// <value></value>
        public double ServiceCompletedRate { get; set; }

        /// <summary>
        /// 签约居民首诊率
        /// </summary>
        /// <value></value>
        public double SignedResidentFirstConsultationRate { get; set; }

        /// <summary>
        /// 签约居民有效转诊率
        /// </summary>
        /// <value></value>
        public double SignedResidentEffectiveReferralRate { get; set; }

    }
}