using System;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Common;

namespace WingInterfaceLibrary.DTO.Vital
{
    /// <summary>
    /// 村级健康平台( 双胜村乙级卫生室)
    /// </summary>
    public class VillageHealthPlatformStatisticsDTO : BaseDTO
    {
        /// <summary>
        /// 签约统计数据
        /// </summary>
        /// <value></value>
        public SignStatisticsBasicDTO SignStatisticsData { get; set; }

        /// <summary>
        /// 人群分类占比统计
        /// </summary>
        /// <value></value>
        public IList<DataItemDTO> PopulationClassificationPercentageStatisticsData { get; set; }

        /// <summary>
        /// 乡镇档案统计数据（包括签约量、医生数量、档案数量）
        /// </summary>
        /// <value></value>
        public ArchivesStatisticsDTO ArchivesStatisticsData { get; set; }

        /// <summary>
        /// 人群分类数量统计（柱状图，村级）
        /// </summary>
        /// <value></value>
        public IList<DataItemDTO> PopulationClassificationStatisticsData { get; set; }

        /// <summary>
        /// 健康管理效果统计数据
        /// </summary>
        /// <value></value>
        public HealthManagerEffectSubordinateStatisticsDTO HealthManagerEffectSubordinateStatisticsData { get; set; }

        /// <summary>
        /// 村级数据统计列表
        /// </summary>
        /// <value></value>
        public IList<PlatformStatisticsDTO> VillageStatisticsList { get; set; }

        /// <summary>
        /// 高血压患者数据统计
        /// </summary>
        /// <value></value>
        public PopulationControlStatisticsDTO HypertensionStatisticsData { get; set; }

        /// <summary>
        /// 2型糖尿病患者数据统计
        /// </summary>
        /// <value></value>
        public PopulationControlStatisticsDTO DiabetesStatisticsData { get; set; }

        /// <summary>
        /// 肺结核患者数据统计
        /// </summary>
        /// <value></value>
        public PopulationFinishStatisticsDTO PhthisisPatientStatisticsData { get; set; }

        /// <summary>
        /// 严重精神障碍患者数据统计
        /// </summary>
        /// <value></value>
        public PopulationFinishStatisticsDTO MentalPatientsStatisticsData { get; set; }

        /// <summary>
        /// 孕产妇数据统计
        /// </summary>
        /// <value></value>
        public PopulationFinishStatisticsDTO MaternalStatisticsData { get; set; }

        /// <summary>
        /// 老年人数据统计
        /// </summary>
        /// <value></value>
        public PopulationFinishStatisticsDTO OldPeopleStatisticsData { get; set; }

        /// <summary>
        /// 0-6岁儿童数据统计
        /// </summary>
        /// <value></value>
        public PopulationFinishStatisticsDTO ChildrenStatisticsData { get; set; }

        /// <summary>
        /// 版本号，如果版本号没变化，则不更新浏览器缓存数据
        /// </summary>
        /// <value></value>
        public string Version { get; set; }

        /// <summary>
        /// 当前村级统计平台名称
        /// </summary>
        /// <value></value>
        public string VillageName { get; set; }

        /// <summary>
        /// 当前村级Code
        /// </summary>
        /// <value></value>
        public string VillageCode { get; set; }

        /// <summary>
        /// 父级乡镇Code
        /// </summary>
        /// <value></value>
        public string TownCode { get; set; }

        /// <summary>
        /// 父级乡镇名称
        /// </summary>
        /// <value></value>
        public string TownName { get; set; }
    }

    /// <summary>
    /// 平台数据统计实体
    /// </summary>
    public class PlatformStatisticsDTO
    {
        /// <summary>
        /// code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 姓名
        /// </summary>
        /// <value></value>
        public string Name { get; set; }

        /// <summary>
        /// 档案数量
        /// </summary>
        /// <value></value>
        public int ArchivesCount { get; set; }

        /// <summary>
        /// 签约数量
        /// </summary>
        /// <value></value>
        public int SignCount { get; set; }       

        /// <summary>
        /// 有档案更新的最新日期
        /// </summary>
        /// <value></value>
        public DateTime ThatDay { get; set; }

        /// <summary>
        /// 今日建档数
        /// </summary>
        /// <value></value>
        public int TodayArchivesCount { get; set; }

        /// <summary>
        /// 签约率
        /// </summary>
        /// <value></value>
        public double SignPercentage { get; set; }

        /// <summary>
        /// 服务率
        /// </summary>
        /// <value></value>
        public double ServiceRate { get; set; }
    }

    /// <summary>
    /// 人群基础数据统计实体
    /// </summary>
    public class PopulationBasicStatisticsDTO
    {
        /// <summary>
        /// 人群分类名称
        /// </summary>
        /// <value></value>
        public string PopulationName { get; set; }

        /// <summary>
        /// 人群分类Key
        /// </summary>
        /// <value></value>
        public string PopulationKey { get; set; }

        /// <summary>
        /// 人群数量
        /// </summary>
        /// <value></value>
        public int Quantity { get; set; }

        /// <summary>
        /// 人群数量
        /// </summary>
        /// <value></value>
        public int QualifiedNum { get; set; }
    }

    /// <summary>
    /// 人群控制率数据统计实体
    /// </summary>
    public class PopulationControlStatisticsDTO : PopulationBasicStatisticsDTO
    {
        /// <summary>
        /// 控制率
        /// </summary>
        /// <value></value>
        public double ControlRate { get; set; }
    }

    /// <summary>
    /// 人群服务完成率数据统计实体
    /// </summary>
    public class PopulationFinishStatisticsDTO : PopulationBasicStatisticsDTO
    {
        /// <summary>
        /// 服务完成率
        /// </summary>
        /// <value></value>
        public double FinishRate { get; set; }
    }
}