namespace WingInterfaceLibrary.Enum.MeasureEnum
{
    public enum DefinitionPriorityEnum
    {
        Notset,

        /// <summary>
        /// Indicate a parameter is redefined or new value is set as default in this level.
        /// </summary>
        /// <remarks>FilePath: e.g., etc\measurement\</remarks>
        Root,

        /// <summary>
        /// Indicate a parameter is defined in SytemSetting
        /// </summary>
        Global,

        GlobalCategory,

        /// <summary>
        /// Indicate a parameter is redefined or new value is set as default in this level.
        /// </summary>
        /// <remarks>FilePath: e.g., etc\measurement\category1\app1</remarks>
        GlobalApp,

        /// <summary>
        /// 
        /// </summary>
        /// <remarks>FilePath: e.g., factoryDef\measurement\category1.app1</remarks>
        FactoryDefault,


        OemDefault,

        /// <summary>
        /// Highest priority
        /// </summary>
        /// <remarks>FilePath: e.g., userdefined\measurement\category1.app1</remarks>
        UserDefined,
    }
    internal enum MeasureTypeUnitEnum
    {
        None,
        AreaUnit,
        VelocityUnit,
        TimeUnit,
    };

    public enum UnExecuteAction
    {
        None = 0,
        OneStep = 1,
        AllSteps = 2,
        GeometryOnly = 3,
    }

    public class PriorityPair
    {
        public DefinitionPriorityEnum Target { get; private set; }

        public DefinitionPriorityEnum? Base { get; private set; }

        public PriorityPair(DefinitionPriorityEnum target = DefinitionPriorityEnum.UserDefined,
            DefinitionPriorityEnum basePriority = DefinitionPriorityEnum.Root)
        {
            Target = target;
            Base = basePriority;
        }

        public DefinitionPriorityEnum Retrieve(DefinitionPriorityEnum priority)
        {
            if (Base == null)
            {
                return Target;
            }
            else
            {
                return priority.IsHigherPriority(Base.Value) ? Target : priority;
            }
        }
    }

    internal static class DefinitionPriorityEnumExtension
    {
        public static bool IsHigherPriority(this DefinitionPriorityEnum priority, DefinitionPriorityEnum other)
        {
            return (int) priority > (int) other;
        }
    }

    public enum TracePeakType
    {
        Normal = 0,
        OnePeak = 1,
        TwoPeaks = 2,
    }

    public enum LineWeightType
    {
        NormalWeight,
        Thin
    }

   
}