﻿using System.Security.AccessControl;
using System.Collections.Generic;
using System.Threading.Tasks;
using WingInterfaceLibrary.DB.Request;
using WingInterfaceLibrary.DTO.Management;
using WingInterfaceLibrary.Result;
using WingInterfaceLibrary.Request.Management;
using WingInterfaceLibrary.DTO.ReportTemplate;
using WingInterfaceLibrary.DTO.User;
using WingInterfaceLibrary.Result.Management;
using WingInterfaceLibrary.DTO.CMSStatistic;
using WingInterfaceLibrary.DTO.GradingProtection;
using System;

namespace WingInterfaceLibrary.Interface.DBInterface
{
    public partial interface IAdminDBService
    {
        Task<string> InsertAdminAsync(CreateAdminDBRequest request);
        Task<AdminInfoDTO> FindAdminByNameAsync(string name);
        /// <summary>模糊查询管理员集合</summary>
        /// <param name="name"></param>
        /// <returns></returns>
        Task<List<AdminInfoDTO>> FindAdminsByNameAsync(string name);
        Task<AdminInfoDTO> FindAdminByCodeAsync(string code);
        Task<PageResult<AdminInfoDTO>> FindAdminPagesAsync(GetAdminPagesRequest request);
        Task<bool> DeleteAdminByCodeAsync(string code);
        Task<bool> UpdateAdminByCodeAsync(string code, AdminInfoDTO data, string extensionData);
        Task<List<AdminInfoDTO>> FindAdminListByRoleCodeAsync(string roleCode);

        Task<List<AdminInfoDTO>> FindAdminListByRoleCodesAsync(List<string> roleCodes);

        /// <summary>
        /// 根据管理员编码列表获取所有管理员信息
        /// </summary>
        /// <param name="adminCodes">管理员编码列表</param>
        /// <returns>是否成功</returns>  
        Task<List<AdminInfoDTO>> FindAdminListByAdminCodesAsync(List<string> adminCodes);

        /// <summary>
        /// 修改管理员密码
        /// </summary>
        /// <param name="code">管理员code</param>
        /// <param name="entity">管理员实体</param>
        /// <returns></returns>
        Task<bool> ModifyAdminPasswordAsync(string code, AdminInfoDTO entity);
        
        /// <summary>
        /// 更新管理员锁定次数
        /// </summary>
        /// <param name="code"></param>
        /// <param name="loginLockInfoDTO"></param>
        /// <returns></returns>
        Task<bool> UpdateAdminLoginLockInfoAsync(string code, LoginLockInfoDTO  loginLockInfoDTO);

        /// <summary>
        /// 查询CMS Json模板接口
        /// </summary>
        /// <param name="request">token请求实体</param>
        /// <returns></returns>
        Task<CMSTemplateResult> FindCMSTemplateDetailDBAsync(FindCMSTemplateDetailDBRequest request);

        /// <summary>
        /// 查询CMS Json模板接口
        /// </summary>
        /// <param name="userCode">用户编码</param>
        /// <returns></returns>
        Task<CMSTemplateResult> GetCMSTemplateDetailByUserCodeAsync(string userCode);

        /// <summary>
        /// 查询CMS统计接口
        /// </summary>
        /// <param name="request">token请求实体</param>
        /// <returns></returns>
        Task<IList<CMSStatisticRecordDTO>> FindCMSStatisticRecordsDBAsync(FindCMSStatisticDBRequest request);

        /// <summary>
        /// 查找CMS模版分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<CMSTemplateResult>> FindCMSTemplatePageDBAsync(FindCMSTemplatePageDBRequest request);

        /// <summary>
        /// 查找等保信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<GradingProtectionConfigDTO>> FindPageGradingProtectionConfigPageDBAsync(FindGradingProtectionConfigByPageRequest request);

        /// <summary>
        /// 更新选定配置
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateGradingProtectionConfigEnableAsync(UpdateGradingProtectionConfigEnableRequest request);

        /// <summary>
        /// 检查管理员密码是否正确
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> CheckAdminPasswordAsync(CheckAdminPasswordRequest request);

        /// <summary>
        /// 查找等保配置
        /// </summary>
        /// <param name="moduleCode">配置编码</param>
        /// <param name="name">配置名称</param>
        /// <returns></returns>
        Task<string> FindGradingProtectionConfigAsync(string moduleCode, string name);

        /// <summary>
        /// 查找等保配置列表
        /// </summary>
        /// <param name="moduleCodes">配置编码</param>
        /// <returns></returns>
        Task<List<GradingProtectionConfigDTO>> FindGradingProtectionConfigListAsync(List<string> moduleCodes);
        
        /// <summary>
        /// 批量新增管理员数据
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>是否成功</returns>
        Task<bool> BatchInsertAdminDataDBAsync(BatchInsertAdminRequest request);

        /// <summary>
        /// 更新密码
        /// </summary>
        /// <param name="code"></param>
        /// <param name="data"></param>
        /// <returns></returns>
        Task<bool> UpdateAdminPasswordAsync(string code, string password, IList<string> pwdRecords = null, DateTime? updateTime = null);
    }
}
