using System.Threading.Tasks;
using WingInterfaceLibrary.DB.Request;
using WingInterfaceLibrary.Result.Record;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Record;
using WingInterfaceLibrary.Request.Examine;
using WingInterfaceLibrary.Result;
using WingInterfaceLibrary.Request.DBRequest;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.DTO.Report;
using WingInterfaceLibrary.DTO.ReportTemplate;
using WingInterfaceLibrary.Request.Management;
using WingInterfaceLibrary.Request.Report;
using WingInterfaceLibrary.DTO.AdminStatistic;

namespace WingInterfaceLibrary.Interface.DBInterface
{
    /// <summary>
    /// 管理端统计服务
    /// </summary>
    public interface IAdminStatisticDBService
    {
        /// <summary>
        /// 查询管理端统计配置集合
        /// </summary>
        /// <returns></returns>
        Task<IList<AdminStatisticDTO>> GetAdminStatisticAsync(GetAdminStatisticDBRequest request);
        
        /// <summary>
        /// 查询管理员统计结果集合
        /// </summary>
        /// <returns></returns>
        Task<IList<AdminStatisticRecordDTO>> GetAdminStatisticRecordsAsync(GetAdminStatisticRecordsDBRequest request);

        /// <summary>
        /// 查询已过期的统计数据
        /// </summary>
        /// <returns></returns>
        Task<IList<AdminStatisticRecordDTO>> GetExpiredRecordsAsync(GetExpiredRecordsDBRequest request);

        /// <summary>
        /// 删除管理员的统计数据
        /// </summary>
        /// <returns></returns>
        Task<bool> DeleteAdminStatisticRecordAsync(DeleteAdminStatisticRecordDBRequest request);

        /// <summary>
        /// 保存统计结果
        /// </summary>
        /// <returns></returns>
        Task<bool> SaveAdminStatisticRecordAsync(SaveAdminStatisticRecordDBRequest request);

        /// <summary>
        /// 认证用户
        /// </summary>
        /// <returns></returns>
        Task<StatisticInfoDTO> GetUserActivateInfoStatisticAsync(GetUserActivateInfoStatisticDBRequest request);

        /// <summary>
        /// 我的待办
        /// </summary>
        /// <returns></returns>
        Task<StatisticInfoDTO> GetUserActivateLogStatisticAsync(GetUserActivateLogStatisticDBRequest request);

        /// <summary>
        /// 认证角色
        /// </summary>
        /// <returns></returns>
        Task<StatisticInfoDTO> GetUserRoleStatisticAsync(GetUserRoleStatisticDBRequest request);

        /// <summary>
        /// 机构分布
        /// </summary>
        /// <returns></returns>
        Task<StatisticInfoDTO> GetOrganizationStatisticAsync(GetOrganizationStatisticDBRequest request);

        /// <summary>
        /// 机型分布，设备型号分布
        /// </summary>
        /// <returns></returns>
        Task<StatisticInfoDTO> GetDeviceStatisticAsync(GetDeviceStatisticDBRequest request);
    }
}