using System.Collections.Generic;
using System.Threading.Tasks;
using WingInterfaceLibrary.DB.Request;
using WingInterfaceLibrary.DTO.Consultation;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.LiveConsultation.Consultation;
using WingInterfaceLibrary.Request.DBRequest;
using WingInterfaceLibrary.Result;
using WingInterfaceLibrary.DTO.DataCenter;
using System;
using WingInterfaceLibrary.Request.DBCopy;

namespace WingInterfaceLibrary.Interface.DBInterface
{
    /// <summary>
    /// 会诊记录DB接口
    /// </summary>
    public interface IConsultationRecordDBService
    {
        /// <summary>
        /// 新增会诊记录
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> InsertConsultationRecordAsync(CreateConsultationRecordDBRequest request);
        /// <summary>
        /// 查询会诊记录
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ConsultationDetailDTO> FindConsultationRecordByCodeAsync(ConsultationRecordCodeDBRequest request);
        /// <summary>
        /// 批量查询查询会诊记录
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<ConsultationDetailDTO>> FindConsultationRecordByCodesAsync(ConsultationRecordCodesDBRequest request);
        /// <summary>
        /// 查询会诊记录分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<ConsultationDetailDTO>> FindConsultationRecordPagesAsync(GetConsultationRecordPagesDBRequest request);
        /// <summary>
        /// 会诊大列表导出
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes></errorCodes>
        Task<ExportConsultationDataResult> ExportConsultationsDBAsync(ExportConsultationRecordsDBRequest request);
        /// <summary>
        /// 删除会诊记录
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeleteConsultationRecordByCodeAsync(ConsultationRecordCodeDBRequest request);
        /// <summary>
        /// 更新会诊记录
        /// </summary>
        /// <param name="data"></param>
        /// <param name="canNull"></param>
        /// <returns></returns>
        Task<bool> UpdateConsultationRecordAsync(ConsultationDetailDTO data, bool canNull = false);

        /// <summary>
        /// 添加随访信息
        /// </summary>
        /// <param name="request">The request</param>
        /// <returns></returns>
        Task<bool> AddFollowUpVisitInfoAsync(AddFollowUpVisitInfoDBRequest request);

        /// <summary>
        /// 删除随访信息
        /// </summary>
        /// <param name="request">The request</param>
        /// <returns></returns>
        Task<bool> DeleteFollowUpVisitInfoAsync(DeleteFollowUpVisitInfoDBRequest request);

        /// <summary>
        /// 修改随访信息
        /// </summary>
        /// <param name="request">The request</param>
        /// <returns></returns>
        Task<bool> UpdateFollowUpVisitInfoAsync(UpdateFollowUpVisitInfoDBRequest request);

        /// <summary>
        /// 查询随访信息
        /// </summary>
        /// <param name="request">The request</param>
        /// <returns></returns>
        Task<List<FollowUpVisitDTO>> GetFollowUpVisitInfoAsync(GetFollowUpVisitInfoDBRequest request);

        /// <summary>
        /// 查询随访信息详情
        /// </summary>
        /// <param name="request">The request</param>
        /// <returns></returns>
        Task<FollowUpVisitDTO> GetFollowUpVisitInfoDetailAsync(GetFollowUpVisitInfoDetailDBRequest request);

        /// <summary>
        /// 设置需要随访
        /// </summary>
        /// <returns></returns>
        Task<bool> SetNeedFollowUpVisitAsync(SetNeedFollowUpVisitDBRequest request);

        /// <summary>
        /// 新增会诊评价
        /// </summary>
        /// <param name="request">The request</param>
        /// <returns></returns>
        Task<bool> AddConsultationEvaluateAsync(AddConsultationEvaluateDBRequest request);

        /// <summary>
        /// 删除会诊评价
        /// </summary>
        /// <param name="request">The request</param>
        /// <returns></returns>
        Task<bool> DeleteConsultationEvaluateAsync(DeleteConsultationEvaluateDBRequest request);

        /// <summary>
        /// 修改会诊评价
        /// </summary>
        /// <param name="request">The request</param>
        /// <returns></returns>
        Task<bool> UpdateConsultationEvaluateAsync(UpdateConsultationEvaluateDBRequest request);

        /// <summary>
        /// 查询会诊评价详情
        /// </summary>
        /// <param name="request">The request</param>
        /// <returns></returns>
        Task<ConsultationEvaluateDTO> GetConsultationEvaluateDetailAsync(GetConsultationEvaluateDBRequest request);

        /// <summary>
        /// 设置会诊参与人信息
        /// </summary>
        /// <returns></returns>
        Task<bool> SetMemberStatusAsync(SetMemberStatusDBRequest request);

        /// <summary>
        ///  查询待开始的会诊记录
        /// </summary>
        /// <returns></returns>
        Task<IList<ConsultationDetailDTO>> FindToStartConsultationRecordListAsync();

        /// <summary>
        /// 根据状态查询会诊记录
        /// </summary>
        /// <returns></returns>
        Task<IList<ConsultationDetailDTO>> GetConsultationRecordsByStatusAsync(GetConsultationRecordsByStatusDBRequest request);

        /// <summary>
        /// 更新会诊发起人编码
        /// </summary>
        /// <param name="recordId"></param>
        /// <param name="initatorCode"></param>
        /// <returns></returns>
        Task<bool> UpdateInitatorCodeAsync(string recordId, string initatorCode);

        /// <summary>
        /// 根据code列表获取评价列表
        /// </summary>
        /// <param name="codeList"></param>
        /// <returns></returns>
        Task<List<ConsultationEvaluateDTO>> GetAllConsultationEvaluatesByCodesAsync(List<string> codeList);

        /// <summary>
        /// 更新会诊状态
        /// </summary>
        /// <param name="consultationCode"></param>
        /// <param name="status"></param>
        /// <returns></returns>
        Task<bool> UpdateConsultationStatusAsync(string consultationCode, TransactionStatusEnum status);

        /// <summary>
        /// 更新会诊邀请信息
        /// </summary>
        /// <param name="consultationCode"></param>
        /// <param name="consultationReminders"></param>
        /// <returns></returns>
        Task<bool> UpdateConsultationRemindersAsync(string consultationCode, List<ConsultationReminderDTO> consultationReminders);

        /// <summary>
        /// 获取急诊订单号
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> GetEmergencyOrderAsync(GetEmergencyOrderDBRequest request);


        /// <summary>
        /// 根据急诊单号和设备号获取急诊单
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ConsultationDetailDTO> GetRecordByEmergencyCodeAndDeviceCodeAsync(GetRecordByEmergencyCodeAndDeviceCodeDBRequest request);

        /// <summary>
        /// 更新会诊专家编码
        /// </summary>
        /// <param name="recordId"></param>
        /// <param name="expertCode"></param>
        /// <returns></returns>
        Task<bool> UpdateExpertCodeAsync(string recordId, string expertCode);

        /// <summary>
        /// 根据会诊单号查询会诊中可直接切换的会诊单列表
        /// </summary>
        /// <returns></returns>
        Task<IList<ConsultationDetailDTO>> FindCanSwitchConsultationsDBAsync(string code);

        /// <summary>
        /// 更新急诊实时状态
        /// </summary>
        /// <param name="recordId"></param>
        /// <param name="expertCode"></param>
        /// <returns></returns>
        Task<bool> UpdateEmergencyStatusAsync(string recordId, EmergencyConsultationStatus status);

        Task<bool> SyncBatchConsultationDBAsync(SyncBatchConsultationRequest syncBatchConsultationRequest);
        /// <summary>
        /// 查询会诊增量数据
        /// </summary>
        /// <param name="startTime"></param>
        /// <param name="endTime"></param>
        /// <returns></returns>
        Task<IList<LiveConsultationDTO>> FindConsultationsDataCenterAsync(DateTime startTime,DateTime endTime);
    }
}