using System.Collections.Generic;
using System.Threading.Tasks;
using WingInterfaceLibrary.DB.Request;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Request.DBRequest;
using WingInterfaceLibrary.Result;
using WingInterfaceLibrary.DTO.Courses;
using WingInterfaceLibrary.Request.Courses;
using WingInterfaceLibrary.DTO.Education;
using WingInterfaceLibrary.DTO.DataCenter;
using WingInterfaceLibrary.Enum.CourseEnum;

namespace WingInterfaceLibrary.Interface.DBInterface
{
    /// <summary>
    /// 课程数据库服务
    /// </summary>
    public interface ICourseDBService
    {
        /// <summary>
        /// 创建新课程
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> CreateCourseAsync(CreateCourseDBRequest request);

        /// <summary>
        /// 查询课程记录
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<CourseInfoDetailDTO> FindCourseByCodeAsync(FindCourseByCodeDBRequest request);

        /// <summary>
        /// 查询课程记录列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<CourseInfoDetailDTO>> FindCoursesByCodesAsync(FindCourseByCodesDBRequest request);

        /// <summary>
        /// 查询课程列表分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<BaseCourseInfoDTO>> FindCoursePagesAsync(FindCoursePagesDBRequest request);

        /// <summary>
        /// 查询管理后台课程列表分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<BaseCourseInfoDTO>> FindAdminCoursePagesAsync(FindCoursePagesDBRequest request);

        /// <summary>
        /// 删除课程记录
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeleteCourseByCodeAsync(DeleteCourseByCodeDBRequest request);

        /// <summary>
        /// 更新课程记录
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateCourseAsync(UpdateCourseDBRequest request);

        /// <summary>
        /// 查询学生状态信息
        /// </summary>
        /// <param name="courseOrAlbumCodes"></param>
        /// <returns></returns>
        Task<IList<SignStudentDTO>> FindSignInListAsync(IList<string> courseOrAlbumCodes);

        /// <summary>
        /// 更新课程记录
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateCourseBindExamsAsync(UpdateCourseBindExamsRequest request);

        /// <summary>
        /// 更新课程状态
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateCourseStatusAsync(UpdateCourseStatusDBRequest request);

        /// <summary>
        /// 创建视频
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> CreateVideoDBAsync(SaveVideoRequest request);

        /// <summary>
        /// 根据课程code查询所属视频
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<VideoInfoDTO>> FindVideosByCourseCodeDBAsync(FindVideosByCourseCodeRequest request);

        /// <summary>
        /// 查询所有视频列表分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<VideoInfoDTO>> FindVideosPagesDBAsync(FindVideoPagesRequest request);

        /// <summary>
        /// 删除视频，同步删除课程管理视频code
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeleteVideoByCodeDBAsync(DeleteVideoRequest request);

        /// <summary>
        /// 学生加入班级
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> AddStudentInCourseUserGroupDBAsync(AddStudentInCourseUserGroupDBRequest request);

        /// <summary>
        /// 学生退出班级
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> StudentLeaveCourseUserGroupDBAsync(StudentLeaveCourseUserGroupDBRequest request);

        /// <summary>
        /// 查询学生所在班级列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<UserGroupDTO>> FindUserGroupByStudentDBAsync(FindUserGroupByStudentDBRequest request);

        /// <summary>
        /// 学习完成处理
        /// </summary>
        /// <returns></returns>
        Task<bool> StudyCompletedDBAsync(StudyCompletedDBRequest request);

        /// <summary>
        /// 添加课程专辑
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> AddCourseAlbumDBAsync(AddCourseAlbumDBRequest request);

        /// <summary>
        /// 更新课程专辑
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateCourseAlbumDBAsync(UpdateCourseAlbumDBRequest request);

        /// <summary>
        /// 删除课程专辑
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeleteCourseAlbumDBAsync(DeleteCourseAlbumDBRequest request);

        /// <summary>
        /// 查询课程专辑分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<CourseAlbumDTO>> FindCourseAlbumPageDBAsync(FindCourseAlbumPageDBRequest request);

        /// <summary>
        /// 查询课程专辑详情
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<CourseAlbumDetailDTO> FindCourseAlbumByCodeDBAsync(FindCourseAlbumByCodeDBRequest request);

        /// <summary>
        /// 根据课程code查询所有的专辑列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<CourseAlbumDTO>> GetCourseAlbumListByCourseCodeDBAsync(string courseCode);

        /// <summary>
        /// 根据讲师code查询所有的专辑列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<CourseAlbumDTO>> GetCourseAlbumListByTeacherCodeDBAsync(string teacherCode);

        /// <summary>
        /// 根据code查询专辑列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<CourseAlbumDTO>> FindAllAlbumListByAlbumCodesDBAsync(IList<string> courseAlbumCodes);

        /// <summary>
        /// 报名课程
        /// 课程状态：“已审核”才可报名
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> SignUpCourseDBAsync(SignUpCourseDBRequest request);

        /// <summary>
        /// 取消报名课程
        /// 课程状态：“已审核”取消报名
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> CancelSignUpCourseDBAsync(CancelSignUpCourseDBRequest request);

        /// <summary>
        /// 学生查询自己课程列表分页
        /// </summary>
        /// <param name="request">学生查询自己课程请求</param>
        /// <returns>课程列表</returns>
        Task<PageResult<MyCoursePageDTO>> FindMyCoursePagesDBAsync(FindMyCoursePagesDBRequest request);

        /// <summary>
        /// 根据时间范围查询在线培训数据
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<OnlineTrainingDTO>> FindCourseByDateCenterDBAsync(FindOnlineTrainingByDateCenterDBRequest request);

        /// <summary>
        /// 根据时间范围查询在线视频数据
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<OnlineVideoDTO>> FindVideoByDateCenterDBAsync(FindOnlineVideoByDateCenterDBRequest request);

        /// <summary>
        /// 根据时间范围查询教培试卷数据
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<ExamPaperDTO>> FindExaminationPapeByDateCenterDBAsync(FindExaminationPaperByDateCenterDBRequest request);

        /// <summary>
        /// 根据时间范围查询课程专辑数据
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<CourseAlbumView>> FindCourseAlbumByDateCenterDBAsync(FindCourseAlbumByDateCenterDBRequest request);

        /// <summary>
        /// 更新素材名称
        /// </summary>
        /// <param name="videoCode">素材编码</param>
        /// <param name="newName">新名称</param>
        /// <returns></returns>
        Task<bool> ChangeVideoNameDBAsync(string videoCode,string newName);
        
         /// <summary>
        /// 增加课程播放量
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> AddCoursePlayCountDBAsync(AddCoursePlayCountDBRequest request);

        /// <summary>
        /// 已报名人数
        /// </summary>
        /// <param name="code"></param>
        /// <returns></returns>
        Task<int> FindSignInListCountAsync(string code);

        /// <summary>
        /// 课程类型查询课程文件
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<VideoInfoDTO>> FindVideoFilesCourseTypeByPageDBAsync(FindVideoFilesCourseTypeByPageDBRequest request);

        /// <summary>
        /// 管理端查询所有视频列表分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<VideoInfoDTO>> FindVideosPagesByManagementDBAsync(FindVideoPagesManagementDBRequest request);
        
        /// <summary>
        /// 设置课程禁言
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SetCourseLiveProhibitionByDBAsync(CourseLiveProhibitionRequest request);

        
        /// <summary>
        /// 根据课程状态列表查询直播课
        /// </summary>
        /// <param name="statuList"></param>
        /// <returns></returns>
        Task<IList<BaseCourseInfoDTO>> FindLiveCoursesByStatusDBAsync(List<CourseStatusEnum> statuList);
    }
}