using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Dictionary;
using WingInterfaceLibrary.DTO.Device;
using WingInterfaceLibrary.DB.Request;
using WingInterfaceLibrary.Result;
using WingInterfaceLibrary.DTO.Management;
using WingInterfaceLibrary.Request.Management;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.DBRequest;
using WingInterfaceLibrary.Request.Device;
using WingInterfaceLibrary.Request.Education;
using WingInterfaceLibrary.Request.IOTDevice;
using WingInterfaceLibrary.Result.IOTDevice;
using System;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.DTO.Common;
using WingInterfaceLibrary.Request.Comment;

namespace WingInterfaceLibrary.Interface.DBInterface
{
    public interface IDeviceInfoDBService
    {
        Task<string> CreateDictionaryItemAsync(CreateDictionaryItemDBRequest request);
        Task<bool> RemoveDictionaryItemAsync(RemoveDictionaryItemDBRequest request);
        Task<List<DictionaryDTO>> FindDictionaryItemsAsync(FindDictionaryItemsDBRequest request);

        Task<List<DictionaryDTO>> FindDictionaryItemsByParentCodeAsync(string parentCode);

        Task<PageResult<DictionaryDTO>> FindDictionaryPagesAsync(GetDeviceTypePagesRequest request);

        Task<DictionaryDTO> FindDictionaryByCodeAsync(string code);

        Task<bool> UpdateDictionaryItemAsync(DictionaryDTO dictionaryDTO, string extensionData, bool canNull = false);

        Task<string> InsertDeviceInfoAsync(CreateDeviceInfoDBRequest request);
        Task<bool> ModifyPasswordAsync(ModifyPasswordDBRequest request);
        Task<DeviceInfoDTO> FindDeviceInfoByNameAsync(string name);
        Task<DeviceInfoDTO> FindDeviceInfoByCodeAsync(string code);
        Task<DeviceInfoDTO> FindDeviceInfoByShortCodeAsync(string shortCode);
        Task<PageCollection<DeviceInfoDTO>> FindDeviceInfoPagesAsync(PageFilterRequest request);
        Task<bool> DeleteDeviceInfoByCodeAsync(string code);
        Task<bool> UpdateDeviceInfoByCodeAsync(string code, DeviceInfoDTO data, string extensionData, bool canNull = false, bool isSync = false, bool isUpdateImg = true);

        /// <summary>
        /// 根据设备code列表获取设备信息列表
        /// </summary>
        /// <param name="request">移除设备请求实体</param>
        /// <returns>设备信息列表</returns>
        Task<List<DeviceInfoDTO>> FindDeviceInfoListByCodeListAsync(List<string> codeList);

        /// <summary>
        /// 根据组织编码查询所属全部设备信息
        /// </summary>
        /// <param name="organizationCode"></param>
        /// <returns></returns>
        Task<List<DeviceInfoDTO>> FindDeviceInfoListByOrganizationCodeAsync(string organizationCode);

        /// <summary>
        /// 根据组织编码列表查询所属全部设备信息
        /// </summary>
        /// <param name="organizationCode"></param>
        /// <returns></returns>
        Task<List<DeviceInfoDTO>> FindDeviceInfoListByOrganizationCodesAsync(IList<string> organizationCodes);

        /// <summary>
        /// 根据设备序列号查询设备
        /// </summary>
        /// <param name="serialNumber">设备序列号</param>
        /// <returns>设备信息</returns>
        Task<DeviceInfoDTO> FindDeviceInfoBySerialNumberAsync(string serialNumber);

        /// <summary>
        /// 根据设备型号code列表获取设备信息列表
        /// </summary>
        /// <param name="modelCodeList"></param>
        /// <returns></returns>
        Task<List<DeviceInfoDTO>> FindDeviceInfoListByModelCodeListAsync(List<string> modelCodeList);

        /// <summary>
        /// 根据设备类型获取设备列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<DeviceInfoDTO>> FindDeviceInfoByDeviceType(FindDeviceInfoByDeviceTypeRequest request);

        /// <summary>
        /// 查询设备列表（分页）
        /// </summary>
        /// <param name="queryRequest"></param>
        /// <returns></returns>
        Task<PageResult<ManageDeviceInfoDTO>> GetDevicePagesAsync(GetDevicePagesRequest queryRequest);

        /// <summary>
        /// 更新最近登录时间
        /// </summary>
        /// <returns>是否操作成功</returns>
        Task<bool> UpdateLoginTimeAsync(UpdateLoginTimeDBRequest request);

        /// <summary>
        /// 删除设备
        /// </summary>
        /// <returns>是否操作成功</returns>
        Task<bool> DeleteDeviceDBAsync(string deviceCode);

        /// <summary>
        /// 查找有效设备总数量
        /// </summary>
        /// <returns></returns>
        Task<long> GetActiveDeviceCount();

        /// <summary>
        /// 更新视频设备画面信息
        /// </summary>
        /// <returns>是否操作成功</returns>
        Task<bool> UpdateVideoDeviceInfosAsync(UpdateVideoDeviceInfosDBRequest request);

        /// <summary>
        /// 新增设备画面尺寸
        /// </summary>
        /// <returns>是否操作成功</returns>
        Task<bool> AddDeviceOutputConfigAsync(AddDeviceOutputConfigDBRequest request);

        /// <summary>
        /// 获取设备画面尺寸
        /// </summary>
        /// <returns>是否操作成功</returns>
        Task<List<DeviceOutputConfigDTO>> GetDeviceOutputConfigAsync(GetDeviceOutputConfigDBRequest request);

        /// <summary>
        /// 新增设备画面尺寸
        /// </summary>
        /// <returns>是否操作成功</returns>
        Task<bool> AddBrandModelOutputConfigAsync(AddBrandModelOutputConfigDBRequest request);

        /// <summary>
        /// 获取设备画面尺寸
        /// </summary>
        /// <returns>是否操作成功</returns>
        Task<List<BrandModelOutputConfigDTO>> GetBrandModelOutputConfigAsync(GetBrandModelOutputConfigDBRequest request);

        /// <summary>
        /// 获取品牌
        /// </summary>
        /// <returns></returns>
        Task<List<string>> GetBrandsAsync();

        /// <summary>
        /// 获取品牌型号列表
        /// </summary>
        /// <returns></returns>
        Task<List<string>> GetModelsAsync(GetModelsDBRequest request);

        /// <summary>
        /// 获取品牌型号分页
        /// </summary>
        /// <param name="queryRequest"></param>
        /// <returns></returns>
        Task<PageResult<BrandModelDetailDTO>> GetDeviceBrandModelPageAsync(GetDeviceBrandModelPageDBRequest queryRequest);

        /// <summary>
        /// 删除品牌型号
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeleteBrandModelOutputConfigAsync(DeleteBrandModelOutputConfigDBRequest request);

        /// <summary>
        /// 增加设备更新包
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> AddDevicePatchDBAsync(AddDevicePatchDBRequest request);
        /// <summary>
        /// 更新设备更新包
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateDevicePatchDBAsync(UpdateDevicePatchDBRequest request);
        /// <summary>
        /// 删除设备更新包
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeleteDevicePatchDBbyCodeAsync(DeleteDevicePatchDBbyCodeRequest request);
        /// <summary>
        /// 分页查询设备更新包
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<DevicePatchDTO>> FindDevicePatchPageDBAsync(FindDevicePatchPageDBRequest request);
        /// <summary>
        /// 通过更新包名称或者Code获取更新包
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<DevicePatchDTO> GetDevicePatchDBbyNameAsync(GetDevicePatchDBbyNameRequest request);
        /// <summary>
        /// 增加设备版本
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> AddDevicePatchVersionDBAsync(AddDevicePatchVersionDBRequest request);
        /// <summary>
        /// 查询设备版本
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<DevicePatchVersionDTO>> FindDevicePatchVersionListDBAsync(FindDevicePatchVersionListDBRequest request);
        /// <summary>
        /// 删除设备版本
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeleteDevicePatchVersionDBAsync(DeleteDevicePatchVersionDBRequest request);

        /// <summary>
        /// 增加打印机驱动包
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> AddDevicePrinterDBAsync(AddDevicePrinterDBRequest request);

        /// <summary>
        /// 增加打印机驱动包
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<DevicePrinterDTO>> FindDevicePrinterPageDBAsync(FindDevicePrinterPageDBRequest request);

        /// <summary>
        /// 删除打印机驱动包
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeleteDevicePrinterDBAsync(DeleteDevicePrinterDBRequest request);

        /// <summary>
        /// 获取打印机驱动包
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<DevicePrinterDTO> GetDevicePrinterDBAsync(GetDevicePrinterDBRequest request);

        /// <summary>
        /// 更新打印机驱动包
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateDevicePrinterDBAsync(UpdateDevicePrinterDBRequest request);

        /// <summary>
        /// 批量新增超声机数据
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>是否成功</returns>
        Task<bool> BatchInsertDeviceDataDBAsync(BatchInsertDeviceRequest request);

        /// <summary>
        /// 查询打印机驱动是否存在
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> ExistsDevicePrinterDBAsync(ExistsDevicePrinterDBRequest request);

        /// <summary>
        /// 批量新增打印机驱动
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>是否成功</returns>
        Task<bool> BatchInsertDevicePrintersDataAsync(MigrateDevicePrinterRequest request);

        /// <summary>
        /// 批量新增补丁包
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>是否成功</returns>
        Task<bool> BatchInsertDevicePatchsDataAsync(MigrateDevicePatchRequest request);

        /// <summary>
        /// 查询个人设备列表分页列表
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns></returns>
        Task<PageResult<DeviceInfoDTO>> FindDeviceInfoListPageDBAsync(FindDeviceInfoPageRequest request);

        /// <summary>
        /// 根据设备code列表获取设备信息列表
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns></returns>
        Task<PageResult<ManageDeviceInfoDTO>> FindDevicesByPageDBAsync(FindDeviceInfoPageRequest request);

        /// <summary>
        /// 查询个人机构内设备列表分页列表
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns></returns>
        Task<PageResult<DeviceInfoDTO>> FindMyOrgDeviceInfoListPageDBAsync(FindDeviceInfoPageRequest request);

        /// <summary>
        /// 清理重复短码
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns></returns>
        Task<bool> ClearRepeatDeviceInfoDBAsync(ShareDeviceRequest request);

        /// <summary>
        /// 初始化数据
        /// </summary>
        Task<bool> InitDeviceModelDBAsync();

        /// <summary>
        /// 设备数据列表-分页 
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<PageResult<DeviceInfoDTO>> QueryIOTDeviceInfoDBByPageAsync(QueryDeviceInfoByPageRequest request);

        /// <summary>
        /// 设备报告数据列表-分页
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<PageResult<DeviceReportDTO>> QueryIOTDeviceReportInfoDBByPageAsync(QueryDeviceReportByPageRequest request);

        /// <summary>
        /// 新增IOT设备版本
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> AddIOTDeviceVersionInfoDBAsync(AddIOTDeviceVersionRequest request);
        
        /// <summary>
        /// 修改IOT设备版本
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> UpdateIOTDeviceVersionInfoDBAsync(UpdateIOTDeviceVersionRequest request);
        
        /// <summary>
        /// 删除IOT设备版本
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> DeleteIOTDeviceVersionInfoDBAsync(QueryIOTDeviceVersionRequest request);

        /// <summary>
        /// 根据查询实体查询设备报告数据
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<IOTDeviceVersionDTO> QueryIOTDeviceVersionInfoDBAsync(QueryIOTDeviceVersionRequest request);

        /// <summary>
        /// IOT设备版本分页信息列表-分页
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<PageResult<IOTDeviceVersionDTO>> QueryIOTDeviceVersionInfoDBByPageAsync(QueryDeviceVersionByPageRequest request);

        /// <summary>
        /// 绑定设备 
        /// 用户:设备 = 1：N；设备同时只能被一个用户绑定
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> SaveUserDevicesDBAsync(UserBindDeviceRequest request);

        /// <summary>
        /// 删除用户绑定设备
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> DeleteUserDeviceDBAsync(DeleteDeviceInfoRequest request);

        /// <summary>
        /// 获取用户设备数据列表
        /// </summary>
        /// <param name="userCode">用户编码</param>
        /// <returns></returns>
        Task<IList<UserDeviceInfoResult>> GetUserDevicesDBAsync(string userCode);

        /// <summary>
        /// 获取设备首页总结数据
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<IOTDeviceSumaryResult> GetUserDevicesSummaryDBAsync(GetSummaryRequest request);

        /// <summary>
        /// 保存设备指定升级版本
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> SaveDeviceUpgradeVersionDBAsync(SaveDeviceUpgradeVersionRequest request);

        /// <summary>
        /// IOT设备注册
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns></returns>
        Task<string> IOTDeviceRegisterDBAsync(IOTDeviceRegisterRequest request);

        /// <summary>
        /// 获取 呼吸机|制氧机 最新版本号数据
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns></returns>
        Task<IOTDeviceVersionResult> GetLasterVersionDBAsync(GetDeviceVersionRequest request);

        /// <summary>
        /// IOT设备属性上报
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns></returns>
        Task<bool> DeviceAttributePostDBAsync(IOTDeviceAttributeEscalationRequest request);

        /// <summary>
        /// IOT设备属性查询
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns></returns>
        Task<string> DeviceAttributeGetDBAsync(IOTDeviceAttributeEscalationRequest request);

        /// <summary>
        /// 获取IOT设备使用模式数据源
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns></returns>
        Task<IList<ModeType>> GetDeviceModeTypesDBAsync(GetIOTDevicBaseRequest request);

        /// <summary>
        /// 获取IOT设备阶段时间内有使用记录日期
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns></returns>
        Task<IList<DateTime>> GetDeviceUseDatesDBAsync(GetIOTDeviceUseDateRequest request);

        /// <summary>
        /// 获取IOT设备阶段报告
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns></returns>
        Task<string> GetIOTDeviceReportDBAsync(GetIOTDeviceReportRequest request);

        /// <summary>
        /// 获取IOT设备详细数据
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns></returns>
        Task<IOTDeviceDetailResult> GetIOTUserDeviceDetailDBAsync(GetIOTDeviceDetailRequest request);

        /// <summary>
        /// 设备报告上报接口
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns></returns>
        Task<bool> DeviceEventPostDBAsync(IOTReportAttributeEscalationRequest request);

        /// <summary>
        /// 保存通用字典数据
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> SaveCommonDictionaryInfoDBAsync(SaveCommonDictionaryRequest request);

        /// <summary>
        /// 移除字典
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> RemoveCommonDictionaryInfoDBAsync(CommonDictionaryRequest request);

        /// <summary>
        /// 移除字典
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<IList<CommonDictionaryDTO>> GetCommonDictionaryInfosDBAsync(CommonDictionaryRequest request);

        /// <summary>
        /// 移除字典
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<PageResult<CommonDictionaryDTO>> FindCommonDictionaryPagesDBAsync(GetCommonDictionaryPageRequest request);

        /// <summary>
        /// 获取用户设备数据列表通过设备code
        /// </summary>
        /// <param name="deviceCode">请求对象</param>
        /// <returns></returns>
        Task<UserDeviceInfoResult> GetUserDevicesByDeviceCodeDBAsync(string deviceCode);

        /// <summary>
        /// 保存通用设备用户信息
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> SaveIOTDeviceUserInfoDBAsync(SaveIOTDeviceUserDataRequest request);

        /// <summary>
        /// 分页查询设备用户信息
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<PageResult<IOTDeviceUserDTO>> FindIOTDeviceUserPagesDBAsync(GetIOTDeviceUserDataPageRequest request);

        /// <summary>
        /// 分页查询设备用户数据列表
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<PageResult<IOTDeviceUserInfoDTO>> FindIOTDeviceUseListPageDBAsync(GetIOTDeviceBindUserDataPageRequest request);

        /// <summary>
        /// 保存设备绑定用户信息
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> SaveIOTDeviceBindUserInfoDBAsync(IOTDeviceBindUserDataRequest request);

        /// <summary>
        /// 获取设备用户信息详情接口
        /// </summary>
        /// <param name="code">请求对象</param>
        /// <param name="name">请求对象</param>
        /// <returns></returns>
        Task<IOTDeviceUserDTO> FindIOTDeviceUserInfoDBAsync(string code, string name);

        /// <summary>
        /// 查询呼吸机设备原始数据列表
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>是否成功</returns>
        Task<IList<IOTDeviceUserListDTO>> GetIOTDeviceDataListDBAsync(GetIOTDeviceFileDataRequest request);

        /// <summary>
        /// 保存设备用户原始数据
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>是否成功</returns>
        Task<UpdateIOTDeviceDataResult> SaveIOTDeviceDataDBAsync(SaveIOTDeviceDataDBRequest request);

        /// <summary>
        /// 查询呼吸机设备绑定用户信息列表
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>是否成功</returns>
        Task<List<IOTDeviceUserListDTO>> GetIOTDeviceUserListDBAsync(GetIOTDeviceUsersRequest request);

        /// <summary>
        /// 保存设备用户原始数据db接口
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>是否成功</returns>
        Task<bool> SaveIOTDeviceDataStatusDBAsync(UpdateIOTDeviceDataResult request);

        /// <summary>
        /// 获取license信息列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<LicenseInfoBasicDTO>> GetLicenseInfoListDBAsync(TokenRequest request);

        /// <summary>
        /// 保存License信息数据
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SaveLicenseInfoListDBAsync(SaveLicenseInfoRequest request);

        /// <summary>
        /// 保存Dongle信息数据
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SaveDongleInfoListDBAsync(SaveDongleInfoRequest request);

        /// <summary>
        /// 分页获取license信息列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<LicenseDetailInfoDTO>> GetLicenseInfoPagesDBAsync(GetLicensePageRequest request);

        /// <summary>
        /// 分页获取Dongle信息列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<DongleDetailInfoDTO>> GetDongleInfoPagesDBAsync(GetDonglePageRequest request);

        /// <summary>
        /// 根据licenseId获取license详情
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<LicenseDetailInfoDTO> GetLicenseDetailDBAsync(GetLicenseOrDongleRequest request);

        /// <summary>
        /// 根据dongleid或者licenseId获取Dongle详情
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<DongleDetailInfoDTO> GetDongleDetailDBAsync(GetLicenseOrDongleRequest request);
  
        /// <summary>
        /// 验证设备是否已经被绑定
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>是否成功</returns>
        Task<List<CheckIOTDeviceBeenBoundResult>> CheckIOTDeviceBeenBoundDBAsync(CheckIOTDeviceBeenBoundRequest request);

        /// <summary>
        /// 设备阶段报告日周月年查询接口
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>是否成功</returns>
        Task<IOTDeviceStageReportResult> GetIOTDeviceStageReportDBAsync(IOTDeviceStageReportRequest request);
        
        /// <summary>
        /// 设备阶段报告趋势图查询接口
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>是否成功</returns>
        Task<IOTDeviceStageReportTrendChartResult> GetIOTDeviceStageReportTrendChartDBAsync(IOTDeviceStageReportTrendChartRequest request);
    }
}