
using System.Collections.Generic;
using System.Threading.Tasks;
using WingInterfaceLibrary.DB.Request;
using WingInterfaceLibrary.DTO.Common;
using WingInterfaceLibrary.DTO.DistributedServerInfo;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.DBRequest;
using WingInterfaceLibrary.Request.FastestServer;
using WingInterfaceLibrary.Result;

namespace WingInterfaceLibrary.Interface.DBInterface
{
    /// <summary>
    /// 分布式服务器信息DB Service
    /// </summary>
    public interface IDistributedServerInfoDBService
    {
        /// <summary>
        /// 查询
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<DistributedServerInfoDTO>> GetDistributedServerInfoPagesAsync(GetDistributedServerInfoDBPagesRequest request);
        /// <summary>
        /// 删除
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeleteDistributedServerInfoAsync(DeleteDistributedServerInfoDBRequest request);
        /// <summary>
        /// 增加
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> AddDistributedServerInfoAsync(AddDistributedServerInfoDBRequest request);
        /// <summary>
        /// 更新
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateDistributedServerInfoAsync(UpdateDistributedServerInfoDBRequest request);
        /// <summary>
        /// 查询codes
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<DistributedServerInfoDTO>> GetDistributedServerInfoDBByCodesAsync(GetDistributedServerInfoDBByCodesRequest request);

        /// <summary>
        /// 查询单个
        /// </summary>
        /// <param name="code"></param>
        /// <returns></returns>
        Task<DistributedServerInfoDTO> GetDistributedServerInfoDBByCodeAsync(GetDistributedServerInfoDBByCodeRequest code);
        
        /// <summary>
        /// 查询服务器配置信息IP列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<IPAddressInfoDTO>> GetDistributedServerIpListDBAsync(GetDistributedServerIpListDBRequest request);
        
        /// <summary>
        /// 更新
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateDistributedServerIPListAsync(UpdateServerInfoDBRequest request);

        /// <summary>
        /// 查询服务器信息
        /// </summary>
        /// <param name="serverUrl"></param>
        /// <returns></returns>
        Task<DistributedServerInfoDTO> GetDistributedServerInfoDBByServerUrlAsync(string serverUrl);
    }
}
