using System.Threading.Tasks;
using WingInterfaceLibrary.DB.Request;
using WingInterfaceLibrary.DTO.FaceRecognition;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.Interface.DBInterface
{
    /// <summary>
    /// 人脸识别数据库服务
    /// </summary>
    public interface IFaceRecognitionDBService
    {        
        /// <summary>
        /// 添加人脸识别数据
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> AddFaceRecognitionAsync(AddFaceRecognitionRequest request);

        /// <summary>
        /// 根据code查询人脸识别数据
        /// </summary>
        /// <param name="code"></param>
        /// <returns></returns>
        Task<FaceRecognitionDTO> FindFaceRecognitionByCodeAsync(string code);

        /// <summary>
        /// 修改人脸识别数据
        /// </summary>
        /// <param name="personFullInfo"></param>
        /// <returns></returns>
        Task<bool> UpdateFaceRecognitionAsync(UpdateFaceRecognitionRequest faceRecognition);

        /// <summary>
        /// 获取人脸识别数据列表分页
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns>返回人脸识别数据列表</returns>
        Task<PageCollection<FaceRecognitionDTO>> GetFaceRecognitionPageAsync(GetFaceRecognitionPageRequest request);

        /// <summary>
        /// 根据code删除人脸识别数据
        /// </summary>
        /// <param name="code"></param>
        /// <returns></returns>
        Task<bool> DeleteFaceRecognitionAsync(string code);

        /// <summary>
        /// 根据personId删除人脸识别数据
        /// </summary>
        /// <param name="code"></param>
        /// <returns></returns>
        Task<bool> DeleteFaceRecognitionByPersonIdAsync(string personId);

    }
}