using System.Collections.Generic;
using System.Threading.Tasks;
using WingInterfaceLibrary.DB.Request;
using WingInterfaceLibrary.DTO.Lab;
using WingInterfaceLibrary.DTO.Record;
using WingInterfaceLibrary.Result;

namespace WingInterfaceLibrary.Interface.DBInterface
{
    /// <summary>
    /// 实验室DB服务
    /// </summary>
    public interface ILabDBService
    {
        ///<summary>
        /// 查询文件夹列表
        /// </summary>
        /// <returns></returns>
        Task<IList<LabFolderDTO>> GetLabFolderListDBAsync(GetLabFolderListDBRequest request);

        /// <summary>
        /// 分页查询图像列表
        /// </summary>
        /// <returns></returns>
        Task<PageResult<RemedicalInfoDTO>> GetFileListByFolderDBAsync(GetFileListByFolderDBRequest request);

        // <summary>
        /// 创建文件夹
        /// </summary>
        /// <returns>FolderCode</returns>
        Task<string> CreateLabFolderDBAsync(CreateLabFolderDBRequest request);

        // <summary>
        /// 创建上传记录
        /// </summary>
        /// <returns>RecordCode</returns>
        Task<string> CreateLabUploadRecordDBAsync(CreateLabUploadRecordDBRequest request);

        /// <summary>
        /// 创建实验室文件转换状态信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> CreateLabConvertStateDBAsync(CreateLabConvertStateDBRequest request);

        /// <summary>
        /// 设置实验室文件转换状态
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SetLabConvertStateDBAsync(SetLabConvertStateDBRequest request);

        /// <summary>
        /// 创建实验室转换错误记录信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> AddConvertErrorInfoStateDBAsync(AddConvertErrorInfoStateDBRequest request);

        /// <summary>
        /// 创建实验室下载错误记录信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> AddDownloadErrorInfoStateDBAsync(AddDownloadErrorInfoStateDBRequest request);

        /// <summary>
        /// 删除实验室转换错误记录信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> RemoveConvertErrorInfoStateDBAsync(RemoveConvertErrorInfoStateDBRequest request);

        /// <summary>
        /// 删除实验室下载错误记录信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> RemoveDownloadErrorInfoStateDBAsync(RemoveDownloadErrorInfoStateDBRequest request);

        /// <summary>
        /// 获取实验室文件处理记录
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<LabConvertStateDTO>> GetLabConvertStateDBAsync(GetLabConvertStateDBRequest request);
    }
}