﻿using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Organization;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.DB.Request;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.DBRequest;
using WingInterfaceLibrary.Request.Management;
using WingInterfaceLibrary.Result;
using WingInterfaceLibrary.Request.User;

namespace WingInterfaceLibrary.Interface.DBInterface
{
    public interface IOrganizationDBService
    {
        Task<long> CreateOrganizationsAsync(CreateOrganizationsDBRequest request);

        Task<OrganizationDTO> GetOrganizationDetailAsync(GetOrganizationDBRequest request);

        Task<OrganizationDTO> GetOrganizationDetailByNameAsync(GetOrganizationByNameDBRequest request);

        Task<PageCollection<OrganizationDTO>> GetOrganizationPageAsync(PageFilterRequest request);

        Task<List<OrganizationDTO>> SearchOrganizationsAsync(string keyword, string parentCode, string parentShortCode, OrganizationTypeEnum organizationType);

        /// <summary>
        ///  分页查询机构信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<OrganizationDTO>> SearchOrganizationPagesDBAsync(SearchOrganizationsRequest request);

        Task<long> RemoveOrganizationsAsync(RemoveOrganizationsDBRequest request);

        /// <summary>
        /// 通过 医院类型  找到所有上级机构
        /// </summary>
        /// <param name="name"></param>
        /// <returns></returns>
        Task<List<OrganizationDTO>> FindAllOrganizationByTypeAsync(string organizationCode);

        /// <summary>
        /// 查询机构列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<OrganizationDTO>> GetOrganizationListAsync(GetOrganizationListDBRequest request);

        /// <summary>
        /// 保存机构信息
        /// </summary>
        /// <param name="code">Id</param>
        /// <param name="model">机构基础信息对象</param>
        /// <param name="canNull">字段是否可置空</param>
        /// <param name="modifyReferralOrgs">是否更新转诊医院</param>
        /// <returns>是否成功</returns>
        Task<bool> SaveOrganizationAsync(string code, OrganizationDTO model, bool canNull = false, bool modifyReferralOrgs = false);

        /// <summary>
        /// 根据机构codes获取机构（有对接机构数据）
        /// </summary>
        /// <param name="organizationCodes"></param>
        /// <returns></returns>
        Task<List<OrganizationDTO>> FindOrganizationListByCodesAsync(List<string> organizationCodes);

        /// <summary>
        /// 根据机构codes获取机构（没有对接机构数据）
        /// </summary>
        /// <param name="organizationCodes"></param>
        /// <returns></returns>
        Task<List<OrganizationDTO>> FindOrganizationDTOListByCodesAsync(List<string> organizationCodes);

        /// <summary>
        /// 更新组织名称
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateOrganizationNameAsync(UpdateOrganizationNameDBRequest request);

        /// <summary>
        /// 后台管理网站通过已分配管理员获取医院
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageCollection<OrganizationDTO>> GetManageOrganizationPageAsync(GetManageOrganizationDBPageRequest request);

        /// <summary>
        /// 查询上级医院集合
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<OrganizationDTO>> GetParentCorporationsAsync(FindParentCorporationsDBRequest request);

        /// <summary>
        /// 根据rootcode列表查询所有相关机构
        /// </summary>
        /// <param name="rootCodes">父级编码</param>
        /// <returns></returns>
        Task<List<OrganizationDTO>> SearchOrgByRootCodesAsync(List<string> rootCodes);

        /// <summary>
        /// CMS首页假数据模块列表请求
        /// </summary>
        /// <param name="organizationCode"></param>
        /// <returns></returns>
        Task<StatisticDetailSettingDTO> GetCMSFakeDataAsync(string organizationCode);

        /// <summary>
        /// CMS首页假数据模块列表请求
        /// </summary>
        /// <param name="organizationCode"></param>
        /// <returns></returns>
        Task<bool> UpdateCMSFakeDataAsync(UpdateCMSFakeDataDBRequest updateCMSFakeDataDBRequest);

        /// <summary>
        /// 批量新增机构数据
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>是否成功</returns>
        Task<bool> BatchInsertOrganizationDataDBAsync(BatchInsertOrganizationRequest request);

        /// <summary>
        /// 批量新增医联体
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>是否成功</returns>
        Task<bool> BatchInsertMedicalConsortiumDBAsync(BatchInsertMedicalConsortiumRequest request);

        /// <summary>
        /// 取该医院组织的子孙医院
        /// </summary>
        /// <param name="rootOrganizationCode"></param>
        /// <returns></returns>
        Task<List<OrganizationDTO>> GetAllChildOrganizations(string rootOrganizationCode);

        /// <summary>
        /// 根据用户和设备列表获取组织
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageCollection<OrganizationSimplifyDTO>> GetOrganizationByUserAndDevicesDBAsync(GetOrganizationByUserAndDevicesDBRequest request);

        /// <summary>
        /// 按机构唯一码字搜索组织
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns></returns>
        Task<OrganizationDTO> QueryOrganizationsByShortCodeDBAsync(QueryOrganizationsRequest request);

        /// <summary>
        /// 所有机构:添加短码字段
        /// </summary>
        /// <returns>是否成功</returns>
        Task<bool> UpdateOrganizationsDBAsync(ModifyUserBindDeviceOrganizationRequest request);

        /// <summary>
        /// 查询所有机构Code列表
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns></returns>
        Task<List<string>> GetAllOrganizationCodesDBAsync(GetUpgradeBusinessDataRequest request);

        /// <summary>
        /// 修改即时会诊配置
        /// </summary>
        /// <returns>是否成功</returns>
        Task<bool> UpdateEmergencySettingDBAsync(UpdateEmergencySettingDBRequest request);
            
        /// <summary>
        /// 监听收费服务包是否过期
        /// </summary>
        /// <returns></returns>
        Task<bool> SetOrganizationResourcePackageExpired();
    }
}
