using System.Collections.Generic;
using System.Threading.Tasks;
using WingInterfaceLibrary.Request.DBRequest;
using WingInterfaceLibrary.DTO.Patient;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Result;
using WingInterfaceLibrary.DB.Request;

namespace WingInterfaceLibrary.Interface.DBInterface
{
    /// <summary>
    /// 病人DB管理
    /// </summary>
    public interface IPatientInfoDBService
    {
        /// <summary>
        /// 创建病人
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> CreatePatientAsync(CreatePatientsDBRequest request);
        /// <summary>
        /// 创建病人
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> CreatePatientByUnregisteredAsync(CreatePatientByUnregisteredDBRequest request);
        /// <summary>
        /// 修改病人
        /// </summary>
        /// <param name="code"></param>
        /// <returns></returns>
        Task<bool> UpdatePatientsAsync(string code, PatientInfoDTO data, string extensionData, bool canNull = false);

        /// <summary>
        /// 分页查询增量患者集合
        /// </summary>
        /// <returns></returns>
        Task<PageResult<PatientInfoDTO>> FindPatientByUpdateTimeDBAsync(FindCollectionByTimeDBRequest request);

        /// <summary>
        /// 保存患者记录
        /// </summary>
        /// <returns></returns>
        Task<bool> SavePatientInfoDBAsync(PatientInfoDTO request);

        /// <summary>
        /// 获取病人信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageCollection<PatientInfoDTO>> GetPatientsAsync(GetPatientsByOrgPageRequest request);
        /// <summary>
        /// 病人名称和机构集合查询病人集合
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<PatientInfoDTO>> GetFindValidPatientsByNameAsync(FindValidPatientsDBbyNameRequest request);

        /// <summary>
        /// 获取病人详细信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PatientInfoDTO> FindPatientByCodeAsync(string code);

        /// <summary>
        /// 根据code列表获取病人列表
        /// </summary>
        /// <param name="request">移除设备请求实体</param>
        /// <returns></returns>
        Task<List<PatientInfoDTO>> FindPatientInfoListByCodeListAsync(List<string> codeList);

        /// <summary>
        /// 查询病人列表
        /// </summary>
        /// <param name="request">请求参数</param>
        /// <returns></returns>
        Task<PageCollection<PatientInfoDTO>> GetPatientListByQueryDataAsync(PageFilterRequest request);

        /// <summary>
        /// 删除病人
        /// </summary>
        /// <param name="codes"></param>
        /// <returns></returns>
        Task<bool> DeletePatientsAsync(IReadOnlyList<string> codes);
        /// <summary>
        /// 更新指定设备对应病人的医院，
        /// 设备主动上传的检查病人带的是设备的医院
        /// </summary>
        /// <param name="deviceCodes"></param>
        /// <param name="newOrgCode"></param>
        /// <returns></returns>
        Task<bool> UpdatePatientWithOrgCodeAsync(List<string> deviceCodes, string newOrgCode);

        /// <summary>
        /// 根据机构ID、姓名、设备病人ID获取病人
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PatientInfoDTO> GetPatientByDevicePatientIDAsync(GetPatientByDevicePatientIDRequest request);

        /// <summary>
        /// 根据项目code、姓名、设备病人ID获取病人
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PatientInfoDTO> GetPatientByDevicePatientIDAndProjectCodeAsync(GetPatientByDevicePatientIDAndProjectCodeRequest request);

        /// <summary>
        /// 获取此人作为操作人或创建人的病人
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<PatientInfoDTO>> GetPatientsByOperatorAsync(GetPatientsByOperatorRequest request);        

        /// <summary>
        /// 根据体检号获取病人
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PatientInfoDTO> GetPatientsByPhysicalExamNumberDBAsync(GetPatientsByPhysicalExamNumberDBRequest request);

        /// <summary>
        /// 根据机构ID、设备ID、设备病人ID获取病人
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PatientInfoDTO> GetPatientByPatientIdDBAsync(GetPatientByPatientIdDBRequest request);

        /// <summary>
        /// 根据项目Code、设备ID、设备病人ID获取病人
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PatientInfoDTO> GetPatientByProjectCodeDBAsync(GetPatientByProjectCodeDBRequest request);
    }
}