
using System.Collections.Generic;
using System.Threading.Tasks;
using WingInterfaceLibrary.DB.Request;
using WingInterfaceLibrary.DTO.Education;
using WingInterfaceLibrary.DTO.Management;
using WingInterfaceLibrary.DTO.Payment;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Request.DBRequest;
using WingInterfaceLibrary.Request.Education;
using WingInterfaceLibrary.Result;

namespace WingInterfaceLibrary.Interface.DBInterface
{
    /// <summary>
    /// 支付数据库服务
    /// </summary>
    public interface IPaymentDBService
    {
        /// <summary>
        /// 创建订单接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<CreateOrderResultDTO> CreateOrderAsync(CreateOrderDBRequest request);

        /// <summary>
        /// 更新订单接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<UpdateOrderResultDTO> UpdateOrderAsync(UpdateOrderDBRequest request);

        /// <summary>
        /// 根据关联编码获取商品详情
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ProductDetailDTO> GetProductByRelationInfoAsync(GetProductByRelationInfoDBRequest request);

        /// <summary>
        /// 订单详情接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<OrderDetailDTO> GetOrderDetailAsync(GetOrderDetailDBRequest request);

        /// <summary>
        /// 订单列表接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<OrderDetailDTO>> GetOrderPagesAsync(GetOrderPagesDBRequest request);

        /// <summary>
        /// 新增商品信息接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<CreateProductDTO> CreateProductAsync(CreateProductDBRequest request);

        /// <summary>
        /// 修改商品信息接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<UpdateProductDTO> UpdateProductAsync(UpdateProductDBRequest request);

        /// <summary>
        /// 根据关联信息修改商品信息接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<UpdateProductDTO> UpdateProductByRelationAsync(UpdateProductByRelationDBRequest request);

        /// <summary>
        /// 新增支付记录信息接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<CreatePaymentRecordResultDTO> CreatePaymentRecordAsync(CreatePaymentRecordDBRequest request);

        /// <summary>
        /// 新增支付记录信息接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<UpdatePaymentRecordResultDTO> UpdatePaymentRecordAsync(UpdatePaymentRecordDBRequest request);

        /// <summary>
        /// 支付记录接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<PaymentRecordDTO>> GetPaymentRecordsAsync(GetPaymentRecordsDBRequest request);

        /// <summary>
        /// 支付成功结果处理
        /// </summary>
        /// <returns></returns>
        Task<PaySuccessDBResult> PaySuccessAsync(PaySuccessDBRequest request);

        /// <summary>
        /// 插入支付链接信息
        /// </summary>
        /// <param name="orderCode"></param>
        /// <param name="payUrl"></param>
        /// <returns></returns>
        Task<InsertPayUrlDBResult> InsertPayUrlAsync(InsertPayUrlDBRequest request);

        /// <summary>
        /// 获取支付链接信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<GetPayUrlDBResult> GetPayUrlAsync(GetPayUrlDBRequest request);
    }
}