using System.Threading.Tasks;
using WingInterfaceLibrary.DB.Request;
using WingInterfaceLibrary.DTO.Record;
using WingInterfaceLibrary.Request;
using System.Collections.Generic;
using WingInterfaceLibrary.Result;
using WingInterfaceLibrary.Result.Record;
using WingInterfaceLibrary.Request.DBRequest;
using WingInterfaceLibrary.DTO.DataCenter;
using WingInterfaceLibrary.Request.Record;

namespace WingInterfaceLibrary.Interface.DBInterface
{
    public interface IRecordsInfoDBService
    {
        Task<string> InsertRecordInfoAsync(CreateRecordInfoDBRequest request);
        Task<bool> UpdateRecordInfoByCodeAsync(string code, RecordInfoDTO data, string extensionData, bool canNull = false);

        /// <summary>
        /// 删除检查
        /// </summary>
        /// <param name="code"></param>
        /// <returns></returns>
        Task<bool> DeleteRecordInfoByCodeAsync(string code);

        Task<RecordInfoDTO> FindRecordInfoByCodeAsync(string code);
        Task<PageCollection<RecordInfoDTO>> FindRecordInfoPagesAsync(FindRecordInfoPagesRequest request);

        Task<PageResult<GetRecordsPageDTO>> FindFullRecordInfoPagesAsync(FindFullRecordInfoPagesRequest request);

        Task<IList<GetRecordsPageDTO>> GetRecordsPageDBAsync(GetRecordsPageDBRequest request);

        /// <summary>
        /// 查询检查记录数量
        /// </summary>
        /// <param name="request">查询检查记录数量请求实体</param>
        /// <returns></returns>
        Task<long> FindRecordInfoNumAsync(FindRecordInfoNumRequest request);

        /// <summary>
        /// 根据记录codes查询记录信息列表
        /// </summary>
        /// <param name="recordCodes">记录列表</param>
        /// <returns>信息列表</returns>
        Task<List<RecordInfoDTO>> FindRecordsByRecordCodesAsync(List<string> recordCodes);

        /// <summary>
        /// 更改指定设备上传检查记录的医院
        /// 设备主动上传检查记录的医院是设备医院
        /// </summary>
        /// <param name="deviceCodes">设备编码集合</param>
        /// <param name="newOrgCode">医院编码</param>
        /// <returns></returns>
        Task<bool> UpdateRecordsWithOrgCodeAsync(List<string> deviceCodes, string newOrgCode);

        /// <summary>
        /// 查询未完成AI诊断的检查记录
        /// </summary>
        /// <returns></returns>
        Task<List<RecordInfoDTO>> GetDiagnosisInProcessRecordAsync();

        /// <summary>
        /// 保存检查AI诊断结果
        /// </summary>
        /// <param name="request">保存检查AI诊断结果请求实体</param>
        /// <returns></returns>
        Task<bool> UpdateRecordDiagnosisResultAsync(UpdateRecordDiagnosisResultDBRequest request);

        /// <summary>
        /// 根据病人ID查询检查记录-健康体检
        /// </summary>
        /// <returns></returns>
        Task<RecordInfoDTO> GetVitalRecordByPatientIdDBAsync(GetVitalRecordByPatientIdDBRequest request);

        /// <summary>
        /// 查询转诊配置信息
        /// </summary>
        /// <returns></returns>
        Task<ReferralRecordSettingDTO> GetReferralRecordSettingAsync(GetReferralRecordSettingDBRequest request);

        /// <summary>
        /// 保存转诊配置信息
        /// </summary>
        /// <returns></returns>
        Task<bool> UpdateReferralRecordSettingAsync(UpdateReferralRecordSettingDBRequest request);

        /// <summary>
        /// 查询对应记录中是否存在用户提交的报告
        /// </summary>
        /// <param name="recordCode">记录编码</param>
        /// <param name="userCode">用户编码</param>
        /// <returns></returns>
        Task<bool> ExistRecordReportsByUserAsync(string recordCode, string userCode);

        /// <summary>
        /// 获取诊断数据发送给数据中心
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<RemoteDiagnosisDTO>> FindRemoteDiagnosisByDateCenterDBAsync(FindRemoteDiagnosisByDateCenterDBRequest request);

        /// <summary>
        /// 查询病人关联检查记录
        /// </summary>
        /// <param name="patientCodes"></param>
        /// <returns></returns>
        Task<IList<RecordInfoDTO>> GetPatientRecordsDBAsync(IList<string> patientCodes);

        /// <summary>
        /// 根据设备查询检查记录
        /// </summary>
        /// <param name="deviceCode"></param>
        /// <returns></returns>
        Task<IList<RecordInfoDTO>> FindRecordInfosByDeviceCodeAsync(string deviceCode);

        /// <summary>
        /// 分页查询增量检查集合
        /// </summary>
        /// <returns></returns>
        Task<PageResult<RecordInfoDTO>> FindRecordInfosByUpdateTimeDBAsync(FindCollectionByTimeDBRequest request);

        /// <summary>
        /// 保存检查记录
        /// </summary>
        /// <returns></returns>
        Task<bool> SaveRecordInfoDBAsync(RecordInfoDTO request);

        Task<PageResult<SimpleRecordInfoDTO>> FindRecordByPageAsync(FindRecordByPageDBRequest request);

        /// <summary>
        /// 查询检查记录大列表（分页）
        /// </summary>
        /// <param name="request">查询检查记录列表（分页）请求实体</param>
        /// <returns></returns>
        Task<PageResult<SimpleRecordInfoDTO>> FindRecordPagesAsync(FindFullRecordInfoPagesRequest request);

        /// <summary>
        /// 查询转诊历史
        /// </summary>
        /// <param name="request">查询查询转诊历史</param>
        /// <returns>转诊历史</returns>
        Task<List<ReferralHistoryDetail>> FindReferralHistoryDBAsync(FindReferralHistoryDBRequest request);

        /// <summary>
        /// 根据recordcode查询转诊列表
        /// </summary>
        /// <param name="request">根据recordcode查询转诊列表</param>
        /// <returns>转诊历史</returns>
        Task<List<ReferralData>> FindReferralDatasByRecordCodeDBAsync(string recordCode);

        /// <summary>
        /// 新增转诊记录
        /// </summary>
        /// <param name=""> </param>
        /// <returns>
        Task<string> InsertReferralDataAsync(ReferralData referralData);

        /// <summary>
        /// 修改转诊记录
        /// </summary>
        /// <param name="data"></param>
        /// <param name="canNull"></param>
        /// <returns></returns>
        Task<bool> UpdateReferralDataAsync(ReferralData data, bool canNull = false);

        /// <summary>
        /// 通过设备检查代码查找记录
        /// </summary>
        /// <param name="code">要查询的记录的代码</param>
        /// <returns>
        /// 一个 RecordInfoDTO 对象
        /// </returns>
        Task<RecordInfoDTO> FindRecordInfoByDeviceExamIdAsync(string code);

        /// <summary>
        /// 根据设备检查编码和项目code查找记录
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<RecordInfoDTO> FindRecordInfoByDeviceExamIdAndProjectCodeAsync(FindRecordInfoByDeviceExamIdAndProjectCodeRequest request);

         /// <summary>
        /// 根据设备检查编码和病人code查找记录
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<RecordInfoDTO> FindRecordInfoByDeviceExamIdAndPatientCodeAsync(FindRecordInfoByDeviceExamIdAndPatientCodeRequest request);
    }
}
