using System.Collections.Generic;
using System.Threading.Tasks;
using WingInterfaceLibrary.DB.Request;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Vital;
using WingInterfaceLibrary.Result;

namespace WingInterfaceLibrary.Interface.DBInterface
{
    /// <summary>
    /// 健康体检-登记详细信息置 数据库服务
    /// </summary>
    public interface IRegisterInfoDBService
    {
        /// <summary>
        /// 新增登记
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> AddRegisterInfoAsync(RegisterInfoDTO request);

        /// <summary>
        /// 根据code查询登记信息
        /// </summary>
        /// <param name="code"></param>
        /// <returns></returns>
        Task<RegisterInfoDTO> FindRegisterInfoByCodeAsync(string code);

        /// <summary>
        /// 修改登记信息
        /// </summary>
        /// <param name="registerInfoDTO"></param>
        /// <returns></returns>
        Task<bool> UpdateRegisterInfoAsync(RegisterInfoDTO registerInfoDTO);

        /// <summary>
        /// 修改结果和建议信息
        /// </summary>
        /// <param name="Code"></param>
        /// <param name="resultsAndSuggestions"></param>
        /// <returns></returns>
        Task<bool> UpdateResultsAndSuggestionsAsync(string code, string resultsAndSuggestions, string healthGuidance, List<DataItemDTO> diagnosis);

        /// <summary>
        /// 根据身份证获取居民登记记录
        /// </summary>
        /// <returns></returns>
        Task<List<RegisterInfoDTO>> GetPersonRegisteredInfosDBAsync(GetPersonRegisteredInfosDBRequest request);

        /// <summary>
        /// 获取登记信息列表分页
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns>返回报告列表</returns>
        Task<PageCollection<RegisterInfoDTO>> GetRegisterInfoPageAsync(GetRegisterInfoPageDBRequest request);

        /// <summary>
        /// 根据code删除登记信息
        /// </summary>
        /// <param name="code"></param>
        /// <returns></returns>
        Task<bool> DeleteRegisterInfoAsync(string code);

        /// <summary>
        /// 删除居民体检记录
        /// </summary>
        /// <returns></returns>
        Task<bool> DeleteRegisterInfoByIdCardNoDBAsync(DeleteRegisterInfoByIdCardNoDBRequest request);

        /// <summary>
        /// 查询该机构当天已经登记了多少人
        /// </summary>
        /// <returns></returns>
        Task<int> GetRegisterNumberAsync(string organizationCode);

        /// <summary>
        /// 查询所有已体检完成未出报告的登记
        /// </summary>
        /// <returns></returns>
        Task<IList<RegisterInfoDTO>> GetInspectedRegisterInfoListDBAsync(List<string> physicalExamNumbers, string cardNo = "", bool isQueryReportState = false);

        /// <summary>
        /// 查询所有已体检完成未出报告的登记
        /// </summary>
        /// <returns></returns>
        Task<RegisterPersonInfoDTO> GetRegisterPersonInfoByPhysicalExamNumberDBAsync(GetRegisterPersonRequest request);

        /// <summary>
        /// 分页查询增量登记集合
        /// </summary>
        /// <returns></returns>
        Task<PageResult<RegisterPersonInfoDTO>> FindRegisterPersonInfosByUpdateTimeDBAsync(FindCollectionByTimeDBRequest request);

        /// <summary>
        /// 保存登记记录
        /// </summary>
        /// <returns></returns>
        Task<bool> SaveRegisterPersonInfoDBAsync(RegisterPersonInfoDTO request);

        /// <summary>
        /// 根据检测编号获取最新的体检登记记录
        /// </summary>
        /// <returns></returns>
        Task<RegisterInfoDTO> GetRegisterInfoByExamNumberDBAsync(GetRegisterInfoByExamNumberDBRequest request);

        /// <summary>
        /// 根据检测编号批量获取最新的体检登记记录
        /// </summary>
        /// <returns></returns>
        Task<List<RegisterInfoDTO>> GetRegisterInfosByExamNumbersDBAsync(GetRegisterInfosByExamNumbersDBRequest request);
    }
}