using System.Threading.Tasks;
using WingInterfaceLibrary.DB.Request;
using WingInterfaceLibrary.Result.Record;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Record;
using WingInterfaceLibrary.Request.Examine;
using WingInterfaceLibrary.Result;
using WingInterfaceLibrary.Request.DBRequest;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.DTO.Report;
using WingInterfaceLibrary.DTO.ReportTemplate;
using WingInterfaceLibrary.Request.Management;
using WingInterfaceLibrary.Request.Report;

namespace WingInterfaceLibrary.Interface.DBInterface
{
    /// <summary>
    /// 报告转发厂商配置服务
    /// </summary>
    public interface IReportPosterDBService
    {
        /// <summary>
        /// 查询报告转发厂商配置详情
        /// </summary>
        /// <returns></returns>
        Task<ReportPosterDTO> GetReportPosterByCodeAsync(GetReportPosterByCodeDBRequest request);

        /// <summary>
        /// Get report post info list from 
        /// </summary>
        /// <param name="codes">The specified codes</param>
        /// <returns></returns>
        Task<List<ReportPosterDTO>> GetReportPostersWithCodesAsync(List<string> codes);

        /// <summary>
        /// 查询所有报告转发厂商配置详情
        /// </summary>
        /// <returns></returns>
        Task<List<ReportPosterDTO>> GetReportPosterAllAsync();

        /// <summary>
        /// 分页查询报告转发厂商配置详情
        /// </summary>
        /// <returns></returns>
        Task<PageResult<ReportPosterDTO>> GetReportPosterByPageAsync(GetReportPosterByPageDBRequest request);

        /// <summary>
        /// 查询关联设备Codes
        /// </summary>
        /// <returns></returns>
        Task<List<string>> GetRelatedDeviceCodesAsync(GetRelatedDeviceCodesDBRequest request);

        /// <summary>
        /// 添加报告转发厂商配置详情
        /// </summary>
        /// <returns></returns>
        Task<string> AddReportPosterAsync(AddReportPosterDBRequest request);

        /// <summary>
        /// 修改报告转发厂商配置详情
        /// </summary>
        /// <returns></returns>
        Task<bool> UpdateReportPosterAsync(UpdateReportPosterDBRequest request);

        /// <summary>
        /// 删除报告转发厂商配置详情
        /// </summary>
        /// <returns></returns>
        Task<bool> DeleteReportPosterAsync(DeleteReportPosterDBRequest request);

        /// <summary>
        /// 设置报告转发厂商关联设备集合 
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<string>> UpdateReportPosterDevicesAsync(UpdateReportPosterDevicesDBRequest request);

        /// <summary>
        ///  分页查询报告转发记录请求
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<ReportPushRecordDTO>> GetReportPushRecordsByPageAsync(GetReportPushRecordsByPageDBRequest request);
        /// <summary>
        /// 增加报告推送记录请求
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ReportPushRecordDTO> AddReportPushRecordAsync(AddReportPushRecordDBRequest request);
        /// <summary>
        /// 更新报告推送记录请求
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ReportPushRecordDTO> UpdateReportPushRecordAsync(UpdateReportPushRecordDBRequest request);

        /// <summary>
        /// 根据状态查询数据
        /// </summary>
        /// <param name="state"></param>
        /// <returns></returns>
        Task<List<ReportPushRecordDTO>> GetAllReportPushRecordsByStateAsync(PushDataStateEnum state);

        /// <summary>
        /// 根据记录集合查询数据
        /// </summary>
        /// <param name="codes"></param>
        /// <returns></returns>
        Task<List<ReportPushRecordDTO>> GetReportPushRecordsByCodesAsync(List<string> codes);

        /// <summary>
        /// 通过报告更新状态
        /// </summary>
        /// <param name="reportId">报告Id</param>
        /// <param name="posterId">转发配置Id</param>
        /// <param name="state">状态</param>
        /// <returns></returns>
        Task<ReportPushRecordDTO> UpdatePushRecordStateByReportIdAsync(string reportId, string posterId, PushDataStateEnum state);

        /// <summary>
        /// 重置转发记录状态
        /// </summary>
        /// <param name="code"></param>
        /// <returns></returns>
        Task<bool> ResetRecordAsync(string code);    
        
        /// <summary>
        /// 批量新增报告推送数据
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>是否成功</returns>
        Task<bool> BatchInsertPosterConfigsDataAsync(BatchInsertPosterConfigRequest request);
    }
}