using System.Collections.Generic;
using System.Threading.Tasks;
using WingInterfaceLibrary.DB.Request;
using WingInterfaceLibrary.DTO.User;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.ResearchEdition;

namespace WingInterfaceLibrary.Interface.DBInterface
{
    /// <summary>
    /// 科研项目db服务接口
    /// </summary>
    public interface IResearchProjectDBService
    {
        /// <summary>
        /// 查询项目列表
        /// </summary>
        /// <param name="request">查询项目列表请求实体</param>
        /// <returns></returns>
        /// <errorCodes></errorCodes>
        Task<IList<ResearchProjectBaseDTO>> GetResearchProjectListDBAsync(GetResearchProjectListDBRequest request);

        /// <summary>
        /// 查询项目详情
        /// </summary>
        /// <param name="request">查询项目详情请求实体</param>
        /// <returns></returns>
        /// <errorCodes></errorCodes>
        Task<ResearchProjectDTO> GetResearchProjectDetailDBAsync(GetResearchProjectDetailRequest request);

        /// <summary>
        /// 创建项目
        /// </summary>
        /// <param name="request">创建项目请求实体</param>
        /// <returns></returns>
        Task<string> CreateResearchProjectDBAsync(CreateResearchProjectDBRequest request);

        /// <summary>
        /// 修改项目
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateResearchProjectDBAsync(UpdateResearchProjectDBRequest request);

        /// <summary>
        /// 删除项目
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeleteResearchProjectDBAsync(DeleteResearchProjectDBRequest request);

        /// <summary>
        /// 邀请成员
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> InviteResearchProjectMembersDBAsync(ResearchProjectMembersDBRequest request);

        /// <summary>
        /// 移除成员
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> RemoveResearchProjectMembersDBAsync(ResearchProjectMembersDBRequest request);

        /// <summary>
        /// 创建任务
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> CreateResearchProjectTaskDBAsync(CreateResearchProjectTaskDBRequest request);

        /// <summary>
        /// 更新任务进度状态
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateResearchProjectTaskDBAsync(UpdateResearchProjectTaskDBRequest request);

        /// <summary>
        /// 查询任务列表
        /// </summary>
        /// <returns></returns>
        Task<IList<TaskBaseDTO>> GetMainTaskListDBAsync(GetMainTaskListDBRequest request);

        /// <summary>
        /// 根据项目查询任务列表(时间轴)
        /// </summary>
        /// <returns></returns>
        Task<IList<TaskBaseDTO>> GetMainTaskListByProjectDBAsync(GetTaskListByProjectRequest request);

        /// <summary>
        /// 查询任务详情
        /// </summary>
        /// <returns></returns>
        Task<MainTaskDTO> GetMainTaskDetailDBAsync(GetMainTaskListDBRequest request);

        /// <summary>
        /// 查询所有用户集合（分页）
        /// </summary>
        /// <param name="request">查询机构专家集合请求实体</param>
        /// <returns></returns>
        /// <errorCodes></errorCodes>
        Task<PageCollection<UserBaseDTO>> GetUserBaseInfoPagesDBAsync(FindUserPageByOrgsRequest request);

        /// <summary>
        /// 查询项目数据
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageCollection<ResearchProjectDataDTO>> GetResearchProjectDataPagesDBAsync(GetResearchProjectDatasRequest request);

        /// <summary>
        /// 获取URM关联图像集合
        /// </summary>
        /// <returns></returns>
        Task<List<SampleRemedicalInfoDTO>> GetUrmRemedicalInfosDBAsync(string urmRemedicalCode);

        /// <summary>
        /// GetSampleDetailDBList
        /// </summary>
        /// <param name="patientCode"></param>
        /// <returns></returns>
        Task<IList<SampleDetail>> GetSampleDetailDBList(IList<string> patientCodes);

        /// <summary>
        /// 转入数据接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> TransferDataDBAsync(TransferDataDBRequest request);

        /// <summary>
        /// GetTimeAxisByProjectDBAsync
        /// </summary>
        /// <param name="projectCode"></param>
        /// <returns></returns>
        Task<IList<TimeAxisDetail>> GetTimeAxisByProjectDBAsync(string projectCode);

        /// <summary>
        /// 样本数据导出列表db接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ProjectSampleDataExportResult> GetProjectSampleDataExportDBAsync(GetProjectSampleDataExportRequest request);

        /// <summary>
        /// 查询所有科研病例样本列表
        /// </summary>
        /// <param name="request">病例样本搜索实体</param>
        /// <returns></returns>
        /// <errorCodes></errorCodes>
        Task<PageCollection<PatientSampleDataDTO>> GetAllPatientSamplePagesDBAsync(GetRRUserPagesRequest request);

        /// <summary>
        /// 删除指定样本数据
        /// </summary>
        /// <param name="request">病例样本搜索实体</param>
        /// <returns></returns>
        /// <errorCodes></errorCodes>
        Task<bool> DeletePatientSampleDataDBAsync(DeletePatientSampleRequest request);

        /// <summary>
        /// 验证用户项目是否有项目权限或者项目是否存在
        /// </summary>
        /// <param name="request">查询项目详情请求实体</param>
        /// <returns></returns>
        Task<bool> ValidateResearchProjectAuthDBAsync(GetResearchProjectDetailRequest request);
    }
}