using System.Threading.Tasks;
using WingInterfaceLibrary.DB.Request;
using WingInterfaceLibrary.Result.Record;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Record;
using WingInterfaceLibrary.Request.Examine;
using WingInterfaceLibrary.Result;
using WingInterfaceLibrary.Request.DBRequest;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.DTO.Report;
using WingInterfaceLibrary.DTO.ReportTemplate;
using WingInterfaceLibrary.Request.Management;
using WingInterfaceLibrary.Request.Report;
using WingInterfaceLibrary.DTO.Statistic;
using WingInterfaceLibrary.Request.DBRequest;
using WingInterfaceLibrary.DTO.CMSStatistic;

namespace WingInterfaceLibrary.Interface.DBInterface
{
    /// <summary>
    /// 统计数据DB
    /// </summary>
    public interface IStatisticDBService
    {
        /// <summary>
        /// 查询统计配置集合
        /// </summary>
        /// <returns></returns>
        Task<IList<StatisticDTO>> GetStatisticAsync(GetStatisticDBRequest request);

        /// <summary>
        /// 保存统计结果
        /// </summary>
        /// <returns></returns>
        Task<bool> SaveStatisticRecordAsync(SaveStatisticRecordDBRequest request);

        /// <summary>
        /// 用户编码查询统计结果
        /// </summary>
        /// <returns></returns>
        Task<IList<StatisticRecordDTO>> GetStatisticRecordsDBByUserAsync(GetStatisticRecordsDBByUserRequest request);

        /// <summary>
        /// 查询已过期的统计数据
        /// </summary>
        /// <returns></returns>
        Task<IList<StatisticRecordDTO>> GetExpiredStatisticRecordsAsync(GetStatisticDBRequest request);

        /// <summary>
        /// 删除统计数据
        /// </summary>
        /// <returns></returns>
        Task<bool> DeleteStatisticRecordAsync(DeleteStatisticRecordDBRequest request);

        /// <summary>
        /// 删除统计数据
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeleteStatisticRecordsByUserCodeAsync(DeleteStatisticRecordsByUserCodeDBRequest request);

        /// <summary>
        /// 我的待办
        /// </summary>
        /// <returns></returns>
        Task<List<StatisticMyPendingDTO>> GetMyPendingStatisticAsync(GetMyPendingStatisticDBRequest request);

        /// <summary>
        /// 我的战绩
        /// </summary>
        /// <returns></returns>
        Task<List<StatisticMyStandingDTO>> GetMyStandingStatisticAsync(GetMyStandingStatisticDBRequest request);

        /// <summary>
        /// 诊断数据统计查询接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<StatisticRealtimeDataDTO>>  GetRealtimeDataStatisticAsync(GeGetRealtimeDataStatisticDBRequest request);
       
        /// <summary>
        /// 提交报告统计查询接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<StatisticSubmittedReportsDTO>> GetSubmittedReportsStatisticAsync(GetGetSubmittedReportsStatisticDBRequest  request);

        /// <summary>
        /// 诊断数据数量统计查询接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<StatisticDiagnosisDataDTO>> GetDiagnosisStatisticAsync(GetDiagnosisStatisticDBRequest   request);


    }
}