﻿using System.Collections.Generic;
using System.Threading.Tasks;
using WingInterfaceLibrary.DB.Request;
using WingInterfaceLibrary.DTO.Position;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.Interface.DBInterface
{
    public interface ITokenDBService
    {
        /// <summary>
        /// 新增tokeninfo
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> AddTokenInfoAsync(AddTokenInfoRequest request);
        /// <summary>
        /// 删除tokeninfo
        /// </summary>
        /// <param name="value"></param>
        /// <returns></returns>
        Task<bool> RemoveTokenAsync(string value);
        /// <summary>
        /// 修改tokeninfo
        /// </summary>
        /// <param name="value"></param>
        /// <param name="token"></param>
        /// <returns></returns>
        Task<bool> UpdateTokenAsync(string value, TokenDTO token);
        /// <summary>
        /// 根据clentid和loginsource获取tokeninfo(按过期时间倒序)
        /// </summary>
        /// <param name="clentId"></param>
        /// <param name="loginSource"></param>
        /// <returns></returns>
        Task<TokenDTO> FindTokenByClentIdAndLoginSourceAsync(string clentId, LoginSource loginSource);
        /// <summary>
        /// 根据clentId查询全部token
        /// </summary>
        /// <param name="clentId"></param>
        /// <returns></returns>
        Task<List<TokenDTO>> FindTokensByClentIdAsync(string clentId);
        /// <summary>
        /// 根据token获取tokeninfo
        /// </summary>
        /// <param name="value">token</param>
        /// <returns></returns>
        Task<TokenDTO> FindTokenByValueAsync(string value);
        /// <summary>
        /// 根据clentid和获取tokeninfo
        /// </summary>
        /// <param name="ids">Id list</param>
        /// <returns></returns>
        Task<List<TokenDTO>> FindTokensWithIdsAsync(IList<string> ids);
        /// <summary>
        /// 查询全部未过期token
        /// </summary>
        /// <returns></returns>
        Task<List<TokenDTO>> FindNotExpiredTokensAsync();
        /// <summary>
        /// 查找所有已过期的令牌
        /// </summary>
        /// <returns></returns>
        Task<List<TokenDTO>> FindExpiredTokensAsync();
    }
}
