using System;
using System.Collections.Generic;
using System.Threading.Tasks;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request.DBRequest;
using WingInterfaceLibrary.Result;

namespace WingInterfaceLibrary.Interface.DBInterface
{
    /// <summary>
    /// 健康体检预约 数据库服务
    /// </summary>
    public interface IVitalHealthExamBookingDBService
    {
        /// <summary>
        /// 分页获取健康检查预约数据
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns></returns>
        Task<PageResult<HealthExamBookingDTO>> GetHealthExamBookingPageDBAsync(GetHealthExamBookingPageDBRequest request);

        /// <summary>
        /// 创建/更新健康检查预约数据
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<string> CreateOrUpdateHealthExamBookingDBAsync(HealthExamBookingDTO request);

        /// <summary>
        /// 根据编码获取健康检查预约数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<HealthExamBookingDTO> GetHealthExamBookingDBAsync(GetHealthExamBookingDBRequest request);

        /// <summary>
        /// 获取最近提交/获取时间
        /// </summary>
        /// <returns></returns>
        Task<DateTime> GetLatestSyncTimeDBAsync(GetLatestSyncTimeDBRequest request);

        /// <summary>
        /// 更新最近提交/获取时间
        /// </summary>
        /// <returns></returns>
        Task<bool> UpdateLatestSyncTimeDBAsync(UpdateLatestSyncTimeDBRequest request);

        /// <summary>
        /// 根据编码删除健康检查预约数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<bool> RemoveHealthExamBookingDBAsync(RemoveHealthExamBookingDBRequest request);

        /// <summary>
        /// 批量删除健康检查预约数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<bool> RemoveHealthExamBookingListDBAsync(RemoveHealthExamBookingListDBRequest request);

        /// <summary>
        /// 团队预约报名
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<bool> HealthExamBookingSignUpDBASync(HealthExamBookingSignUpDBRequest request);

        /// <summary>
        /// 根据录入人查询预约记录
        /// </summary>
        /// <param name="operatorCode"></param>
        /// <returns></returns>
        Task<List<HealthExamBookingDTO>> GetHealthExamBookingByInitiatorDBAsync(string operatorCode);

        /// <summary>
        /// 根据机构查询当日预约记录
        /// </summary>
        /// <param name="orgCode"></param>
        /// <returns></returns>
        Task<List<HealthExamBookingDTO>> GetHealthExamBookingByIDCardNoDBAsync(string orgCode);
        
        /// <summary>
        /// 根据机构codes查询所有的预约信息
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<IList<HealthExamBookingDTO>> GetHealthExamBookingListByOrgCodesDBAsync(List<string> orgCodes);

        /// <summary>
        /// 解除预约数据
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<bool> CancelHealthExamBookingDBAsync(string code,string identityCard);
    }
}