using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.DBVitalRequest;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.Interface.DBVitalInterface
{
    /// <summary>
    /// 接口解析配置服务
    /// </summary>
    public interface IVitalAnalyzeConfigDBService
    {
        /// <summary>
        /// 创建接口解析配置数据
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<string> CreateAnalyzeConfigAsync(CreateAnalyzeConfigDBRequest request);

        /// <summary>
        /// 根据编码获取接口解析配置数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<AnalyzeConfigDTO> GetAnalyzeConfigDetailAsync(GetAnalyzeConfigDBRequest request);

        /// <summary>
        /// 根据关键字段获取接口解析配置数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<AnalyzeConfigDTO> GetAnalyzeConfigDetailByKeyAsync(GetAnalyzeConfigByKeyDBRequest request);

        /// <summary>
        /// 获取接口解析配置数据分页
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns>返回接口解析配置列表</returns>
        Task<PageCollection<AnalyzeConfigDTO>> GetAnalyzeConfigPageAsync(DBPageRequest request);


        /// <summary>
        /// 删除接口解析配置数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<bool> RemoveAnalyzeConfigAsync(RemoveAnalyzeConfigDBRequest request);

        
        /// <summary>
        /// 删除多个接口解析配置数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<long> RemoveAnalyzeConfigListAsync(RemoveAnalyzeConfigListDBRequest request);


        /// <summary>
        /// 获取接口解析配置数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<AnalyzeConfigDTO>> GetAnalyzeConfigListAsync(GetAnalyzeConfigListDBRequest request);

        /// <summary>
        /// 根据关键字段获取接口解析配置数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<AnalyzeConfigDTO>> GetAnalyzeConfigListByKeyAsync(GetAnalyzeConfigListByKeyDBRequest request);

        /// <summary>
        /// 更新接口解析配置数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns></returns>
        Task<bool> UpdateAnalyzeConfigAsync(UpdateAnalyzeConfigDBRequest request);
    }
}
