using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.DBVitalRequest;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.Interface.DBVitalInterface
{
    /// <summary>
    /// 履约记录服务
    /// </summary>
    public interface IVitalCompletionRecordDBService
    {
        /// <summary>
        /// 创建履约记录数据
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<string> CreateCompletionRecordAsync(CreateCompletionRecordDBRequest request);

        /// <summary>
        /// 根据编码获取履约记录数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<CompletionRecordDTO> GetCompletionRecordDetailAsync(GetCompletionRecordDBRequest request);

        /// <summary>
        /// 根据关键字段获取履约记录数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<CompletionRecordDTO> GetCompletionRecordDetailByKeyAsync(GetCompletionRecordByKeyDBRequest request);

        /// <summary>
        /// 获取履约记录数据分页
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns>返回履约记录列表</returns>
        Task<PageCollection<CompletionRecordDTO>> GetCompletionRecordPageAsync(DBPageRequest request);


        /// <summary>
        /// 删除履约记录数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<bool> RemoveCompletionRecordAsync(RemoveCompletionRecordDBRequest request);

        
        /// <summary>
        /// 删除多个履约记录数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<long> RemoveCompletionRecordListAsync(RemoveCompletionRecordListDBRequest request);


        /// <summary>
        /// 获取履约记录数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<CompletionRecordDTO>> GetCompletionRecordListAsync(GetCompletionRecordListDBRequest request);

        /// <summary>
        /// 根据关键字段获取履约记录数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<CompletionRecordDTO>> GetCompletionRecordListByKeyAsync(GetCompletionRecordListByKeyDBRequest request);

        /// <summary>
        /// 更新履约记录数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns></returns>
        Task<bool> UpdateCompletionRecordAsync(UpdateCompletionRecordDBRequest request);
    }
}
