using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.DBVitalRequest;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.Interface.DBVitalInterface
{
    /// <summary>
    /// 合约记录服务
    /// </summary>
    public interface IVitalContractRecordDBService
    {
        /// <summary>
        /// 创建合约记录数据
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<string> CreateContractRecordAsync(CreateContractRecordDBRequest request);

        /// <summary>
        /// 根据编码获取合约记录数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<ContractRecordDTO> GetContractRecordDetailAsync(GetContractRecordDBRequest request);

        /// <summary>
        /// 根据关键字段获取合约记录数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<ContractRecordDTO> GetContractRecordDetailByKeyAsync(GetContractRecordByKeyDBRequest request);

        /// <summary>
        /// 获取合约记录数据分页
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns>返回合约记录列表</returns>
        Task<PageCollection<ContractRecordDTO>> GetContractRecordPageAsync(DBPageRequest request);


        /// <summary>
        /// 删除合约记录数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<bool> RemoveContractRecordAsync(RemoveContractRecordDBRequest request);

        
        /// <summary>
        /// 删除多个合约记录数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<long> RemoveContractRecordListAsync(RemoveContractRecordListDBRequest request);


        /// <summary>
        /// 获取合约记录数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<ContractRecordDTO>> GetContractRecordListAsync(GetContractRecordListDBRequest request);

        /// <summary>
        /// 根据关键字段获取合约记录数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<ContractRecordDTO>> GetContractRecordListByKeyAsync(GetContractRecordListByKeyDBRequest request);

        /// <summary>
        /// 查询医生最近签约记录数据
        /// </summary>
        /// <param name="request">查询医生最近签约记录数据请求</param>
        /// <returns></returns>
        Task<ContractRecordDTO> GetDoctorContractRecordDBAsync(GetDoctorContractRecordDBRequest request);

        /// <summary>
        /// 查询续签关联的签约记录数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<List<ContractRecordDTO>> GetRenewalContractDBAsync(GetRenewalContractDBRequest request);

        /// <summary>
        /// 更新合约记录数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns></returns>
        Task<bool> UpdateContractRecordAsync(UpdateContractRecordDBRequest request);

        /// <summary>
        /// 查询最后一次签约记录的信息
        /// </summary>
        /// <param name="request">请求</param>
        /// <returns></returns>
        Task<ContractRecordDTO> GetPatientLastContractRecordAsync(GetPatientLastContractRecordDBRequest request);

        /// <summary>
        /// 更新签约记录状态
        /// </summary>
        /// <param name="request">update request</param>
        /// <returns></returns>
        Task<bool> UpdateContractRecordStateAsync(UpdateContractRecordStateDBRequest request);
    }
}
