using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.DBVitalRequest;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.Interface.DBVitalInterface
{
    /// <summary>
    /// 合同模板服务
    /// </summary>
    public interface IVitalContractTemplateDBService
    {
        /// <summary>
        /// 创建合同模板数据
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<string> CreateContractTemplateAsync(CreateContractTemplateDBRequest request);

        /// <summary>
        /// 根据编码获取合同模板数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<ContractTemplateDTO> GetContractTemplateDetailAsync(GetContractTemplateDBRequest request);

        /// <summary>
        /// 根据关键字段获取合同模板数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<ContractTemplateDTO> GetContractTemplateDetailByKeyAsync(GetContractTemplateByKeyDBRequest request);

        /// <summary>
        /// 获取合同模板数据分页
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns>返回合同模板列表</returns>
        Task<PageCollection<ContractTemplateDTO>> GetContractTemplatePageAsync(GetContractTemplatePageDBRequest request);


        /// <summary>
        /// 删除合同模板数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<bool> RemoveContractTemplateAsync(RemoveContractTemplateDBRequest request);

        
        /// <summary>
        /// 删除多个合同模板数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<long> RemoveContractTemplateListAsync(RemoveContractTemplateListDBRequest request);


        /// <summary>
        /// 获取合同模板数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<ContractTemplateDTO>> GetContractTemplateListAsync(GetContractTemplateListDBRequest request);

        /// <summary>
        /// 根据关键字段获取合同模板数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<ContractTemplateDTO>> GetContractTemplateListByKeyAsync(GetContractTemplateListByKeyDBRequest request);

        /// <summary>
        /// 更新合同模板数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns></returns>
        Task<bool> UpdateContractTemplateAsync(UpdateContractTemplateDBRequest request);
    }
}
