using System.Threading.Tasks;
using WingInterfaceLibrary.Request.DBVitalRequest;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.Interface.DBVitalInterface
{
    /// <summary>
    /// 设备数据库服务
    /// </summary>
    public interface IVitalDeviceDBService
    {
        /// <summary>
        /// 创建设备
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<string> CreateDeviceAsync(CreateDeviceDBRequest request);

        /// <summary>
        /// 根据设备编码获取设备详情
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<DeviceDTO> GetDeviceDetailAsync(GetDeviceDBRequest request);

        /// <summary>
        ///根据唯一码获取设备信息接口
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<DeviceDTO> GetDeviceDetailByUniqueCodeAsync(GetDeviceByUniqueCodeDBRequest request);


        /// <summary>
        ///根据物理唯一码获取设备信息接口
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<bool> SetDeviceOrganizationAsync(SetDeviceOrganizationDBRequest request);

        /// <summary>
        /// 获取设备信息分页
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns></returns>
        Task<PageCollection<DeviceDTO>> GetDevicePageAsync(GetDevicePageDBPageRequest request);

        /// <summary>
        /// 删除设备
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<bool> RemoveDeviceAsync(RemoveDeviceDBRequest request);

        /// <summary>
        /// 更新设备数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns></returns>
        Task<bool> UpdateDeviceAsync(UpdateDeviceDBRequest request);

        /// <summary>
        /// 更新物理唯一码数据
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<DeviceDTO> GetDeviceDetailBySerialNumberAsync(GetDeviceByUniqueCodeDBRequest request);

        /// <summary>
        /// 上报设备信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> ReportingDeviceInfoAsync(ReportingDeviceInfoDBRequest request);

        /// <summary>
        /// 创建外设设备
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> CreatePeripheralDeviceAsync(CreatePeripheralDeviceDBRequest request);

        /// <summary>
        /// 删除外设设备
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> RemovePeripheralDeviceAsync(RemovePeripheralDeviceDBRequest request);
    }

}
