using System.Threading.Tasks;
using System.Collections.Generic;
using System.Collections.Concurrent;
using WingInterfaceLibrary.Request.DBVitalRequest;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.Interface.DBVitalInterface
{
    /// <summary>
    /// 诊疗服务
    /// </summary>
    public interface IVitalDiagnosisDBService
    {
        /// <summary>
        /// 创建诊疗数据
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<string> CreateDiagnosisAsync(CreateDiagnosisDBRequest request);

        /// <summary>
        /// 根据编码获取诊疗数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<DiagnosisDTO> GetDiagnosisDetailAsync(GetDiagnosisDBRequest request);

        /// <summary>
        /// 根据关键字段获取诊疗数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<DiagnosisDTO> GetDiagnosisDetailByKeyAsync(GetDiagnosisByKeyDBRequest request);

        /// <summary>
        /// 获取诊疗数据分页
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns>返回诊疗列表</returns>
        Task<PageCollection<DiagnosisDTO>> GetDiagnosisPageAsync(DBPageRequest request);


        /// <summary>
        /// 删除诊疗数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<bool> RemoveDiagnosisAsync(RemoveDiagnosisDBRequest request);

        
        /// <summary>
        /// 删除多个诊疗数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<long> RemoveDiagnosisListAsync(RemoveDiagnosisListDBRequest request);


        /// <summary>
        /// 获取诊疗数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<DiagnosisDTO>> GetDiagnosisListAsync(GetDiagnosisListDBRequest request);

        /// <summary>
        /// 根据关键字段获取诊疗数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<DiagnosisDTO>> GetDiagnosisListByKeyAsync(GetDiagnosisListByKeyDBRequest request);

        /// <summary>
        /// 获取诊疗聚合数据
        /// </summary>
        /// <param name="request">数据分页查询请求</param>
        /// <returns></returns>
        Task<PageCollection<DiagnosisAggregationRecord>> GetDiagnosisAggregationPageAsync(DBPageRequest request);

        /// <summary>
        /// 更新诊疗数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns></returns>
        Task<bool> UpdateDiagnosisAsync(UpdateDiagnosisDBRequest request);

        /// <summary>
        /// 提交诊疗数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns>true</returns>
        Task<bool> SubmitDiagnosisAsync(SubmitDiagnosisDBRequest request);

        /// <summary>
        /// 重新提交诊疗数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns>true</returns>
        Task<bool> ReinfusionDiagnosisAsync(ReinfusionDiagnosisDBRequest request);

        /// <summary>
        /// 设置诊疗时间
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns>true</returns>
        Task<bool> SetDiagnosisTimeAsync(SetDiagnosisTimeDBRequest request);

        /// <summary>
        /// 同步居民和诊疗数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns>true</returns>
        Task<bool> SyncPatientAndDiagnosisDataAsync(SyncPatientAndDiagnosisDataDBRequest request);

        /// <summary>
        /// 老平台同步过来的数据量
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> OldPlatformDiagnosisDataCountAsync(OldPlatformDiagnosisDataCountDBRequest request);

        /// <summary>
        /// 根据批次号删除诊疗数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns>true</returns>
        Task<bool> RemoveDiagnosisByAppDataIdAsync(RemoveDiagnosisByAppDataIdDBRequest request);
    }
}
