using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.DBVitalRequest;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.Interface.DBVitalInterface
{
    /// <summary>
    /// 字典服务
    /// </summary>
    public interface IVitalDictionaryDBService
    {
        /// <summary>
        /// 创建字典数据
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<string> CreateDictionaryAsync(CreateDictionaryDBRequest request);

        /// <summary>
        /// 根据编码获取字典数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<DictionaryDTO> GetDictionaryDetailAsync(GetDictionaryDBRequest request);

        /// <summary>
        /// 根据关键字段获取字典数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<DictionaryDTO> GetDictionaryDetailByKeyAsync(GetDictionaryByKeyDBRequest request);

        /// <summary>
        /// 获取字典数据分页
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns>返回字典列表</returns>
        Task<PageCollection<DictionaryDTO>> GetDictionaryPageAsync(DBPageRequest request);


        /// <summary>
        /// 删除字典数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<bool> RemoveDictionaryAsync(RemoveDictionaryDBRequest request);

        
        /// <summary>
        /// 删除多个字典数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<long> RemoveDictionaryListAsync(RemoveDictionaryListDBRequest request);


        /// <summary>
        /// 获取字典数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<DictionaryDTO>> GetDictionaryListAsync(GetDictionaryListDBRequest request);

        /// <summary>
        /// 根据关键字段获取字典数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<DictionaryDTO>> GetDictionaryListByKeyAsync(GetDictionaryListByKeyDBRequest request);

        /// <summary>
        /// 更新字典数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns></returns>
        Task<bool> UpdateDictionaryAsync(UpdateDictionaryDBRequest request);

        /// <summary>
        /// 根据关键字获取字典数据列表(包含单位列表)
        /// </summary>
        /// <param name="request">列表请求</param>
        /// <returns></returns>
        Task<List<DictionaryWithUnitDTO>> GetDictionaryNameAndUnitByKeysAsync(GetDictionaryNameAndUnitByKeysDBRequest request);
    }
}
