using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.DBVitalRequest;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.Interface.DBVitalInterface
{
    /// <summary>
    /// 服务
    /// </summary>
    public interface IVitalDynamicTypeDBService
    {
        /// <summary>
        /// 创建数据
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<string> CreateDynamicTypeAsync(CreateDynamicTypeDBRequest request);

        /// <summary>
        /// 根据编码获取数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<DynamicTypeDTO> GetDynamicTypeDetailAsync(GetDynamicTypeDBRequest request);

        /// <summary>
        /// 根据关键字段获取数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<DynamicTypeDTO> GetDynamicTypeDetailByKeyAsync(GetDynamicTypeByKeyDBRequest request);

        /// <summary>
        /// 获取数据分页
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns>返回列表</returns>
        Task<PageCollection<DynamicTypeDTO>> GetDynamicTypePageAsync(DBPageRequest request);


        /// <summary>
        /// 删除数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<bool> RemoveDynamicTypeAsync(RemoveDynamicTypeDBRequest request);

        
        /// <summary>
        /// 删除多个数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<long> RemoveDynamicTypeListAsync(RemoveDynamicTypeListDBRequest request);


        /// <summary>
        /// 获取数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<DynamicTypeDTO>> GetDynamicTypeListAsync(GetDynamicTypeListDBRequest request);

        /// <summary>
        /// 根据关键字段获取数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<DynamicTypeDTO>> GetDynamicTypeListByKeyAsync(GetDynamicTypeListByKeyDBRequest request);

        /// <summary>
        /// 更新数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns></returns>
        Task<bool> UpdateDynamicTypeAsync(UpdateDynamicTypeDBRequest request);
    }
}
