using System.Collections.Generic;
using System.Threading.Tasks;
using WingInterfaceLibrary.DB.Request;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.DBVitalRequest;
using WingInterfaceLibrary.Result;

namespace WingInterfaceLibrary.Interface.DBVitalInterface
{
    public interface IVitalElectrocardiogramDBService
    {
        /// <summary>
        /// 创建心电数据
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<string> CreateElectrocardiogramDBAsync(CreateElectrocardiogramDBRequest request);

        /// <summary>
        /// 根据编码获取心电数据
        /// </summary>
        /// <param name="code"></param>
        /// <returns></returns>
        Task<ElectrocardiogramRecord> GetExamElectrocardiogramDBAsync(string code);

        /// <summary>
        /// 修改心电数据
        /// </summary>
        /// <param name="record"></param>
        /// <returns></returns>
        Task<bool> UpdateExamElectrocardiogramDBAsync(ElectrocardiogramRecord record);

        /// <summary>
        /// 获取心电数据分页
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns>返回检查列表</returns>
        Task<PageCollection<ElectrocardiogramRecord>> GetElectrocardiogramDBPageAsync(GetElectrocardiogramDBPageRequest request);

        /// <summary>
        /// 删除心电数据
        /// </summary>
        /// <param name="code"></param>
        /// <returns></returns>
        Task<bool> RemoveElectrocardiogramDBAsync(string code);

        /// <summary>
        /// 根据体检号获取心电数据
        /// </summary>
        /// <param name="PhysicalExamNumber"></param>
        /// <returns></returns>
        Task<ElectrocardiogramRecord> GetElectrocardiogramDBByPhysicalExamNumberDBAsync(string physicalExamNumber);

        /// <summary>
        /// 分页查询增量心电记录集合
        /// </summary>
        /// <returns></returns>
        Task<PageResult<ElectrocardiogramRecord>> FindElectrocardiogramRecordByUpdateTimeDBAsync(FindCollectionByTimeDBRequest request);

        /// <summary>
        /// 保存心电记录
        /// </summary>
        /// <returns></returns>
        Task<bool> SaveElectrocardiogramRecordDBAsync(ElectrocardiogramRecord record);
 
    }
}