using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.DBVitalRequest;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.DB.Request;

namespace WingInterfaceLibrary.Interface.DBVitalInterface
{
    /// <summary>
    /// 检查服务
    /// </summary>
    public interface IVitalExamDBService
    {
        /// <summary>
        /// 创建检查数据
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<string> CreateExamAsync(CreateExamDBRequest request);

        /// <summary>
        /// 工作站体检更新检查结果
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> CreateOrUpdateExamAsync(ExamDTO request);

        /// <summary>
        /// 根据编码获取检查数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<ExamDTO> GetExamDetailAsync(GetExamDBRequest request);

        /// <summary>
        /// 根据关键字段获取检查数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<ExamDTO> GetExamDetailByKeyAsync(GetExamByKeyDBRequest request);

        /// <summary>
        /// 查询检查记录集合
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<List<ExamDTO>> GetExamInfosDBAsync(GetExamInfosDBRequest request);

        /// <summary>
        /// 获取检查数据分页
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns>返回检查列表</returns>
        Task<PageCollection<ExamDTO>> GetExamPageAsync(DBPageRequest request);

        /// <summary>
        /// 分页查询检查数据
        /// </summary>
        /// <param name="request">分页请求</param>
        /// /// <returns></returns>
        Task<PageCollection<ExamDTO>> GetExamInfoByPageDBAsync(GetExamInfoByPageDBRequest request);

        /// <summary>
        /// 删除检查数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<bool> RemoveExamAsync(RemoveExamDBRequest request);

        
        /// <summary>
        /// 删除多个检查数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<long> RemoveExamListAsync(RemoveExamListDBRequest request);


        /// <summary>
        /// 获取检查数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<ExamDTO>> GetExamListAsync(GetExamListDBRequest request);

        /// <summary>
        /// 根据关键字段获取检查数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<ExamDTO>> GetExamListByKeyAsync(GetExamListByKeyDBRequest request);

        /// <summary>
        /// 更新检查数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns></returns>
        Task<bool> UpdateExamAsync(UpdateExamDBRequest request);

        /// <summary>
        /// 查询是否存在已检查的信息
        /// </summary>
        /// <param name="request">请求</param>
        /// <returns></returns>
        Task<bool> ExistsPatientExamAsync(ExistsPatientExamDBRequest request);

        /// <summary>
        /// 查询最后一次检查的信息
        /// </summary>
        /// <param name="request">请求</param>
        /// <returns></returns>
        Task<ExamDTO> GetPatientLastExamAsync(GetPatientLastExamDBRequest request);
  
        /// <summary>
        /// 获取体检记录居民信息
        /// </summary>
        /// <param name="request">请求</param>
        /// <returns></returns>
        Task<PageCollection<ExamDTO>> GetExamRecordPageAsync(GetExamRecordPageDBRequest request);

        /// <summary>
        /// 根据批次号查询体检结果
        /// </summary>
        /// <returns></returns>
        Task<List<ExamDTO>> GetExamByBatchNumberDBAsync(GetExamByBatchNumberDBRequest request);

        /// <summary>
        /// 获取居民体检记录信息
        /// </summary>
        /// <param name="request">请求</param>
        /// <returns></returns>
        Task<List<ExamRecordDTO>> GetExamRecordListAsync(GetExamRecordListDBRequest request);

        /// <summary>
        /// 保存快捷检查
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SaveQuickCheckRecordAsync(SaveQuickCheckRecordDBRequest request);

        /// <summary>
        /// 根据批次号更新检查数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns></returns>
        Task<bool> UpdateExamByBatchNumberAsync(UpdateExamByBatchNumberDBRequest request);

         /// <summary>
        /// 根据体检号获取检查数据列表
        /// </summary>
        /// <param name="request">列表请求</param>
        /// <returns></returns>
        Task<List<ExamDTO>> GetExamListByPhysicalExamNumberDBAsync(string PhysicalExamNumber);

                 /// <summary>
        /// 根据体检号和key获取检查数据列表
        /// </summary>
        /// <param name="request">列表请求</param>
        /// <returns></returns>
        Task<ExamDTO> GetExamInfoByConditionDBAsync(string physicalExamNumber, string key);

        /// <summary>
        /// 根据体检号批量获取检查数据列表
        /// </summary>
        /// <param name="request">列表请求</param>
        /// <returns></returns>
        Task<List<ExamDTO>> GetExamInfosByExamNumbersDBAsync(List<string> physicalExamNumbers);

        /// <summary>
        /// 更新检查数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns></returns>
        Task<bool> UpdateExamStateAsync(UpdateExamDBRequest request);

        /// <summary>
        /// 分页查询增量检查信息集合
        /// </summary>
        /// <returns></returns>
        Task<PageCollection<ExamDTO>> FindExamByUpdateTimeDBAsync(FindCollectionByTimeDBRequest request);

        /// <summary>
        /// 保存检查记录
        /// </summary>
        /// <returns></returns>
        Task<bool> SaveExamInfoDBAsync(ExamDTO request);
    }
}
