using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.DBVitalRequest;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.DTO.Region;

namespace WingInterfaceLibrary.Interface.DBVitalInterface
{
    /// <summary>
    /// 第三方厂商信息服务
    /// </summary>
    public interface IVitalFacturyUserDBService
    {
        /// <summary>
        /// 创建数据
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<string> CreateFacturyUserDBAsync(CreateFacturyUserDBRequest request);

        /// <summary>
        /// 更新数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns></returns>
        Task<bool> UpdateFacturyUserDBAsync(UpdateFacturyUserDBRequest request);

        /// <summary>
        /// 根据编码获取第三方厂商信息
        /// </summary>
        /// <param name="request">数据编码</param>
        /// <returns></returns>
        Task<FacturyUserDTO> GetFacturyUserDBAsync(GetFacturyUserDBRequest request);

        /// <summary>
        /// 分页获取厂商数据
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns></returns>
        Task<PageCollection<FacturyUserDTO>> GetFacturyOrgByPageDBAsync(GetFacturyOrgByPageDBRequest request);

        /// <summary>
        /// 分页获取厂商员工数据
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns></returns>
        Task<PageCollection<FacturyUserDTO>> GetFacturyUserByPageDBAsync(GetFacturyUserByPageDBRequest request);

        /// <summary>
        /// 获取厂商员工列表
        /// </summary>
        /// <param name="request">列表请求</param>
        /// <returns></returns>
        Task<List<FacturyUserDTO>> GetFacturyUserInfosDBAsync(GetFacturyUserInfosDBRequest request);

        /// <summary>
        /// 获取所有厂商数据
        /// </summary>
        /// <returns></returns>
        Task<List<RegionDataItemDTO>> GetFacturyTreeDBAsync(GetFacturyTreeDBDBRequest request);

        /// <summary>
        /// 删除数据
        /// </summary>
        /// <param name="request">数据编码</param>
        /// <returns></returns>
        Task<bool> RemoveFacturyUserDBAsync(RemoveFacturyUserDBRequest request);
    }
}
