using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.DBVitalRequest;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.DB.Request;

namespace WingInterfaceLibrary.Interface.DBVitalInterface
{
    /// <summary>
    /// 随访服务
    /// </summary>
    public interface IVitalFollowUpDBService
    {
        /// <summary>
        /// 创建随访数据
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<string> CreateFollowUpAsync(CreateFollowUpDBRequest request);

        /// <summary>
        /// 根据体检号获取随访数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<FollowUpDTO> GetFollowUpDetailByPhysicalExamNumberAsync(GetFollowUpByPhysicalExamNumberDBRequest request);

        /// <summary>
        /// 根据编码获取随访数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<FollowUpDTO> GetFollowUpDetailAsync(GetFollowUpDBRequest request);

        /// <summary>
        /// 根据关键字段获取随访数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<FollowUpDTO> GetFollowUpDetailByKeyAsync(GetFollowUpByKeyDBRequest request);

        /// <summary>
        /// 获取随访数据分页
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns>返回随访列表</returns>
        Task<PageCollection<FollowUpDTO>> GetFollowUpPageAsync(DBPageRequest request);


        /// <summary>
        /// 删除随访数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<bool> RemoveFollowUpAsync(RemoveFollowUpDBRequest request);


        /// <summary>
        /// 删除多个随访数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<long> RemoveFollowUpListAsync(RemoveFollowUpListDBRequest request);


        /// <summary>
        /// 获取随访数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<FollowUpDTO>> GetFollowUpListAsync(GetFollowUpListDBRequest request);

        /// <summary>
        /// 根据关键字段获取随访数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<FollowUpDTO>> GetFollowUpListByKeyAsync(GetFollowUpListByKeyDBRequest request);

        /// <summary>
        /// 更新随访数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns></returns>
        Task<bool> UpdateFollowUpAsync(UpdateFollowUpDBRequest request);

        /// <summary>
        /// 查询是否存在已检查的信息
        /// </summary>
        /// <param name="request">请求</param>
        /// <returns></returns>
        Task<bool> ExistsPatientFollowUpAsync(ExistsPatientFollowUpDBRequest request);

        /// <summary>
        /// 查询最后一次检查的信息
        /// </summary>
        /// <param name="request">请求</param>
        /// <returns></returns>
        Task<FollowUpDTO> GetPatientLastFollowUpAsync(GetPatientLastFollowUpDBRequest request);

        /// <summary>
        /// 查询居民对应的随访记录信息
        /// </summary>
        /// <param name="request">请求</param>
        /// <returns></returns>
        Task<List<FollowUpRecordDTO>> GetFollowUpRecordListAsync(GetFollowUpRecordListDBRequest request);

        /// <summary>
        /// 查询居民对应的随访记录信息（按年）
        /// </summary>
        /// <param name="request">请求</param>
        /// <returns></returns>
        Task<List<FollowUpRecordDTO>> GetFollowUpRecordListByYearAsync(GetFollowUpRecordListByYearDBRequest request);

        /// <summary>
        /// 获取已随访的居民编码
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<string>> GetHasFollowUpPatientListAsync(GetHasFollowUpPatientListDBRequest request);        

        /// <summary>
        /// 分页查询增量中医体质集合
        /// </summary>
        /// <returns></returns>
        Task<PageCollection<FollowUpDTO>> FindFollowUpInfoByUpdateTimeDBAsync(FindCollectionByTimeDBRequest request);

        /// <summary>
        /// 保存中医体质记录
        /// </summary>
        /// <returns></returns>
        Task<bool> SaveFollowUpEntityInfoDBAsync(FollowUpDTO request);
    }
}
