using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.DBVitalRequest;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.Interface.DBVitalInterface
{
    /// <summary>
    /// 标签服务
    /// </summary>
    public interface IVitalLabelDBService
    {
        /// <summary>
        /// 创建标签数据
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<string> CreateLabelAsync(CreateLabelDBRequest request);

        /// <summary>
        /// 根据编码获取标签数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<LabelDTO> GetLabelDetailAsync(GetLabelDBRequest request);

        /// <summary>
        /// 根据关键字段获取标签数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<LabelDTO> GetLabelDetailByKeyAsync(GetLabelByKeyDBRequest request);

        /// <summary>
        /// 获取标签数据分页
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns>返回标签列表</returns>
        Task<PageCollection<LabelDTO>> GetLabelPageAsync(DBPageRequest request);


        /// <summary>
        /// 删除标签数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<bool> RemoveLabelAsync(RemoveLabelDBRequest request);

        
        /// <summary>
        /// 删除多个标签数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<long> RemoveLabelListAsync(RemoveLabelListDBRequest request);


        /// <summary>
        /// 获取标签数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<LabelDTO>> GetLabelListAsync(GetLabelListDBRequest request);

        /// <summary>
        /// 根据关键字段获取标签数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<LabelDTO>> GetLabelListByKeyAsync(GetLabelListByKeyDBRequest request);

        /// <summary>
        /// 更新标签数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns></returns>
        Task<bool> UpdateLabelAsync(UpdateLabelDBRequest request);
    }
}
