using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.DBVitalRequest;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.Interface.DBVitalInterface
{
    /// <summary>
    /// 服务
    /// </summary>
    public interface IVitalNotificationDBService
    {
        /// <summary>
        /// 创建数据
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<string> CreateNotificationAsync(CreateNotificationDBRequest request);

        /// <summary>
        /// 根据编码获取数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<NotificationDTO> GetNotificationDetailAsync(GetNotificationDBRequest request);

        /// <summary>
        /// 根据关键字段获取数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<NotificationDTO> GetNotificationDetailByKeyAsync(GetNotificationByKeyDBRequest request);

        /// <summary>
        /// 获取数据分页
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns>返回列表</returns>
        Task<FilterNotificationDTO> GetNotificationPageAsync(NotificationDBPageRequest request);


        /// <summary>
        /// 删除数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<bool> RemoveNotificationAsync(RemoveNotificationDBRequest request);

        
        /// <summary>
        /// 删除多个数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<long> RemoveNotificationListAsync(RemoveNotificationListDBRequest request);


        /// <summary>
        /// 获取数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<NotificationDTO>> GetNotificationListAsync(GetNotificationListDBRequest request);

        /// <summary>
        /// 根据关键字段获取数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<NotificationDTO>> GetNotificationListByKeyAsync(GetNotificationListByKeyDBRequest request);

        /// <summary>
        /// 更新数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns></returns>
        Task<bool> UpdateNotificationAsync(UpdateNotificationDBRequest request);
    }
}
