using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.DBVitalRequest;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.Interface.DBVitalInterface
{
    /// <summary>
    /// 操作日志服务
    /// </summary>
    public interface IVitalOperationLogDBService
    {
        /// <summary>
        /// 创建操作日志数据
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<string> CreateOperationLogAsync(CreateOperationLogDBRequest request);

        /// <summary>
        /// 根据编码获取操作日志数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<OperationLogDTO> GetOperationLogDetailAsync(GetOperationLogDBRequest request);

        /// <summary>
        /// 根据关键字段获取操作日志数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<OperationLogDTO> GetOperationLogDetailByKeyAsync(GetOperationLogByKeyDBRequest request);

        /// <summary>
        /// 获取操作日志数据分页
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns>返回操作日志列表</returns>
        Task<PageCollection<OperationLogDTO>> GetOperationLogPageAsync(DBPageRequest request);


        /// <summary>
        /// 删除操作日志数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<bool> RemoveOperationLogAsync(RemoveOperationLogDBRequest request);

        
        /// <summary>
        /// 删除多个操作日志数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<long> RemoveOperationLogListAsync(RemoveOperationLogListDBRequest request);


        /// <summary>
        /// 获取操作日志数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<OperationLogDTO>> GetOperationLogListAsync(GetOperationLogListDBRequest request);

        /// <summary>
        /// 根据关键字段获取操作日志数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<OperationLogDTO>> GetOperationLogListByKeyAsync(GetOperationLogListByKeyDBRequest request);

        /// <summary>
        /// 更新操作日志数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns></returns>
        Task<bool> UpdateOperationLogAsync(UpdateOperationLogDBRequest request);
    }
}
