using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.DBVitalRequest;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.Interface.DBVitalInterface
{
    /// <summary>
    /// 组织服务
    /// </summary>
    public interface IVitalOrganizationDBService
    {
        /// <summary>
        /// 创建组织数据
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<string> CreateOrganizationAsync(CreateOrganizationDBRequest request);

        /// <summary>
        /// 根据编码获取组织数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<OrganizationDTO> GetOrganizationDetailAsync(GetOrganizationDBRequest request);

        /// <summary>
        /// 根据关键字段获取组织数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<OrganizationDTO> GetOrganizationDetailByKeyAsync(GetOrganizationByKeyDBRequest request);

        /// <summary>
        /// 获取组织数据分页
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns>返回组织列表</returns>
        Task<PageCollection<OrganizationDTO>> GetOrganizationPageAsync(DBPageRequest request);


        /// <summary>
        /// 删除组织数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<bool> RemoveOrganizationAsync(RemoveOrganizationDBRequest request);


        /// <summary>
        /// 删除多个组织数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<long> RemoveOrganizationListAsync(RemoveOrganizationListDBRequest request);


        /// <summary>
        /// 获取组织数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<OrganizationDTO>> GetOrganizationListAsync(GetOrganizationListDBRequest request);

        /// <summary>
        /// 根据关键字段获取组织数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<OrganizationDTO>> GetOrganizationListByKeyAsync(GetOrganizationListByKeyDBRequest request);

        /// <summary>
        /// 更新组织数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns></returns>
        Task<bool> UpdateOrganizationAsync(UpdateOrganizationDBRequest request);

        /// <summary>
        /// 获取组织树状节点
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<OrganizationTreeDTO>> GetOrganizationTreeAsync(GetOrganizationTreeDBRequest request);

        /// <summary>
        /// 获取已启用的外设配置（Key）
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<string>> GetEnableDeviceKeysAsync(GetEnableDeviceKeysDBRequest request);

        /// <summary>
        /// 获取参数配置
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<DynamicParameterDTO>> GetDynamicParameterAsync(GetDynamicParameterDBRequest request);

        /// <summary>
        /// 查询子集机构
        /// </summary>
        /// <param name="fatherCode"></param>
        /// <returns></returns>
        Task<List<OrganizationDTO>> GetOrganizationsByFatherCodeAsync(string fatherCode);
    }
}
