using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.DBVitalRequest;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.DB.Request;

namespace WingInterfaceLibrary.Interface.DBVitalInterface
{
    /// <summary>
    /// 居民服务
    /// </summary>
    public interface IVitalPatientDBService
    {
        /// <summary>
        /// 创建居民数据
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<string> CreatePatientAsync(CreatePatientDBRequest request);

        /// <summary>
        /// 根据编码获取居民数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<PatientDTO> GetPatientDetailAsync(GetPatientDBRequest request);

        /// <summary>
        /// 根据编码获取居民数据，无权限控制
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<PatientDTO> GetPatientByCodeAsync(GetPatientByCodeDBRequest request);

        /// <summary>
        /// 根据编码获取居民数据如非同一团队则迁移人员
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<PatientDTO> GetPatientDetailOrMoveAsync(GetPatientDBRequest request);

        /// <summary>
        /// 根据关键字段获取居民数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<PatientDTO> GetPatientDetailByKeyAsync(GetPatientByKeyDBRequest request);

        /// <summary>
        /// 获取居民数据分页
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns>返回居民列表</returns>
        Task<PageCollection<PatientDTO>> GetPatientPageAsync(PatientPageDBRequest request);


        /// <summary>
        /// 删除居民数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<bool> RemovePatientAsync(RemovePatientDBRequest request);

        
        /// <summary>
        /// 删除多个居民数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<long> RemovePatientListAsync(RemovePatientListDBRequest request);


        /// <summary>
        /// 获取居民数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<PatientDTO>> GetPatientListAsync(GetPatientListDBRequest request);

        /// <summary>
        /// 根据关键字段获取居民数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<PatientDTO>> GetPatientListByKeyAsync(GetPatientListByKeyDBRequest request);

        /// <summary>
        /// 更新居民数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns></returns>
        Task<bool> UpdatePatientAsync(UpdatePatientDBRequest request);

        /// <summary>
        /// 更新居民照片数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns>true</returns>
        Task<bool> UpdatePatientPhotosAsync(UpdatePatientPhotosDBRequest request);

        /// <summary>
        /// 获取居民数据统计
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PatientStatisticDTO> GetPatientStatisticDBAsync(GetPatientStatisticDBRequest request);

        /// <summary>
        /// 分页查询增量居民信息集合
        /// </summary>
        /// <returns></returns>
        Task<PageCollection<PatientDTO>> FindPatientByUpdateTimeDBAsync(FindCollectionByTimeDBRequest request);

        /// <summary>
        /// 保存居民记录
        /// </summary>
        /// <returns></returns>
        Task<bool> SavePatientInfoDBAsync(PatientDTO request);
    }
}
