using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.DBVitalRequest;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.DB.Request;

namespace WingInterfaceLibrary.Interface.DBVitalInterface
{
    /// <summary>
    /// 居民扩展信息服务
    /// </summary>
    public interface IVitalPatientExtensionDBService
    {
        /// <summary>
        /// 创建居民扩展信息数据
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<string> CreatePatientExtensionAsync(CreatePatientExtensionDBRequest request);

        /// <summary>
        /// 根据编码获取居民扩展信息数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<PatientExtensionDTO> GetPatientExtensionDetailAsync(GetPatientExtensionDBRequest request);

        /// <summary>
        /// 根据编码和Key获取居民扩展信息数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<PatientExtensionDTO> GetPatientExtensionDetailByCodeAndKeyAsync(GetPatientExtensionByCodeAndKeyDBRequest request);

        /// <summary>
        /// 获取居民扩展信息数据分页
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns>返回居民扩展信息列表</returns>
        Task<PageCollection<PatientExtensionDTO>> GetPatientExtensionPageAsync(DBPageRequest request);


        /// <summary>
        /// 删除居民扩展信息数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<bool> RemovePatientExtensionAsync(RemovePatientExtensionDBRequest request);

        
        /// <summary>
        /// 删除多个居民扩展信息数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<long> RemovePatientExtensionListAsync(RemovePatientExtensionListDBRequest request);


        /// <summary>
        /// 获取居民扩展信息数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<PatientExtensionDTO>> GetPatientExtensionListAsync(GetPatientExtensionListDBRequest request);

        /// <summary>
        /// 根据关键字段获取居民扩展信息数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<PatientExtensionDTO>> GetPatientExtensionListByKeyAsync(GetPatientExtensionListByKeyDBRequest request);

        /// <summary>
        /// 更新居民扩展信息数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns></returns>
        Task<bool> UpdatePatientExtensionAsync(UpdatePatientExtensionDBRequest request);

        /// <summary>
        /// 分页查询增量居民扩展信息集合
        /// </summary>
        /// <returns></returns>
        Task<PageCollection<PatientExtensionDTO>> FindPatientExtensionByUpdateTimeDBAsync(FindCollectionByTimeDBRequest request);

        /// <summary>
        /// 保存居民扩展记录
        /// </summary>
        /// <returns></returns>
        Task<bool> SavePatientExtensionInfoDBAsync(PatientExtensionDTO request);
    }
}
