using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.DBVitalRequest;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Vital;
using WingInterfaceLibrary.DB.Request;
using WingInterfaceLibrary.Result;

namespace WingInterfaceLibrary.Interface.DBVitalInterface
{
    /// <summary>
    /// 处方服务
    /// </summary>
    public interface IVitalPrescriptionDBService
    {
        /// <summary>
        /// 创建处方数据
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<string> CreatePrescriptionAsync(CreatePrescriptionDBRequest request);

        /// <summary>
        /// 根据编码获取处方数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<PrescriptionDTO> GetPrescriptionDetailAsync(GetPrescriptionDBRequest request);

        /// <summary>
        /// 获取处方详情
        /// </summary>
        /// <param name="request">查询详情请求</param>
        /// <returns></returns>
        Task<PrescriptionDTO> GetPrescriptionDetailByFollowAnPatientAsync(GetPrescriptionDetailByFollowAnPatientDBRequest request);

        /// <summary>
        /// 根据关键字段获取处方数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<PrescriptionDTO> GetPrescriptionDetailByKeyAsync(GetPrescriptionByKeyDBRequest request);

        /// <summary>
        /// 获取处方数据分页
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns>返回处方列表</returns>
        Task<PageCollection<PrescriptionDTO>> GetPrescriptionPageAsync(PrescriptionDBPageRequest request);

        /// <summary>
        /// 删除处方数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<bool> RemovePrescriptionAsync(RemovePrescriptionDBRequest request);

        /// <summary>
        /// 删除多个处方数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<long> RemovePrescriptionListAsync(RemovePrescriptionListDBRequest request);

        /// <summary>
        /// 获取处方数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<PrescriptionDTO>> GetPrescriptionListAsync(GetPrescriptionListDBRequest request);

        /// <summary>
        /// 根据关键字段获取处方数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<PrescriptionDTO>> GetPrescriptionListByKeyAsync(GetPrescriptionListByKeyDBRequest request);

        /// <summary>
        /// 更新处方数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns></returns>
        Task<bool> UpdatePrescriptionAsync(UpdatePrescriptionDBRequest request);

        /// <summary>
        /// 设置处方预览图
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SetPrescriptionPreviewInfoAsync(SetPrescriptionPreviewInfoDBRequest request);

        /// <summary>
        /// 获取vital处方列表数据
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<PrescriptionDTO>> GetVitalPrescriptionListDBAsync(GetPrescriptionConditionRequest request);
    }
}
