using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.DBVitalRequest;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Vital;
using WingInterfaceLibrary.DB.Request;
using WingInterfaceLibrary.Result;

namespace WingInterfaceLibrary.Interface.DBVitalInterface
{
    /// <summary>
    /// 报告服务
    /// </summary>
    public interface IVitalReportDBService
    {
        /// <summary>
        /// 创建报告数据
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<string> CreateReportAsync(CreateReportDBRequest request);

        /// <summary>
        /// 根据编码获取报告数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<ReportDTO> GetReportDetailAsync(GetReportDBRequest request);

        /// <summary>
        /// 根据关键字段获取报告数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<ReportDTO> GetReportDetailByKeyAsync(GetReportByKeyDBRequest request);

        /// <summary>
        /// 获取报告数据分页
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns>返回报告列表</returns>
        Task<PageCollection<ReportDTO>> GetReportPageAsync(DBPageRequest request);


        /// <summary>
        /// 删除报告数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<bool> RemoveReportAsync(RemoveReportDBRequest request);


        /// <summary>
        /// 删除多个报告数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<long> RemoveReportListAsync(RemoveReportListDBRequest request);


        /// <summary>
        /// 获取报告数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<ReportDTO>> GetReportListAsync(GetReportListDBRequest request);

        /// <summary>
        /// 根据关键字段获取报告数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<ReportDTO>> GetReportListByKeyAsync(GetReportListByKeyDBRequest request);

        /// <summary>
        /// 更新报告数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns></returns>
        Task<bool> UpdateReportAsync(UpdateReportDBRequest request);

        /// <summary>
        /// 设置报告预览图
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SetReportPreviewInfoAsync(SetReportPreviewInfoDBRequest request);

        /// <summary>
        /// 获取vital报告列表数据
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<ReportDTO>> GetVitalReportListDBAsync(GetReportConditionRequest request);

        /// <summary>
        /// 获取vital报告数据根据reportCode
        /// </summary>
        /// <param name="reportCode"></param>
        /// <returns></returns>
        Task<ReportDTO> GetVitalReportInfoByReportCodeDBAsync(string reportCode, string examCode);

        Task<PageResult<ReportDTO>> FindReportDTOByUpdateTimeDBAsync(FindCollectionByTimeDBRequest request);

        Task<bool> SaveReportDBAsync(ReportDTO request);
    }
}
