using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.DBVitalRequest;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.Interface.DBVitalInterface
{
    /// <summary>
    /// 村、小区服务
    /// </summary>
    public interface IVitalResidenceDBService
    {
        /// <summary>
        /// 创建村、小区数据
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<string> CreateResidenceAsync(CreateResidenceDBRequest request);

        /// <summary>
        /// 根据编码获取村、小区数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<ResidenceDTO> GetResidenceDetailAsync(GetResidenceDBRequest request);

        /// <summary>
        /// 根据关键字段获取村、小区数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<ResidenceDTO> GetResidenceDetailByKeyAsync(GetResidenceByKeyDBRequest request);

        /// <summary>
        /// 获取村、小区数据分页
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns>返回村、小区列表</returns>
        Task<PageCollection<ResidenceDTO>> GetResidencePageAsync(DBPageRequest request);


        /// <summary>
        /// 删除村、小区数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<bool> RemoveResidenceAsync(RemoveResidenceDBRequest request);

        
        /// <summary>
        /// 删除多个村、小区数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<long> RemoveResidenceListAsync(RemoveResidenceListDBRequest request);


        /// <summary>
        /// 获取村、小区数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<ResidenceDTO>> GetResidenceListAsync(GetResidenceListDBRequest request);

        /// <summary>
        /// 根据关键字段获取村、小区数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<ResidenceDTO>> GetResidenceListByKeyAsync(GetResidenceListByKeyDBRequest request);

        /// <summary>
        /// 更新村、小区数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns></returns>
        Task<bool> UpdateResidenceAsync(UpdateResidenceDBRequest request);
    }
}
