using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.DBVitalRequest;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.Interface.DBVitalInterface
{
    /// <summary>
    /// 角色服务
    /// </summary>
    public interface IVitalRoleDBService
    {
        /// <summary>
        /// 创建角色数据
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<string> CreateRoleAsync(CreateRoleDBRequest request);

        /// <summary>
        /// 根据编码获取角色数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<RoleDTO> GetRoleDetailAsync(GetRoleDBRequest request);

        /// <summary>
        /// 根据关键字段获取角色数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<RoleDTO> GetRoleDetailByKeyAsync(GetRoleByKeyDBRequest request);

        /// <summary>
        /// 获取角色数据分页
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns>返回角色列表</returns>
        Task<PageCollection<RoleDTO>> GetRolePageAsync(DBPageRequest request);


        /// <summary>
        /// 删除角色数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<bool> RemoveRoleAsync(RemoveRoleDBRequest request);

        
        /// <summary>
        /// 删除多个角色数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<long> RemoveRoleListAsync(RemoveRoleListDBRequest request);

        /// <summary>
        /// 获取角色数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<RoleDTO>> GetRoleListAsync(GetRoleListDBRequest request);

        /// <summary>
        /// 根据关键字段获取角色数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<RoleDTO>> GetRoleListByKeyAsync(GetRoleListByKeyDBRequest request);

        /// <summary>
        /// 更新角色数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns></returns>
        Task<bool> UpdateRoleAsync(UpdateRoleDBRequest request);
    }
}
