using System.Collections.Generic;
using System.Threading.Tasks;
using WingInterfaceLibrary.Request.DBVitalRequest;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.Interface.DBVitalInterface
{
    /// <summary>
    /// 日历服务
    /// </summary>
    public interface IVitalScheduleDBService
    {
        /// <summary>
        /// 添加日历数据
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> AddScheduleDBAsync(AddScheduleDBRequest request);

        /// <summary>
        /// 更新日历数据
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateScheduleDBAsync(UpdateScheduleDBRequest request);

        /// <summary>
        /// 添加用户与日历关联信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> AddScheduleUsersDBAsync(AddScheduleUsersDBRequest request);

        /// <summary>
        /// 更新日历状态
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateScheduleStateDBAsync(UpdateScheduleStateDBRequest request);

        /// <summary>
        /// 删除日历
        /// </summary>
        /// <param name="code"></param>
        /// <returns></returns>
        Task<bool> DeleteScheduleDBAsync(string code);

        /// <summary>
        /// 获取日历详情
        /// </summary>
        /// <param name="code"></param>
        /// <returns></returns>
        Task<ScheduleDTO> GetScheduleDBByCodeAsync(string code);

        /// <summary>
        /// 通过关联code获取日历
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<ScheduleDTO>> GetScheduleDBAsync(GetScheduleDBRequest request);

        /// <summary>
        /// 获取日历列表
        /// </summary>
        /// <param name="code"></param>
        /// <returns></returns>
        Task<ScheduleDTO> GetScheduleDBByRelevanceCodeAsync(string code);
    }
}