using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.DBVitalRequest;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.Interface.DBVitalInterface
{
    /// <summary>
    /// 服务包数据库接口
    /// </summary>
    public interface IVitalServicePackDBService
    {
        /// <summary>
        ///  创建服务包
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> CreateServicePackAsync(CreateServicePackDBRequest request);

        /// <summary>
        /// 获取服务包详情
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ServicePackDTO> GetServicePackDetailAsync(GetServicePackDBRequest request);

        /// <summary>
        /// 获取服务包分页查询
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageCollection<ServicePackDTO>> GetServicePackPageAsync(GetServicePackPageDBRequest request);

        /// <summary>
        /// 删除服务包
        /// <summary>
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> RemovetServicePackAsync(RemovetServicePackDBRequest request);

        /// <summary>
        ///获取所有服务包列表
        /// </summary>
        /// <param name="request">get list request</param>
        /// <returns></returns>
        Task<List<ServicePackDTO>> GetServicePackListAsync(GetServicePackListDBRequest request);

        /// <summary>
        /// 更新服务包
        /// </summary>
        /// <param name="request">update request</param>
        /// <returns></returns>
        Task<bool> UpdateServicePackAsync(UpdateServicePackDBRequest request);

        /// <summary>
        ///设服务包上设置服务项目
        /// </summary>
        /// <param name="request">update request</param>
        /// <returns></returns>
        Task<bool> UpdateServicePackForItemsAsync(UpdateServicePackForItemsDBRequest request);

        /// <summary>
        /// 创建项目包
        /// </summary>
        /// <param name="request">create request</param>
        /// <returns></returns>
        Task<string> CreateServiceItemAsync(CreateServiceItemDBRequest request);

        /// <summary>
        ///获取项目详情
        /// </summary>
        /// <param name="request">get request</param>
        /// <returns></returns>
        Task<ServiceItemDTO> GetServiceItemDetailAsync(GetServiceItemDBRequest request);

        /// <summary>
        /// 获取服务项目分页查询
        /// </summary>
        /// <param name="request">Get page request</param>
        /// <returns></returns>
        Task<PageCollection<ServiceItemDTO>> GetServiceItemPageAsync(GetServiceItemPageDBRequest request);

        /// <summary>
        ///删除服务项
        /// </summary>
        /// <param name="request">remove request</param>
        /// <returns></returns>
        Task<bool> RemovetServiceItemAsync(RemovetServiceItemDBRequest request);

        /// <summary>
        ///获取所有服务项集合
        /// </summary>
        /// <param name="request">get list request</param>
        /// <returns></returns>
        Task<List<ServiceItemDTO>> GetServiceItemListAsync(GetServiceItemListDBRequest request);

        // <summary>
        /// 更新服务项目
        /// </summary>
        /// <param name="request">update request</param>
        /// <returns></returns>
        Task<bool> UpdateServiceItemAsync(UpdateServiceItemDBRequest request);

        /// <summary>
        /// 服务包设定人群分标签
        /// </summary>
        /// <param name="request">update request</param>
        /// <returns></returns>
        Task<bool> UpdateServicePackForLabelsAsync(UpdateServicePackForLabelsDBRequest request);
    }
}
