using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.DBVitalRequest;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.Interface.DBVitalInterface
{
    /// <summary>
    /// 统计服务
    /// </summary>
    public interface IVitalStatisticDBService
    {
        /// <summary>
        /// 创建统计数据
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<string> CreateStatisticAsync(CreateStatisticDBRequest request);

        /// <summary>
        /// 根据编码获取统计数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<StatisticDTO> GetStatisticDetailAsync(GetStatisticDBRequest request);

        /// <summary>
        /// 根据关键字段获取统计数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<StatisticDTO> GetStatisticDetailByKeyAsync(GetStatisticByKeyDBRequest request);

        /// <summary>
        /// 根据关键字段获取今日统计数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<StatisticDTO> GetTodayStatisticAsync(GetTodayStatisticDBRequest request);

        /// <summary>
        /// 获取统计数据分页
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns>返回统计列表</returns>
        Task<PageCollection<StatisticDTO>> GetStatisticPageAsync(DBPageRequest request);


        /// <summary>
        /// 删除统计数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<bool> RemoveStatisticAsync(RemoveStatisticDBRequest request);

        
        /// <summary>
        /// 删除多个统计数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<long> RemoveStatisticListAsync(RemoveStatisticListDBRequest request);


        /// <summary>
        /// 获取统计数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<StatisticDTO>> GetStatisticListAsync(GetStatisticListDBRequest request);

        /// <summary>
        /// 根据关键字段获取统计数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<StatisticDTO>> GetStatisticListByKeyAsync(GetStatisticListByKeyDBRequest request);

        /// <summary>
        /// 更新统计数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns></returns>
        Task<bool> UpdateStatisticAsync(UpdateStatisticDBRequest request);
    }
}
