using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.DBVitalRequest;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.Interface.DBVitalInterface
{
    /// <summary>
    /// 系统设置服务
    /// </summary>
    public interface IVitalSystemSettingDBService
    {
        /// <summary>
        /// 创建系统设置数据
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<string> CreateSystemSettingAsync(CreateSystemSettingDBRequest request);

        /// <summary>
        /// 根据编码获取系统设置数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<SystemSettingDTO> GetSystemSettingDetailAsync(GetSystemSettingDBRequest request);

        /// <summary>
        /// 根据关键字段获取系统设置数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<SystemSettingDTO> GetSystemSettingDetailByKeyAsync(GetSystemSettingByKeyDBRequest request);

        /// <summary>
        /// 获取系统设置数据分页
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns>返回系统设置列表</returns>
        Task<PageCollection<SystemSettingDTO>> GetSystemSettingPageAsync(DBPageRequest request);


        /// <summary>
        /// 删除系统设置数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<bool> RemoveSystemSettingAsync(RemoveSystemSettingDBRequest request);

        
        /// <summary>
        /// 删除多个系统设置数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<long> RemoveSystemSettingListAsync(RemoveSystemSettingListDBRequest request);


        /// <summary>
        /// 获取系统设置数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<SystemSettingDTO>> GetSystemSettingListAsync(GetSystemSettingListDBRequest request);

        /// <summary>
        /// 根据关键字段获取系统设置数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<SystemSettingDTO>> GetSystemSettingListByKeyAsync(GetSystemSettingListByKeyDBRequest request);

        /// <summary>
        /// 更新系统设置数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns></returns>
        Task<bool> UpdateSystemSettingAsync(UpdateSystemSettingDBRequest request);
    }
}
