using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.DBVitalRequest;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.Interface.DBVitalInterface
{
    /// <summary>
    /// 团队服务
    /// </summary>
    public interface IVitalTeamDBService
    {
        /// <summary>
        /// 创建团队数据
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<string> CreateTeamAsync(CreateTeamDBRequest request);

        /// <summary>
        /// 根据编码获取团队数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<TeamDTO> GetTeamDetailAsync(GetTeamDBRequest request);

        /// <summary>
        /// 根据关键字段获取团队数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<TeamDTO> GetTeamDetailByKeyAsync(GetTeamByKeyDBRequest request);

        /// <summary>
        /// 根据用户编码获取团队数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<TeamDTO> GetTeamDetailByUserAsync(GetTeamByUserDBRequest request);

        /// <summary>
        /// 获取团队数据分页
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns>返回团队列表</returns>
        Task<PageCollection<TeamDTO>> GetTeamPageAsync(DBPageRequest request);


        /// <summary>
        /// 删除团队数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<bool> RemoveTeamAsync(RemoveTeamDBRequest request);

        
        /// <summary>
        /// 删除多个团队数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<long> RemoveTeamListAsync(RemoveTeamListDBRequest request);


        /// <summary>
        /// 获取团队数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<TeamDTO>> GetTeamListAsync(GetTeamListDBRequest request);

        /// <summary>
        /// 根据关键字段获取团队数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<TeamDTO>> GetTeamListByKeyAsync(GetTeamListByKeyDBRequest request);

        /// <summary>
        /// 更新团队数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns></returns>
        Task<bool> UpdateTeamAsync(UpdateTeamDBRequest request);
    }
}
