using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.DBVitalRequest;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.Interface.DBVitalInterface
{
    /// <summary>
    /// 团队区域服务
    /// </summary>
    public interface IVitalTeamRegionDBService
    {
        /// <summary>
        /// 创建团队区域数据
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<string> CreateTeamRegionAsync(CreateTeamRegionDBRequest request);

        /// <summary>
        /// 根据编码获取团队区域数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<TeamRegionDTO> GetTeamRegionDetailAsync(GetTeamRegionDBRequest request);

        /// <summary>
        /// 根据关键字段获取团队区域数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<TeamRegionDTO> GetTeamRegionDetailByKeyAsync(GetTeamRegionByKeyDBRequest request);

        /// <summary>
        /// 获取团队区域数据分页
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns>返回团队区域列表</returns>
        Task<PageCollection<TeamRegionDTO>> GetTeamRegionPageAsync(DBPageRequest request);


        /// <summary>
        /// 删除团队区域数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<bool> RemoveTeamRegionAsync(RemoveTeamRegionDBRequest request);

        
        /// <summary>
        /// 删除多个团队区域数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<long> RemoveTeamRegionListAsync(RemoveTeamRegionListDBRequest request);


        /// <summary>
        /// 获取团队区域数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<TeamRegionDTO>> GetTeamRegionListAsync(GetTeamRegionListDBRequest request);

        /// <summary>
        /// 根据关键字段获取团队区域数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<TeamRegionDTO>> GetTeamRegionListByKeyAsync(GetTeamRegionListByKeyDBRequest request);

        /// <summary>
        /// 更新团队区域数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns></returns>
        Task<bool> UpdateTeamRegionAsync(UpdateTeamRegionDBRequest request);
    }
}
