using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.DBVitalRequest;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Enum.VitalEnum;

namespace WingInterfaceLibrary.Interface.DBVitalInterface
{
    /// <summary>
    /// 模板服务
    /// </summary>
    public interface IVitalTemplateDBService
    {
        /// <summary>
        /// 创建模板数据
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<string> CreateTemplateAsync(CreateTemplateDBRequest request);

        /// <summary>
        /// 根据编码获取模板数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<TemplateDTO> GetTemplateDetailAsync(GetTemplateDBRequest request);

        /// <summary>
        /// 根据关键字段获取模板数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<TemplateDTO> GetTemplateDetailByKeyAsync(GetTemplateByKeyDBRequest request);

        /// <summary>
        /// 获取模板数据分页
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns>返回模板列表</returns>
        Task<PageCollection<TemplateDTO>> GetTemplatePageAsync(DBPageRequest request);


        /// <summary>
        /// 删除模板数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<bool> RemoveTemplateAsync(RemoveTemplateDBRequest request);


        /// <summary>
        /// 删除多个模板数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<long> RemoveTemplateListAsync(RemoveTemplateListDBRequest request);


        /// <summary>
        /// 获取模板数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<TemplateDTO>> GetTemplateListAsync(GetTemplateListDBRequest request);

        /// <summary>
        /// 根据关键字段获取模板数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<TemplateDTO>> GetTemplateListByKeyAsync(GetTemplateListByKeyDBRequest request);

        /// <summary>
        /// 更新模板数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns></returns>
        Task<bool> UpdateTemplateAsync(UpdateTemplateDBRequest request);

        /// <summary>
        /// 根据Key列表获取模板编码列表
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<List<TemplateDTO>> GetLastTemplateCodesByKeysAsync(GetLastTemplateCodesByKeysDBRequest request);

        /// <summary>
        /// 查询模板集合
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<List<TemplateDTO>> GetTemplateInfosDBAsync(GetTemplateInfosDBRequest request);

        /// <summary>
        /// 获取模板数据根据key和type
        /// </summary>
        /// <param name="code"></param>
        /// <param name="key"></param>
        /// <param name="templateType"></param>
        /// <returns></returns>
        Task<TemplateDTO> GetTemplateInfoByConditionDBAsync(string code, string key, TemplateTypeEnum templateType = TemplateTypeEnum.Form);
    }
}
