using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.DBVitalRequest;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.Interface.DBVitalInterface
{
    /// <summary>
    /// 乡镇服务
    /// </summary>
    public interface IVitalTownDBService
    {
        /// <summary>
        /// 创建乡镇数据
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<string> CreateTownAsync(CreateTownDBRequest request);

        /// <summary>
        /// 根据编码获取乡镇数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<TownDTO> GetTownDetailAsync(GetTownDBRequest request);

        /// <summary>
        /// 根据关键字段获取乡镇数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<TownDTO> GetTownDetailByKeyAsync(GetTownByKeyDBRequest request);

        /// <summary>
        /// 获取乡镇数据分页
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns>返回乡镇列表</returns>
        Task<PageCollection<TownDTO>> GetTownPageAsync(DBPageRequest request);


        /// <summary>
        /// 删除乡镇数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<bool> RemoveTownAsync(RemoveTownDBRequest request);

        
        /// <summary>
        /// 删除多个乡镇数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<long> RemoveTownListAsync(RemoveTownListDBRequest request);


        /// <summary>
        /// 获取乡镇数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<TownDTO>> GetTownListAsync(GetTownListDBRequest request);

        /// <summary>
        /// 根据关键字段获取乡镇数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<TownDTO>> GetTownListByKeyAsync(GetTownListByKeyDBRequest request);

        /// <summary>
        /// 更新乡镇数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns></returns>
        Task<bool> UpdateTownAsync(UpdateTownDBRequest request);
    }
}
