using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.DBVitalRequest;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.Interface.DBVitalInterface
{
    /// <summary>
    /// 更新服务
    /// </summary>
    public interface IVitalUpgradeDBService
    {
        /// <summary>
        /// 创建更新数据
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<string> CreateUpgradeAsync(CreateUpgradeDBRequest request);

        /// <summary>
        /// 根据编码获取更新数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<UpgradeDTO> GetUpgradeDetailAsync(GetUpgradeDBRequest request);

        /// <summary>
        /// 根据关键字段获取更新数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<UpgradeDTO> GetUpgradeDetailByKeyAsync(GetUpgradeByKeyDBRequest request);

        /// <summary>
        /// 获取更新数据分页
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns>返回更新列表</returns>
        Task<PageCollection<UpgradeDTO>> GetUpgradePageAsync(DBPageRequest request);


        /// <summary>
        /// 删除更新数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<bool> RemoveUpgradeAsync(RemoveUpgradeDBRequest request);

        
        /// <summary>
        /// 删除多个更新数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<long> RemoveUpgradeListAsync(RemoveUpgradeListDBRequest request);


        /// <summary>
        /// 获取更新数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<UpgradeDTO>> GetUpgradeListAsync(GetUpgradeListDBRequest request);

        /// <summary>
        /// 根据关键字段获取更新数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<UpgradeDTO>> GetUpgradeListByKeyAsync(GetUpgradeListByKeyDBRequest request);

        /// <summary>
        /// 更新更新数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns></returns>
        Task<bool> UpdateUpgradeAsync(UpdateUpgradeDBRequest request);

        /// <summary>
        /// 获取最新的更新
        /// </summary>
        /// <param name="request">查询详情请求</param>
        /// <returns></returns>
        Task<UpgradeDTO> GetLastUpgradeAsync(GetLastUpgradeDBRequest request);
    }
}
