using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.DBVitalRequest;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.Interface.DBVitalInterface
{
    /// <summary>
    /// 用户服务
    /// </summary>
    public interface IVitalUserDBService
    {
        /// <summary>
        /// 创建用户数据
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<string> CreateUserAsync(CreateUserDBRequest request);

        /// <summary>
        /// 根据编码获取用户数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<UserDTO> GetUserDetailAsync(GetUserDBRequest request);

        /// <summary>
        /// 根据关键字段获取用户数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<UserDTO> GetUserDetailByKeyAsync(GetUserByKeyDBRequest request);

        /// <summary>
        /// 获取用户数据分页
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns>返回用户列表</returns>
        Task<PageCollection<UserDTO>> GetUserPageAsync(DBPageRequest request);


        /// <summary>
        /// 删除用户数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<bool> RemoveUserAsync(RemoveUserDBRequest request);

        
        /// <summary>
        /// 删除多个用户数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<long> RemoveUserListAsync(RemoveUserListDBRequest request);


        /// <summary>
        /// 获取用户数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<UserDTO>> GetUserListAsync(GetUserListDBRequest request);

        /// <summary>
        /// 根据关键字段获取用户数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<UserDTO>> GetUserListByKeyAsync(GetUserListByKeyDBRequest request);

        /// <summary>
        /// 更新用户数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns></returns>
        Task<bool> UpdateUserAsync(UpdateUserDBRequest request);

        /// <summary>
        /// 重新设置用户名
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> ResetUserNameAsync(ResetUserNameDBRequest request);

        /// <summary>
        /// 设备用户关联的超声机
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> BindUltrasoundCodeDBAsync(BindUltrasoundCodeDBRequest request);        

        /// <summary>
        /// 设备用户关联的心电
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> BindEcgCodeDBAsync(BindEcgCodeDBRequest request);

        /// <summary>
        /// 设置负责区域
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SetAreaOfResponsibilityAsync(SetAreaOfResponsibilityDBRequest request);

        /// <summary>
        /// 关联晶奇工号
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SetJingQiUserDBAsync(SetJingQiUserDBRequest request);

        /// <summary>
        /// 获取菜单权限
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<UserFeatureDTO>> GetMenuPermissionAsync(GetMenuPermissionDBRequest request);

        /// <summary>
        /// 获取操作权限
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<UserFeatureDTO>> GetOperationPermissionAsync(GetOperationPermissionDBRequest request);
    }
}
