using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.DBVitalRequest;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.Interface.DBVitalInterface
{
    /// <summary>
    /// 用户权限服务
    /// </summary>
    public interface IVitalUserFeatureDBService
    {
        /// <summary>
        /// 创建用户权限数据
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<string> CreateUserFeatureAsync(CreateUserFeatureDBRequest request);

        /// <summary>
        /// 根据编码获取用户权限数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<UserFeatureDTO> GetUserFeatureDetailAsync(GetUserFeatureDBRequest request);

        /// <summary>
        /// 根据关键字段获取用户权限数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<UserFeatureDTO> GetUserFeatureDetailByKeyAsync(GetUserFeatureByKeyDBRequest request);

        /// <summary>
        /// 获取用户权限数据分页
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns>返回用户权限列表</returns>
        Task<PageCollection<UserFeatureDTO>> GetUserFeaturePageAsync(DBPageRequest request);


        /// <summary>
        /// 删除用户权限数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<bool> RemoveUserFeatureAsync(RemoveUserFeatureDBRequest request);

        
        /// <summary>
        /// 删除多个用户权限数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<long> RemoveUserFeatureListAsync(RemoveUserFeatureListDBRequest request);


        /// <summary>
        /// 获取用户权限数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<UserFeatureDTO>> GetUserFeatureListAsync(GetUserFeatureListDBRequest request);

        /// <summary>
        /// 根据关键字段获取用户权限数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<UserFeatureDTO>> GetUserFeatureListByKeyAsync(GetUserFeatureListByKeyDBRequest request);

        /// <summary>
        /// 更新用户权限数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns></returns>
        Task<bool> UpdateUserFeatureAsync(UpdateUserFeatureDBRequest request);
    }
}
