using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.DBVitalRequest;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.Interface.DBVitalInterface
{
    /// <summary>
    /// 用户密码服务
    /// </summary>
    public interface IVitalUserPasswordDBService
    {
        /// <summary>
        /// 创建用户密码数据
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<string> CreateUserPasswordAsync(CreateUserPasswordDBRequest request);

        /// <summary>
        /// 根据编码获取用户密码数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<UserPasswordDTO> GetUserPasswordDetailAsync(GetUserPasswordDBRequest request);

        /// <summary>
        /// 根据关键字段获取用户密码数据
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<UserPasswordDTO> GetUserPasswordDetailByKeyAsync(GetUserPasswordByKeyDBRequest request);

        /// <summary>
        /// 获取用户密码数据分页
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns>返回用户密码列表</returns>
        Task<PageCollection<UserPasswordDTO>> GetUserPasswordPageAsync(DBPageRequest request);


        /// <summary>
        /// 删除用户密码数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<bool> RemoveUserPasswordAsync(RemoveUserPasswordDBRequest request);

        
        /// <summary>
        /// 删除多个用户密码数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns></returns>
        Task<long> RemoveUserPasswordListAsync(RemoveUserPasswordListDBRequest request);


        /// <summary>
        /// 获取用户密码数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<UserPasswordDTO>> GetUserPasswordListAsync(GetUserPasswordListDBRequest request);

        /// <summary>
        /// 根据关键字段获取用户密码数据列表
        /// </summary>
        /// <param name="request">获取列表请求</param>
        /// <returns></returns>
        Task<List<UserPasswordDTO>> GetUserPasswordListByKeyAsync(GetUserPasswordListByKeyDBRequest request);

        /// <summary>
        /// 更新用户密码数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns></returns>
        Task<bool> UpdateUserPasswordAsync(UpdateUserPasswordDBRequest request);
    }
}
