using System.Collections.Generic;
using System.Threading.Tasks;
using WingInterfaceLibrary.Request.AppletAPI;
using WingInterfaceLibrary.Result;
using WingInterfaceLibrary.Result.AppletAPI;

namespace WingInterfaceLibrary.Interface
{
    /// <summary>
    /// 小程序接口
    /// </summary>
    /// <docFirstDirectory>小程序接口服务API</docFirstDirectory>
    /// <docSecondDirectory>小程序接口</docSecondDirectory>
    public interface IAppletAPIService
    {
        /// <summary>
        /// 服务状态测试
        /// </summary>
        /// <returns></returns>
        Task<bool> ServiceIsExist();

        /// <summary>
        /// 小程序挂断通知
        /// </summary>
        /// <param name="request">小程序挂断通知请求对象</param>
        /// <errorCodes></errorCodes>
        Task<bool> LiveMemberLeaveAsync(LiveMemberLeaveRequest request);

        /// <summary>
        /// 小程序拒绝通知
        /// </summary>
        /// <param name="request">小程序拒绝通知请求对象</param>
        /// <errorCodes></errorCodes>
        Task<bool> LiveMemberRejectAsync(LiveMemberRejectRequest request);
        
        /// <summary>
        /// 小程序发起者收到对方接受通知
        /// </summary>
        /// <param name="request">小程序发起者收到对方接受通知请求对象</param>
        /// <errorCodes></errorCodes>
        Task<bool> LiveMemberAcceptAsync(LiveMemberAcceptRequest request);
        
        /// <summary>
        /// 小程序接听超时
        /// </summary>
        /// <param name="request">小程序接听超时请求对象</param>
        /// <errorCodes></errorCodes>
        Task<bool> LiveMemberTimeoutAsync(LiveMemberTimeoutRequest request);

        /// <summary>
        /// 根据openid获取用户信息
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>用户信息</returns>
        /// <errorCodes></errorCodes>
        Task<GetUserInfoByOpenIdResult> GetUserInfoByOpenIdAsync(GetUserInfoByOpenIdRequest request);

        /// <summary>
        /// 绑定Openid和杏聆荟账号
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>true</returns>
        /// <errorCodes></errorCodes>
        Task<bool> BindVcloudAccountAndOpenIdAsync(BindVcloudAccountAndOpenIdRequest request);

        /// <summary>
        /// 查询远程诊断记录列表分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<RemedicalRecordInfo>> GetRemedicalRecordListAsync(GetRemedicalRecordListRequest request);

        /// <summary>
        /// 查询远程诊断图像列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<ImageData>> GetRemedicalDataListAsync(GetRemedicalDataListRequest request);

        /// <summary>
        /// 查询远程诊断报告列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<ReportInfo>> GetRemedicalReportListAsync(GetRemedicalReportListRequest request);

        /// <summary>
        /// 查询预约记录分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<ConsultationInfo>> GetConsultationListAsync(GetConsultationListRequest request);

        /// <summary>
        /// 查询会诊报告列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<ReportInfo>> GetConsultationReportListAsync(GetConsultationReportListRequest request);

        /// <summary>
        /// 新建预约
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> CreateConsultationAsync(CreateConsultationRequest request);

        /// <summary>
        /// 审批预约
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> ArrangeConsultationAsync(ArrangeConsultationRequest request);

        /// <summary>
        /// 查询对接医院列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<OrganBaseInfo>> GetHospitalsAsync(GetHospitalsRequest request);

        /// <summary>
        /// 查询会诊专家列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<DoctorInfo>> GetExpertsAsync(GetExpertsRequest request);

        /// <summary>
        /// 查询当前人设备列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<TerminalInfo>> GetTerminalListAsync(GetTerminalListRequest request);

        /// <summary>
        /// 扫查部位列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<string>> GetScanLocationsAsync(GetScanLocationsRequest request);

        /// <summary>
        /// 开始会诊
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<StartConsultationResult> StartConsultationAsync(StartConsultationRequest request);

        /// <summary>
        /// 取消开始会诊
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<CancelStartConsultationResult> CancelStartConsultationAsync(CancelStartConsultationRequest request);

        /// <summary>
        /// 退出会诊
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ExitConsultationResult> ExitConsultationAsync(ExitConsultationRequest request);

        /// <summary>
        /// 会诊心跳
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <show>false</show>
        Task<bool> ConsultationHeartRateAsync(ConsultationHeartRateRequest request);

        /// <summary>
        /// 获取文件流
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<AppletAPIDownloadFileResult> DownloadFileAsync(DownloadFileRequest request);

        /// <summary>
        /// 查询系统默认报告模板
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<VinnoTemplateInfo>> GetReportTemplatesAsync(GetReportTemplatesRequest request);

        /// <summary>
        /// 查询系统默认词条
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<VinnoTemplateInfo>> GetThesaurusTemplatesAsync(GetThesaurusTemplatesRequest request);

        /// <summary>
        /// 保存报告信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> SaveReportAsync(SaveAppletReportRequest request);

        /// <summary>
        /// 查询报告详情
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ReportResultInfo> GetReportByIdAsync(GetAppletReportRequest request);

        /// <summary>
        /// 保存会诊截图信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> UploadConsultationImageAsync(UploadConsultationImageRequest request);

    }
}