using System.Threading.Tasks;
using WingInterfaceLibrary.DTO.Message;
using WingInterfaceLibrary.Request.ChatMessage;
using WingInterfaceLibrary.Result;

namespace WingInterfaceLibrary.Interface
{
    /// <summary>
    /// 聊天消息
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>聊天消息接口</docSecondDirectory>
    public interface IChatMessageService
    {
        /// <summary>
        /// 获取聊天消息分页倒序
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>授权响应</returns>
        /// <remarks>POST</remarks>
        Task<PageResult<ChatMessagesDTO>> GetChatMessagePagesAsync(GetChatMessagePageRequest request);

        /// <summary>
        /// 游客获取聊天消息分页倒序
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>授权响应</returns>
        /// <remarks>POST</remarks>
        Task<PageResult<ChatMessagesDTO>> GetChatMessagePagesVisitorAsync(GetChatMessagePageVisitorRequest request);

        /// <summary>
        /// 发送聊天消息
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>聊天记录编码</returns>
        /// <remarks>POST</remarks>
        /// <errorCodes>SendChatMessageFailed</errorCodes>
        Task<ChatMessagesDTO> SendChatMessageAsync(SendChatMessageRequest request);

        /// <summary>
        /// 发送聊天消息，游客
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>聊天记录编码</returns>
        /// <remarks>POST</remarks>
        /// <errorCodes>SendChatMessageFailed</errorCodes>
        Task<ChatMessagesDTO> SendVisitChatMessageAsync(SendVisitChatMessageRequest request);


    }
}