using System.Collections.Generic;
using System.Threading.Tasks;
using WingInterfaceLibrary.DTO.DeployPlatform;
using WingInterfaceLibrary.Request.DeployPlatform;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.Interface
{
    public interface IDeployPlatformService
    {
        /// <summary>
        /// 获取server列表
        /// </summary>
        /// <param name="request"></param>
        /// <show>false</show>
        /// <returns></returns>
        Task<IList<DeployPlatServerInfoDTO>> GetServerListAsync();

        /// <summary>
        /// 新增server 
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> AddServerAsync(AddServerRequest request);

        /// <summary>
        /// 修改Server
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateServerAsync(UpdateServerRequest request);

        /// <summary>
        /// 保存日志
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SaveLogsAsync(SaveLogsRequest request);

        /// <summary>
        /// 获取server
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<DeployPlatServerInfoDTO> GetServerAsync(GetServerRequest request);

        /// <summary>
        /// 查询上传日志
        /// </summary>
        /// <returns></returns>
        Task<List<string>> GetUploadLogsAsync(GetServerRequest request);

        /// <summary>
        /// 获取操作人列表
        /// </summary>
        /// <returns></returns>
        Task<IList<DeployPlatOperatorDTO>> GetOperatorListAsync();

        /// <summary>
        /// 查询打包记录
        /// </summary>
        /// <returns></returns>
        Task<IList<DeployRecordInfoDTO>> GetRecordListAsync(GetDeployRecordRequest request);

        /// <summary>
        /// 新增/修改打包记录
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SaveRecordAsync(SaveDeployRecordRequest request);

        /// <summary>
        /// 删除打包记录
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> RemoveRecordAsync(RemoveDeployRecordRequest request);

        /// <summary>
        /// 新增操作人
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> AddOperatorAsync(AddDeployPlatOperatorRequest request);

        /// <summary>
        /// 修改操作人
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> ModifyperatorAsync(ModifyDeployPlatOperatorRequest request);

        /// <summary>
        /// 删除操作人
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeleteOperatorAsync(DeleteDeployPlatOperatorRequest request);

        /// <summary>
        /// 登录
        /// </summary>
        /// <returns></returns>
        Task<DeployPlatLoginResultEnum> LoginAsync(OperatorLoginRequest request);

        /// <summary>
        /// 根据url和前缀获取编译包数据
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<string>> FindTextWithUrlAndPrefixAsync(FindTextWithUrlAndPrefixRequest request);

        /// <summary>
        /// 申请打包
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> GeneratePackageAsync(GeneratePackageRequest request);

        /// <summary>
        /// 上传到指定服务器
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UploadTotargetServerAsync(UploadTotargetServerRequest request);

        /// <summary>
        /// 查询Record上传日志
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<string>> GetRecordUploadLogsAsync(GetPackageRequest request);

        /// <summary>
        /// 打包记录上传更新包(上传到特定服务器的云存储)
        /// </summary>
        /// <param name="getPackageRequest"></param>
        /// <returns></returns>
        Task<bool> UploadForRecordAsync(GetPackageRequest getPackageRequest);

        /// <summary>
        /// 查询打包日志
        /// </summary>
        /// <returns></returns>
        Task<List<string>> GetPackageLogsAsync();

        /// <summary>
        /// 查询打包记录详情
        /// </summary>
        /// <returns></returns>
        Task<DeployRecordInfoDTO> GetPackageAsync(GetPackageRequest request);

        /// <summary>
        /// 取消打包
        /// </summary>
        /// <returns></returns>
        Task<bool> CancelPackagingAsync(CancelPackagingRequest request);

        /// <summary>
        /// 远程服务是否在线
        /// </summary>
        /// <returns></returns>
        Task<bool> Check();

        /// <summary>
        /// 查询是否部署中
        /// </summary>
        /// <returns></returns>
        Task<bool> GetIsPublishing();

        /// <summary>
        /// 获取配置
        /// </summary>
        /// <returns></returns>
        Task<string> ReadAppSettingsJsonAsync(ReadAppSettingsJsonRequest request);

        /// <summary>
        /// 修改配置
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> ModifyAppSettingsJsonAsync(ModifyAppSettingsJsonRequest request);

        /// <summary>
        /// 一键部署Server
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeployAsync(DeployRequest request);

        /// <summary>
        /// 部署-启动前全部步骤
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeployWaitStartAsync(DeployRequest request);

        /// <summary>
        /// 部署-启动
        /// </summary>
        /// <returns></returns>
        bool Start();


        /// <summary>
        /// 停止Server
        /// </summary>
        /// <returns></returns>
        bool StopServer();

        /// <summary>
        /// 查询部署日志
        /// </summary>
        /// <returns></returns>
        Task<IList<string>> GetPublishPackageLogsAsync();

        /// <summary>
        /// 运行自动化测试应用
        /// </summary>
        /// <returns></returns>
        Task<bool> RunAutoTestApplication();
    }
}