using System.Collections.Generic;
using System.Threading.Tasks;
using WingInterfaceLibrary.DTO.Education;
using WingInterfaceLibrary.Request.Education;
using WingInterfaceLibrary.Request.Courses;
using WingInterfaceLibrary.Result;
using WingInterfaceLibrary.DTO.Courses;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Result.Education;
using WingInterfaceLibrary.Result.Courses;
using WingInterfaceLibrary.DTO.User;
using WingInterfaceLibrary.Request.Management;
using WingInterfaceLibrary.LiveConsultation.Consultation;
using WingInterfaceLibrary.DTO.Consultation;
using WingInterfaceLibrary.DTO.Message;

namespace WingInterfaceLibrary.Interface
{
    /// <summary>
    /// 杏聆荟学院服务接口
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>  
    /// <docSecondDirectory>杏聆荟学院服务接口</docSecondDirectory>   
    /// <docThirdDirectory>老师视角</docThirdDirectory>  
    public interface IEducationService
    {
        /// <summary>
        /// 获取标签列表
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>标签信息</returns>
        /// <errorCodes></errorCodes>
        Task<IList<CourseLabelDTO>> GetCourseLabelsAsync(QueryCourseLabelListRequest request);

        /// <summary>
        /// 老师申请课程
        /// </summary>
        /// <param name="request">申请课程请求</param>
        /// <returns>成功或者失败</returns>
        /// <errorCodes>TeacherCodeEmpty,TeacherNoFound,UserNotFind </errorCodes>
        Task<bool> ApplyCourseAsync(ApplyCourseRequest request);

        /// <summary>
        /// 通用课程列表查询接口
        /// </summary>
        /// <param name="request">请求参数</param>
        /// <returns>课程列表信息</returns>
        /// <errorCodes>UserNotFind</errorCodes>
        Task<PageResult<CourseInfoDetailDTO>> FindCoursePagesAsync(FindCoursePagesRequest request);

        /// <summary>
        /// 老师删除课程记录
        /// </summary>
        /// <param name="request">删除课程请求</param>
        /// <returns>删除成功或者失败</returns>
        /// <errorCodes>UserNotFind,CourseCodeEmpty,CourseNoFound,NotDeleteForCourseStatus</errorCodes>
        Task<bool> DeleteCourseByCodeAsync(DeleteCourseByCodeRequest request);

        /// <summary>
        /// 老师更新课程记录
        /// </summary>
        /// <param name="request">更新课程请求</param>
        /// <returns>更新成功或者失败</returns>
        ///  <errorCodes>UserNotFind,CourseCodeEmpty,TeacherNoFound,CourseNoFound,NotUpdateForCourseStatus </errorCodes>
        Task<bool> UpdateCourseAsync(UpdateCourseRequest request);

        /// <summary>
        /// 根据课程编码获取课程详细信息
        /// </summary>
        /// <param name="request">获取详细信息课程请求</param>
        /// <returns>课程详细信息</returns>
        ///  <errorCodes>UserNotFind,CourseCodeEmpty</errorCodes>
        Task<CourseInfoDetailDTO> FindCourseByCodeAsync(FindCourseByCodeRequest request);

        /// <summary>
        /// 学生已报名课程列表
        /// </summary>
        /// <param name="request">学生查询自己课程请求</param>
        /// <returns>课程列表</returns>        
        /// <docFirstDirectory>客户端API</docFirstDirectory>
        /// <docSecondDirectory>杏聆荟学院服务接口</docSecondDirectory>   
        /// <docThirdDirectory>学生视角</docThirdDirectory>  
        /// <errorCodes>UserNotFind</errorCodes>
        Task<PageResult<CourseInfoDetailDTO>> FindMyCoursePagesAsync(FindMyCoursePagesRequest request);

        /// <summary>
        /// 学生已报名专辑列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns>专辑列表</returns>        
        /// <docFirstDirectory>客户端API</docFirstDirectory>
        /// <docSecondDirectory>杏聆荟学院服务接口</docSecondDirectory>   
        /// <docThirdDirectory>学生视角</docThirdDirectory>  
        Task<PageResult<CourseAlbumDTO>> FindMyAlbumPagesAsync(FindMyCoursePagesRequest request);

        /// <summary>
        /// 客户端根据老师查询班级分页列表
        /// </summary> 
        /// <param name="request">创建人code</param>
        /// <returns></returns>
        /// <errorCodes>UserNotFind</errorCodes>
        Task<PageResult<UserGroupDTO>> GetUserGroupListsByCreatorCodeAsync(QueryUserGroupPageRequest request);

        /// <summary>
        /// 客户端老师新增班级
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        /// <errorCodes>UserNotFind,UserGroupNameIsEmpty,UserGroupMaxPeopleNotValid</errorCodes>
        Task<bool> AddUserGroupAsync(UserGroupRequest request);

        // /// <summary>
        // /// 查询用户分页
        // /// </summary>
        // /// <param name="request">请求对象</param>
        // /// <returns></returns>
        // /// <errorCodes>UserGroupCodeIsEmpty</errorCodes>
        // Task<PageResult<StudentInfoDTO>> FindUserGroupStudentsPagesAsync(QueryStudentByGroupCodePageRequest request);

        /// <summary>
        /// 客户端老师移除班级内学生
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        /// <errorCodes>UserGroupCodeIsEmpty,UserGroupStudentsIsEmpty</errorCodes>
        Task<bool> RemoveStudentsByGroupCodeAsync(UserGroupFilterRequest request);

        /// <summary>
        /// 客户端老师创建视频
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>VideoNameIsEmpty,VideoTokenIsEmpty</errorCodes>
        Task<bool> CreateVideoAsync(SaveVideoRequest request);

        /// <summary>
        /// 客户端查询所有视频列表分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes></errorCodes>
        Task<PageResult<VideoInfoDTO>> FindVideosPagesAsync(FindVideoPagesRequest request);

        /// <summary>
        /// 客户端老师 删除视频，同步删除课程管理视频code
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>VideoCodeIsEmpty</errorCodes>
        Task<bool> DeleteVideoByCodeAsync(DeleteVideoRequest request);

        /// <summary>
        /// 学生购买课程
        /// </summary>
        /// <param name="request">购买课程请求实体</param>
        /// <returns></returns>
        /// <docFirstDirectory>客户端API</docFirstDirectory>
        /// <docSecondDirectory>杏聆荟学院服务接口</docSecondDirectory>   
        /// <docThirdDirectory>学生视角</docThirdDirectory>  
        /// <errorCodes>CourseNoFound,CourseNotReviewed,CourseNoPayRequired,CourseQuantityError,CreateCourseOrderFailed</errorCodes>
        Task<BuyCourseResult> BuyCourseAsync(BuyCourseRequest request);

        /// <summary>
        /// 支付结果回调
        /// </summary>
        /// <param name="request">支付结果回调请求实体</param>
        /// <returns></returns>
        /// <docFirstDirectory>客户端API</docFirstDirectory>
        /// <docSecondDirectory>杏聆荟学院服务接口</docSecondDirectory>   
        /// <docThirdDirectory>学生视角</docThirdDirectory>  
        /// <errorCodes></errorCodes>
        /// <show>false</show>
        Task<bool> PaymentCallbackAsync(PaymentCallbackRequest request);

        /// <summary>
        /// 学生报名课程
        /// 课程状态：“已审核”才可报名
        /// </summary>
        /// <param name="request"></param>
        /// <docFirstDirectory>客户端API</docFirstDirectory>
        /// <docSecondDirectory>杏聆荟学院服务接口</docSecondDirectory>   
        /// <docThirdDirectory>学生视角</docThirdDirectory>  
        /// <returns></returns>
        /// <errorCodes>CourseAlbumCodeEmpty,CourseCodeEmpty,CourseNoFound,SignedUp,NotUpdateForCourseStatus</errorCodes>
        Task<bool> SignUpCourseAsync(SignUpCourseRequest request);

        /// <summary>
        /// 学生取消报名课程
        /// 课程状态：“已审核”取消报名
        /// </summary>
        /// <param name="request"></param>
        /// <docFirstDirectory>客户端API</docFirstDirectory>
        /// <docSecondDirectory>杏聆荟学院服务接口</docSecondDirectory>   
        /// <docThirdDirectory>学生视角</docThirdDirectory>  
        /// <returns></returns>
        ///  <errorCodes>CourseAlbumCodeEmpty,CourseCodeEmpty,CourseNoFound,NoSignedUp,NotUpdateForCourseStatus</errorCodes>
        Task<bool> CancelSignUpCourseAsync(CancelSignUpCourseRequest request);

        /// <summary>
        /// 客户端查询课程资料和课程素材分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes></errorCodes>
        Task<PageResult<VideoInfoDTO>> FindVideoFilesCourseTypeByPageAsync(FindVideoFilesCourseTypeByPageRequest request);

        #region 考试

        /// <summary>
        /// 发布考试或者练习试卷接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>CourseCodeEmpty,CourseNoFound,ExaminationPaperNoFound</errorCodes>
        Task<bool> PublishCourseExaminationPaperAsync(PublishCourseExaminationPaperRequest request);

        /// <summary>
        /// 查询课程考试列表接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>CourseCodeEmpty,CourseNoFound</errorCodes>
        Task<List<BaseCourseExaminationDTO>> FindCourseExaminationPapersAsync(FindCourseExaminationPapersRequest request);

        /// <summary>
        /// 查询课程考试详情接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>CourseCodeEmpty,CourseNoFound,ExaminationPaperNoFound</errorCodes>
        Task<CourseExaminationDTO> FindCourseExaminationPaperByCodeAsync(FindCourseExaminationPaperByCodeRequest request);

        /// <summary>
        /// 提交课程考试接口
        /// </summary>
        /// <param name="request"></param>
        /// <docFirstDirectory>客户端API</docFirstDirectory>
        /// <docSecondDirectory>杏聆荟学院服务接口</docSecondDirectory>   
        /// <docThirdDirectory>学生视角</docThirdDirectory>  
        /// <returns></returns>
        /// <errorCodes>CourseCodeEmpty,CourseNoFound,ExaminationPaperNoFound</errorCodes>
        Task<bool> SubmitCourseExaminationPaperAsync(SubmitCourseExaminationPaperRequest request);

        /// <summary>
        ///老师查询分页查询学生答题列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>CourseCodeEmpty,CourseNoFound</errorCodes>
        Task<PageResult<BaseStudentExaminationDTO>> FindCourseStudentExaminationPagesAsync(FindCourseStudentExaminationPagesRequest request);
        /// <summary>
        ///老师查询学生课程答题详情 
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>ExaminationCodeIsEmpty,StudentExaminationNoFound,CourseNoFound,ExaminationPaperNoFound</errorCodes>
        Task<StudentExaminationDetailDTO> FindStudentExaminationByCodeAsync(FindStudentExaminationByCodeRequest request);
        /// <summary>
        /// 提交批阅试卷
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>ExaminationCodeIsEmpty,StudentExaminationNoFound</errorCodes>
        Task<bool> SubmitReviewStudentExaminationAsync(SubmitReviewStudentExaminationRequest request);

        /// <summary>
        ///分页查看课程自己考试列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <docFirstDirectory>客户端API</docFirstDirectory>
        /// <docSecondDirectory>杏聆荟学院服务接口</docSecondDirectory>   
        /// <docThirdDirectory>学生视角</docThirdDirectory>  
        /// <errorCodes>CourseCodeEmpty,CourseNoFound</errorCodes>
        Task<PageResult<BaseStudentExaminationDTO>> FindMyCourseStudentExaminationResultsAsync(FindMyCourseStudentExaminationResultPagesRequest request);


        /// <summary>
        /// 学生查看自己考试结果
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <docFirstDirectory>客户端API</docFirstDirectory>
        /// <docSecondDirectory>杏聆荟学院服务接口</docSecondDirectory>   
        /// <docThirdDirectory>学生视角</docThirdDirectory>  
        /// <errorCodes>ExaminationCodeIsEmpty,StudentExaminationNoFound,CourseNoFound,ExaminationPaperNoFound</errorCodes>
        Task<StudentExaminationDetailDTO> FindMyCourseStudentExaminationResultAsync(FindMyCourseStudentExaminationResultRequest request);

        #endregion

        #region 直播课
        /// <summary>
        /// 老师开始直播
        /// </summary>
        /// <param name="request">开始直播请求实体</param>
        /// <returns></returns>
        /// <errorCodes>LiveTeacherNotFound,CourseNoFound,CourseNotReviewed,CourseInProcess,CourseEnded,TeacherNotOnline,StudentsNotOnline,CourseDBError</errorCodes>
        Task<InitiateLiveCourseResult> InitiateLiveCourseAsync(InitiateLiveCourseRequest request);

        /// <summary>
        /// 互动专家加入房间
        /// </summary>
        /// <param name="request">加入课程请求实体</param>
        /// <errorCodes></errorCodes>
        /// <returns></returns>
        /// <errorCodes>LiveTeacherNotFound,CourseEnded,LiveCourseNotFound,CourseNotInProcess,StudentNotPay</errorCodes>
        Task<JoinLiveCourseResult> JoinLiveCourseAsync(JoinLiveCourseRequest request);

        /// <summary>
        /// 学生获取观看地址
        /// </summary>
        /// <param name="request">观看地址请求实体</param>
        /// <errorCodes></errorCodes>
        /// <returns></returns>
        /// <docFirstDirectory>客户端API</docFirstDirectory>
        /// <docSecondDirectory>杏聆荟学院服务接口</docSecondDirectory>   
        /// <docThirdDirectory>学生视角</docThirdDirectory>  
        /// <errorCodes>LiveTeacherNotFound,CourseEnded,LiveCourseNotFound,CourseNotInProcess,StudentNotPay</errorCodes>
        Task<StudentLivePullUrlResult> GetCoursePullUrlAsync(InitiateLiveCourseRequest request);

        /// <summary>
        /// 发送心跳，设备和用户共用
        /// </summary>
        /// <param name="request">The request</param>
        /// <returns></returns> 
        /// <errorCodes>CourseNoFound,LiveTeacherNotFound,ReservationNotReviewed,CourseEnded</errorCodes>
        Task<LiveHeartRateResult> HeartRateAsync(LiveHeartRateRequest request);

        /// <summary>
        /// 暂离直播间
        /// </summary>
        /// <param name="request">The request</param>
        /// <returns></returns>
        /// <errorCodes>CourseNoFound,CourseLivMemberNotFound,LiveTeacherNotFound</errorCodes>
        Task<LiveCourseBaseResult> LeaveLiveCourseAsync(LeaveLiveCourseRequest request);

        /// <summary>
        /// 结束课程直播
        /// </summary>
        /// <param name="request">The request</param>
        /// <returns></returns>
        /// <errorCodes>CourseNoFound,CourseLivMemberNotFound,LiveTeacherNotFound</errorCodes>
        Task<LiveCourseBaseResult> CompletedLiveCourseAsync(LeaveLiveCourseRequest request);

        /// <summary>
        /// 设置开启或关闭静音状态
        /// </summary>
        /// <param name="request">设置开启或关闭静音状态的请求</param>
        /// <returns></returns>
        /// <errorCodes>CourseNoFound,CourseNotInProcess,CourseLivMemberNotFound</errorCodes>
        Task<LiveCourseBaseResult> SetMuteLiveCourseAsync(SetMuteLiveCourseRequest request);

        /// <summary>
        /// 开启或关闭视频
        /// </summary>
        /// <param name="request">开启或关闭视频请求</param>
        /// <returns></returns>   
        /// <errorCodes>CourseNoFound,CourseNotInProcess,CourseLivMemberNotFound</errorCodes>    
        Task<LiveCourseBaseResult> SetVideoLiveCourseAsync(SetVideoLiveCourseRequest request);

        /// <summary>
        /// 设置设备调参
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>CourseNoFound,CourseLivMemberNotFound,ControllingParameterByOtherUser</errorCodes>
        Task<bool> SetControlParameterLiveCourseAsync(ControlParameterInCourseRequest request);

        /// <summary>
        /// 设备直播中加入房间
        /// </summary>
        /// <param name="request">The request</param>
        /// <returns></returns>
        /// <errorCodes>LiveCourseNotFound,CourseNotInProcess,DeviceCodeIsEmpty,DeviceNotExist</errorCodes>
        Task<LiveCourseMember> DeviceJoinInLiveCourseAsync(JoinLiveCourseRequest request);
        #endregion

        /// <summary>
        /// 上传远程考核图像
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <docFirstDirectory>设备端API</docFirstDirectory>
        /// <docSecondDirectory>杏聆荟学院服务接口</docSecondDirectory>   
        /// <docThirdDirectory>学生视角</docThirdDirectory>  
        /// <errorCodes>UniqueCodeIsEmpty,UniqueCodeIsError,FileTokenIsEmpty,PreviewFileTokenIsEmpty,CoverImageTokenIsEmpty</errorCodes>
        Task<bool> UploadRemoteExaminationDataAsync(UploadRemoteExamRequest request);

        /// <summary>
        /// 获取个人远程考核图像列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <docFirstDirectory>客户端API</docFirstDirectory>
        /// <docSecondDirectory>杏聆荟学院服务接口</docSecondDirectory>   
        /// <docThirdDirectory>学生视角</docThirdDirectory>  
        Task<IList<RemoteExaminationPageDTO>> GetRemoteExaminationList(TokenRequest request);

        /// <summary>
        /// 学生加入班级
        /// </summary>
        /// <param name="request"></param>
        /// <errorCodes>UserGroupCodeIsEmpty,UserCodeEmptyError,UserGroupStudentsIsEmpty,UserGroupNotExists</errorCodes>
        /// <returns></returns>
        /// <docFirstDirectory>客户端API</docFirstDirectory>
        /// <docSecondDirectory>杏聆荟学院服务接口</docSecondDirectory>   
        /// <docThirdDirectory>学生视角</docThirdDirectory>  
        Task<bool> AddStudentInCourseUserGroupAsync(AddStudentInCourseUserGroupRequest request);

        /// <summary>
        /// 学生退出班级
        /// </summary>
        /// <param name="request"></param>
        /// <errorCodes>UserGroupCodeIsEmpty,UserCodeEmptyError,UserGroupStudentsIsEmpty,UserGroupNotExists</errorCodes>
        /// <returns></returns>
        /// <docFirstDirectory>客户端API</docFirstDirectory>
        /// <docSecondDirectory>杏聆荟学院服务接口</docSecondDirectory>   
        /// <docThirdDirectory>学生视角</docThirdDirectory>  
        Task<bool> StudentLeaveCourseUserGroupAsync(StudentLeaveCourseUserGroupRequest request);

        /// <summary>
        /// 学生查询自己所在班级列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <docFirstDirectory>客户端API</docFirstDirectory>
        /// <docSecondDirectory>杏聆荟学院服务接口</docSecondDirectory>   
        /// <docThirdDirectory>学生视角</docThirdDirectory>  
        /// <errorCodes>StudentCodeEmpty</errorCodes>
        Task<PageResult<UserGroupDTO>> FindUserGroupByStudentAsync(QueryUserGroupPageRequest request);

        /// <summary>
        /// 学习完成处理
        /// </summary>
        /// <param name="request"></param>
        /// <errorCodes>CourseCodeEmpty,UserCodeEmptyError,CourseNoFound</errorCodes>
        /// <returns></returns>
        /// <docFirstDirectory>客户端API</docFirstDirectory>
        /// <docSecondDirectory>杏聆荟学院服务接口</docSecondDirectory>   
        /// <docThirdDirectory>学生视角</docThirdDirectory>  
        Task<bool> StudyCompletedAsync(StudyCompletedRequest request);

        /// <summary>
        /// 客户端老师添加课程专辑
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>AlbumNameIsEmpty</errorCodes>
        Task<string> AddCourseAlbumAsync(AddCourseAlbumRequest request);

        /// <summary>
        /// 客户端老师删除课程专辑
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>CodeIsEmpty</errorCodes>
        Task<bool> DeleteCourseAlbumAsync(DeleteCourseAlbumRequest request);

        /// <summary>
        /// 客户端通用查询课程专辑分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<CourseCommonInfoDTO>> FindCourseAlbumPageAsync(FindCoursePagesRequest request);

        /// <summary>
        /// 查询课程专辑详情
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<CourseAlbumExtendDTO> FindCourseAlbumByCodeAsync(FindCourseAlbumByCodeRequest request);

        /// <summary>
        /// 查询老师创建的课程专辑列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>TeacherCodeEmpty</errorCodes>
        Task<IList<BaseCourseAlbumDTO>> FindCourseAlbumListAsync(TokenRequest request);

        /// <summary>
        /// 老师添加学生，无需审核
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>TeacherCodeEmpty,StudentCodeEmpty,UserGroupCodeIsEmpty</errorCodes>
        Task<bool> AddUserGroupsStudentByTeacherAsync(TeacherAddStudentsInUserGroupsRequest request);

        /// <summary>
        /// 同意学生加入班级
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>TeacherCodeEmpty</errorCodes>
        Task<bool> JoinClassApprovedAsync(JoinClassApprovedRequest request);

        /// <summary>
        /// 拒绝学生加入班级
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>TeacherCodeEmpty</errorCodes>
        Task<bool> JoinClassRejectedAsync(JoinClassRejectedRequest request);
        
        /// <summary>
        /// 查询学生列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>TeacherCodeEmpty</errorCodes>
        Task<IList<UserGroupStudentsDTO>> FindStudentListAsync(FindStudentListRequest request);

        /// <summary>
        /// 创建素材
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> CreateVideosAsync(CreateVideosRequest request);

        /// <summary>
        /// 查询所有学员列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<UserExtendDTO>> GetAllStudentsAsync(GetUserPagesRequest request);

        /// <summary>
        /// 设置课程共享请求接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SetShareInLiveCourseAsync(SetShareInLiveCourseRequest request);

        /// <summary>
        /// 查询我的机构专家集合
        /// </summary>
        /// <param name="request">查询机构专家集合请求实体</param>
        /// <returns></returns>
        /// <errorCodes></errorCodes>
        Task<IList<UserBaseDTO>> FindMyOrganizationExpertsAsync(FindMyOrganizationExpertsRequest request);

        /// <summary>
        /// 发送白板交互数据
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SendCourseInteractiveBoardDataAsync(SendLiveInteractiveBoardDataRequest request);

        /// <summary>
        /// 转发进入课程通知到客户端（用于H5到壳子的通知）
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SendCourseEntryNoticeAsync(SendCourseEntryNoticeRequest request);

        /// <summary>
        /// 设备课程中离开房间
        /// </summary>
        /// <param name="request">The request</param>
        /// <returns></returns>
        Task<LiveCourseBaseResult> DeviceLeaveLiveCourseAsync(DeviceLeaveLiveCourseRequest request);

        /// <summary>
        /// 编辑课程专辑
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateCourseAlbumAsync(UpdateCourseAlbumRequest request);

        /// <summary>
        /// 修改素材名称
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> ChangeVideoNameAsync(ChangeVideoNameRequest request);
        
         /// <summary>
        /// 增加播放量
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> AddCoursePlayCountAsync(AddCoursePlayCountRequest request);

        /// <summary>
        /// 保存课程浏览记录
        /// </summary>
        /// <returns>是否成功</returns>
        Task<CourseBrowsedRecordDTO> SaveCourseBrowsedRecordAsync(CourseBrowsedRecordRequest request);

        /// <summary>
        /// 查询课程浏览记录
        /// </summary>
        /// <returns>是否成功</returns>
        Task<PageResult<CourseBrowsedRecordDTO>> QueryCourseBrowsedRecordsAsync(QueryBrowsedRecordPageRequest request);

        /// <summary>
        /// 发送心跳，游客，观众
        /// </summary>
        /// <param name="request">The request</param>
        /// <returns></returns> 
        Task<bool> VisitorHeartRateAsync(QueryBrowsedRecordRequest request);

        /// <summary>
        /// 游客，观众暂离直播间
        /// </summary>
        /// <param name="request">The request</param>
        /// <returns></returns>
        Task<bool> VisitorLeaveLiveCourseAsync(QueryBrowsedRecordRequest request);

        /// <summary>
        /// 设置课程禁言
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SetCourseLiveProhibitionAsync(CourseLiveProhibitionRequest request);

        /// <summary>
        /// 获取课程观看人数和在线人数
        /// </summary>
        /// <returns>是否成功</returns>
        Task<CourseVisitorsStatisticResult> QueryCourseBrowsedCountAsync(QueryBrowsedRecordRequest request);

        /// <summary>
        /// 根据课程code和用户code查询课程浏览记录
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<CourseBrowsedRecordDTO> GetCourseBrowsedRecordByRelevanceCodeAsync(QueryBrowsedRecordRequest request);

        /// <summary>
        /// 查询微信公众号轮播图列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<WXCarouselsResult>> GetWXCarouselsAsync(GetWXCarouselRequest request);
    }
}