using System.Collections;
using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.Management;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Result;
using WingInterfaceLibrary.DTO.Management;
using WingInterfaceLibrary.DTO.UserFeature;
using WingInterfaceLibrary.DTO.Device;
using WingInterfaceLibrary.Result.Management;
using WingInterfaceLibrary.DTO.AdminFeature;
using WingInterfaceLibrary.DTO.Storage;
using WingInterfaceLibrary.Request.Authentication;
using WingInterfaceLibrary.Request.Storage;
using WingInterfaceLibrary.Result.Organization;
using WingInterfaceLibrary.DTO.Record;
using WingInterfaceLibrary.DTO.User;
using WingInterfaceLibrary.DTO.ReportTemplate;
using WingInterfaceLibrary.DB.Request;
using WingInterfaceLibrary.DTO.Report;
using WingInterfaceLibrary.Request.Report;
using WingInterfaceLibrary.DTO.DiagnosisModule;
using WingInterfaceLibrary.DTO.DistributedServerInfo;
using WingInterfaceLibrary.DTO.AdminStatistic;
using WingInterfaceLibrary.DTO.Organization;
using WingInterfaceLibrary.DTO.CMSStatistic;
using WingInterfaceLibrary.DTO.GradingProtection;
using WingInterfaceLibrary.Request.User;
using WingInterfaceLibrary.DTO.Message;
using WingInterfaceLibrary.Request.Education;
using WingInterfaceLibrary.DTO.Education;
using WingInterfaceLibrary.DTO.Courses;
using WingInterfaceLibrary.Request.Courses;
using WingInterfaceLibrary.DTO.Payment;
using WingInterfaceLibrary.Request.DBRequest;
using WingInterfaceLibrary.DTO.Dictionary;
using WingInterfaceLibrary.DTO.Project;
using WingInterfaceLibrary.Result.Courses;
using WingInterfaceLibrary.DTO.Common;
using WingInterfaceLibrary.Request.IOTDevice;
using WingInterfaceLibrary.Request.Comment;
using WingInterfaceLibrary.ResearchEdition;

namespace WingInterfaceLibrary.Interface
{
    /// <summary>
    /// 后台管理服务
    /// </summary>
    public interface IManagementService
    {
        /// <summary>
        /// 管理员登
        /// </summary>
        /// <param name="request">管理员登录请求实</param>
        /// <returns></returns>
        Task<AdminLoginResult> AdminLogin(LoginRequest request);

        /// <summary>
        /// 修改管理员账
        /// </summary>
        /// <param name="request">修改管理员账号请求实</param>
        /// <returns></returns>
        Task<bool> ModifyAdminAsync(ModifyAdminRequest request);

        /// <summary>
        /// 创建管理员账
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns></returns>
        Task<bool> CreateAdminAsync(ModifyAdminRequest request);

        /// <summary>
        /// 获取管理员账号（分页
        /// </summary>
        /// <param name="request">获取管理员账号（分页）请求实</param>
        /// <returns></returns>
        Task<PageResult<AdminExtendInfoDTO>> GetAdminPagesAsync(GetAdminPagesRequest request);

        /// <summary>
        /// 删除管理员账
        /// </summary>
        /// <param name="request">删除管理员账号请求实</param>
        /// <returns></returns>
        Task<bool> RemoveAdminAsync(RemoveAdminRequest request);

        /// <summary>
        /// 查找管理员账
        /// </summary>
        /// <param name="request">查找管理员账号请求实</param>
        /// <returns></returns>
        Task<AdminInfoDTO> FindAdminByCodeAsync(FindAdminByCodeRequest request);

        /// <summary>
        /// 根据token获取登录信息
        /// </summary>
        /// <param name="request">根据token获取登录信息请求实体</param>
        /// <returns></returns>
        Task<AdminInfoDTO> GetLoginInfoByToken(TokenRequest request);

        /// <summary>
        /// 管理员登
        /// </summary>
        /// <param name="request">管理员登出请求实</param>
        /// <returns></returns>
        Task<bool> AdminLoginOut(TokenRequest request);

        /// <summary>
        /// 修改管理员密
        /// </summary>
        /// <param name="request">修改管理员密码请求实</param>
        /// <returns></returns>
        Task<bool> ModifyAdminPassword(ModifyAdminPasswordRequest request);

        /// <summary>
        /// 管理员角色配
        /// </summary>
        /// <param name="request">角色管理员配置请求实</param>
        /// <returns>是否成功</returns>  
        /// <value>true</value>
        /// <remarks>POST</remarks>
        Task<bool> ModifyAdminsRoles(ModifyAdminsRolesRequest request);
        /// <summary>
        /// 分配管理员到指定医院的请
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> AssignedAdminsToOrganizationsAsync(AssignedAdminsToOrganizationsRequest request);


        /// <summary>
        /// 修改用户账户
        /// </summary>
        /// <param name="request">修改用户账户请求实体</param>
        /// <returns></returns>
        Task<bool> ModifyUser(ModifyUserRequest request);

        /// <summary>
        /// 重置用户密码
        /// </summary>
        /// <param name="request">重置用户密码请求实体</param>
        /// <returns></returns>
        Task<bool> ResetUserPassword(ResetUserPasswordRequest request);

        /// <summary>
        /// 创建用户账户
        /// </summary>
        /// <param name="request">创建用户账户请求实体</param>
        /// <returns></returns>
        Task<bool> CreateUser(ModifyUserRequest request);

        /// <summary>
        /// 获取用户账户信息（分页）
        /// </summary>
        /// <param name="request">获取用户账户信息（分页）请求实体</param>
        /// <returns></returns>
        Task<PageResult<ManageUserInfoDTO>> GetUserPagesAsync(GetUserPagesRequest request);

        /// <summary>
        /// 删除用户账户
        /// </summary>
        /// <param name="request">删除用户账户请求实体</param>
        /// <returns></returns>
        Task<bool> RemoveUserAccountAsync(RemoveUserRequest request);

        /// <summary>
        /// 根据用户编码获取用户账户
        /// </summary>
        /// <param name="request">根据用户编码获取用户账户请求实体</param>
        /// <returns></returns>
        Task<ManageUserInfoDTO> FindUserByCode(FindUserByCodeRequest request);

        /// <summary>
        /// 根据解锁用户账号
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UnlockAccountAsync(UnlockAccountRequest request);

        /// <summary>
        /// 身份申请审核通过
        /// </summary>
        /// <param name="reuquest">身份申请审核通过请求实体</param>
        /// <returns></returns>
        Task<bool> ConfirmIdentityApply(ConfirmIdentityApplyRequest reuquest);

        /// <summary>
        /// 身份申请审核驳回
        /// </summary>
        /// <param name="request">身份申请审核驳回请求实体</param>
        /// <returns></returns>
        Task<bool> RejectIdentityApply(RejectIdentityApplyRequest request);

        /// <summary>
        /// 获取权限列表
        /// </summary>
        /// <param name="request">获取权限列表请求实体</param>
        /// <returns></returns>
        Task<List<UserFeatureItemDTO>> GetUserFeatureList(GetFeatureListRequest request);

        /// <summary>
        /// 创建权限
        /// </summary>
        /// <param name="request">创建权限请求实体</param>
        /// <returns></returns>
        Task<bool> CreateUserFeature(ModifyUserFeatureRequest request);

        /// <summary>
        /// 修改权限
        /// </summary>
        /// <param name="request">修改权限请求实体</param>
        /// <returns></returns>
        Task<bool> ModifyUserFeature(ModifyUserFeatureRequest request);

        /// <summary>
        /// 删除权限
        /// </summary>
        /// <param name="request">删除权限请求实体</param>
        /// <returns></returns>
        Task<bool> DeleteUserFeature(DeleteUserFeatureRequest request);

        /// <summary>
        /// 获取权限下拉列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<SelectItemDTO>> GetUserFeatureSelectList(TokenRequest request);

        /// <summary>
        /// 获取平台角色下拉列表
        /// </summary>
        /// <param name="request">获取平台角色下拉列表请求实体</param>
        /// <returns></returns>
        Task<List<SelectItemDTO>> GetRoleSelectList(GetRoleSelectListRequest request);

        /// <summary>
        /// 获取平台角色（分页）
        /// </summary>
        /// <param name="request">获取平台角色（分页）请求实体</param>
        /// <returns></returns>
        Task<PageResult<ManageRoleInfoDTO>> GetRolePagesAsync(GetRolePagesRequest request);

        /// <summary>
        /// 创建平台角色
        /// </summary>
        /// <param name="request">创建平台角色请求实体</param>
        /// <returns></returns>
        Task<bool> CreateRole(ModifyRoleInfoRequest request);

        /// <summary>
        /// 平台角色详情
        /// </summary>
        /// <param name="request">平台角色详情请求实体</param>
        /// <returns></returns>
        Task<ManageRoleInfoDTO> RoleDetail(FindRoleByCodeRequest request);

        /// <summary>
        /// 修改平台角色
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> ModifyRole(ModifyRoleInfoRequest request);

        /// <summary>
        /// 删除平台角色
        /// </summary>
        /// <param name="request">删除平台角色请求实体</param>
        /// <returns></returns>
        Task<bool> DeleteRole(DeleteRoleRequest request);

        /// <summary>
        /// 查询该角色关联用户数
        /// </summary>
        /// <param name="request">查询该角色关联用户数请求实体</param>
        /// <returns></returns>
        Task<int> QueryRoleUserNum(QueryRoleUserNumRequest request);

        /// <summary>
        /// 获取后台权限列表
        /// </summary>
        /// <param name="request">获取权限列表请求实体</param>
        /// <returns></returns>
        Task<List<AdminFeatureItemDTO>> GetAdminFeatureList(GetFeatureListRequest request);

        /// <summary>
        /// 创建后台权限
        /// </summary>
        /// <param name="request">创建权限请求实体</param>
        /// <returns></returns>
        Task<bool> CreateAdminFeature(ModifyAdminFeatureRequest request);

        /// <summary>
        /// 修改后台权限
        /// </summary>
        /// <param name="request">修改权限请求实体</param>
        /// <returns></returns>
        Task<bool> ModifyAdminFeature(ModifyAdminFeatureRequest request);

        /// <summary>
        /// 删除后台权限
        /// </summary>
        /// <param name="request">删除权限请求实体</param>
        /// <returns></returns>
        Task<bool> DeleteAdminFeature(DeleteAdminFeatureRequest request);

        /// <summary>
        /// 获取后台权限下拉列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<AdminFeatureInfoDTO>> GetAdminFeatureSelectList(TokenRequest request);

        /// <summary>
        /// 获取后台角色下拉列表
        /// </summary>
        /// <param name="request">获取后台角色下拉列表请求实体</param>
        /// <returns></returns>
        Task<List<SelectItemDTO>> GetAdminRoleSelectList(GetFeatureListRequest request);

        /// <summary>
        /// 获取后台角色（分页）
        /// </summary>
        /// <param name="request">获取后台角色（分页）请求实体</param>
        /// <returns></returns>
        Task<PageResult<ManageAdminRoleInfoDTO>> GetAdminRolePagesAsync(GetAdminRolePagesRequest request);

        /// <summary>
        /// 创建后台角色
        /// </summary>
        /// <param name="request">创建后台角色请求实体</param>
        /// <returns></returns>
        Task<bool> CreateAdminRole(ModifyAdminRoleInfoRequest request);

        /// <summary>
        /// 后台角色详情
        /// </summary>
        /// <param name="request">后台角色详情请求实体</param>
        /// <returns></returns>
        Task<ManageAdminRoleInfoDTO> AdminRoleDetail(FindAdminRoleByCodeRequest request);

        /// <summary>
        /// 后台角色权限列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ManageAdminFeatureInfoDTO> GetAdminRoleFeaturs(FindAdminRoleByCodeRequest request);

        /// <summary>
        /// 修改后台角色
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> ModifyAdminRole(ModifyAdminRoleInfoRequest request);

        /// <summary>
        /// 删除后台角色
        /// </summary>
        /// <param name="request">删除后台角色请求实体</param>
        /// <returns></returns>
        Task<bool> DeleteAdminRole(DeleteAdminRoleRequest request);

        /// <summary>
        /// 查询该角色关联管理员
        /// </summary>
        /// <param name="request">查询该角色关联管理员数请求实</param>
        /// <returns></returns>
        Task<int> QueryRoleAdminNum(QueryRoleAdminNumRequest request);

        /// <summary>
        /// 创建设备
        /// </summary>
        /// <param name="request">创建设备请求实体</param>
        /// <returns></returns>
        Task<bool> AddDevice(ModifyDeviceRequest request);

        /// <summary>
        /// 查询设备类型集合
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<ManageDeviceTypeDTO>> FindDeviceTypesAsync(TokenRequest request);

        /// <summary>
        /// 修改设备密码
        /// </summary>
        /// <param name="request">修改设备密码请求实体</param>
        /// <returns></returns>
        Task<bool> ModifyDevicePasswordAsync(ModifyDevicePasswordRequest request);

        /// <summary>
        /// 修改设备
        /// </summary>
        /// <param name="request">创建设备请求实体</param>
        /// <returns></returns>
        Task<bool> ModifyDevice(ModifyDeviceRequest request);

        /// <summary>
        /// 查询设备列表（分页）
        /// </summary>
        /// <param name="request">查询设备列表（分页）请求实体</param>
        /// <returns></returns>
        Task<PageResult<ManageDeviceInfoDTO>> GetDevicePages(GetDevicePagesRequest request);

        /// <summary>
        /// 管理端删除设备
        /// </summary>
        /// <param name="request">管理端删除设备请求实体</param>
        /// <returns></returns>
        Task<bool> DeleteDeviceAsync(DeleteDeviceRequest request);

        /// <summary>
        /// 查询设备用户列表（分页）
        /// </summary>
        /// <param name="request">查询设备用户列表（分页）请求实体</param>
        /// <returns></returns>
        Task<PageResult<ManageDeviceUserDTO>> GetManageDeviceUserPages(GetDeviceUserPagesRequest request);

        /// <summary>
        /// 设备分享
        /// </summary>
        /// <param name="request">设备分享请求实体</param>
        /// <returns></returns>
        Task<bool> ShareDevice(ShareDeviceRequest request);

        /// <summary>
        /// 移除设备分享
        /// </summary>
        /// <param name="request">移除设备分享请求实体</param>
        /// <returns></returns>
        Task<bool> RemoveShareDevice(ShareDeviceRequest request);

        /// <summary>
        /// 查询设备类型列表（分页）
        /// </summary>
        /// <param name="request">查询设备列表（分页）请求实体</param>
        /// <returns></returns>
        Task<PageResult<DictionaryDTO>> GetDeviceTypePages(GetDeviceTypePagesRequest request);

        /// <summary>
        /// 新增设备类型
        /// </summary>
        /// <param name="request"> 新增设备类型请求实体</param>
        /// <returns></returns>
        Task<bool> AddDeviceType(ModifyDeviceTypeRequest request);

        /// <summary>
        /// 修改设备类型
        /// </summary>
        /// <param name="request"> 新增设备类型请求实体</param>
        /// <returns></returns>
        Task<bool> ModifyDeviceType(ModifyDeviceTypeRequest request);

        /// <summary>
        /// 删除设备类型
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeleteDeviceTypeAsync(DeleteDeviceTypeRequest request);

        /// <summary>
        /// 设备型号使用情况
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<int> QueryDeviceModelBindNum(QueryDeviceModelBindNumRequest request);

        /// <summary>
        /// 设备类型下拉
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<SelectItemDTO>> GetDeviceTypeSelectList(GetDeviceModelSelectRequest request);

        /// <summary>
        /// 设备型号下拉
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<SelectParentItemDTO>> GetDeviceModelSelectList(GetDeviceModelSelectRequest request);

        /// <summary>
        /// 查询机构列表（分页）
        /// </summary>
        /// <param name="request">查询机构用户列表（分页）请求实体</param>
        /// <returns></returns>
        Task<PageResult<ManageOrganizationDTO>> GetManageOrganizationPages(GetOrganizationPagesRequest request);

        /// <summary>
        /// 创建机构
        /// </summary>
        /// <param name="request">创建机构请求实体</param>
        /// <returns></returns>
        Task<bool> AddOrganization(ModifyOrganizationRequest request);

        /// <summary>
        /// 查询机构绑定用户和设备情
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<OrganizationBindQueryResult> OrganizationBindQueryResult(GetOrganizationRequest request);

        /// <summary>
        /// 删除机构
        /// </summary>
        /// <param name="request">删除机构请求实体</param>
        /// <returns></returns>
        Task<bool> RemoveOrganization(RemoveOrganizationRequest request);

        /// <summary>
        /// 查询机构用户列表（分页）
        /// </summary>
        /// <param name="request">查询机构用户列表（分页）请求实体</param>
        /// <returns></returns>
        Task<PageResult<ManageOrganizationUserDTO>> GetManageOrganizationUserPages(GetOrganizationUserPagesRequest request);

        /// <summary>
        /// 查询机构
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ManageOrganizationDTO> GetOrganizationAsync(GetOrganizationRequest request);

        /// <summary>
        /// 编辑机构信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> ModifyOrganizationAsync(ModifyOrganizationRequest request);

        /// <summary>
        /// 维护负责
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> ModifyOrganizationDirectorsAsync(ModifyOrganizationDirectorsRequest request);

        /// <summary>
        /// 审核机构
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> ModifyOrganizationStateAsync(ModifyOrganizationStateRequest request);

        /// <summary>
        /// 查询机构负责
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> GetOrganizationDirectors(GetOrganizationRequest request);

        /// <summary>
        /// 获取机构下拉列表
        /// </summary>
        /// <param name="request">获取机构下拉列表请求实体</param>
        /// <returns></returns>
        Task<List<SelectItemDTO>> GetOrganizationSelectList(GetSelectOrganizationPageRequest request);

        /// <summary>
        /// 获取机构配置信息
        /// </summary>
        /// <param name="request">获取配置信息请求实体</param>
        /// <returns></returns>
        Task<OrganizationSettingResult> GetOrganizationSetting(GetOrganizationSettingRequest request);

        /// <summary>
        /// 修改配置信息
        /// </summary>
        /// <param name="request">修改配置信息请求实体</param>
        /// <returns></returns>
        Task<bool> ModifyOrganizationSetting(ModifyOrganizationSettingRequest request);

        /// <summary>
        /// 修改即时会诊配置
        /// </summary>
        /// <param name="request">修改即时会诊配置请求实体</param>
        /// <returns></returns>
        Task<bool> UpdateEmergencySettingAsync(UpdateEmergencySettingRequest request);

        /// <summary>
        /// 获取科室下拉列表
        /// </summary>
        /// <param name="request">获取科室下拉列表请求实体</param>
        /// <returns></returns>
        Task<List<SelectItemDTO>> GetDepartmentSelectList(GetOrganizationRequest request);

        /// <summary>
        /// 获取权限验证
        /// </summary>
        /// <param name="request">验签平台类型</param>
        /// <returns>验证后生成的验签信息</returns>
        Task<StorageServiceSettingDTO> GetAuthorizationAsync(FileServiceRequest request);

        /// <summary>
        /// 获取语言类型集合
        /// </summary>
        /// <param name="request">获取语言类型集合请求实体</param>
        /// <returns></returns>
        Task<Dictionary<string, string>> GetServerLanguages(TokenRequest request);

        /// <summary>
        /// 分页查询词库
        /// </summary>
        /// <param name="request">分页查询词库请求实体</param>
        /// <returns></returns>
        Task<PageResult<ThesaurusDTO>> FindThesaurusPagesAsync(FindThesaurusPagesRequest request);

        /// <summary>
        /// 查询词库详情
        /// </summary>
        /// <param name="request">查询词条详情请求实体</param>
        /// <returns></returns>
        Task<ThesaurusDTO> FindThesaurusByCodeAsync(FindThesaurusByCodeRequest request);

        /// <summary>
        /// 分页查询词库引用人
        /// </summary>
        /// <param name="request">查询词条详情请求实体</param>
        /// <returns></returns>
        Task<PageResult<ManageUserInfoDTO>> FindThesaurusUserPagesAsync(FindThesaurusUserPagesRequest request);

        /// <summary>
        /// 保存词库
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SaveThesaurusAsync(SaveThesaurusRequest request);

        /// <summary>
        /// 删除词库
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeleteThesaurusAsync(DeleteThesaurusRequest request);

        /// <summary>
        /// 发布词库
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> PublishThesaurusAsync(PublishThesaurusRequest request);

        /// <summary>
        /// 获取词条列表【tree】
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<ManageThesaurusItemDTO>> GetThesaurusItemListAsync(GetThesaurusItemRequest request);

        /// <summary>
        /// 保存词条项分类
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SaveThesaurusItemTypeAsync(ThesaurusItemRequest request);

        /// <summary>
        /// 删除词条项分类
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeleteThesaurusItemAsync(GetThesaurusItemRequest request);

        /// <summary>
        /// 保存词条详情
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SaveThesaurusItemAsync(ThesaurusItemRequest request);

        /// <summary>
        /// 获取词条列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<ThesaurusItemDTO>> GetItemListByParentCodeAsync(GetThesaurusItemRequest request);

        /// <summary>
        /// 分页查询报告模板
        /// </summary>
        /// <param name="request">分页查询报告模板请求实体</param>
        /// <returns></returns>
        Task<PageResult<ReportTemplateDTO>> FindReportTemplatePagesAsync(FindReportTemplatePagesRequest request);

        /// <summary>
        /// 添加报告模板
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> AddReportTemplateAsync(AddReportTemplateDBRequest request);

        /// <summary>
        /// 更新报告模板
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateReportTemplateAsync(UpdateReportTemplateDBRequest request);

        /// <summary>
        /// 更新报告模板
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> RemoveReportTemplateAsync(RemoveReportTemplateDBRequest request);

        /// <summary>
        /// 获取报告模板
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ReportTemplateDTO> GetReportTemplateAsync(GetReportTemplateDBRequest request);

        /// <summary>
        /// 发布报告模板
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> PublishReportTemplateAsync(PublishReportTemplateRequest request);

        /// <summary>
        /// 分页查询报告模板引用人
        /// </summary>
        /// <param name="request">查询词条详情请求实体</param>
        /// <returns></returns>
        Task<PageResult<ManageUserInfoDTO>> FindReportTemplateUserPagesAsync(FindReportTemplateUserPagesRequest request);

        /// <summary>
        /// 分页查询报告标签
        /// </summary>
        /// <returns></returns>
        Task<PageResult<ReportLabelDTO>> FindReportLabelByPageAsync(FindReportLabelByPageRequest request);

        /// <summary>
        /// 查询报告标签详情
        /// </summary>
        /// <returns></returns>
        Task<ReportLabelDTO> FindReportLabelByCodeAsync(FindReportLabelByCodeRequest request);

        /// <summary>
        /// 保存报告标签
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SaveReportLabelAsync(SaveReportLabelRequest request);

        /// <summary>
        /// 删除报告标签
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeleteReportLabelAsync(RemoveReportLabelRequest request);

        /// <summary>
        /// 刷新读到内存中的配置
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SettingReloadAsync(SettingReloadRequest request);

        /// <summary>
        /// 获取机构翻译自定义配置
        /// </summary>
        /// <param name="request">获取配置信息请求实体</param>
        /// <returns></returns>
        Task<OrganizationSettingResult> GetOrganizationCustomSettingAsync(GetOrganizationCustomSettingRequest request);

        /// <summary>
        /// 修改机构翻译自定义配置
        /// </summary>
        /// <param name="request">修改配置信息请求实体</param>
        /// <returns></returns>
        Task<bool> ModifyOrganizationCustomSettingAsync(ModifyOrganizationCustomSettingRequest request);

        /// <summary>
        /// 增量添加AI应用
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> MofifyDiagnosisModulesAsync(ModifyDiagnosisModulesRequest request);

        /// <summary>
        /// 分页查询AI应用
        /// </summary>
        /// <returns></returns>
        Task<PageResult<DiagnosisModuleDTO>> FindDiagnosisModuleByPageAsync(FindDiagnosisModuleByPageRequest request);

        /// <summary>
        /// 开启/关闭AI应用
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> ModifyDiagnosisModuleEnableStateAsync(ModifyDiagnosisModuleEnableStateRequest request);

        /// <summary>
        /// 查询机构AI应用集合
        /// </summary>
        /// <returns></returns>
        Task<List<DiagnosisModuleDTO>> FindOrganizationDiagnosisModulesAsync(FindOrganizationDiagnosisModulesRequest request);

        /// <summary>
        /// 保存机构AI应用集合
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> ModifyOrganizationDiagnosisModulesAsync(ModifyOrganizationDiagnosisModulesRequest request);

        /// <summary>
        /// 查询设备AI应用集合
        /// </summary>
        /// <returns></returns>
        Task<List<DiagnosisModuleDTO>> FindDeviceDiagnosisModulesAsync(FindDeviceDiagnosisModulesRequest request);

        /// <summary>
        /// 修改设备AI权限开关闭状态
        /// </summary>
        /// <returns></returns>
        Task<bool> UpdateDeviceDiagnosisModuleEnabledAsync(UpdateDeviceDiagnosisModuleEnabledRequest request);

        /// <summary>
        /// 新增第三方信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> AddThirdPartyInfoAsync(ModifyThirdPartyInfoRequest request);

        /// <summary>
        /// 修改第三方信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateThirdPartyInfoByCodeAsync(ModifyThirdPartyInfoRequest request);

        /// <summary>
        /// 查询第三方信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ThirdPartyInfoDTO> FindThirdPartyInfoByCodeAsync(FindThirdPartyInfoByCodeRequest request);

        /// <summary>
        /// 查询第三方信息分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<ThirdPartyInfoDTO>> FindThirdPartyInfoPagesAsync(GetThirdPartyInfoPagesRequest request);

        /// <summary>
        /// 删除第三方信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeleteThirdPartyInfoByCodeAsync(DeleteThirdPartyInfoRequest request);

        /// <summary>
        /// 生成第三方token
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> CreateThirdPartyTokenAsync(CreateThirdPartyTokenRequest request);

        /// <summary>
        /// 第三方可选接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<SelectItemDTO>> GetThirdPartyInterfacesAsync(TokenRequest request);

        /// <summary>
        /// 查询日志
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<DBLog>> FindLogPagesAsync(GetLogPagesRequest request);

        // /// <summary>
        // /// 删除日志
        // /// </summary>
        // /// <param name="request"></param>
        // /// <returns></returns>
        // Task<bool> DeleteLogsAsync(DeleteLogsRequest request);

        /// <summary>
        /// 查询待删除日志数量
        /// </summary>
        /// <param name="request"></param>
        /// <returns>是否删除成功</returns>
        Task<WaitDeleteLogsDTO> QueryWaitDeleteLogsCountAsync(QueryWaitDeleteLogsRequest request);

        /// <summary>
        /// 查询删除了多少
        /// </summary>
        /// <param name="request"></param>
        /// <returns>是否删除成功</returns>
        Task<long> QueryDeletedLogsCountAsync(DeleteDBLogsRequest request);


        /// <summary>
        /// 删除日志数据，适合大批量
        /// </summary>
        /// <param name="request"></param>
        /// <returns>是否删除成功</returns>
        Task<bool> DeleteManyLogsAsync(BatchDeleteDBLogsRequest request);

        // /// <summary>
        // /// 查询清理日志日志记录
        // /// </summary>
        // /// <param name="request"></param>
        // /// <returns></returns>
        // Task<ClearSystemLogRecordResult> QueryClearLogsRecordAsync(QueryClearLogsRequest request);

        /// <summary>
        /// Get paged online accounts
        /// </summary>
        /// <param name="request">The request parameters</param>
        /// <returns>The online account list</returns>
        Task<PageResult<OnlineTokenDTO>> GetPagedOnlineAccountsAsync(GetPagedTokensOnlineRequest request);

        /// <summary>
        /// 分页查询报告转发厂商配置详情
        /// </summary>
        /// <returns></returns>
        Task<PageResult<ReportPosterDTO>> FindReportPosterByPageAsync(FindReportPosterByPageRequest request);

        /// <summary>
        /// 查询报告转发厂商配置详情
        /// </summary>
        /// <returns></returns>
        Task<ReportPosterDTO> FindReportPosterByCodeAsync(FindReportPosterByCodeRequest request);

        /// <summary>
        /// 查询关联设备Codes
        /// </summary>
        /// <returns></returns>
        Task<List<string>> FindRelatedDeviceCodesAsync(FindRelatedDeviceCodesRequest request);

        /// <summary>
        /// 保存报告转发厂商配置详情
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SaveReportPosterAsync(SaveReportPosterRequest request);

        /// <summary>
        /// 设置报告转发厂商关联设备集合
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> ModifyReportPosterDevicesAsync(ModifyReportPosterDevicesRequest request);

        /// <summary>
        /// 删除报告转发厂商配置详情
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> RemoveReportPosterAsync(RemoveReportPosterRequest request);
        /// <summary>
        ///  分页查询报告转发记录请求
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <show>false</show>
        Task<PageResult<ReportPushRecordDTO>> FindReportPushRecordsByPageAsync(FindReportPushRecordsByPageRequest request);

        /// <summary>
        /// 重发选择的报告转发记录请求
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <show>false</show>
        Task<bool> RetryPushReportRecordsAsync(RetryPushReportRecordsRequest request);

        /// <summary>
        /// 查询分享的报告链接
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <show>false</show>
        Task<string> FindReportShareConentAsync(FindReportShareConentRequest request);

        /// <summary>
        /// 查询报告预览图请求
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <show>false</show>
        Task<string> FindReportPreviewUrlAsync(FindReportPreviewUrlRequest request);

        /// <summary>
        /// 获取服务器配置信息列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<DistributedServerInfoDTO>> GetDistributedServerInfoPagesAsync(GetDistributedServerRequest request);

        /// <summary>
        /// 删除服务器配置信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeleteDistributedServerInfoAsync(DistributedServerInfoRequest request);

        /// <summary>
        /// 查询服务器配置信息详情
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<DistributedServerInfoDTO>> GetDistributedServerInfoDBByCodesAsync(DistributedServerInfoRequest request);

        /// <summary>
        /// 查询服务器配置信息IP列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<IPAddressInfoDTO>> GetDistributedServerIpListAsync(GetDistributedServerIpListRequest request);

        /// <summary>
        /// 保存服务器配置信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SaveDistributedServerInfoAsync(DistributedServerInfoRequest request);

        /// <summary>
        /// 保存IP段
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SaveDistributedServerIpAsync(SaveDistributedServerIpRequest request);

        /// <summary>
        /// 删除IP段
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DelDistributedServerIpAsync(SaveDistributedServerIpRequest request);

        /// <summary>
        /// 查询该IP段是否已在配置中
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<DistributedServerInfoDTO> VerifyDistributedServerIpAsync(SaveDistributedServerIpRequest request);

        /// <summary>
        /// 验证Token信息
        /// </summary>
        /// <param name="request">token请求实体</param>
        /// <returns></returns>
        Task<bool> GetValidateTokenAsync(TokenRequest request);

        /// <summary>
        /// 查询转诊配置信息
        /// </summary>
        /// <returns></returns>
        Task<ReferralRecordSettingDTO> FindReferralRecordSettingAsync(FindReferralRecordSettingRequest request);

        /// <summary>
        /// 保存转诊配置信息
        /// </summary>
        /// <returns></returns>
        Task<bool> ModifyReferralRecordSettingAsync(ModifyReferralRecordSettingRequest request);

        /// <summary>
        /// 查询管理员统计结果集合
        /// </summary>
        /// <returns></returns>
        Task<List<AdminStatisticRecordDTO>> FindAdminStatisticRecordsAsync(FindAdminStatisticRecordsRequest request);

        /// <summary>
        /// 获取扫查文件播放地址
        /// </summary>
        /// <returns></returns>
        Task<ShareExamUrlResult> GetShareExamUrlAsync(GetShareExamUrlRequest request);

        /// <summary>
        /// 获取会诊配置
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<ConsultationBaseInfoItem>> GetConsultationBaseInfoSetting(GetOrganizationSettingRequest request);

        /// <summary>
        /// 修改会诊配置
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> ModifyGetConsultationBaseInfoSetting(ModifycConsultationBaseInfoSettingRequest request);

        /// <summary>
        /// 查询CMS Json模板接口
        /// </summary>
        /// <param name="request">token请求实体</param>
        /// <returns></returns>
        Task<CMSTemplateResult> FindCMSTemplateDetailAsync(FindCMSTemplateDetailRequest request);

        /// <summary>
        /// 查询CMS Json模板接口
        /// </summary>
        /// <param name="request">token请求实体</param>
        /// <returns></returns>
        Task<PageResult<CMSTemplateResult>> FindCMSTemplatePageAsync(FindCMSTemplatePageRequest request);

        /// <summary>
        /// 模仿登录
        /// </summary>
        /// <param name="request">token请求实体</param>
        /// <returns></returns>
        Task<ImitateLoginResult> ImitateLoginAsync(ImitateLoginRequest request);

        /// <summary>
        /// CMS统计，查询模板详情
        /// </summary>
        /// <param name="request">token请求实体</param>
        /// <returns></returns>
        Task<CMSTemplateResult> FindCMSTemplateByUserAsync(FindCMSTemplateByUserRequest request);

        /// <summary>
        /// CMS统计接口
        /// </summary>
        /// <param name="request">token请求实体</param>
        /// <returns></returns>
        Task<IList<CMSStatisticRecordDTO>> FindCMSStatisticRecordsAsync(FindCMSStatisticRequest request);

        /// <summary>
        /// CMS保存模版
        /// </summary>
        /// <param name="request">token请求实体</param>
        /// <returns></returns>
        Task<bool> SaveCMSTemplateAsync(SaveCMSTemplateDetailRequest request);

        /// <summary>
        /// 获取CMS模板列表
        /// </summary>
        /// <param name="request">获取CMS模板请求实体</param>
        /// <returns></returns>
        Task<List<SelectItemDTO>> GetCMSTemplateSelectList(TokenRequest request);

        /// <summary>
        /// 解锁账号
        /// </summary>
        /// <param name="adminCode"></param>
        /// <returns></returns>
        Task<bool> UnlockAdminAccountAsync(RemoveAdminRequest request);

        /// <summary>
        /// 修改设备下载类型
        /// </summary>
        /// <param name="request">修改设备下载类型请求</param>
        /// <returns></returns>
        Task<bool> ModifyDeviceDownloadModeAsync(ModifyDeviceDownloadModeRequest request);


        /// <summary>
        /// 修改设备合流画面尺寸
        /// </summary>
        /// <param name="request">修改设备合流尺寸请求</param>
        /// <returns></returns>
        Task<bool> ModifyDeviceMergedVideoSizeAsync(ModifyDeviceMergedVideoSizeRequest request);

        /// <summary>
        /// CMS模版删除
        /// </summary>
        /// <param name="request">删除请求实体</param>
        /// <returns></returns>
        Task<bool> DeleteCmsTemplateAsync(SaveCMSTemplateDetailRequest request);

        /// <summary>
        /// 查找等保信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<GradingProtectionConfigDTO>> FindPageGradingProtectionConfigPageAsync(FindGradingProtectionConfigByPageRequest request);

        /// <summary>
        /// 更新选定配置
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateGradingProtectionConfigEnableAsync(UpdateGradingProtectionConfigEnableRequest request);

        /// <summary>
        /// 增加公告内容接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> AddAnnouncementAsync(AddAnnouncementRequest request);

        /// <summary>
        /// 获取公告内容列表接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<AnnouncementInfoDTO>> QueryAnnouncementsByPageAsync(QueryAnnouncementPageRequest request);

        /// <summary>
        /// 根据公告Code获取内容接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<AnnouncementInfoDTO> GetAnnouncementAsync(GetAnnouncementRequest request);

        /// <summary>
        /// 更新公告内容接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateAnnouncementAsync(UpdateAnnouncementRequest request);

        /// <summary>
        /// 删除公告内容接口
        /// </summary>
        /// <returns></returns>
        Task<bool> DeleteAnnouncementAsync(GetAnnouncementRequest request);

        /// <summary>
        /// 发布公告
        /// </summary>
        /// <returns></returns>
        Task<bool> PublishAnnouncementAsync(GetAnnouncementRequest request);

        /// <summary>
        /// 获取标签列表
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>标签信息</returns>
        /// <errorCodes></errorCodes>
        Task<IList<CourseLabelDTO>> GetCourseLabelsAsync(QueryCourseLabelPageRequest request);

        /// <summary>
        ///新增标签
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> AddCourseLabelAsync(CourseLabelRequest request);

        /// <summary>
        /// 修改标签
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> UpdateCourseLabelAsync(CourseLabelRequest request);

        /// <summary>
        /// 通过code删除标签
        /// </summary> 
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> DeleteCourseLabelByCodeAsync(CourseLabelRequest request);

        /// <summary>
        /// 课程申请
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> ApplyCourseAsync(AdminApplyCourseRequest request);

        /// <summary>
        /// 课程更新
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateCourseAsync(AdminUpdateCourseRequest request);

        /// <summary>
        /// 删除课程记录
        /// </summary>
        /// <param name="request">删除课程请求</param>
        /// <returns>删除成功或者失败</returns>
        /// <errorCodes>UserNotFind,CourseCodeEmpty,CourseNoFound,NotDeleteForCourseStatus</errorCodes>
        Task<bool> DeleteCourseByCodeAsync(AdminDeleteCourseByCodeRequest request);

        /// <summary>
        ///查询课程分页列表 
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<CourseInfoDetailDTO>> FindCoursePagesAsync(AdminFindCoursePagesRequest request);

        /// <summary>
        /// 审核课程
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> ApprovalCourseAsync(AdminApprovalCourseRequest request);

        /// <summary>
        /// 获取老师列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<SelectItemDTO>> GetTeacherSelectListAsync(TokenRequest request);

        /// <summary>
        /// 查询用户组分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<UserGroupDTO>> FindUserGroupsPagesAsync(QueryUserGroupPageRequest request);

        /// <summary>
        /// 查询用户分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<StudentInfoDTO>> FindUserGroupStudentsPagesAsync(QueryStudentByGroupCodePageRequest request);

        /// <summary>
        /// 新增用户组
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> AddUserGroupAsync(UserGroupRequest request);

        /// <summary>
        /// 修改用户组
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> UpdateUserGroupAsync(UserGroupRequest request);

        /// <summary>
        /// 删除用户组
        /// </summary> 
        /// <param name="request">用户组code</param>
        /// <returns></returns>
        Task<bool> DeleteUserGroupByCodeAsync(UserGroupFilterRequest request);

        /// <summary>
        /// 用户组新增用户
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> AddStudentsByGroupCodeAsync(UserGroupRequest request);

        /// <summary>
        /// 用户组移除用户
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> RemoveStudentsByGroupCodeAsync(UserGroupFilterRequest request);

        /// <summary>
        /// 分页查询题目列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<ExaminationQuestionDTO>> FindExaminationQuestionPagesAsync(FindExaminationQuestionPagesRequest request);

        /// <summary>
        /// 根据codes查询题目列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<ExaminationQuestionDTO>> FindExaminationQuestionsByCodesAsync(FindExaminationQuestionsByCodesRequest request);

        /// <summary>
        /// 创建题目
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> CreateExaminationQuestionAsync(CreateExaminationQuestionRequest request);

        /// <summary>
        /// 详情
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ExaminationQuestionDTO> GetExaminationAsync(GetExaminationQuestionRequest request);

        /// <summary>
        /// 修改题目
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateExaminationQuestionAsync(UpdateExaminationQuestionRequest request);

        /// <summary>
        /// 删除题目
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeleteExaminationQuestionAsync(DeleteExaminationQuestionRequest request);

        /// <summary>
        /// 新增试卷
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> AddExaminationPaperAsync(AddExaminationPaperRequest request);

        /// <summary>
        /// 删除试卷
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeleteExaminationPaperAsync(DeleteExaminationPaperRequest request);

        /// <summary>
        /// 修改试卷
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateExaminationPaperAsync(UpdateExaminationPaperRequest request);

        /// <summary>
        /// 查询试卷
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ExaminationPaperDTO> GetExaminationPaperAsync(GetExaminationPaperRequest request);

        /// <summary>
        /// 查询试卷分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<ExaminationPaperDTO>> GetExaminationPaperPagesAsync(GetExaminationPaperPagesRequest request);

        /// <summary>
        /// 创建视频
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> CreateVideoAsync(SaveVideoRequest request);

        /// <summary>
        /// 根据课程code查询所属视频
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<VideoInfoDTO>> FindVideosByCourseCodeAsync(FindVideosByCourseCodeRequest request);

        /// <summary>
        /// 查询所有视频列表分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<VideoInfoDTO>> FindVideosPagesAsync(FindVideoPagesRequest request);

        /// <summary>
        /// 删除视频，同步删除课程管理视频code
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeleteVideoByCodeAsync(DeleteVideoRequest request);

        /// <summary>
        /// 修改课程绑定试卷
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> AdminUpdateCourseBindExamsAsync(AdminUpdateCourseBindExamsRequest request);

        /// <summary>
        /// 订单详情接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ManageOrderDetailDTO> ManageGetOrderDetailAsync(ManageGetOrderDetailRequest request);

        /// <summary>
        /// 订单列表接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<ManageOrderDetailDTO>> ManageGetOrderPagesAsync(ManageGetOrderPagesRequest request);

        /// <summary>
        /// 新增商品信息接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ManageCreateProductDTO> ManageCreateProductAsync(ManageCreateProductRequest request);

        /// <summary>
        /// 修改商品信息接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ManageUpdateProductDTO> ManageUpdateProductAsync(ManageUpdateProductRequest request);

        /// <summary>
        /// 支付记录接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<ManagePaymentRecordDTO>> ManageGetPaymentRecordsAsync(ManageGetPaymentRecordsRequest request);

        /// <summary>
        /// 新增设备画面尺寸
        /// </summary>
        /// <returns>是否操作成功</returns>
        Task<bool> AddDeviceOutputConfigAsync(AddDeviceOutputConfigRequest request);

        /// <summary>
        /// 获取设备画面尺寸
        /// </summary>
        /// <returns>是否操作成功</returns>
        Task<List<DeviceOutputConfigDTO>> GetDeviceOutputConfigAsync(GetDeviceOutputConfigRequest request);

        /// <summary>
        /// 获取品牌型号分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<BrandModelDetailDTO>> GetDeviceBrandModelPageAsync(GetDeviceBrandModelPageRequest request);

        /// <summary>
        /// 新增设备画面尺寸
        /// </summary>
        /// <returns>是否操作成功</returns>
        Task<bool> ReportBrandModelOutputConfigAsync(WingInterfaceLibrary.Request.Device.ReportBrandModelOutputConfigRequest request);

        /// <summary>
        /// 删除品牌型号
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeleteBrandModelOutputConfigAsync(DeleteBrandModelOutputConfigRequest request);

        /// <summary>
        /// 取消删除日志
        /// </summary>
        /// <param name="request"></param>
        /// <returns>是否删除成功</returns>
        Task<bool> CancelDeleteLogsAsync(BatchDeleteDBLogsRequest request);

        /// <summary>
        /// 保存CMS画布背景色
        /// </summary>
        /// <param name="request"></param>
        /// <returns>是否成功</returns>
        Task<bool> SaveCMSTemplateBgAsync(SaveCMSTemplateDetailRequest request);

        /// <summary>
        /// 保存系统配置
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SaveSystemConfigAsync(SystemConfigDTO request);

        /// <summary>
        /// 获取系统配置通过code
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<SystemConfigDTO> GetSystemConfigByCodeAsync(QuerySystemConfigRequest request);

        /// <summary>
        /// 分页获取系统配置
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<SystemConfigDTO>> GetSystemConfigByPagesAsync(FindSystemConfigPagesDBRequest request);

        // <summary>
        /// 审核用户组学员
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> AuditUserGroupLearnerAsync(UserGroupRequest request);

        /// <summary>
        /// 添加课程专辑
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> AddCourseAlbumAsync(AddCourseAlbumRequest request);

        /// <summary>
        /// 删除课程专辑
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeleteCourseAlbumAsync(DeleteCourseAlbumRequest request);

        /// <summary>
        /// 查询课程专辑
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<CourseAlbumDTO>> FindCourseAlbumPageAsync(FindCourseAlbumPageRequest request);

        /// <summary>
        /// 修改课程专辑
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateCourseAlbumAsync(UpdateCourseAlbumRequest request);

        /// <summary>
        /// 根据课程code查询所有的专辑列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<CourseAlbumDTO>> GetCourseAlbumListByCourseCodeAsync(FindCourseByCodeRequest request);

        /// <summary>
        /// 根据讲师code查询所有的专辑列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<CourseAlbumDTO>> GetCourseAlbumListByTeacherCodeAsync(FindCourseByCodeRequest request);

        /// <summary>
        /// 批量新增管理员数据
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>是否成功</returns>
        Task<bool> BatchInsertAdminDataAsync(BatchInsertAdminRequest request);

        /// <summary>
        /// 批量新增超声机数据
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>是否成功</returns>
        Task<bool> BatchInsertDeviceDataAsync(BatchInsertDeviceRequest request);

        /// <summary>
        /// 批量新增机构数据
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>是否成功</returns>
        Task<bool> BatchInsertOrganizationDataAsync(BatchInsertOrganizationRequest request);

        /// <summary>
        /// 批量新增报告推送数据
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>是否成功</returns>
        Task<bool> BatchInsertPosterConfigsDataAsync(BatchInsertPosterConfigRequest request);

        /// <summary>
        /// 批量新增报告推送数据
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>是否成功</returns>
        Task<bool> BatchInsertReportTemplateDataAsync(BatchInsertReportTemplateRequest request);

        /// <summary>
        /// 批量新增课程标签数据
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>是否成功</returns>
        Task<bool> BatchInsertCourseLabelDataAsync(BatchInsertCourseLabelRequest request);

        /// <summary>
        /// 批量新增用户组数据
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>是否成功</returns>
        Task<bool> BatchInsertUserGroupDataAsync(BatchInsertUserGroupRequest request);

        /// <summary>
        /// 批量新增课程数据
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>是否成功</returns>
        Task<bool> BatchInsertCourseDataAsync(BatchInsertCourseRequest request);

        /// <summary>
        /// 获取支付完整链接
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns></returns>
        Task<GetPayUrlResult> GetPayUrlAsync(GetPayUrlRequest request);

        /// <summary>
        /// 批量新增报告标签推送数据
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>是否成功</returns>
        Task<bool> BatchInsertReportLabelAsync(BatchInsertReportLabelRequest request);

        /// <summary>
        /// 批量新增医联体
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>是否成功</returns>
        Task<bool> BatchInsertMedicalConsortiumAsync(BatchInsertMedicalConsortiumRequest request);

        /// <summary>
        /// 导入词条
        /// </summary>
        /// <param name="ImportThesaurusRequest">词条信息</param>
        /// <returns></returns>
        Task<bool> ImportThesaurusAsync(ImportThesaurusRequest request);

        /// <summary>
        /// 重置管理员密码
        /// </summary>
        /// <param name="request">重置管理员密码请求实体</param>
        /// <returns></returns>
        Task<bool> ResetAdminPassword(ResetAdminPasswordRequest request);

        /// <summary>
        /// 获取职称列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<WingInterfaceLibrary.DTO.Rank.RankDTO>> GetRankListAsync(GetOrganizationRequest request);

        /// <summary>
        /// 修改用户账户
        /// </summary>
        /// <param name="request">修改用户账户请求实体</param>
        /// <returns></returns>
        Task<bool> AddUserAsync(ModifyUserRequest request);

        /// <summary>
        /// 获取职称列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeleteUserByCode(ResetUserPasswordRequest request);

        /// <summary>
        /// 转换地址
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> TransferUrlAsync(StorageRequest request);

        /// <summary>
        /// 获取用户设备信息（分页）
        /// </summary>
        /// <param name="request">获取用户设备信息（分页）请求实体</param>
        /// <returns></returns>
        Task<PageResult<ManageDeviceInfoDTO>> GetUserDevicesPagesAsync(GetUserDevicesPagesRequest request);

        /// <summary>
        /// 获取机构设备信息（分页）
        /// </summary>
        /// <param name="request">获取机构设备信息（分页）请求实体</param>
        /// <returns></returns>
        Task<PageResult<ManageDeviceInfoDTO>> GetOrganizationDevicesPagesAsync(GetOrganizationDevicesPagesRequest request);

        /// <summary>
        /// 设置用户设备
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> SaveUserDevicesAsync(BindUserDevicesRequest request);

        /// <summary>
        /// 清洗数据-修改用户绑定设备机构，以及绑定机构的机构负责人对应的设备和机构数据；
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> ModifyUserBindDeviceOrganizationsAsync(ModifyUserBindDeviceOrganizationRequest request);

        /// <summary>
        /// 清洗数据-将机构数据为空，且用户角色不为空的用户数据清洗到vinno_fis平台下面
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> ModifyUserSpecialOrganizationInfoAsycn(ModifyUserSpecialOrganizationRequest request);
        
        /// <summary>
        /// 清洗数据-重新清洗报告模板数据及个人绑定数据
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> ModifyReportTemplateHistoryDataAsync(BatchModifyReportTemplateRequest request);

        /// <summary>
        /// 清洗数据-清理新平台报告数据是否用户报告
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> SynIsUserReportInfoAsync(BatchModifyRecordReportDataRequest request);

        /// <summary>
        /// 导出词条信息
        /// </summary>
        /// <param name="request">查询词条详情请求实体</param>
        /// <returns></returns>
        Task<ExportThesaurusResult> ExportThesaurusAsync(FindThesaurusByCodeRequest request);

        /// <summary>
        /// 查询相关配置
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns></returns>
        Task<ConfigRecordResult> QueryConfigRecordAsync(TokenRequest request);

        /// <summary>
        /// 清理重复短码
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns></returns>
        Task<bool> ClearRepeatDeviceInfoAsync(ShareDeviceRequest request);

        /// <summary>
        /// 所有机构:添加短码字段
        /// </summary>
        /// <returns>是否成功</returns>
        Task<bool> UpdateOrganizationsAsync(ModifyUserBindDeviceOrganizationRequest request);

        /// <summary>
        /// 查询所有机构Code列表
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns></returns>
        Task<List<string>> GetAllOrganizationCodesAsync(GetUpgradeBusinessDataRequest request);

        /// <summary>
        /// 更新用户角色为空的，调整为默认普通用户角色
        /// </summary>
        /// <returns>是否成功</returns>
        Task<bool> UpdateUserBindRoleAsync(ModifyUserBindDeviceOrganizationRequest request);

        /// <summary>
        /// 获取机构模板列表
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns></returns>
        Task<BindOrganizationTemplateResult> GetOrganizationTemplateSelectList(GetOrganizationSettingRequest request);

        /// <summary>
        /// 设置机构默认模板
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns></returns>
        Task<bool> SetOrganizationTemplateDataAsync(SaveOrgTemplateDataRequest request);

        /// <summary>
        /// 报告模板预览图数据清洗
        /// </summary>
        /// <returns>是否成功</returns>
        Task<bool> UpgradeDefaultReportTemplateToOtherNodeAsync(SaveOrgTemplateDataRequest request);

        /// <summary>
        /// 获取用户权限列表codes
        /// </summary>
        /// <returns>数据列表</returns>
        Task<UserFeatureInformationResult> GetUserFeatureCodesAsync(UserFeatureInfoRequest request);

        /// <summary>
        /// 保存用户权限列表codes
        /// </summary>
        /// <returns>数据列表</returns>
        Task<bool> SaveUserFeatureCodesAsync(SaveUserFeatureInfoRequest request);

        /// <summary>
        /// 修改远程维护管理员角色的用户数据
        /// </summary>
        /// <returns>是否成功</returns>
        Task<bool> UpgradeRemoteMaintainUserRoleAsync(TokenRequest request);

        /// <summary>
        /// 初始化代理商跳转地址数据同步
        /// </summary>
        /// <param name="request">修改用户账户请求实体</param>
        /// <returns></returns>
        Task<bool> InitUserAgentInfoXlhAsync(TokenRequest request);

        /// <summary>
        /// 获取分享图片列表文件播放地址
        /// </summary>
        /// <returns></returns>
        Task<ShareImagesUrlResult> GetShareImagesUrlAsync(GetShareImagesUrlRequest request);

        /// <summary>
        /// 分页查询用户群组
        /// </summary>
        /// <returns></returns>
        Task<PageResult<UserGroupDTO>> FindUserGroupPagesAsync(FindUserGroupPagesRequest request);

        /// <summary>
        /// 查询用户群组详情
        /// </summary>
        /// <returns></returns>
        Task<UserGroupDTO> FindUserGroupAsync(FindUserGroupRequest request);

        /// <summary>
        /// 新增/更新用户组信息
        /// </summary>
        /// <returns></returns>
        Task<string> AddOrUpdateUserGroupAsync(UserGroupDTO request);

        /// <summary>
        /// 分页查询设备集合
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<DeviceInfoDTO>> FindDevicePagesAsync(FindDevicePagesRequest request);

        /// <summary>
        /// 分页查询用户集合
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<UserDTO>> FindUserPagesAsync(FindUserPagesRequest request);

        /// <summary>
        /// 分页查询机构集合
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<OrganizationDTO>> FindOrganizationPagesAsync(FindOrganizationPagesRequest request);
        
        /// <summary>
        /// 初始化数据
        /// </summary>
        /// <returns></returns>
        Task<bool> InitDeviceModelAsync(TokenRequest request);

        /// <summary>
        /// 重新加载语言配置信息
        /// </summary>
        /// <returns></returns>
        Task<bool> ReloadLanguageConfigAsync(TokenRequest request);

        /// <summary>
        /// 更新模板配置，包括词条和报告模板
        /// </summary>
        /// <returns>是否成功</returns>
        Task<bool> LoadTemplateFromTemplateAsync(TokenRequest request);

        /// <summary>
        /// 检查课程标签是否存在课程相关信息
        /// </summary>
        /// <returns>是否成功</returns>
        Task<bool> CheckCourseLableExistCourseInfoAsync(CourseLabelRequest request);
        
        /// <summary>
        /// 分页查询项目配置
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<ProjectInfoDTO>> FindProjectPagesAsync(FindProjectPagesRequest request);

        /// <summary>
        /// 查询项目配置详情
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ProjectInfoDTO> FindProjectAsync(FindProjectRequest request);

        /// <summary>
        /// 新增/更新项目配置
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> AddOrUpdateProjectAsync(ProjectInfoDTO request);

        /// <summary>
        /// 删除项目配置
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeleteProjectAsync(DeleteProjectRequest request);

        /// <summary>
        /// 分页查询项目数据推送记录
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<ProjectPushRecordDTO>> FindProjectPushRecordPagesAsync(FindProjectPushRecordPagesRequest request);

        /// <summary>
        /// 查询项目数据推送记录详情
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ProjectPushRecordDTO> FindProjectPushRecordAsync(FindProjectPushRecordRequest request);

        /// <summary>
        /// 删除项目数据推送记录
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeleteProjectPushRecordAsync(DeleteProjectPushRecordRequest request);

        /// <summary>
        /// 重新发送
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> ReSendProjectPushRecordAsync(ReSendProjectPushRecordRequest request);

        /// <summary>
        /// 查询课程文件分类列表分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<VideoInfoDTO>> FindVideoFilesCourseTypeByPageAsync(QueryVideoFilesByPageRequest request);

        /// <summary>
        /// 绑定课程素材
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> BindCourseMaterialsAsync(BindCourseMaterialsRequest request);

        /// <summary>
        /// 获取课程观看人数和在线人数
        /// </summary>
        /// <returns>是否成功</returns>
        Task<CourseVisitorsStatisticResult> QueryCourseBrowsedCountAsync(QueryBrowsedRecordRequest request);

        /// <summary>
        /// 查询课程报名情况
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<SignStudentDTO>> GetCourseSignStudentListAsync(FindCourseByCodeRequest request);

        /// <summary>
        /// 管理端查询课程浏览记录
        /// </summary>
        /// <returns>是否成功</returns>
        Task<PageResult<CourseBrowsedRecordDTO>> QueryCourseBrowsedRecordsAsync(QueryBrowsedRecordPageRequest request);

        /// <summary>
        /// 同步批量处理浏览记录 
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> BatchSaveCourseBrowsedRecordAsync(CourseMigrateBrowsedRecordRequest request);

        /// <summary>
        /// 设备数据列表-分页 
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<PageResult<DeviceInfoDTO>> QueryIOTDeviceInfoByPageAsync(QueryDeviceInfoByPageRequest request);

        /// <summary>
        /// 设备报告数据列表-分页
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<PageResult<dynamic>> QueryIOTDeviceReportInfoByPageAsync(QueryDeviceReportByPageRequest request);

        /// <summary>
        /// 新增IOT设备版本
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> AddIOTDeviceVersionInfoAsync(AddIOTDeviceVersionRequest request);
        
        /// <summary>
        /// 修改IOT设备版本
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> UpdateIOTDeviceVersionInfoAsync(UpdateIOTDeviceVersionRequest request);
        
        /// <summary>
        /// 删除IOT设备版本
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> DeleteIOTDeviceVersionInfoAsync(QueryIOTDeviceVersionRequest request);

        /// <summary>
        /// 根据查询实体查询设备报告数据
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<IOTDeviceVersionDTO> QueryIOTDeviceVersionInfoAsync(QueryIOTDeviceVersionRequest request);

        /// <summary>
        /// IOT设备版本分页信息列表-分页
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<PageResult<IOTDeviceVersionDTO>> QueryIOTDeviceVersionInfoByPageAsync(QueryDeviceVersionByPageRequest request);

        /// <summary>
        /// 保存设备指定升级版本
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> SaveDeviceUpgradeVersionAsync(Request.Device.SaveDeviceUpgradeVersionRequest request);

        /// <summary>
        /// 保存通用字典数据
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> SaveCommonDictionaryInfoAsync(SaveCommonDictionaryRequest request);

        /// <summary>
        /// 移除字典
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> RemoveCommonDictionaryInfoAsync(CommonDictionaryRequest request);

        /// <summary>
        /// 分页字典列表
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<PageResult<CommonDictionaryDTO>> FindCommonDictionaryPagesAsync(GetCommonDictionaryPageRequest request);

        /// <summary>
        /// 根据key获取字典信息对象
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<CommonDictionaryDTO> GetCommonDictionaryDetailAsync(CommonDictionaryRequest request);

        /// <summary>
        /// 获取通用的Vod签名
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<string> GetCommonVodAuthorizationAsync(TokenRequest request);

        /// <summary>
        /// 分页获取license信息列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<LicenseDetailInfoDTO>> GetLicenseInfoPagesAsync(GetLicensePageRequest request);

        /// <summary>
        /// 分页获取Dongle信息列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<DongleDetailInfoDTO>> GetDongleInfoPagesAsync(GetDonglePageRequest request);

        /// <summary>
        /// 根据licenseId获取license详情
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<LicenseDetailInfoDTO> GetLicenseDetailAsync(GetLicenseOrDongleRequest request);

        /// <summary>
        /// 根据dongleid或者licenseId获取Dongle详情
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<DongleDetailInfoDTO> GetDongleDetailAsync(GetLicenseOrDongleRequest request);

        /// <summary>
        /// 根据用户名获取用户信息
        /// </summary>
        /// <returns></returns>
        Task<UserDTO> GetUserByNameAsync(GetUserByNameRequest request);

        /// <summary>
        /// 根据科研版Dongle获取用户信息
        /// </summary>
        /// <returns></returns>
        Task<UserDTO> GetUserByLabDongleAsync(GetUserByLabDongleRequest request);

        /// <summary>
        /// 分页获取资源计费信息列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<ChargeResourcePackageDTO>> GetChargeResourcePackagePagesAsync(ChargeResourcePackagePageRequest request);

        /// <summary>
        /// 保存资源计费信息数据
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SaveChargeResourcePackageAsync(SaveChargeResourcePackageRequest request);

        /// <summary>
        /// 获取收费业务列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<DataItemDTO>> GetChargeBussinessListAsync(GetPresetCommentsRequest request);
        
        /// <summary>
        /// 删除资源计费信息数据
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeleteChargeResourcePackageAsync(DeleteChargeResourcePackageRequest request);

        /// <summary>
        /// 获取资源包类型数据列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<DataItemDTO>> GetResourcePackageTypeListAsync(TokenRequest request);

        /// <summary>
        /// 查询所有科研病例样本列表
        /// </summary>
        /// <param name="request">病例样本搜索实体</param>
        /// <returns></returns>
        /// <errorCodes></errorCodes>
        Task<PageCollection<PatientSampleDataDTO>> GetAllPatientSamplePagesAsync(GetRRUserPagesRequest request);

        /// <summary>
        /// 删除指定样本数据
        /// </summary>
        /// <param name="request">病例样本搜索实体</param>
        /// <returns></returns>
        /// <errorCodes></errorCodes>
        Task<bool> DeletePatientSampleDataAsync(DeletePatientSampleRequest request);
    }
}