﻿using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Rank;
using WingInterfaceLibrary.Request.User;

namespace WingInterfaceLibrary.Interface
{
    /// <summary>
    /// 职称信息服务接口
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>机构信息模块</docSecondDirectory>
    public interface IRankService
    {
        /// <summary>
        /// 获取职称信息
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>职称信息</returns>
        Task<RankDTO> GetRankByCodeAsync(GetRankByCodeRequest request);

        /// <summary>
        /// 获取所有职称信息
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>职称信息列表</returns>
        Task<List<RankDTO>> GetAllRanksAsync(GetRanksRequest request);

        /// <summary>
        /// 添加职称信息
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <errorCodes>RankNameIsEmpty,RankNameDuplicate,OrganizationCodeIsEmpty,TooLongCharacter,OrganizationNotExist</errorCodes>
        Task<bool> AddRanksAsync(AddRanksRequest request);

        /// <summary>
        /// 删除职称信息
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        Task<bool> RemoveRanksAsync(RemoveRanksRequest request);

        /// <summary>
        /// 更新职称名
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <errorCodes>RankCodeIsEmpty,RankNameIsEmpty,RankNameDuplicate</errorCodes>
        Task<bool> UpdateRankNameAsync(UpdateRankNameRequest request);
    }
}
