using System.Threading.Tasks;
using WingInterfaceLibrary.Recognition;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.FaceRecognition;

namespace WingInterfaceLibrary.Interface
{
    /// <summary>
    /// 识别服务接口
    /// </summary>
    /// <docFirstDirectory>公共API</docFirstDirectory>
    /// <docSecondDirectory>识别服务接口</docSecondDirectory>
    public interface IRecognitionService
    {
        /// <summary>
        /// 身份证识别
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<RecognitionResult> GetIDCardInfoAsync(IDCardInfoRequest request);

        /// <summary>
        /// 添加/修改人员信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> AddOrUpdatePersonAsync(AddOrUpdatePersonRequest request);

        /// <summary>
        /// 人员搜索
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<SearchPersonsResult> SearchPersonsAsync(SearchPersonsRequest request);

        /// <summary>
        /// 保存人员信息，含失败原因
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<SavePersonResult> SavePersonAsync(SavePersonRequest request);

        /// <summary>
        /// 删除人员信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<DeletePersonResult> DeletePersonAsync(DeletePersonRequest request);

        /// <summary>
        /// 添加人脸识别数据
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SavePersonFaceLocalAsync(AddPersonFaceRequest request);

        /// <summary>
        /// 获取所有人脸识别数据
        /// </summary>
        /// <param name="pageSize"></param>
        /// <returns></returns>
        Task<List<FaceRecognitionDTO>> GetAllPersonListLocalAsync(GetPersonListRequest request);

        /// <summary>
        /// 删除人脸识别数据
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeletePersonLocalAsync(DeletePersonRequest request);
    }

}