﻿using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Position;
using WingInterfaceLibrary.Request.User;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request.Vital;
using WingInterfaceLibrary.DB.Request;

namespace WingInterfaceLibrary.Interface
{
    /// <summary>
    /// 健康体检登记服务
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>登记服务接口</docSecondDirectory>
    public interface IRegisterService
    {
        /// <summary>
        /// 登录状态查询接口
        /// </summary>
        /// <param name="request">新建请求</param>
        /// <returns>F6B05EA898F244D1A389268CBE409825</returns>
        Task<bool> GetUserInfoByOpenIdAsync(GetUserInfoByVitalOpenIdRequest request);

        /// <summary>
        /// 退出登录接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> LoginOutAsync(TokenRequest request);

        /// <summary>
        /// 扫脸登记接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PersonInfoByFaceImageDTO> GetPersonInfoByFaceImageAsync(GetPersonInfoByFaceImageRequest request);

        /// <summary>
        /// 登记确认接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> RegisterConfirmAsync(RegisterConfirmRequest request);

        /// <summary>
        /// 查询登记人员列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageCollection<PersonInfoFullDTO>> GetPersonInfoListAsync(GetPersonPageRequest request);

        /// <summary>
        /// 根据code获取人员信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PersonInfoFullDTO> GetPersonInfoByCodeAsync(GetPersonRequest request);

        /// <summary>
        /// 删除人员接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeletePersonAsync(DeletePersonRequest request);

        /// <summary>
        /// 扫脸录入查询接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<EnterPersonFaceQueryResult> EnterPersonFaceQueryAsync(EnterPersonFaceQueryRequest request);

        /// <summary>
        /// 人员录入接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> EnterPersonFaceAsync(EnterPersonFaceRequest request);
    }
}
