﻿using System.Collections.Generic;
using System.Threading.Tasks;
using WingInterfaceLibrary.DTO.Comment;
using WingInterfaceLibrary.DTO.Measure;
using WingInterfaceLibrary.DTO.Patient;
using WingInterfaceLibrary.DTO.Record;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Comment;
using WingInterfaceLibrary.Request.Examine;
using WingInterfaceLibrary.Request.Languge;
using WingInterfaceLibrary.Request.Measure;
using WingInterfaceLibrary.Request.Patient;
using WingInterfaceLibrary.Request.Record;
using WingInterfaceLibrary.Request.Report;
using WingInterfaceLibrary.Result;
using WingInterfaceLibrary.Result.Languge;
using WingInterfaceLibrary.Result.Measure;
using WingInterfaceLibrary.Result.Record;

namespace WingInterfaceLibrary.Interface
{
    /// <summary>
    /// 远程超声服务接口
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>超声检查接口</docSecondDirectory>
    public interface IRemoteUltrasoundService
    {
        /// <summary>
        /// 根据体检号查询远程超声详情
        /// </summary>
        /// <returns></returns>
        Task<VitalRecordInfoDTO> VitalGetRecordByNumberAsync(VitalGetRecordByNumberRequest request);

        /// <summary>
        /// 查询检查记录大列表（分页）
        /// </summary>
        /// <param name="request">查询检查记录大列表（分页）请求实体</param>
        /// <returns></returns>
        Task<PageResult<SimpleRecordInfoDTO>> VitalFindRecordPagesAsync(FindRecordPagesRequest request);

        /// <summary>
        /// 查询检查记录详情
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<QueryRecordResult> VitalQueryRecordInfoAsync(QueryRecordRequest request);

        /// <summary>
        /// 根据扫查记录获取扫查图像详情
        /// </summary>
        /// <param name="request">扫查记录请求实体</param>
        /// <returns>扫查图像列表</returns>
        /// <value></value>
        /// <remarks>POST</remarks>
        Task<RemedicalListResult> VitalGetRemedicalListByRecordInfoAsync(QueryRecordRequest request);

        /// <summary>
        /// 根据患者编号查询所有的扫查图像
        /// </summary>
        /// <param name="request">患者编号请求实体</param>
        /// <returns>扫查图像列表</returns>
        /// <value></value>
        /// <remarks>POST</remarks>
        Task<PageResult<RemedicalListResult>> VitalGetRemedicalListPagesAsync(GetRecordsPageRequest request);

        /// <summary>
        /// 查询检查图像详情
        /// </summary>
        /// <param name="request">查询检查图像详情请求实体/param>
        /// <returns>扫查图像详情</returns>
        /// <value></value>
        /// <remarks>POST</remarks>
        Task<RemedicalInfoDTO> VitalFindRemedicalByCodeAsync(FindRemedicalByCodeRequest request);

        /// <summary>
        /// 查询病人详细信息
        /// </summary>
        /// <param name="request">获取病人信息的请求实体/param>
        /// <returns>病人详细信息实体</returns>
        Task<ClientPatientInfoDTO> VitalFindPatientByCodeAsync(FindPatientByCodeRequest request);

        /// <summary>
        /// 获取语言配置列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<LangugeDataResult>> VitalGetLangugeDataListAsync(LangugeDataRequest request);

        /// <summary>
        /// 查询客户端保存到云端测量图像信息接口
        /// </summary>
        /// <param name="request">查询客户端保存到云端测量图像信息请求实体</param>
        /// <returns>返回是否成功</returns>
        Task<List<RemedicalMeasuredInfoDTO>> VitalFindRemedicalMeasuredInfoAsync(FindRemedicalMeasuredInfoRequest request);

        /// <summary>
        /// 保存客户端上传云端测量图像信息接口
        /// </summary>
        /// <param name="request">客户端完成检查请求实体</param>
        /// <returns>返回是否成功</returns>
        /// <value>true</value>
        Task<bool> VitalAddRemedicalMeasuredInfoAsync(AddRemedicalMeasuredInfoRequest request);

        /// <summary>
        /// 获取测量系统设置请求
        /// </summary>
        /// <param name="request">获取测量系统设置请求实体</param>
        /// <returns></returns>
        Task<MeasureSystemSettingDTO> VitalGetMeasureSystemSettingAsync(GetMeasureSystemSettingRequest request);

        /// <summary>
        /// 获取测量配置项请求
        /// </summary>
        /// <param name="request">获取测量配置项请求实体</param>
        /// <returns></returns>
        Task<MeasureApplicationDTO> VitalGetMeasureApplicationAsync(GetMeasureApplicationRequest request);

        /// <summary>
        ///获取应用的注释配置项请求
        /// </summary>
        /// <param name="request">获取应用的注释配置项请求实体</param>
        /// <returns></returns>
        Task<CommentItemResultDTO> VitalGetCommentsByApplicationAsync(GetCommentsByApplicationRequest request);

        /// <summary>
        /// 获取应用的体标配置项请求
        /// </summary>
        /// <param name="request">获取应用的体标配置项请求实体</param>
        /// <returns></returns>
        Task<BodyPatternsResult> VitalGetBodyPatternsByApplicationAsync(GetBodyPatternByApplicationRequest request);

        /// <summary>
        /// 获取所有应用的体标配置项请求
        /// </summary>
        /// <param name="request">获取所有体标配置项请求实体</param>
        /// <returns></returns>
        Task<IList<BodyPatternsResult>> VitalGetAllBodyPatternsAsync(GetBodyPatternByApplicationRequest request);

        /// <summary>
        /// 用户自定义保存体标项请求
        /// </summary>
        /// <param name="request">用户自定义保存体标项请求实体</param>
        /// <returns></returns>
        Task<bool> VitalSaveUserDefinedBodyPatternAsync(SaveUserDefinedBodyPatternsRequest request);

        /// <summary>
        /// 重置用户保存体标项请求
        /// </summary>
        /// <param name="request">重置用户保存体标项请求</param>
        /// <returns></returns>
        Task<bool> VitalResetUserBodyPatternsAsync(ResetUserBodyPatternsRequest request);
    }
}
