﻿using System.Collections.Generic;
using System.Threading.Tasks;
using WingInterfaceLibrary.DTO.Report;
using WingInterfaceLibrary.DTO.ReportTemplate;
using WingInterfaceLibrary.Request.Report;
using WingInterfaceLibrary.Result;

namespace WingInterfaceLibrary.Interface
{
    /// <summary>
    /// 远程超声服务接口
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>超声报告接口</docSecondDirectory>
    public interface IUltrasoundReportService
    {
        /// <summary>
        /// 根据业务编码查询关联报告
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>报告集合</returns>
        /// <value></value>
        /// <remarks>POST</remarks>
        Task<List<ReportDTO>> VitalFindReportsAsync(FindReportsRequest request);

        /// <summary>
        /// 查询报告详情
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ReportDTO> VitalFindReportByCodeAsync(FindReportByCodeRequest request);

        /// <summary>
        /// 创建报告
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> VitalAddReportAsync(AddReportRequest request);

        /// <summary>
        /// 修改报告
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> VitalModifyReportAsync(ModifyReportRequest request);

        /// <summary>
        /// 获取用户默认词条库
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ThesaurusAllDTO> VitalGetDefaultThesaurusContentAsync(GetDefaultThesaurusContentRequest request);

        /// <summary>
        /// 获取词条项列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<ThesaurusItemDTO>> VitalGetThesaurusItemsAsync(GetThesaurusItemsRequest request);

        /// <summary>
        /// 获取词条库（分页）
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<ThesaurusDTO>> VitalGetThesaurusPageAsync(GetThesaurusPageRequest request);

        /// <summary>
        /// 获取报告模板分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<ReportTemplateDTO>> VitalGetReportTemplatePageAsync(FindReportTemplatePagesRequest request);

        /// <summary>
        /// 获取用户默认报告模板
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ReportTemplateDTO> VitalGetDefaultReportTemplateContentAsync(GetDefaultReportTemplateContentRequest request);

        /// <summary>
        /// 查询报告模板详情
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ReportTemplateDTO> VitalFindReportTemplateByCodeAsync(FindReportTemplateByCodeRequest request);

        /// <summary>
        /// 创建远程心电报告
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> VitalAddEcgReportAsync(AddEcgReportRequest request);

        /// <summary>
        /// 修改远程心电报告
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> VitalModifyEcgReportAsync(ModifyEcgReportRequest request);
    }
}
