using System.Collections.Generic;
using System.Threading.Tasks;
using WingInterfaceLibrary.DTO.Organization;
using WingInterfaceLibrary.DTO.User;
using WingInterfaceLibrary.Request.Upgrade;
using WingInterfaceLibrary.Request.User;
using WingInterfaceLibrary.Result.Upgrade;

namespace WingInterfaceLibrary.Interface
{
    /// <summary>
    /// 检查更新
    /// </summary>
    /// <docFirstDirectory>检查更新API</docFirstDirectory>
    /// <docSecondDirectory>检查更新接口</docSecondDirectory>
    public interface IUpgradeService
    {
        /// <summary>
        /// 获取检查更新配置
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<GetUpgradeInfoResult> GetUpgradeInfoAsync(GetUpgradeInfoRequest request);

        /// <summary>
        /// 上报版本接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateClientVersion(SetUpgradeInfoRequest request);

        /// <summary>
        /// 刷新配置
        /// </summary>
        /// <returns></returns>
        /// <show>false</shou>
        Task<bool> ReloadUpgradeConfig();

        /// <summary>
        /// 灰度发布搜索组织
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>组织信息列表</returns>
        /// <show>false</shou>
        Task<List<OrganizationDTO>> SearchGrayscaleOrganizationsAsync(SearchOrganizationsRequest request);

        /// <summary>
        /// 灰度发布根据组织和岗位身份查询用户列表信息
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>用户信息</returns>
        /// <remarks>POST</remarks>
        /// <show>false</shou>
        Task<List<UserExtendDTO>> GetGrayscaleUserListAsync(GetUserListRequest request);
        /// <summary>
        /// 获取当前Server配置客户端配置版本号请求
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> GetFlyinsonoVersionAsync(GetFlyinsonoVersionRequest request);
    }
}