﻿using System.Threading.Tasks;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Result;
using WingInterfaceLibrary.Request.Vital;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Record;

namespace WingInterfaceLibrary.Interface
{
    /// <summary>
    /// 健康体检预约服务
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>预约服务接口</docSecondDirectory>
    public interface IVitalHealthExamBookingService
    {
        /// <summary>
        /// 分页获取健康检查预约数据
        /// </summary>
        /// <returns></returns>
        Task<PageResult<HealthExamBookingDTO>> GetHealthExamBookingPageAsync(GetHealthExamBookingPageRequest request);

        /// <summary>
        /// 新增/修改体检信息
        /// </summary>
        /// <returns></returns>
        Task<string> SaveHealthExamBookingAsync(SaveHealthExamBookingRequest request);

        /// <summary>
        /// 查询体检信息
        /// </summary>
        /// <returns></returns>
        Task<HealthExamBookingDTO> GetHealthExamBookingAsync(GetHealthExamBookingRequest request);

        /// <summary>
        /// 删除体检信息
        /// </summary>
        /// <returns></returns>
        Task<bool> DeleteHealthExamBookingAsync(DeleteHealthExamBookingRequest request);

        /// <summary>
        /// 团队预约，报名
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<bool> SignUpASync(SignUpHealthExamBookingRequest request);


        /// <summary>
        /// 根据身份证号查询预约信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<HealthExamPersonDTO> GetExamBookingByIDCardAsync(GetExamBookingByIDCardRequest request);

        /// <summary>
        /// 根据体检号查询机构体检项目
        /// </summary>
        /// <returns></returns>
        Task<List<HealthExamItemDTO>> GetExamItemsByExamNoAsync(GetExamItemsByExamNoRequest request);

        /// <summary>
        /// 根据体检号查询机构体检标签
        /// </summary>
        /// <returns></returns>
        Task<GetExamLabelsByExamNoResult> GetExamLabelsByExamNoAsync(GetExamLabelsByExamNoRequest request);

        /// <summary>
        /// 新增登记信息
        /// </summary>
        /// <returns></returns>
        /// <errorCodes>JingQiException,JingQiNonArea,JingQiExamedInYear,JingQiApiFailed</errorCodes>
        Task<AddRegiterInfoResult> AddRegiterInfoAsync(AddRegiterInfoRequest request);

        /// <summary>
        /// 删除登记信息
        /// </summary>
        /// <returns></returns>
        Task<bool> DeleteRegiterInfoAsync(DeleteRegiterInfoRequest request);

        /// <summary>
        /// 修改登记信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateRegiterInfoAsync(UpdateRegiterInfoRequest request);

        /// <summary>
        /// 修改结果和建议信息
        /// </summary>
        /// <param name="Code"></param>
        /// <param name="resultsAndSuggestions"></param>
        /// <returns></returns>
        Task<bool> UpdateResultsAndSuggestionsAsync(UpdateResultsAndSuggestionsRequest request);

        /// <summary>
        /// 查询登记信息列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<RegisterInfoDTO>> GetRegisterInfoPageAsync(GetRegiterInfoPageRequest request);

        /// <summary>
        /// 查询登记人员信息
        /// </summary>
        /// <returns></returns>
        Task<RegisterPersonInfoDTO> GetRegisterPersonInfoByPhysicalExamNumberAsync(GetRegisterPersonRequest request);

        /// <summary>
        /// 根据体检号查询远程诊断记录
        /// </summary>
        /// <returns></returns>
        Task<RecordInfoDTO> GetVitalRecordByPhysicalExamNumberAsync(GetVitalRecordByPhysicalExamNumberRequest request);

        /// <summary>
        /// 解除预约
        /// </summary>
        /// <returns></returns>
        Task<bool> CancelHealthExamBookingAsync(CancelHealthExamBookingRequest request);
    }
}
