using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Vital;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Result;

namespace WingInterfaceLibrary.Interface.VitalInterface
{
    /// <summary>
    /// 体检API服务
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>体检API接口</docSecondDirectory>
    public interface IExamService
    {
        /// <summary>分页查询体检记录</summary>
        /// <returns></returns>
        Task<PageResult<RegisterInfoDTO>> GetRegisterInfoPageAsync(GetRegisterInfoPageRequest request);

        /// <summary>分页查询体检记录</summary>
        /// <returns></returns>
        Task<RegisterPersonInfoDTO> GetRegisterInfoByPhysicalExamNumberAsync(GetRegisterInfoByPhysicalExamNumberRequest request);

        /// <summary>查询体检结果详情</summary>
        /// <returns></returns>
        Task<GetExamInfoByPhysicalExamNumberResult> GetExamInfoByPhysicalExamNumberAsync(GetExamInfoByPhysicalExamNumberRequest request);

        /// <summary>
        /// 查询体检报告
        /// </summary>
        /// <returns></returns>
        Task<List<ReportDTO>> GetVitalReportInfoAsync(GetVitalReportInfoRequest request);

        /// <summary>
        /// 分页查询中医体质辨识或老年人自理能力随访
        /// </summary>
        /// <returns></returns>
        Task<PageResult<ExamTileConslusionDTO>> GetPatientExamByPageAsync(GetExamByPatientPageRequest request);

        /// <summary>上传心电报告</summary>
        /// <returns></returns>
        Task<bool> UploadElectrocardiogramReportAsync(UploadElectrocardiogramReportRequest request);
    }
}
