using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.Vital;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.DTO.Vital;

namespace WingInterfaceLibrary.Interface.VitalInterface
{
    /// <summary>
    /// 接口解析配置服务
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>接口解析配置管理接口</docSecondDirectory>
    public interface IVitalAnalyzeConfigService
    {
        /// <summary>
        /// 创建接口解析配置数据
        /// </summary>
        /// <param name="request">新建请求</param>
        /// <returns>F6B05EA898F244D1A389268CBE409825</returns>
        Task<string> CreateAnalyzeConfigAsync(CreateAnalyzeConfigRequest request);

        /// <summary>
        /// 获取接口解析配置详情
        /// </summary>
        /// <param name="request">查询详情请求</param>
        /// <returns></returns>
        Task<AnalyzeConfigDTO> GetAnalyzeConfigDetailAsync(GetAnalyzeConfigRequest request);

        /// <summary>
        /// 根据关键字段获取接口解析配置详情
        /// </summary>
        /// <param name="request">关键字段查询请求</param>
        /// <returns></returns>
        Task<AnalyzeConfigDTO> GetAnalyzeConfigDetailByKeyAsync(GetAnalyzeConfigByKeyRequest request);

        /// <summary>
        /// 获取接口解析配置数据分页
        /// </summary>
        /// <param name="request">数据分页查询请求</param>
        /// <returns>返回接口解析配置数据列表</returns>
        Task<PageCollection<AnalyzeConfigDTO>> GetAnalyzeConfigPageAsync(AnalyzeConfigPageRequest request);


        /// <summary>
        /// 删除接口解析配置数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns>true</returns>
        Task<bool> RemoveAnalyzeConfigAsync(RemoveAnalyzeConfigRequest request);


        /// <summary>
        /// 获取接口解析配置数据列表
        /// </summary>
        /// <param name="request">数据列表查询请求</param>
        /// <returns></returns>
        Task<List<AnalyzeConfigDTO>> GetAnalyzeConfigListAsync(GetAnalyzeConfigListRequest request);

        /// <summary>
        /// 更新接口解析配置数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns>true</returns>
        Task<bool> UpdateAnalyzeConfigAsync(UpdateAnalyzeConfigRequest request);
    }
}
