using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.Vital;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.DTO.Vital;

namespace WingInterfaceLibrary.Interface.VitalInterface
{
    /// <summary>
    /// 履约记录服务
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>履约记录管理接口</docSecondDirectory>
    public interface IVitalCompletionRecordService
    {
        /// <summary>
        /// 创建履约记录数据
        /// </summary>
        /// <param name="request">新建请求</param>
        /// <returns>F6B05EA898F244D1A389268CBE409825</returns>
        Task<string> CreateCompletionRecordAsync(CreateCompletionRecordRequest request);

        /// <summary>
        /// 获取履约记录详情
        /// </summary>
        /// <param name="request">查询详情请求</param>
        /// <returns></returns>
        Task<CompletionRecordDTO> GetCompletionRecordDetailAsync(GetCompletionRecordRequest request);

        /// <summary>
        /// 根据关键字段获取履约记录详情
        /// </summary>
        /// <param name="request">关键字段查询请求</param>
        /// <returns></returns>
        Task<CompletionRecordDTO> GetCompletionRecordDetailByKeyAsync(GetCompletionRecordByKeyRequest request);

        /// <summary>
        /// 获取履约记录数据分页
        /// </summary>
        /// <param name="request">数据分页查询请求</param>
        /// <returns>返回履约记录列表</returns>
        Task<PageCollection<CompletionRecordDTO>> GetCompletionRecordPageAsync(CompletionRecordPageRequest request);


        /// <summary>
        /// 删除履约记录数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns>true</returns>
        Task<bool> RemoveCompletionRecordAsync(RemoveCompletionRecordRequest request);


        /// <summary>
        /// 获取履约记录数据列表
        /// </summary>
        /// <param name="request">数据列表查询请求</param>
        /// <returns></returns>
        Task<List<CompletionRecordDTO>> GetCompletionRecordListAsync(GetCompletionRecordListRequest request);

        /// <summary>
        /// 更新履约记录数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns>true</returns>
        Task<bool> UpdateCompletionRecordAsync(UpdateCompletionRecordRequest request);
    }
}
