using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.Vital;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.Interface.VitalInterface
{
    /// <summary>
    /// 合约记录服务
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>合约记录管理接口</docSecondDirectory>
    public interface IVitalContractRecordService
    {
        /// <summary>
        /// 创建合约记录数据
        /// </summary>
        /// <param name="request">新建请求</param>
        /// <returns>F6B05EA898F244D1A389268CBE409825</returns>
        Task<string> CreateContractRecordAsync(CreateContractRecordRequest request);

        /// <summary>
        /// 获取合约记录详情
        /// </summary>
        /// <param name="request">查询详情请求</param>
        /// <returns></returns>
        Task<ContractRecordDTO> GetContractRecordDetailAsync(GetContractRecordRequest request);

        /// <summary>
        /// 根据关键字段获取合约记录详情
        /// </summary>
        /// <param name="request">关键字段查询请求</param>
        /// <returns></returns>
        Task<ContractRecordDTO> GetContractRecordDetailByKeyAsync(GetContractRecordByKeyRequest request);

        /// <summary>
        /// 获取合约记录数据分页
        /// </summary>
        /// <param name="request">数据分页查询请求</param>
        /// <returns>返回合约记录列表</returns>
        Task<PageCollection<ContractRecordDTO>> GetContractRecordPageAsync(ContractRecordPageRequest request);

        /// <summary>
        /// 删除合约记录数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns>true</returns>
        Task<bool> RemoveContractRecordAsync(RemoveContractRecordRequest request);


        /// <summary>
        /// 获取合约记录数据列表
        /// </summary>
        /// <param name="request">数据列表查询请求</param>
        /// <returns></returns>
        Task<List<ContractRecordDTO>> GetContractRecordListAsync(GetContractRecordListRequest request);

        /// <summary>
        /// 更新合约记录数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns>true</returns>
        Task<bool> UpdateContractRecordAsync(UpdateContractRecordRequest request);

        /// <summary>
        /// 根据居民编码获取签约记录分页
        /// </summary>
        /// <param name="request">Get page request</param>
        /// <returns></returns>
        Task<PageCollection<ContractRecordDTO>> GetContractRecordPageByPatientCodeAsync(GetContractRecordPageByPatientCodeRequest request);

        /// <summary>
        /// 获取签约居民分页
        /// </summary>
        /// <param name="request">Get page request</param>
        /// <returns></returns>
        Task<PageCollection<ContractRecordDTO>> GetContractPatientPageAsync(GetContractPatientPageRequest request);

        /// <summary>
        /// 更新签约记录状态
        /// </summary>
        /// <param name="request">update request</param>
        /// <returns></returns>
        Task<bool> UpdateContractRecordStateAsync(UpdateContractRecordStateRequest request);

        /// <summary>
        /// 续约
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> RenewalContractRecordAsync(RenewalContractRecordRequest request);

        /// <summary>
        /// 查询医生最近签约记录
        /// </summary>
        /// <param name="request">查询医生最近签约记录请求</param>
        /// <returns></returns>
        Task<ContractRecordDTO> GetDoctorContractRecordAsync(GetDoctorContractRecordRequest request);
    }
}
