using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.Vital;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.DTO.Vital;

namespace WingInterfaceLibrary.Interface.VitalInterface
{
    /// <summary>
    /// 合同模板服务
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>合同模板管理接口</docSecondDirectory>
    public interface IVitalContractTemplateService
    {
        /// <summary>
        /// 创建合同模板数据
        /// </summary>
        /// <param name="request">新建请求</param>
        /// <returns>F6B05EA898F244D1A389268CBE409825</returns>
        Task<string> CreateContractTemplateAsync(CreateContractTemplateRequest request);

        /// <summary>
        /// 获取合同模板详情
        /// </summary>
        /// <param name="request">查询详情请求</param>
        /// <returns></returns>
        Task<ContractTemplateDTO> GetContractTemplateDetailAsync(GetContractTemplateRequest request);

        /// <summary>
        /// 根据关键字段获取合同模板详情
        /// </summary>
        /// <param name="request">关键字段查询请求</param>
        /// <returns></returns>
        Task<ContractTemplateDTO> GetContractTemplateDetailByKeyAsync(GetContractTemplateByKeyRequest request);

        /// <summary>
        /// 获取合同模板数据分页
        /// </summary>
        /// <param name="request">数据分页查询请求</param>
        /// <returns>返回合同模板列表</returns>
        Task<PageCollection<ContractTemplateDTO>> GetContractTemplatePageAsync(ContractTemplatePageRequest request);


        /// <summary>
        /// 删除合同模板数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns>true</returns>
        Task<bool> RemoveContractTemplateAsync(RemoveContractTemplateRequest request);


        /// <summary>
        /// 获取合同模板数据列表
        /// </summary>
        /// <param name="request">数据列表查询请求</param>
        /// <returns></returns>
        Task<List<ContractTemplateDTO>> GetContractTemplateListAsync(GetContractTemplateListRequest request);

        /// <summary>
        /// 更新合同模板数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns>true</returns>
        Task<bool> UpdateContractTemplateAsync(UpdateContractTemplateRequest request);
    }
}
