using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Vital;
using WingInterfaceLibrary.DTO.Device;

namespace WingInterfaceLibrary.Interface.VitalInterface
{
    /// <summary>
    /// 设备服务
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>设备接口</docSecondDirectory>
    public interface IVitalDeviceService
    {
        /// <summary>
        /// 创建新设备
        /// </summary>
        /// <param name="request">新建请求</param>
        /// <returns>F6B05EA898F244D1A389268CBE409825</returns>
        Task<string> CreateDeviceAsync(CreateDeviceRequest request);

        /// <summary>
        /// 获取设备信息通过设备Code
        /// </summary>
        /// <param name="request">请求</param>
        /// <returns></returns>
        Task<DeviceDTO> GetDeviceDetailAsync(GetDeviceRequest request);

        /// <summary>
        /// 获取超声设备信息
        /// </summary>
        /// <param name="request">请求</param>
        /// <returns></returns>
        Task<DeviceInfoDTO> GetUltrasoundByCodeAsync(GetUltrasoundByCodeRequest request);

        /// <summary>
        /// 通过超声分享码获取设备信息
        /// </summary>
        /// <param name="request">请求</param>
        /// <returns></returns>
        Task<DeviceInfoDTO> GetUltrasoundByShortCodeAsync(GetUltrasoundByShortCodeRequest request);

        /// <summary>
        /// 获取设备信息通过设备唯一码
        /// </summary>
        /// <param name="request">请求</param>
        /// <returns></returns>
        Task<DeviceDTO> GetDeviceDetailByUniqueCodeAsync(GetDeviceByUniqueCodeRequest request);

        /// <summary>
        ///根据物理唯一码获取设备信息接口
        /// </summary>
        /// <param name="request">获取请求</param>
        /// <returns></returns>
        Task<DeviceDTO> GetDeviceDetailBySerialNumberAsync(GetDeviceBySerialNumberRequest request);

        /// <summary>
        /// 针对设备设置机构或者团队
        /// </summary>
        /// <param name="request">请求</param>
        /// <returns></returns>
        Task<bool> SetDeviceOrganizationAsync(SetDeviceOrganizationRequest request);

        /// <summary>
        /// 分页查询设备信息
        /// </summary>
        /// <param name="request">请求</param>
        /// <returns></returns>
        Task<PageCollection<DeviceDTO>> GetDevicePageAsync(DevicePageRequest request);

        /// <summary>
        /// 删除设备
        /// </summary>
        /// <param name="request">请求</param>
        /// <returns></returns>
        Task<bool> RemoveDeviceAsync(RemoveDeviceRequest request);

        /// <summary>
        /// 更新设备信息
        /// </summary>
        /// <param name="request">请求</param>
        /// <returns></returns>
        Task<bool> UpdateDeviceAsync(UpdateDeviceRequest request);

        /// <summary>
        /// 上报设备信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> ReportingDeviceInfoAsync(ReportingDeviceInfoRequest request);

        /// <summary>
        /// 创建外设设备
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> CreatePeripheralDeviceAsync(CreatePeripheralDeviceRequest request);

        /// <summary>
        /// 删除外设设备
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> RemovePeripheralDeviceAsync(RemovePeripheralDeviceRequest request);

        /// <summary>
        /// 获取已启用的外设配置（Key）
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<string>> GetEnablePeripheralDeviceKeysAsync(GetEnablePeripheralDeviceKeysRequest request);
    }
}
