using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request.Vital;

namespace WingInterfaceLibrary.Interface.VitalInterface
{
    /// <summary>
    /// 诊疗服务
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>诊疗管理接口</docSecondDirectory>
    public interface IVitalDiagnosisService
    {
        /// <summary>
        /// 创建诊疗数据
        /// </summary>
        /// <param name="request">新建请求</param>
        /// <returns>F6B05EA898F244D1A389268CBE409825</returns>
        Task<string> CreateDiagnosisAsync(CreateDiagnosisRequest request);

        /// <summary>
        /// 获取诊疗详情
        /// </summary>
        /// <param name="request">查询详情请求</param>
        /// <returns></returns>
        Task<DiagnosisDTO> GetDiagnosisDetailAsync(GetDiagnosisRequest request);

        /// <summary>
        /// 根据关键字段获取诊疗详情
        /// </summary>
        /// <param name="request">关键字段查询请求</param>
        /// <returns></returns>
        Task<DiagnosisDTO> GetDiagnosisDetailByKeyAsync(GetDiagnosisByKeyRequest request);

        /// <summary>
        /// 获取诊疗数据分页
        /// </summary>
        /// <param name="request">数据分页查询请求</param>
        /// <returns>返回诊疗列表</returns>
        Task<PageCollection<DiagnosisDTO>> GetDiagnosisPageAsync(DiagnosisPageRequest request);


        /// <summary>
        /// 删除诊疗数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns>true</returns>
        Task<bool> RemoveDiagnosisAsync(RemoveDiagnosisRequest request);


        /// <summary>
        /// 获取诊疗数据列表
        /// </summary>
        /// <param name="request">数据列表查询请求</param>
        /// <returns></returns>
        Task<List<DiagnosisDTO>> GetDiagnosisListAsync(GetDiagnosisListRequest request);

        /// <summary>
        /// 更新诊疗数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns>true</returns>
        Task<bool> UpdateDiagnosisAsync(UpdateDiagnosisRequest request);

        /// <summary>
        /// 获取诊疗聚合数据
        /// </summary>
        /// <param name="request">数据分页查询请求</param>
        /// <returns></returns>
        Task<PageCollection<DiagnosisAggregationRecord>> GetDiagnosisAggregationPageAsync(DiagnosisPageRequest request);

        /// <summary>
        /// 提交诊疗数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns>true</returns>
        Task<bool> SubmitDiagnosisAsync(SubmitDiagnosisRequest request);

        /// <summary>
        /// 重新提交诊疗数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns>true</returns>
        Task<bool> ReinfusionDiagnosisAsync(ReinfusionDiagnosisRequest request);

        /// <summary>
        /// 设置诊疗时间
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns>true</returns>
        Task<bool> SetDiagnosisTimeAsync(SetDiagnosisTimeRequest request);

        /// <summary>
        /// 同步居民和诊疗数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns>true</returns>
        Task<bool> SyncPatientAndDiagnosisDataAsync(SyncPatientAndDiagnosisDataRequest request);

        /// <summary>
        /// 老平台同步过来的数据量
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> OldPlatformDiagnosisDataCountAsync(OldPlatformDiagnosisDataCountRequest request);

        /// <summary>
        /// 根据批次号删除诊疗数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns>true</returns>
        Task<bool> RemoveDiagnosisByAppDataIdAsync(RemoveDiagnosisByAppDataIdRequest request);
    }
}
