using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Vital;
using WingInterfaceLibrary.DTO.Vital;

namespace WingInterfaceLibrary.Interface.VitalInterface
{
    /// <summary>
    /// 字典服务
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>字典接口</docSecondDirectory>
    public interface IVitalDictionaryService
    {
        /// <summary>
        /// 创建字典数据
        /// </summary>
        /// <param name="request">新建请求</param>
        /// <returns>F6B05EA898F244D1A389268CBE409825</returns>
        Task<string> CreateDictionaryAsync(CreateDictionaryRequest request);

        /// <summary>
        /// 获取字典详情
        /// </summary>
        /// <param name="request">查询详情请求</param>
        /// <returns></returns>
        Task<DictionaryDTO> GetDictionaryDetailAsync(GetDictionaryRequest request);

        /// <summary>
        /// 根据关键字段获取字典详情
        /// </summary>
        /// <param name="request">关键字段查询请求</param>
        /// <returns></returns>
        Task<DictionaryDTO> GetDictionaryDetailByKeyAsync(GetDictionaryByKeyRequest request);

        /// <summary>
        /// 获取字典数据分页
        /// </summary>
        /// <param name="request">数据分页查询请求</param>
        /// <returns>返回字典列表</returns>
        Task<PageCollection<DictionaryDTO>> GetDictionaryPageAsync(DictionaryPageRequest request);


        /// <summary>
        /// 删除字典数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns>true</returns>
        Task<bool> RemoveDictionaryAsync(RemoveDictionaryRequest request);


        /// <summary>
        /// 获取字典数据列表
        /// </summary>
        /// <param name="request">数据列表查询请求</param>
        /// <returns></returns>
        Task<List<DictionaryDTO>> GetDictionaryListAsync(GetDictionaryListRequest request);

        /// <summary>
        /// 更新字典数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns>true</returns>
        Task<bool> UpdateDictionaryAsync(UpdateDictionaryRequest request);

        /// <summary>
        /// 根据关键字获取字典数据列表(包含单位列表)
        /// </summary>
        /// <param name="request">列表请求</param>
        /// <returns></returns>
        Task<List<DictionaryWithUnitDTO>> GetDictionaryNameAndUnitByKeysAsync(GetDictionaryNameAndUnitByKeysRequest request);
    }
}
