using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Vital;
using WingInterfaceLibrary.DTO.Vital;

namespace WingInterfaceLibrary.Interface.VitalInterface
{
    /// <summary>
    /// 服务
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>管理接口</docSecondDirectory>
    public interface IVitalDynamicTypeService
    {
        /// <summary>
        /// 创建数据
        /// </summary>
        /// <param name="request">新建请求</param>
        /// <returns>F6B05EA898F244D1A389268CBE409825</returns>
        Task<string> CreateDynamicTypeAsync(CreateDynamicTypeRequest request);

        /// <summary>
        /// 获取详情
        /// </summary>
        /// <param name="request">查询详情请求</param>
        /// <returns></returns>
        Task<DynamicTypeDTO> GetDynamicTypeDetailAsync(GetDynamicTypeRequest request);

        /// <summary>
        /// 根据关键字段获取详情
        /// </summary>
        /// <param name="request">关键字段查询请求</param>
        /// <returns></returns>
        Task<DynamicTypeDTO> GetDynamicTypeDetailByKeyAsync(GetDynamicTypeByKeyRequest request);

        /// <summary>
        /// 获取数据分页
        /// </summary>
        /// <param name="request">数据分页查询请求</param>
        /// <returns>返回列表</returns>
        Task<PageCollection<DynamicTypeDTO>> GetDynamicTypePageAsync(DynamicTypePageRequest request);


        /// <summary>
        /// 删除数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns>true</returns>
        Task<bool> RemoveDynamicTypeAsync(RemoveDynamicTypeRequest request);


        /// <summary>
        /// 获取数据列表
        /// </summary>
        /// <param name="request">数据列表查询请求</param>
        /// <returns></returns>
        Task<List<DynamicTypeDTO>> GetDynamicTypeListAsync(GetDynamicTypeListRequest request);

        /// <summary>
        /// 更新数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns>true</returns>
        Task<bool> UpdateDynamicTypeAsync(UpdateDynamicTypeRequest request);

        /// <summary>
        /// 根据字典键获取数据列表
        /// </summary>
        /// <param name="request">数据列表查询请求</param>
        /// <returns></returns>
        Task<List<DynamicTypeDTO>> GetDynamicTypeListByKeyAsync(GetDynamicTypeListByKeyRequest request);
    }
}
