using System.Collections.Generic;
using System.Threading.Tasks;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Vital;

namespace WingInterfaceLibrary.Interface.VitalInterface
{
    /// <summary>
    /// 远程心电服务
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>远程心电接口</docSecondDirectory>
    public interface IVitalElectrocardiogramService
    {

        /// <summary>
        /// 获取心电记录详情
        /// </summary>
        /// <param name="request">查询详情请求</param>
        /// <returns></returns>
        Task<ElectrocardiogramRecord> GetElectrocardiogramRecordAsync(GetElectrocardiogramRecordRequest request);

        /// <summary>
        /// 获取心电记录分页
        /// </summary>
        /// <param name="request">数据分页查询请求</param>
        /// <returns>返回检查数据列表</returns>
        Task<PageCollection<ElectrocardiogramRecord>> GetElectrocardiogramRecordPageAsync(ElectrocardiogramRecordPageRequest request);

        /// <summary>
        /// 根据体检号查询心电记录
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ElectrocardiogramRecord> GetElectrocardiogramRecordByPhysicalExamNumberAsync(GetElectrocardiogramRecordByPhysicalExamNumberRequest request);

        /// <summary>
        /// 修改心电检测数据
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateElectrocardiogramExamInfoRecordAsync(UpdateElectrocardiogramExamInfoRecordRequest request);

        /// <summary>
        /// 删除心电检测数据
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> RemoveElectrocardiogramAsync(GetElectrocardiogramRecordRequest request);
    }
}