using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Vital;
using WingInterfaceLibrary.DTO.Vital;

namespace WingInterfaceLibrary.Interface.VitalInterface
{
    /// <summary>
    /// 体检检查服务
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>体检管理接口</docSecondDirectory>
    public interface IVitalExamService
    {
        /// <summary>
        /// 创建检查数据
        /// </summary>
        /// <param name="request">新建请求</param>
        /// <returns>F6B05EA898F244D1A389268CBE409825</returns>
        Task<string> CreateExamAsync(CreateExamRequest request);

        /// <summary>
        /// 批量保存检测结果
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<int> BatchAddExamAsync(BatchAddExamRequest request);

        /// <summary>
        /// 获取检查详情
        /// </summary>
        /// <param name="request">查询详情请求</param>
        /// <returns></returns>
        Task<ExamDTO> GetExamDetailAsync(GetExamRequest request);

        /// <summary>
        /// 根据关键字段获取检查详情
        /// </summary>
        /// <param name="request">关键字段查询请求</param>
        /// <returns></returns>
        Task<ExamDTO> GetExamDetailByKeyAsync(GetExamByKeyRequest request);

        /// <summary>
        /// 获取检查数据分页
        /// </summary>
        /// <param name="request">数据分页查询请求</param>
        /// <returns>返回检查数据列表</returns>
        Task<PageCollection<ExamDTO>> GetExamPageAsync(ExamPageRequest request);

        /// <summary>
        /// 获取用户检查数据分页
        /// </summary>
        /// <param name="request">数据分页查询请求</param>
        /// <returns></returns>
        Task<PageCollection<ExamConclusionDTO>> GetPatientExamByPageAsync(GetPatientExamByPageRequest request);

        /// <summary>
        /// 删除检查数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns>true</returns>
        Task<bool> RemoveExamAsync(RemoveExamRequest request);


        /// <summary>
        /// 获取检查数据列表
        /// </summary>
        /// <param name="request">数据列表查询请求</param>
        /// <returns></returns>
        Task<List<ExamDTO>> GetExamListAsync(GetExamListRequest request);

        /// <summary>
        /// 更新检查数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns>true</returns>
        Task<bool> UpdateExamAsync(UpdateExamRequest request);

        /// <summary>
        /// 根据字典键获取体检记录分页
        /// </summary>
        /// <param name="request">Get page request</param>
        /// <returns></returns>
        Task<PageCollection<ExamDTO>> GetExamPageByKeyAsync(GetExamPageByKeyRequest request);

        /// <summary>
        /// 根据字典键获取体检居民分页
        /// </summary>
        /// <param name="request">Get page request</param>
        /// <returns></returns>
        Task<PageCollection<ExamDTO>> GetExamPatientPageByKeyAsync(GetExamPatientPageByKeyRequest request);

        /// <summary>
        /// 获取体检记录居民分页
        /// </summary>
        /// <param name="request">请求</param>
        /// <returns></returns>
        Task<PageCollection<ExamDTO>> GetExamRecordPageAsync(GetExamRecordPageRequest request);

        /// <summary>
        /// 根据批次号查询体检结果
        /// </summary>
        /// <returns></returns>
        Task<List<ExamDTO>> GetExamByBatchNumberAsync(GetExamByBatchNumberRequest request);

        /// <summary>
        /// 查询居民对应的体检记录信息
        /// </summary>
        /// <param name="request">请求</param>
        /// <returns></returns>
        Task<List<ExamRecordDTO>> GetExamRecordListAsync(GetExamRecordListRequest request);

        /// <summary>
        /// 保存快捷检查
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SaveQuickCheckRecordAsync(SaveQuickCheckRecordRequest request);

        /// <summary>
        /// 根据批次号更新检查数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns></returns>
        Task<bool> UpdateExamByBatchNumberAsync(UpdateExamByBatchNumberRequest request);

        /// <summary>
        /// 根据体检号查询检查数据
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<ExamDTO>> GetExamListByPhysicalExamNumberAsync(GetExamListByPhysicalExamNumberRequest request);
    }
}
