using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request.Vital;
using WingInterfaceLibrary.DTO.Region;

namespace WingInterfaceLibrary.Interface.VitalInterface
{
    /// <summary>
    /// 第三方厂商信息服务
    /// </summary>
    /// <docFirstDirectory>管理端API</docFirstDirectory>
    /// <docSecondDirectory>厂商管理接口</docSecondDirectory>
    public interface IVitalFacturyUserService
    {
        /// <summary>
        /// 创建数据
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<string> CreateFacturyUserAsync(CreateFacturyUserRequest request);

        /// <summary>
        /// 更新数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns></returns>
        Task<bool> UpdateFacturyUserAsync(UpdateFacturyUserRequest request);

        /// <summary>
        /// 根据编码获取第三方厂商信息
        /// </summary>
        /// <param name="request">数据编码</param>
        /// <returns></returns>
        Task<FacturyUserDTO> GetFacturyUserAsync(GetFacturyUserRequest request);

        /// <summary>
        /// 分页获取厂商数据
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns></returns>
        Task<PageCollection<FacturyUserDTO>> GetFacturyOrgByPageAsync(GetFacturyOrgByPageRequest request);

        /// <summary>
        /// 分页获取厂商员工数据
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns></returns>
        Task<PageCollection<FacturyUserDTO>> GetFacturyUserByPageAsync(GetFacturyUserByPageRequest request);

        /// <summary>
        /// 获取厂商员工列表
        /// </summary>
        /// <param name="request">列表请求</param>
        /// <returns></returns>
        Task<List<FacturyUserDTO>> GetFacturyUserInfosAsync(GetFacturyUserInfosRequest request);

        /// <summary>
        /// 获取所有厂商数据
        /// </summary>
        /// <returns></returns>
        Task<List<RegionDataItemDTO>> GetFacturyTreeAsync(GetFacturyTreeRequest request);

        /// <summary>
        /// 删除数据
        /// </summary>
        /// <param name="request">数据编码</param>
        /// <returns></returns>
        Task<bool> RemoveFacturyUserAsync(RemoveFacturyUserRequest request);

        /// <summary>
        /// 晶奇系统登记注册
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns></returns>
        Task<FacturyExamRegisterResult> FacturyExamRegisterAsync(FacturyExamRegisterRequest request);

        /// <summary>
        /// 晶奇系统删除注册
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns></returns>
        Task<FacturyExamDeleteResult> FacturyExamDeleteAsync(FacturyExamDeleteRequest request);
    }
}
