using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Request.Vital;

namespace WingInterfaceLibrary.Interface.VitalInterface
{
    /// <summary>
    /// 第三方厂商数据推送服务
    /// </summary>
    /// <docFirstDirectory>管理端API</docFirstDirectory>
    /// <docSecondDirectory>厂商管理接口</docSecondDirectory>
    public interface IVitalFacturyPostHistoryService
    {
        /// <summary>
        /// 创建数据
        /// </summary>
        /// <param name="request">创建请求</param>
        /// <returns></returns>
        Task<string> CreateFacturyPostHistoryAsync(CreateFacturyPostHistoryRequest request);

        /// <summary>
        /// 根据编码获取第三方厂商推送记录
        /// </summary>
        /// <param name="request">数据编码</param>
        /// <returns></returns>
        Task<FacturyPostHistoryDTO> GetFacturyPostHistoryAsync(GetFacturyPostHistoryRequest request);

        /// <summary>
        /// 分页获取厂商推送记录
        /// </summary>
        /// <param name="request">分页请求</param>
        /// <returns></returns>
        Task<PageCollection<FacturyPostHistoryDTO>> GetFacturyPostHistoryByPageAsync(GetFacturyPostHistoryByPageRequest request);

        /// <summary>
        /// 删除厂商推送记录
        /// </summary>
        /// <param name="request">数据编码</param>
        /// <returns></returns>
        Task<bool> RemoveFacturyPostHistoryAsync(RemoveFacturyPostHistoryRequest request);

        /// <summary>
        /// 重发厂商推送记录
        /// </summary>
        /// <param name="request">数据编码</param>
        /// <returns></returns>
        Task<bool> ResendFacturyPostHistoryAsync(ResendFacturyPostHistoryRequest request);

        /// <summary>
        /// 晶奇数据推送 中医体质、老年人自理能力评估
        /// </summary>
        /// <returns></returns>
        Task<bool> CreateJingQiExamPostHistoryAsync(CreateJingQiExamPostHistoryRequest request);

        /// <summary>
        /// 晶奇数据推送 超声、心电报告
        /// </summary>
        /// <returns></returns>
        Task<bool> CreateJingQiReportPostHistoryAsync(CreateJingQiReportPostHistoryRequest request);
    }
}
