using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Vital;
using WingInterfaceLibrary.DTO.Vital;

namespace WingInterfaceLibrary.Interface.VitalInterface
{
    /// <summary>
    /// 随访服务
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>随访管理接口</docSecondDirectory>
    public interface IVitalFollowUpService
    {
        /// <summary>
        /// 创建随访数据
        /// </summary>
        /// <param name="request">新建请求</param>
        /// <returns>F6B05EA898F244D1A389268CBE409825</returns>
        Task<string> CreateFollowUpAsync(CreateFollowUpRequest request);

        /// <summary>
        /// 根据体检号获取随访详情
        /// </summary>
        /// <param name="request">查询详情请求</param>
        /// <returns></returns>
        Task<FollowUpDTO> GetFollowUpDetailByPhysicalExamNumberAsync(GetFollowUpByPhysicalExamNumberRequest request);

        /// <summary>
        /// 获取随访详情
        /// </summary>
        /// <param name="request">查询详情请求</param>
        /// <returns></returns>
        Task<FollowUpDTO> GetFollowUpDetailAsync(GetFollowUpRequest request);

        /// <summary>
        /// 根据关键字段获取随访详情
        /// </summary>
        /// <param name="request">关键字段查询请求</param>
        /// <returns></returns>
        Task<FollowUpDTO> GetFollowUpDetailByKeyAsync(GetFollowUpByKeyRequest request);

        /// <summary>
        /// 获取随访数据分页
        /// </summary>
        /// <param name="request">数据分页查询请求</param>
        /// <returns>返回随访数据列表</returns>
        Task<PageCollection<FollowUpDTO>> GetFollowUpPageAsync(FollowUpPageRequest request);


        /// <summary>
        /// 删除随访数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns>true</returns>
        Task<bool> RemoveFollowUpAsync(RemoveFollowUpRequest request);


        /// <summary>
        /// 获取随访数据列表
        /// </summary>
        /// <param name="request">数据列表查询请求</param>
        /// <returns></returns>
        Task<List<FollowUpDTO>> GetFollowUpListAsync(GetFollowUpListRequest request);

        /// <summary>
        /// 更新随访数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns>true</returns>
        Task<bool> UpdateFollowUpAsync(UpdateFollowUpRequest request);

        /// <summary>
        /// 根据字典键获取随访记录分页
        /// </summary>
        /// <param name="request">Get page request</param>
        /// <returns></returns>
        Task<PageCollection<FollowUpDTO>> GetFollowUpPageByKeyAsync(GetFollowUpPageByKeyRequest request);

        /// <summary>
        /// 根据字典键获取随访居民分页
        /// </summary>
        /// <param name="request">Get page request</param>
        /// <returns></returns>
        Task<PageCollection<FollowUpDTO>> GetFollowUpPatientPageByKeyAsync(GetFollowUpPatientPageByKeyRequest request);

        /// <summary>
        /// 查询居民对应的随访记录信息
        /// </summary>
        /// <param name="request">请求</param>
        /// <returns></returns>
        Task<List<FollowUpRecordDTO>> GetFollowUpRecordListAsync(GetFollowUpRecordListRequest request);

        /// <summary>
        /// 查询居民对应的随访记录信息(按年)
        /// </summary>
        /// <param name="request">请求</param>
        /// <returns></returns>
        Task<List<FollowUpRecordDTO>> GetFollowUpRecordListByYearAsync(GetFollowUpRecordListByYearRequest request);
    }
}
