using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Vital;
using WingInterfaceLibrary.DTO.Vital;

namespace WingInterfaceLibrary.Interface.VitalInterface
{
    /// <summary>
    /// 标签服务
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>标签接口</docSecondDirectory>
    public interface IVitalLabelService
    {
        /// <summary>
        /// 创建标签数据
        /// </summary>
        /// <param name="request">新建请求</param>
        /// <returns>F6B05EA898F244D1A389268CBE409825</returns>
        Task<string> CreateLabelAsync(CreateLabelRequest request);

        /// <summary>
        /// 获取标签详情
        /// </summary>
        /// <param name="request">查询详情请求</param>
        /// <returns></returns>
        Task<LabelDTO> GetLabelDetailAsync(GetLabelRequest request);

        /// <summary>
        /// 根据关键字段获取标签详情
        /// </summary>
        /// <param name="request">关键字段查询请求</param>
        /// <returns></returns>
        Task<LabelDTO> GetLabelDetailByKeyAsync(GetLabelByKeyRequest request);

        /// <summary>
        /// 获取标签数据分页
        /// </summary>
        /// <param name="request">数据分页查询请求</param>
        /// <returns>返回标签数据列表</returns>
        Task<PageCollection<LabelDTO>> GetLabelPageAsync(LabelPageRequest request);


        /// <summary>
        /// 删除标签数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns>true</returns>
        Task<bool> RemoveLabelAsync(RemoveLabelRequest request);


        /// <summary>
        /// 获取标签数据列表
        /// </summary>
        /// <param name="request">数据列表查询请求</param>
        /// <returns></returns>
        Task<List<LabelDTO>> GetLabelListAsync(GetLabelListRequest request);

        /// <summary>
        /// 更新标签数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns>true</returns>
        Task<bool> UpdateLabelAsync(UpdateLabelRequest request);

        /// <summary>
        /// 根据字典键获取数据列表
        /// </summary>
        /// <param name="request">数据列表查询请求</param>
        /// <returns></returns>
        Task<List<LabelDTO>> GetLabelListByKeyAsync(GetLabelListByKeyRequest request);

        /// <summary>
        /// 获取人员分类集合
        /// </summary>
        /// <param name="request">获取人员分类集合请求</param>
        /// <returns></returns>
        Task<List<LabelDTO>> GetCrowdLabelsAsync(GetCrowdLabelsRequest request);
    }
}
