﻿using System.Threading.Tasks;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Vital;
using WingInterfaceLibrary.DTO.Vital;

namespace WingInterfaceLibrary.Interface.VitalInterface
{
    /// <summary>
    /// 登录注册服务
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>登录接口</docSecondDirectory>
    public interface IVitalLoginService
    {
        /// <summary>
        /// 通用登录
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>Session信息</returns>
        /// <errorCodes>VerificationCodeIllegality,UserNotRegistered,IncorrectPasswordFormat,AccountIsEmpty,AccountLengthError,SMSVerifyCodeIsEmpty,SMSVerifyCodeExpired,SMSVerifyCodeIllegality,ExceptionError,EmailVerifyCodeExpired,PhoneIncorrect,EmailIncorrect,EmailEmpty,EmailUserNotExisted,PasswordEmpty,PasswordError,IncorrectAccount,PhoneEmpty,PhoneUserNotExisted,AccountIsLocked</errorCodes>
        Task<LoginResult> CommonLoginAsync(CommonLoginRequest request);

        /// <summary>
        /// 修改密码
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <errorCodes>UserNotExisted,PhoneIllegality,VerificationCodeIllegality,EmailIllegality,UserNameIllegality,PasswordError,UserNotRegistered,NewPasswordEmpty</errorCodes>
        Task<bool> ModifyPasswordAsync(ModifyPasswordRequest request);

        /// <summary>
        /// 退出登录
        /// </summary>
        /// <param name="request">登录token信息</param>
        /// <returns>是否成功</returns>
        Task<bool> LoginOutAsync(TokenRequest request);

        /// <summary>
        /// 验证账户名是否可用
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否可用</returns>
        /// <value>true</value>
        Task<bool> VerifyAccountAsync(VerifyAccountRequest request);
    }
}
