using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Vital;
using WingInterfaceLibrary.DTO.Vital;

namespace WingInterfaceLibrary.Interface.VitalInterface
{
    /// <summary>
    /// 操作日志服务
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>操作日志管理接口</docSecondDirectory>
    public interface IVitalOperationLogService
    {
        /// <summary>
        /// 创建操作日志数据
        /// </summary>
        /// <param name="request">新建请求</param>
        /// <returns>F6B05EA898F244D1A389268CBE409825</returns>
        Task<string> CreateOperationLogAsync(CreateOperationLogRequest request);

        /// <summary>
        /// 获取操作日志详情
        /// </summary>
        /// <param name="request">查询详情请求</param>
        /// <returns></returns>
        Task<OperationLogDTO> GetOperationLogDetailAsync(GetOperationLogRequest request);

        /// <summary>
        /// 根据关键字段获取操作日志详情
        /// </summary>
        /// <param name="request">关键字段查询请求</param>
        /// <returns></returns>
        Task<OperationLogDTO> GetOperationLogDetailByKeyAsync(GetOperationLogByKeyRequest request);

        /// <summary>
        /// 获取操作日志数据分页
        /// </summary>
        /// <param name="request">数据分页查询请求</param>
        /// <returns>返回操作日志列表</returns>
        Task<PageCollection<OperationLogDTO>> GetOperationLogPageAsync(OperationLogPageRequest request);


        /// <summary>
        /// 删除操作日志数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns>true</returns>
        Task<bool> RemoveOperationLogAsync(RemoveOperationLogRequest request);


        /// <summary>
        /// 获取操作日志数据列表
        /// </summary>
        /// <param name="request">数据列表查询请求</param>
        /// <returns></returns>
        Task<List<OperationLogDTO>> GetOperationLogListAsync(GetOperationLogListRequest request);

        /// <summary>
        /// 更新操作日志数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns>true</returns>
        Task<bool> UpdateOperationLogAsync(UpdateOperationLogRequest request);
    }
}
