using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Vital;
using WingInterfaceLibrary.DTO.Vital;

namespace WingInterfaceLibrary.Interface.VitalInterface
{
    /// <summary>
    /// 组织服务
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>组织管理接口</docSecondDirectory>
    public interface IVitalOrganizationService
    {
        /// <summary>
        /// 创建组织数据
        /// </summary>
        /// <param name="request">新建请求</param>
        /// <returns>F6B05EA898F244D1A389268CBE409825</returns>
        Task<string> CreateOrganizationAsync(CreateOrganizationRequest request);

        /// <summary>
        /// 生成体检地区码
        /// </summary>
        /// <returns></returns>
        Task<string> GetNextOrganizationUniqueCodeAsync(TokenRequest request);

        /// <summary>
        /// 获取组织详情
        /// </summary>
        /// <param name="request">查询详情请求</param>
        /// <returns></returns>
        Task<OrganizationDTO> GetOrganizationDetailAsync(GetOrganizationRequest request);

        /// <summary>
        /// 根据关键字段获取组织详情
        /// </summary>
        /// <param name="request">关键字段查询请求</param>
        /// <returns></returns>
        Task<OrganizationDTO> GetOrganizationDetailByKeyAsync(GetOrganizationByKeyRequest request);

        /// <summary>
        /// 获取组织数据分页
        /// </summary>
        /// <param name="request">数据分页查询请求</param>
        /// <returns>返回组织列表</returns>
        Task<PageCollection<OrganizationDTO>> GetOrganizationPageAsync(OrganizationPageRequest request);


        /// <summary>
        /// 删除组织数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns>true</returns>
        Task<bool> RemoveOrganizationAsync(RemoveOrganizationRequest request);


        /// <summary>
        /// 获取组织数据列表
        /// </summary>
        /// <param name="request">数据列表查询请求</param>
        /// <returns></returns>
        Task<List<OrganizationDTO>> GetOrganizationListAsync(GetOrganizationListRequest request);

        /// <summary>
        /// 更新组织数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns>true</returns>
        Task<bool> UpdateOrganizationAsync(UpdateOrganizationRequest request);

        /// <summary>
        /// 获取组织树状节点
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<OrganizationTreeDTO>> GetOrganizationTreeAsync(GetOrganizationTreeRequest request);

        /// <summary>
        /// 获取已启用的外设配置（Key）
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<string>> GetEnableDeviceKeysAsync(GetEnableDeviceKeysRequest request);

        /// <summary>
        /// 获取参数配置
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<DynamicParameterDTO>> GetDynamicParameterAsync(GetDynamicParameterRequest request);
    }
}
