using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Vital;
using WingInterfaceLibrary.DTO.Vital;

namespace WingInterfaceLibrary.Interface.VitalInterface
{
    /// <summary>
    /// 居民扩展信息服务
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>居民扩展信息管理接口</docSecondDirectory>
    public interface IVitalPatientExtensionService
    {
        /// <summary>
        /// 创建居民扩展信息数据
        /// </summary>
        /// <param name="request">新建请求</param>
        /// <returns>F6B05EA898F244D1A389268CBE409825</returns>
        Task<string> CreatePatientExtensionAsync(CreatePatientExtensionRequest request);

        /// <summary>
        /// 获取居民扩展信息详情
        /// </summary>
        /// <param name="request">查询详情请求</param>
        /// <returns></returns>
        Task<PatientExtensionDTO> GetPatientExtensionDetailAsync(GetPatientExtensionRequest request);

        /// <summary>
        /// 根据编码和Key获取居民扩展信息详情
        /// </summary>
        /// <param name="request">关键字段查询请求</param>
        /// <returns></returns>
        Task<PatientExtensionDTO> GetPatientExtensionDetailByCodeAndKeyAsync(GetPatientExtensionByCodeAndKeyRequest request);

        /// <summary>
        /// 获取居民扩展信息数据分页
        /// </summary>
        /// <param name="request">数据分页查询请求</param>
        /// <returns>返回居民扩展信息列表</returns>
        Task<PageCollection<PatientExtensionDTO>> GetPatientExtensionPageAsync(PatientExtensionPageRequest request);


        /// <summary>
        /// 删除居民扩展信息数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns>true</returns>
        Task<bool> RemovePatientExtensionAsync(RemovePatientExtensionRequest request);


        /// <summary>
        /// 获取居民扩展信息数据列表
        /// </summary>
        /// <param name="request">数据列表查询请求</param>
        /// <returns></returns>
        Task<List<PatientExtensionDTO>> GetPatientExtensionListAsync(GetPatientExtensionListRequest request);

        /// <summary>
        /// 更新居民扩展信息数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns>true</returns>
        Task<bool> UpdatePatientExtensionAsync(UpdatePatientExtensionRequest request);
    }
}
