using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Vital;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.DTO.FaceRecognition;

namespace WingInterfaceLibrary.Interface.VitalInterface
{
    /// <summary>
    /// 档案服务
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>档案接口</docSecondDirectory>
    public interface IVitalPatientService
    {
        /// <summary>
        /// 创建居民数据
        /// </summary>
        /// <param name="request">新建请求</param>
        /// <returns>F6B05EA898F244D1A389268CBE409825</returns>
        Task<string> CreatePatientAsync(CreatePatientRequest request);

        /// <summary>
        /// 获取居民详情
        /// </summary>
        /// <param name="request">查询详情请求</param>
        /// <returns></returns>
        Task<PatientDTO> GetPatientDetailAsync(GetPatientRequest request);

        /// <summary>
        /// 根据关键字段获取居民详情
        /// </summary>
        /// <param name="request">关键字段查询请求</param>
        /// <returns></returns>
        Task<PatientDTO> GetPatientDetailByKeyAsync(GetPatientByKeyRequest request);

        /// <summary>
        /// 获取居民数据分页
        /// </summary>
        /// <param name="request">数据分页查询请求</param>
        /// <returns>返回居民数据列表</returns>
        Task<PageCollection<PatientDTO>> GetPatientPageAsync(PatientPageRequest request);


        /// <summary>
        /// 删除居民数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns>true</returns>
        Task<bool> RemovePatientAsync(RemovePatientRequest request);


        /// <summary>
        /// 获取居民数据列表
        /// </summary>
        /// <param name="request">数据列表查询请求</param>
        /// <returns></returns>
        Task<List<PatientDTO>> GetPatientListAsync(GetPatientListRequest request);

        /// <summary>
        /// 更新居民数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns>true</returns>
        Task<bool> UpdatePatientAsync(UpdatePatientRequest request);

        /// <summary>
        /// 设置人群分类
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SetCrowdLabelsAsync(SetCrowdLabelsRequest request);

        /// <summary>
        /// 更新居民照片数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns>true</returns>
        Task<bool> UpdatePatientPhotosAsync(UpdatePatientPhotosRequest request);

        /// <summary>
        /// 根据居民身份证照片获取基本信息
        /// </summary>
        /// <param name="request">查询详情请求</param>
        /// <returns></returns>
        Task<PatientBaseDTO> GetPatientBaseByImageAsync(GetPatientBaseByImageRequest request);

        /// <summary>
        /// 根据居民人脸照片获取基本信息
        /// </summary>
        /// <param name="request">查询详情请求</param>
        /// <returns></returns>
        Task<PatientBaseDTO> GetPatientBaseByFaceImageAsync(GetPatientBaseByFaceImageRequest request);

        /// <summary>
        /// 居民人脸照片保存接口
        /// </summary>
        /// <param name="request">查询详情请求</param>
        /// <returns></returns>
        Task<SavePersonDTO> SavePatientBaseByFaceImageAsync(SavePatientBaseByFaceImageRequest request);

        /// <summary>
        /// 解除人脸并重新绑定信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<DeletePersonDTO> UnbindAndCreateByFaceImageAsync(UnbindAndCreateByFaceImageRequest request);

        /// <summary>
        /// 解除人脸绑定信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<DeletePersonDTO> UnbindByCardNoAsync(UnbindByCardNoRequest request);

        /// <summary>
        /// 获取居民数据统计
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PatientStatisticDTO> GetPatientStatisticAsync(GetPatientStatisticRequest request);

        /// <summary>
        /// 添加人脸识别数据
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SavePatientBaseByFaceImageLocalAsync(SavePatientBaseByFaceImageLocalRequest request);

        /// <summary>
        /// 添加人脸识别数据
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UnbindByCardNoLocalAsync(UnbindByCardNoRequest request);

        /// <summary>
        /// 获取所有人脸识别数据
        /// </summary>
        /// <returns></returns>
        Task<List<FaceRecognitionDTO>> GetAllPersonListLocalAsync(GetPersonListRequest request);
    }
}
