using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Vital;
using WingInterfaceLibrary.DTO.Vital;

namespace WingInterfaceLibrary.Interface.VitalInterface
{
    /// <summary>
    /// 处方服务
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>处方管理接口</docSecondDirectory>
    public interface IVitalPrescriptionService
    {
        /// <summary>
        /// 创建处方数据
        /// </summary>
        /// <param name="request">新建请求</param>
        /// <returns>F6B05EA898F244D1A389268CBE409825</returns>
        Task<string> CreatePrescriptionAsync(CreatePrescriptionRequest request);

        /// <summary>
        /// 获取处方详情
        /// </summary>
        /// <param name="request">查询详情请求</param>
        /// <returns></returns>
        Task<PrescriptionDTO> GetPrescriptionDetailAsync(GetPrescriptionRequest request);

        /// <summary>
        /// 获取处方详情
        /// </summary>
        /// <param name="request">查询详情请求</param>
        /// <returns></returns>
        Task<PrescriptionDTO> GetPrescriptionDetailByFollowAnPatientAsync(GetPrescriptionDetailByFollowAnPatientRequest request);

        /// <summary>
        /// 获取处方数据分页
        /// </summary>
        /// <param name="request">数据分页查询请求</param>
        /// <returns>返回处方列表</returns>
        Task<PageCollection<PrescriptionDTO>> GetPrescriptionPageAsync(PrescriptionPageRequest request);


        /// <summary>
        /// 删除处方数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns>true</returns>
        Task<bool> RemovePrescriptionAsync(RemovePrescriptionRequest request);

        /// <summary>
        /// 获取处方数据列表
        /// </summary>
        /// <param name="request">数据列表查询请求</param>
        /// <returns></returns>
        Task<List<PrescriptionDTO>> GetPrescriptionListAsync(GetPrescriptionListRequest request);

        /// <summary>
        /// 更新处方数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns>true</returns>
        Task<bool> UpdatePrescriptionAsync(UpdatePrescriptionRequest request);
    }
}
