using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Vital;
using WingInterfaceLibrary.DTO.Vital;

namespace WingInterfaceLibrary.Interface.VitalInterface
{
    /// <summary>
    /// 报告服务
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>报告管理接口</docSecondDirectory>
    public interface IVitalReportService
    {
        /// <summary>
        /// 创建报告数据
        /// </summary>
        /// <param name="request">新建请求</param>
        /// <returns>F6B05EA898F244D1A389268CBE409825</returns>
        Task<string> CreateReportAsync(CreateReportRequest request);

        /// <summary>
        /// 获取报告详情
        /// </summary>
        /// <param name="request">查询详情请求</param>
        /// <returns></returns>
        Task<ReportDTO> GetReportDetailAsync(GetReportRequest request);

        /// <summary>
        /// 根据关键字段获取报告详情
        /// </summary>
        /// <param name="request">关键字段查询请求</param>
        /// <returns></returns>
        Task<ReportDTO> GetReportDetailByKeyAsync(GetReportByKeyRequest request);

        /// <summary>
        /// 获取报告数据分页
        /// </summary>
        /// <param name="request">数据分页查询请求</param>
        /// <returns>返回报告列表</returns>
        Task<PageCollection<ReportDTO>> GetReportPageAsync(ReportPageRequest request);


        /// <summary>
        /// 删除报告数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns>true</returns>
        Task<bool> RemoveReportAsync(RemoveReportRequest request);


        /// <summary>
        /// 获取报告数据列表
        /// </summary>
        /// <param name="request">数据列表查询请求</param>
        /// <returns></returns>
        Task<List<ReportDTO>> GetReportListAsync(GetReportListRequest request);

        /// <summary>
        /// 更新报告数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns>true</returns>
        Task<bool> UpdateReportAsync(UpdateReportRequest request);
    }
}
