using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Vital;
using WingInterfaceLibrary.DTO.Vital;

namespace WingInterfaceLibrary.Interface.VitalInterface
{
    /// <summary>
    /// 村、小区服务
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>村、小区管理接口</docSecondDirectory>
    public interface IVitalResidenceService
    {
        /// <summary>
        /// 创建村、小区数据
        /// </summary>
        /// <param name="request">新建请求</param>
        /// <returns>F6B05EA898F244D1A389268CBE409825</returns>
        Task<string> CreateResidenceAsync(CreateResidenceRequest request);

        /// <summary>
        /// 获取村、小区详情
        /// </summary>
        /// <param name="request">查询详情请求</param>
        /// <returns></returns>
        Task<ResidenceDTO> GetResidenceDetailAsync(GetResidenceRequest request);

        /// <summary>
        /// 根据关键字段获取村、小区详情
        /// </summary>
        /// <param name="request">关键字段查询请求</param>
        /// <returns></returns>
        Task<ResidenceDTO> GetResidenceDetailByKeyAsync(GetResidenceByKeyRequest request);

        /// <summary>
        /// 获取村、小区数据分页
        /// </summary>
        /// <param name="request">数据分页查询请求</param>
        /// <returns>返回村、小区列表</returns>
        Task<PageCollection<ResidenceDTO>> GetResidencePageAsync(ResidencePageRequest request);


        /// <summary>
        /// 删除村、小区数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns>true</returns>
        Task<bool> RemoveResidenceAsync(RemoveResidenceRequest request);


        /// <summary>
        /// 获取村、小区数据列表
        /// </summary>
        /// <param name="request">数据列表查询请求</param>
        /// <returns></returns>
        Task<List<ResidenceDTO>> GetResidenceListAsync(GetResidenceListRequest request);

        /// <summary>
        /// 更新村、小区数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns>true</returns>
        Task<bool> UpdateResidenceAsync(UpdateResidenceRequest request);

        /// <summary>
        /// 根据乡镇编码获取分页
        /// </summary>
        /// <param name="request">数据分页查询请求</param>
        /// <returns></returns>
        Task<PageCollection<ResidenceDTO>> GetResidencePageByTownAsync(GetResidencePageByTownRequest request);
    }
}
