using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Vital;
using WingInterfaceLibrary.DTO.Vital;

namespace WingInterfaceLibrary.Interface.VitalInterface
{
    /// <summary>
    /// 角色服务
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>角色接口</docSecondDirectory>
    public interface IVitalRoleService
    {
        /// <summary>
        /// 创建角色数据
        /// </summary>
        /// <param name="request">新建请求</param>
        /// <returns>F6B05EA898F244D1A389268CBE409825</returns>
        Task<string> CreateRoleAsync(CreateRoleRequest request);

        /// <summary>
        /// 获取角色详情
        /// </summary>
        /// <param name="request">查询详情请求</param>
        /// <returns></returns>
        Task<RoleDTO> GetRoleDetailAsync(GetRoleRequest request);

        /// <summary>
        /// 根据关键字段获取角色详情
        /// </summary>
        /// <param name="request">关键字段查询请求</param>
        /// <returns></returns>
        Task<RoleDTO> GetRoleDetailByKeyAsync(GetRoleByKeyRequest request);

        /// <summary>
        /// 获取角色数据分页
        /// </summary>
        /// <param name="request">数据分页查询请求</param>
        /// <returns>返回角色数据列表</returns>
        Task<PageCollection<RoleDTO>> GetRolePageAsync(RolePageRequest request);


        /// <summary>
        /// 删除角色数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns>true</returns>
        Task<bool> RemoveRoleAsync(RemoveRoleRequest request);


        /// <summary>
        /// 获取角色数据列表
        /// </summary>
        /// <param name="request">数据列表查询请求</param>
        /// <returns></returns>
        Task<List<RoleDTO>> GetRoleListAsync(GetRoleListRequest request);

        /// <summary>
        /// 更新角色数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns>true</returns>
        Task<bool> UpdateRoleAsync(UpdateRoleRequest request);


    }
}
