using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Vital;
using WingInterfaceLibrary.DTO.Vital;

namespace WingInterfaceLibrary.Interface.VitalInterface
{
    /// <summary>
    /// 服务包服务
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>服务包接口</docSecondDirectory>
    public interface IVitalServicePackService
    {

        /// <summary>
        ///  创建服务包
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> CreateServicePackAsync(CreateServicePackRequest request);

        /// <summary>
        /// 获取服务包详情
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ServicePackDTO> GetServicePackDetailAsync(GetServicePackRequest request);

        /// <summary>
        /// 获取服务包分页查询
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageCollection<ServicePackDTO>> GetServicePackPageAsync(ServicePackPageRequest request);

        /// <summary>
        /// 删除服务包
        /// <summary>
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> RemovetServicePackAsync(RemovetServicePackRequest request);


        /// <summary>
        /// 更新服务包
        /// </summary>
        /// <param name="request">update request</param>
        /// <returns></returns>
        Task<bool> UpdateServicePackAsync(UpdateServicePackRequest request);

        /// <summary>
        ///设服务包上设置服务项目
        /// </summary>
        /// <param name="request">update request</param>
        /// <returns></returns>
        Task<bool> UpdateServicePackForItemsAsync(UpdateServicePackForItemsRequest request);

        /// <summary>
        /// 创建项目包
        /// </summary>
        /// <param name="request">create request</param>
        /// <returns></returns>
        Task<string> CreateServiceItemAsync(CreateServiceItemRequest request);

        /// <summary>
        ///获取项目详情
        /// </summary>
        /// <param name="request">get request</param>
        /// <returns></returns>
        Task<ServiceItemDTO> GetServiceItemDetailAsync(GetServiceItemRequest request);

        /// <summary>
        /// 获取服务项目分页查询
        /// </summary>
        /// <param name="request">Get page request</param>
        /// <returns></returns>
        Task<PageCollection<ServiceItemDTO>> GetServiceItemPageAsync(GetServiceItemPageRequest request);

        /// <summary>
        /// 通过编码获取服务项目列表
        /// </summary>
        /// <param name="request">Get page request</param>
        /// <returns></returns>
       Task<List<ServiceItemDTO>> GetServiceItemListAsync(GetServiceItemListRequest request);

        /// <summary>
        ///删除服务项
        /// </summary>
        /// <param name="request">remove request</param>
        /// <returns></returns>
        Task<bool> RemovetServiceItemAsync(RemovetServiceItemRequest request);

        // <summary>
        /// 更新服务项目
        /// </summary>
        /// <param name="request">update request</param>
        /// <returns></returns>
        Task<bool> UpdateServiceItemAsync(UpdateServiceItemRequest request);

        /// <summary>
        /// 服务包设定人群分标签
        /// </summary>
        /// <param name="request">update request</param>
        /// <returns></returns>
        Task<bool> UpdateServicePackForLabelsAsync(UpdateServicePackForLabelsRequest request);
    }
}
