using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Vital;
using WingInterfaceLibrary.DTO.Vital;

namespace WingInterfaceLibrary.Interface.VitalInterface
{
    /// <summary>
    /// 统计服务
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>统计管理接口</docSecondDirectory>
    public interface IVitalStatisticService
    {
        /// <summary>
        /// 创建统计数据
        /// </summary>
        /// <param name="request">新建请求</param>
        /// <returns>F6B05EA898F244D1A389268CBE409825</returns>
        Task<string> CreateStatisticAsync(CreateStatisticRequest request);

        /// <summary>
        /// 获取统计详情
        /// </summary>
        /// <param name="request">查询详情请求</param>
        /// <returns></returns>
        Task<StatisticDTO> GetStatisticDetailAsync(GetStatisticRequest request);

        /// <summary>
        /// 根据关键字段获取统计详情
        /// </summary>
        /// <param name="request">关键字段查询请求</param>
        /// <returns></returns>
        Task<StatisticDTO> GetStatisticDetailByKeyAsync(GetStatisticByKeyRequest request);

        /// <summary>
        /// 获取统计数据分页
        /// </summary>
        /// <param name="request">数据分页查询请求</param>
        /// <returns>返回统计列表</returns>
        Task<PageCollection<StatisticDTO>> GetStatisticPageAsync(StatisticPageRequest request);


        /// <summary>
        /// 删除统计数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns>true</returns>
        Task<bool> RemoveStatisticAsync(RemoveStatisticRequest request);


        /// <summary>
        /// 获取统计数据列表
        /// </summary>
        /// <param name="request">数据列表查询请求</param>
        /// <returns></returns>
        Task<List<StatisticDTO>> GetStatisticListAsync(GetStatisticListRequest request);

        /// <summary>
        /// 更新统计数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns>true</returns>
        Task<bool> UpdateStatisticAsync(UpdateStatisticRequest request);

        /// <summary>
        /// 获取首页数据
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> GetHomePageStatisticAsync(GetHomePageStatisticRequest request);
    }
}
