using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Vital;
using WingInterfaceLibrary.DTO.Vital;

namespace WingInterfaceLibrary.Interface.VitalInterface
{
    /// <summary>
    /// 系统设置服务
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>系统设置管理接口</docSecondDirectory>
    public interface IVitalSystemSettingService
    {
        /// <summary>
        /// 创建系统设置数据
        /// </summary>
        /// <param name="request">新建请求</param>
        /// <returns>F6B05EA898F244D1A389268CBE409825</returns>
        Task<string> CreateSystemSettingAsync(CreateSystemSettingRequest request);

        /// <summary>
        /// 获取系统设置详情
        /// </summary>
        /// <param name="request">查询详情请求</param>
        /// <returns></returns>
        Task<SystemSettingDTO> GetSystemSettingDetailAsync(GetSystemSettingRequest request);

        /// <summary>
        /// 根据关键字段获取系统设置详情
        /// </summary>
        /// <param name="request">关键字段查询请求</param>
        /// <returns></returns>
        Task<SystemSettingDTO> GetSystemSettingDetailByKeyAsync(GetSystemSettingByKeyRequest request);

        /// <summary>
        /// 获取系统设置数据分页
        /// </summary>
        /// <param name="request">数据分页查询请求</param>
        /// <returns>返回系统配置数据列表</returns>
        Task<PageCollection<SystemSettingDTO>> GetSystemSettingPageAsync(SystemSettingPageRequest request);


        /// <summary>
        /// 删除系统设置数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns>true</returns>
        Task<bool> RemoveSystemSettingAsync(RemoveSystemSettingRequest request);


        /// <summary>
        /// 获取系统设置数据列表
        /// </summary>
        /// <param name="request">数据列表查询请求</param>
        /// <returns></returns>
        Task<List<SystemSettingDTO>> GetSystemSettingListAsync(GetSystemSettingListRequest request);

        /// <summary>
        /// 更新系统设置数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns>true</returns>
        Task<bool> UpdateSystemSettingAsync(UpdateSystemSettingRequest request);

        /// <summary>
        /// 同步系统配置
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<SyncSettingsDTO> SyncSettingAsync(SyncSettingRequest request);
    }
}
