using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Vital;
using WingInterfaceLibrary.DTO.Vital;

namespace WingInterfaceLibrary.Interface.VitalInterface
{
    /// <summary>
    /// 登录注册服务
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>机构接口</docSecondDirectory>
    public interface IVitalTeamRegionService
    {
        /// <summary>
        /// 创建团队区域数据
        /// </summary>
        /// <param name="request">新建请求</param>
        /// <returns>F6B05EA898F244D1A389268CBE409825</returns>
        Task<string> CreateTeamRegionAsync(CreateTeamRegionRequest request);

        /// <summary>
        /// 获取团队区域详情
        /// </summary>
        /// <param name="request">查询详情请求</param>
        /// <returns></returns>
        Task<TeamRegionDTO> GetTeamRegionDetailAsync(GetTeamRegionRequest request);

        /// <summary>
        /// 根据关键字段获取团队区域详情
        /// </summary>
        /// <param name="request">关键字段查询请求</param>
        /// <returns></returns>
        Task<TeamRegionDTO> GetTeamRegionDetailByKeyAsync(GetTeamRegionByKeyRequest request);

        /// <summary>
        /// 获取团队区域数据分页
        /// </summary>
        /// <param name="request">数据分页查询请求</param>
        /// <returns>返回团队区域数据列表</returns>
        Task<PageCollection<TeamRegionDTO>> GetTeamRegionPageAsync(TeamRegionPageRequest request);


        /// <summary>
        /// 删除团队区域数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns>true</returns>
        Task<bool> RemoveTeamRegionAsync(RemoveTeamRegionRequest request);


        /// <summary>
        /// 获取团队区域数据列表
        /// </summary>
        /// <param name="request">数据列表查询请求</param>
        /// <returns></returns>
        Task<List<TeamRegionDTO>> GetTeamRegionListAsync(GetTeamRegionListRequest request);

        /// <summary>
        /// 更新团队区域数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns>true</returns>
        Task<bool> UpdateTeamRegionAsync(UpdateTeamRegionRequest request);
    }
}
