using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Vital;
using WingInterfaceLibrary.DTO.Vital;

namespace WingInterfaceLibrary.Interface.VitalInterface
{
    /// <summary>
    /// 团队服务
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>团队管理接口</docSecondDirectory>
    public interface IVitalTeamService
    {
        /// <summary>
        /// 创建团队数据
        /// </summary>
        /// <param name="request">新建请求</param>
        /// <returns>F6B05EA898F244D1A389268CBE409825</returns>
        Task<string> CreateTeamAsync(CreateTeamRequest request);

        /// <summary>
        /// 获取团队详情
        /// </summary>
        /// <param name="request">查询详情请求</param>
        /// <returns></returns>
        Task<TeamDTO> GetTeamDetailAsync(GetTeamRequest request);

        /// <summary>
        /// 根据关键字段获取团队详情
        /// </summary>
        /// <param name="request">关键字段查询请求</param>
        /// <returns></returns>
        Task<TeamDTO> GetTeamDetailByKeyAsync(GetTeamByKeyRequest request);

        /// <summary>
        /// 获取团队数据分页
        /// </summary>
        /// <param name="request">数据分页查询请求</param>
        /// <returns>返回团队列表</returns>
        Task<PageCollection<TeamDTO>> GetTeamPageAsync(TeamPageRequest request);


        /// <summary>
        /// 删除团队数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns>true</returns>
        Task<bool> RemoveTeamAsync(RemoveTeamRequest request);


        /// <summary>
        /// 获取团队数据列表
        /// </summary>
        /// <param name="request">数据列表查询请求</param>
        /// <returns></returns>
        Task<List<TeamDTO>> GetTeamListAsync(GetTeamListRequest request);

        /// <summary>
        /// 更新团队数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns>true</returns>
        Task<bool> UpdateTeamAsync(UpdateTeamRequest request);

        /// <summary>
        /// 用户加入团队
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> JoinTeamAsync(JoinTeamRequest request);

        /// <summary>
        /// 用户退出团队
        /// </summary>
        /// <param name="request">退出请求</param>
        /// <returns></returns>
        Task<bool> QuitTeamAsync(QuitTeamRequest request);

        /// <summary>
        /// 根据机构获取团队数据分页
        /// </summary>
        /// <param name="request">数据分页查询请求</param>
        /// <returns></returns>
        Task<PageCollection<TeamDTO>> GetTeamPageByOrganizationAsync(GetTeamPageByOrganizationRequest request);

        /// <summary>
        /// 设置主任医师
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SetTeamPrincipalAsync(SetTeamPrincipalRequest request);
    }
}
