using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Vital;
using WingInterfaceLibrary.DTO.Vital;

namespace WingInterfaceLibrary.Interface.VitalInterface
{
    /// <summary>
    /// 模板服务
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>模板接口</docSecondDirectory>
    public interface IVitalTemplateService
    {
        /// <summary>
        /// 创建模板数据
        /// </summary>
        /// <param name="request">新建请求</param>
        /// <returns>F6B05EA898F244D1A389268CBE409825</returns>
        Task<string> CreateTemplateAsync(CreateTemplateRequest request);

        /// <summary>
        /// 获取模板详情
        /// </summary>
        /// <param name="request">查询详情请求</param>
        /// <returns></returns>
        Task<TemplateDTO> GetTemplateDetailAsync(GetTemplateRequest request);

        /// <summary>
        /// 根据关键字段获取模板详情
        /// </summary>
        /// <param name="request">关键字段查询请求</param>
        /// <returns></returns>
        Task<TemplateDTO> GetTemplateDetailByKeyAsync(GetTemplateByKeyRequest request);

        /// <summary>
        /// 获取模板数据分页
        /// </summary>
        /// <param name="request">数据分页查询请求</param>
        /// <returns>返回模板数据列表</returns>
        Task<PageCollection<TemplateDTO>> GetTemplatePageAsync(TemplatePageRequest request);


        /// <summary>
        /// 删除模板数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns>true</returns>
        Task<bool> RemoveTemplateAsync(RemoveTemplateRequest request);


        /// <summary>
        /// 获取模板数据列表
        /// </summary>
        /// <param name="request">数据列表查询请求</param>
        /// <returns></returns>
        Task<List<TemplateDTO>> GetTemplateListAsync(GetTemplateListRequest request);

        /// <summary>
        /// 更新模板数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns>true</returns>
        Task<bool> UpdateTemplateAsync(UpdateTemplateRequest request);

        /// <summary>
        /// 根据Key获取最新的模版
        /// </summary>
        /// <param name="request">get request</param>
        /// <returns></returns>
        Task<TemplateDTO> GetLastOneTemplateByKeyAsync(GetLastOneTemplateByKeyRequest request);

        /// <summary>
        /// 查询模板集合
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<TemplateDTO>> GetTemplateInfosAsync(GetTemplateInfosRequest request);
    }
}
