using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Vital;
using WingInterfaceLibrary.DTO.Vital;

namespace WingInterfaceLibrary.Interface.VitalInterface
{
    /// <summary>
    /// 乡镇服务
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>乡镇管理接口</docSecondDirectory>
    public interface IVitalTownService
    {
        /// <summary>
        /// 创建乡镇数据
        /// </summary>
        /// <param name="request">新建请求</param>
        /// <returns>F6B05EA898F244D1A389268CBE409825</returns>
        Task<string> CreateTownAsync(CreateTownRequest request);

        /// <summary>
        /// 获取乡镇详情
        /// </summary>
        /// <param name="request">查询详情请求</param>
        /// <returns></returns>
        Task<TownDTO> GetTownDetailAsync(GetTownRequest request);

        /// <summary>
        /// 根据关键字段获取乡镇详情
        /// </summary>
        /// <param name="request">关键字段查询请求</param>
        /// <returns></returns>
        Task<TownDTO> GetTownDetailByKeyAsync(GetTownByKeyRequest request);

        /// <summary>
        /// 获取乡镇数据分页
        /// </summary>
        /// <param name="request">数据分页查询请求</param>
        /// <returns>返回乡镇列表</returns>
        Task<PageCollection<TownDTO>> GetTownPageAsync(TownPageRequest request);


        /// <summary>
        /// 删除乡镇数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns>true</returns>
        Task<bool> RemoveTownAsync(RemoveTownRequest request);


        /// <summary>
        /// 获取乡镇数据列表
        /// </summary>
        /// <param name="request">数据列表查询请求</param>
        /// <returns></returns>
        Task<List<TownDTO>> GetTownListAsync(GetTownListRequest request);

        /// <summary>
        /// 更新乡镇数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns>true</returns>
        Task<bool> UpdateTownAsync(UpdateTownRequest request);

        /// <summary>
        /// 根据区Id获取乡镇分页
        /// </summary>
        /// <param name="request">数据分页查询请求</param>
        /// <returns></returns>
        Task<PageCollection<TownDTO>> GetTownPageByDistrictAsync(GetTownPageByDistrictRequest request);
    }
}
