using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Vital;
using WingInterfaceLibrary.DTO.Vital;

namespace WingInterfaceLibrary.Interface.VitalInterface
{
    /// <summary>
    /// 更新服务
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>更新管理接口</docSecondDirectory>
    public interface IVitalUpgradeService
    {
        /// <summary>
        /// 创建更新数据
        /// </summary>
        /// <param name="request">新建请求</param>
        /// <returns>F6B05EA898F244D1A389268CBE409825</returns>
        Task<string> CreateUpgradeAsync(CreateUpgradeRequest request);

        /// <summary>
        /// 获取更新详情
        /// </summary>
        /// <param name="request">查询详情请求</param>
        /// <returns></returns>
        Task<UpgradeDTO> GetUpgradeDetailAsync(GetUpgradeRequest request);

        /// <summary>
        /// 获取更新数据分页
        /// </summary>
        /// <param name="request">数据分页查询请求</param>
        /// <returns>返回更新列表</returns>
        Task<PageCollection<UpgradeDTO>> GetUpgradePageAsync(UpgradePageRequest request);

        /// <summary>
        /// 获取最新的更新
        /// </summary>
        /// <param name="request">查询详情请求</param>
        /// <returns></returns>
        Task<UpgradeDTO> GetLastUpgradeAsync(GetLastUpgradeRequest request);

        /// <summary>
        /// 查询系统资源文件内容
        /// </summary>
        /// <returns></returns>
        Task<VitalResourceInfoDTO> GetResourceInfoByVersionAsync(GetResourceInfoByVersionRequest request);
    }
}
