using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Vital;
using WingInterfaceLibrary.DTO.Vital;

namespace WingInterfaceLibrary.Interface.VitalInterface
{
    /// <summary>
    /// 权限服务
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>权限接口</docSecondDirectory>
    public interface IVitalUserFeatureService
    {
        /// <summary>
        /// 创建用户权限数据
        /// </summary>
        /// <param name="request">新建请求</param>
        /// <returns>F6B05EA898F244D1A389268CBE409825</returns>
        Task<string> CreateUserFeatureAsync(CreateUserFeatureRequest request);

        /// <summary>
        /// 获取用户权限详情
        /// </summary>
        /// <param name="request">查询详情请求</param>
        /// <returns></returns>
        Task<UserFeatureDTO> GetUserFeatureDetailAsync(GetUserFeatureRequest request);

        /// <summary>
        /// 根据关键字段获取用户权限详情
        /// </summary>
        /// <param name="request">关键字段查询请求</param>
        /// <returns></returns>
        Task<UserFeatureDTO> GetUserFeatureDetailByKeyAsync(GetUserFeatureByKeyRequest request);

        /// <summary>
        /// 获取用户权限数据分页
        /// </summary>
        /// <param name="request">数据分页查询请求</param>
        /// <returns>返回用户权限数据列表</returns>
        Task<PageCollection<UserFeatureDTO>> GetUserFeaturePageAsync(UserFeaturePageRequest request);


        /// <summary>
        /// 删除用户权限数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns>true</returns>
        Task<bool> RemoveUserFeatureAsync(RemoveUserFeatureRequest request);


        /// <summary>
        /// 获取用户权限数据列表
        /// </summary>
        /// <param name="request">数据列表查询请求</param>
        /// <returns></returns>
        Task<List<UserFeatureDTO>> GetUserFeatureListAsync(GetUserFeatureListRequest request);

        /// <summary>
        /// 更新用户权限数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns>true</returns>
        Task<bool> UpdateUserFeatureAsync(UpdateUserFeatureRequest request);
    }
}
