using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Vital;
using WingInterfaceLibrary.DTO.Vital;

namespace WingInterfaceLibrary.Interface.VitalInterface
{
    /// <summary>
    /// 用户管理服务
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>用户管理接口</docSecondDirectory>
    public interface IVitalUserService
    {
        /// <summary>
        /// 创建用户数据
        /// </summary>
        /// <param name="request">新建请求</param>
        /// <returns>F6B05EA898F244D1A389268CBE409825</returns>
        Task<string> CreateUserAsync(CreateUserRequest request);

        /// <summary>
        /// 获取用户详情
        /// </summary>
        /// <param name="request">查询详情请求</param>
        /// <returns></returns>
        Task<UserDTO> GetUserDetailAsync(GetUserRequest request);

        /// <summary>
        /// 根据关键字段获取用户详情
        /// </summary>
        /// <param name="request">关键字段查询请求</param>
        /// <returns></returns>
        Task<UserDTO> GetUserDetailByKeyAsync(GetUserByKeyRequest request);

        /// <summary>
        /// 获取用户数据分页
        /// </summary>
        /// <param name="request">数据分页查询请求</param>
        /// <returns>返回用户数据列表</returns>
        Task<PageCollection<UserDTO>> GetUserPageAsync(UserPageRequest request);


        /// <summary>
        /// 删除用户数据
        /// </summary>
        /// <param name="request">删除请求</param>
        /// <returns>true</returns>
        Task<bool> RemoveUserAsync(RemoveUserRequest request);

        /// <summary>
        /// 获取用户数据列表
        /// </summary>
        /// <param name="request">数据列表查询请求</param>
        /// <returns></returns>
        Task<List<UserDTO>> GetUserListAsync(GetUserListRequest request);

        /// <summary>
        /// 更新用户数据
        /// </summary>
        /// <param name="request">更新请求</param>
        /// <returns>true</returns>
        Task<bool> UpdateUserAsync(UpdateUserRequest request);

        /// <summary>
        /// 重新设置用户名
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> ResetUserNameAsync(ResetUserNameRequest request);

        /// <summary>
        /// 设备用户关联的超声机
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> BindUltrasoundCodeAsync(BindUltrasoundCodeRequest request);

        /// <summary>
        /// 设备用户关联的心电
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> BindEcgCodeAsync(BindEcgCodeRequest request);

        /// <summary>
        /// 关联晶奇工号
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SetJingQiUserAsync(SetJingQiUserRequest request);

        /// <summary>
        /// 根据机构编码获取用户列表
        /// </summary>
        /// <param name="request">get list request</param>
        /// <returns></returns>
        Task<PageCollection<UserDTO>> GetUserPageByOrganizationCodeAsync(GetUserPageByOrganizationCodeRequest request);

        /// <summary>
        /// 设置负责区域
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SetAreaOfResponsibilityAsync(SetAreaOfResponsibilityRequest request);

        /// <summary>
        /// 获取负责区域
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<ResidenceDTO>> GetAreaOfResponsibilityAsync(GetAreaOfResponsibilityRequest request);

        /// <summary>
        /// 根据团队编码获取用户分页
        /// </summary>
        /// <param name="request">get list request</param>
        /// <returns></returns>
        Task<PageCollection<UserDTO>> GetUserPageByTeamCodeAsync(GetUserPageByTeamCodeRequest request);

        /// <summary>
        /// 设置签名
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SetSignatureAsync(SetSignatureRequest request);

        /// <summary>
        /// 获取菜单权限
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<UserFeatureDTO>> GetMenuPermissionAsync(GetMenuPermissionRequest request);

        /// <summary>
        /// 获取操作权限
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<UserFeatureDTO>> GetOperationPermissionAsync(GetOperationPermissionRequest request);
    }
}
