using System.Threading.Tasks;
using WingInterfaceLibrary.Internal.Request;
using WingInterfaceLibrary.DTO.LiveRoom;
using System.Collections.Generic;
using WingInterfaceLibrary.LiveConsultation;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Device;
using WingInterfaceLibrary.Notifications.Live;
using WingInterfaceLibrary.Notifications.Remote;
using WingInterfaceLibrary.Notifications;
using WingInterfaceLibrary.DTO.RemoteParameters;

namespace WingInterfaceLibrary.Internal.Interface
{
    /// <summary>
    /// 老平台设备请求转发服务
    /// </summary>
    public interface IDeviceForwardService
    {
        #region Receive

        /// <summary>
        /// 设备连接云服务
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeviceConnectAsync(DeviceConnectRequest request);

        /// <summary>
        /// 设备断开云服务
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeviceDisconnectAsync(DeviceDisconnectRequest request);

        /// <summary>
        /// 设备心跳
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeviceHeartRateAsync(DeviceHeartRateRequest request);

        /// <summary>
        /// 上报设备画面尺寸相关信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ReportVideoDeviceInfoResult> ReportVideoInfosAsync(ReportVideoDeviceInfoRequest request);

        /// <summary>
        /// 获取实时音视频参数
        /// </summary>
        /// <param name="request">获取实时音视频参数请求实体</param>
        /// <returns></returns>
        Task<CreateLiveRoomInfoResult> CreateLiveRoomInfoAsync(CreateLiveRoomInfoRequest request);

        /// <summary>
        /// 会诊心跳
        /// </summary>
        /// <param name="request">会诊心跳请求实体</param>
        /// <returns></returns>
        Task<bool> LiveConsultationHeartRateAsync(DeviceConsultationHeartRateRequest request);

        /// <summary>
        /// 设备端接受连接/断开远程连接
        /// </summary>
        /// <param name="request">设备端接受连接/断开远程连接请求实体</param>
        /// <returns></returns>
        Task<bool> ReplyRemoteConnectAsync(ReplyRemoteConnectRequest request);

        /// <summary>
        /// 设备下载日志实时响应
        /// </summary>
        /// <param name="request">设备下载日志实时响应请求实体</param>
        /// <returns></returns>
        Task<bool> DeviceReplyRemoteLogAsync(DeviceReplyRemoteLogRequest request);

        /// <summary>
        /// 设备取消日志下载
        /// </summary>
        /// <param name="request">设备取消日志下载请求实体</param>
        /// <returns></returns>
        Task<bool> DeviceCancelRemoteLogAsync(DeviceCancelRemoteLogRequest request);

        /// <summary>
        /// 设备发送调参初始化数据
        /// </summary>
        /// <param name="request">设备发送调参初始化数据请求实体</param>
        /// <returns></returns>
        Task<bool> DeviceSendControlParameterAsync(DeviceSendControlParameterRequest request);

        /// <summary>
        /// 上传补丁包下载进度
        /// </summary>
        /// <param name="request">上传补丁包下载进度请求实体</param>
        /// <returns></returns>
        Task<bool> UploadPatchProgressAsync(UploadDeviceDownloadPatchProgressToUserRequest request);

        /// <summary>
        /// 设备端响应探头应用设置
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> ResponseProbeApplicationSettingAsync(ProbeApplicationSettingResultRequest request);

        /// <summary>
        /// 设备端获取探头应用数据请求
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ProbeApplicationSettingInfoDTO> GetProbeApplicationSettingAsync(GetControlParametersRequest request);

        /// <summary>
        /// 发送结果给客户端
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> SendResultToClientAsync(SendResultToClientRequest request);

        /// <summary>
        /// 从Server获取远程维护结果
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> GetResultFromServerAsync(GetResultFromServerRequest request);

        /// <summary>
        /// 设备上传打印机信息
        /// </summary>
        /// <param name="request"></param>
        /// <docFirstDirectory>设备端API</docFirstDirectory>
        /// <docSecondDirectory>设备信息接口</docSecondDirectory>
        /// <returns></returns>
        Task<bool> UploadDevicePrinterAsync(UploadDevicePrinterRequest request);

        /// <summary>
        /// 生成分享码
        /// </summary>
        /// <returns></returns>
        Task<string> CreateShareCodeAsync(CreateShareCodeRequest request);

        /// <summary>
        /// 删除设备
        /// </summary>
        /// <returns></returns>
        Task<bool> DeleteDeviceAsync(DeleteDeviceRequest request);

        /// <summary>
        /// 更新设备缓存
        /// </summary>
        /// <returns></returns>
        Task<bool> UpdateDeviceAsync(WingInterfaceLibrary.Request.Management.ModifyDevicePasswordRequest request);

        #endregion

        /// <summary>
        /// 通知设备开始推流
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> StartLiveAsync(StartLiveToDeviceNotification request);

        /// <summary>
        /// 通知设备结束推流
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> CloseLiveAsync(CloseLiveToDeviceNotification request);

        /// <summary>
        /// 重启设备
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> RestartDeviceAsync(RestartDeviceNotification request);

        /// <summary>
        /// 用户申请连接/断开远程连接
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> ApplyRemoteConnectAsync(ConnectStatusToDeviceNotification request);

        /// <summary>
        /// 开始日志下载
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> GetRemoteLogAsync(GetRemoteLogToDeviceNotification request);

        /// <summary>
        /// 取消日志下载
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> CancelLogDownloadAsync(CancelLogDownloadNotification request);

        /// <summary>
        /// 申请远程控制参数
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeviceApplyRemoteControlAsync(DeviceControlledParametersNotification request);

        /// <summary>
        /// 申请探头参数
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> ApplyProbeApplicationSettingAsync(ApplyProbeApplicationSettingNotification request);

        /// <summary>
        /// 发送指令给设备
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SendCommandToDeviceAsync(SendCommandToDeviceNotification request);

        /// <summary>
        /// 推送/取消推送设备补丁包
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> PushDevicePatchAsync(PushDevicePatchToDeviceNotification request);

        /// <summary>
        /// 客户端设置设备打印机
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SetDevicePrinterAsync(DevicePrinterRequestNotification request);

        /// <summary>
        /// 获取设备设备画面尺寸相关信息
        /// </summary>
        /// <returns></returns>
        Task<ReportVideoDeviceInfoRequest> GetDeviceVideoInfosAsync(GetDeviceVideoInfosRequest request);
    }
}