using System.Threading.Tasks;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Internal.Request;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.Internal.Interface
{
    /// <summary>
    /// 信鸽-数据同步服务
    /// </summary>
    public interface IPigeonService
    {
        /// <summary>
        /// 保存超声检查记录
        /// </summary>
        /// <returns></returns>
        Task<bool> AddOrUpdateRecordAsync(AddOrUpdateRecordInternalRequest request);

        /// <summary>
        /// 保存患者记录
        /// </summary>
        /// <returns></returns>
        Task<bool> AddOrUpdatePatientInfoAsync(AddOrUpdatePatientInfoRequest request);

        /// <summary>
        /// 保存远程图像
        /// </summary>
        /// <returns></returns>
        Task<bool> AddOrUpdateRemedicalAsync(AddOrUpdateRemedicalRequest request);

        /// <summary>
        /// 保存登记记录
        /// </summary>
        /// <returns></returns>
        Task<bool> AddOrUpdateRegisterPersonInfoAsync(AddOrUpdateRegisterPersonInfoRequest request);

        /// <summary>
        /// 保存基础检查记录
        /// </summary>
        /// <returns></returns>
        Task<bool> AddOrUpdateExamInfoAsync(AddOrUpdateExamInfoRequest request);

        /// <summary>
        /// 保存中医体质记录
        /// </summary>
        /// <returns></returns>
        Task<bool> AddOrUpdateFollowUpInfoAsync(AddOrUpdateFollowUpInfoRequest request);

        /// <summary>
        /// 保存心电记录
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> AddOrUpdateElectrocardiogramRecordAsync(AddOrUpdateElectrocardiogramRecordInfoRequest request);

        /// <summary>
        /// 保存vital报告
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> AddOrUpdateVitalReportAsync(AddOrUpdateVitalReportRequest request);

        /// <summary>
        /// 保存超声报告
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> AddOrUpdateReportAsync(AddOrUpdateReportRequest request);

        /// <summary>
        /// 保存居民信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> AddOrUpdatPatientInfoAsync(AddOrUpdatPatientInfoRequest request);

        /// <summary>
        /// 保存居民扩展信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> AddOrUpdatPatientExtensionInfoAsync(AddOrUpdatPatientExtensionInfoRequest request);

        /// <summary>
        /// 批量查询增量居民信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageCollection<PatientDTO>> GetVitalPatientByPageAsync(GetCollectionByTimeRequest request);

        /// <summary>
        /// 批量查询增量居民扩展信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageCollection<PatientExtensionDTO>> GetVitalPatientExtensionByPageAsync(GetCollectionByTimeRequest request);

    }
}