using System.Threading.Tasks;
using WingInterfaceLibrary.Internal.Request;
using WingInterfaceLibrary.DTO.LiveRoom;
using System.Collections.Generic;
using WingInterfaceLibrary.LiveConsultation;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.Internal.Interface
{
    /// <summary>
    /// RTC服务
    /// </summary>
    public interface IRtcService
    {
        /// <summary>
        /// 获取房间详情和发送关闭推流通知给设备端
        /// </summary>
        /// <returns></returns>
        Task<LiveRoomDTO> GetOrCloseDeviceAsync(GetOrCloseDeviceRequest request);
        /// <summary>
        /// 检查关闭设备直播
        /// </summary>
        /// <returns></returns>
        Task CheckDeviceLiveRoomAsync(TokenRequest request);
        /// <summary>
        /// 创建或更新房间信息
        /// </summary>
        /// <returns></returns>
        Task<LiveRoomDTO> AddOrUpdateLiveRoomAsync(AddOrUpdateLiveRoomRequest request);
        /// <summary>
        /// 获取房间信息
        /// </summary>
        /// <returns></returns>
        Task<LiveRoomDTO> GetLiveRoomAsync(GetLiveRoomRequest request);
        /// <summary>
        /// 查询房间白板交互数据
        /// </summary>
        /// <returns></returns>
        Task<IList<LiveBoardDataDTO>> GetLiveBoardDatasAsync(GetLiveBoardDatasRequest request);
        /// <summary>
        /// 查询房间用户列表
        /// </summary>
        /// <returns></returns>
        Task<List<LiveConsultationMember>> GetLiveMemberInfosAsync(GetLiveMemberInfosRequest request);

        /// <summary>
        /// 根据用户codes查询房间用户状态
        /// </summary>
        /// <returns></returns>
        Task<IList<LiveMemberStatusDTO>> GetLiveMemberStatusInfosAsync(GetLiveMemberStatusInfosRequest request);
        /// <summary>
        /// 查询正在推流的设备房间
        /// </summary>
        /// <returns></returns>
        Task<LiveRoomDTO> GetInitiatingRoomByDeviceCodeAsync(GetInitiatingRoomByDeviceCodeRequest request);
        /// <summary>
        /// 开始直播
        /// </summary>
        /// <returns></returns>
        Task<LiveRoomDTO> InitiateAsync(InitiateRequest request);
        /// <summary>
        /// 同意
        /// </summary>
        /// <returns></returns>
        Task<LiveMemberDTO> AcceptAsync(AcceptRequest request);
        /// <summary>
        /// 拒绝
        /// </summary>
        /// <returns></returns>
        Task<bool> RejectAsync(RejectRequest request);
        /// <summary>
        /// 取消直播
        /// </summary>
        /// <returns></returns>
        Task<bool> CancelAsync(CancelRequest request);
        /// <summary>
        /// 切换是否开启静音
        /// </summary>
        /// <returns></returns>
        Task<bool> ChangeMuteOpenedAsync(ChangeMuteOpenedRequest request);
        /// <summary>
        /// 切换是否开启视频
        /// </summary>
        /// <returns></returns>
        Task<bool> ChangeVideoOpenedAsync(ChangeVideoOpenedRequest request);
        /// <summary>
        /// 离开房间
        /// </summary>
        /// <returns></returns>
        Task<bool> LeaveAsync(LeaveRequest request);
        /// <summary>
        /// 关闭直播
        /// </summary>
        /// <returns></returns>
        Task<bool> CloseAsync(CloseRequest request);
        /// <summary>
        /// 发送白板数据
        /// </summary>
        /// <returns></returns>
        Task<bool> SendBoardDataAsync(SendBoardDataRequest request);
        /// <summary>
        /// 进入房间-心跳
        /// </summary>
        /// <returns></returns>
        Task<bool> HeartRateJoinedAsync(HeartRateJoinRequest request);
        /// <summary>
        /// 网络质量不佳
        /// </summary>
        /// <returns></returns>
        Task<bool> NetworkErrorAsync(NetworkErrorRequest request);
        /// <summary>
        /// 离开房间-心跳
        /// </summary>
        /// <returns></returns>
        Task<bool> HeartRateLeavedAsync(HeartRateLeavedRequest request);
        /// <summary>
        /// 直播中邀请
        /// </summary>
        /// <returns></returns>
        Task<bool> InviteInAsync(InviteInRequest request);
        /// <summary>
        /// 取消直播中邀请
        /// </summary>
        /// <returns></returns>
        Task<bool> CancelInviteInAsync(CancelInviteInRequest request);
        /// <summary>
        /// 直播中加入房间
        /// </summary>
        /// <returns></returns>
        Task<LiveMemberDTO> JoinInAsync(JoinInRequest request);
        /// <summary>
        /// 拒绝直播中邀请
        /// </summary>
        /// <returns></returns>
        Task<bool> RejectInviteAsync(RejectInviteRequest request);
        /// <summary>
        /// 加入房间
        /// </summary>
        /// <returns></returns>
        Task<bool> AgreeInAsync(AgreeInRequest request);
        /// <summary>
        /// 切换房间
        /// </summary>
        /// <returns></returns>
        Task<bool> ChangeRoomAsync(ChangeRoomRequest request);
        /// <summary>
        /// 切换调参状态
        /// </summary>
        /// <returns></returns>
        Task<bool> ChangeControllingStateAsync(ChangeControllingStateRequest request);
        /// <summary>
        /// 记录直播观看人信息
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>false</returns>
        /// <show>false</show>
        Task<bool> SaveViewerAsync(SaveViewerRequest request);
        /// <summary>
        /// 删除直播观看人信息
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>false</returns>
        /// <show>false</show>
        Task<bool> RemoveViewerAsync(RemoveViewerRequest request);
        /// <summary>
        /// 查询用户在房间的状态
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>用户房间信息</returns>
        /// <show>false</show>
        Task<LiveMemberDTO> GetLiveMemberByRoomIdAsync(GetLiveMemberByRoomIdRequest request);
        /// <summary>
        /// 服务器间转发请求
        /// </summary>
        /// <param name="request">The request</param>
        /// <returns></returns>
        Task<bool> SyncServerMessageAsync(SyncReceiveServiceDataRequest request);
        /// <summary>
        /// 设备直播中加入房间
        /// </summary>
        /// <returns></returns>
        Task<LiveMemberDTO> DeviceJoinInAsync(DeviceJoinInRequest request);

    }
}