using System.Collections.Generic;
using WingInterfaceLibrary.Enum.NotificationEnum;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Notifications;
using WingInterfaceLibrary.Interface;

namespace WingInterfaceLibrary.Internal.Request
{
    /// <summary>
    /// 发送通知
    /// </summary>
    public class SendNotificationRequest : BaseNotificationRequest
    {
        /// <summary>
        /// 客户端、设备端编码
        /// </summary>
        /// <value>UserInfoDO_202203161231555YjY3j(userCode,deviceCode)</value>
        public string ClientId { get; set; }

        /// <summary>
        /// 指定通知tokens，非必填，不填则通知client查到的所有token,场景：登录挤出通知根据clientId发给所有的token，导致手机端登录后PC端也会收到登录挤出通知，调整为发送给特定token
        /// </summary>
        /// <value></value>
        public IList<TokenDTO> Tokens { get; set; } = new List<TokenDTO>();

    }

    /// <summary>
    /// 通知基类
    /// </summary>
    public class BaseNotificationRequest
    {
        /// <summary>
        /// 指定通知tokens，非必填，不填则通知client查到的所有token,场景：登录挤出通知根据clientId发给所有的token，导致手机端登录后PC端也会收到登录挤出通知，调整为发送给特定token
        /// </summary>
        /// <value></value>
        public IList<TokenDTO> Tokens { get; set; } = new List<TokenDTO>();
        
        /// <summary>
        /// 发送的通知消息对象
        /// </summary>
        /// <value>object</value>
        public object Message { get; set; }

        /// <summary>
        /// 发送的通知消息json 
        /// </summary>
        /// <value>json</value>
        public string JsonMessage { get; set; }

        /// <summary>
        /// 通知类型
        /// </summary>
        /// <value>1</value>
        public NotificationTypeEnum NotificationType { get; set; }

        /// <summary>
        /// 业务类型【会诊、聊天会话、公告】
        /// </summary>
        /// <value>1</value>
        public TransactionTypeEnum TransactionType { get; set; }

        /// <summary>
        /// 关联业务编码
        /// </summary>
        /// <value>4914352a75f645279f6b4ad6764cc288</value>
        public string RelevanceCode { get; set; }

        /// <summary>
        /// 接收方类型【客户端、设备端】
        /// </summary>
        /// <value>1</value>
        public ApplicantTypeEnum ReceiverType { get; set; }

        /// <summary>
        /// ws连接类型
        /// </summary>
        /// <value></value>
        public WSConnectTypeEnum WSConnectType { get; set; } = WSConnectTypeEnum.Default;

        /// <summary>
        /// 是否需要同步
        /// </summary>
        /// <value>false</value>
        public bool IsNeedSyn { get; set; } = true;
    }
    /// <summary>
    /// 服务器之间同步通知
    /// </summary>
    public class SyncNotification
    {

        /// <summary>
        /// 客户端、设备端编码
        /// </summary>
        /// <value>UserInfoDO_202203161231555YjY3j,UserInfoDO_202203161231555YjY31</value>
        public List<NotificationClientInfo> Clients { get; set; }

        /// <summary>
        /// 发送的通知消息
        /// </summary>
        /// <value>json</value>
        public object Message { get; set; }

        /// <summary>
        /// ws连接类型
        /// </summary>
        /// <value></value>
        public WSConnectTypeEnum WSConnectType { get; set; } = WSConnectTypeEnum.Default;
    }

}