using System;
using System.Collections.Generic;

namespace WingInterfaceLibrary.Internal.Request
{
    public class VNotePageResult<T>
    {
        public IEnumerable<T> Data { get; set; }

        public long Total { get; set; }


    }

    public class VNotePageData<T>
    {
        public IEnumerable<T> Data { get; set; }

        public long Total { get; set; }
    }

    public class VNotePageRequest
    {
        public VNotePageCondition PageCondition { get; set; }

        public VNoteFilterGroup FilterGroup { get; set; }
    }

    public class VNoteFilterGroup
    {
        //
        // 摘要:
        //     获取或设置 条件集合
        public ICollection<VNoteFilterRule> Rules { get; set; }
        //
        // 摘要:
        //     获取或设置 条件组集合
        public ICollection<VNoteFilterGroup> Groups { get; set; }
        //
        // 摘要:
        //     获取或设置 条件间操作方式，仅限And, Or
        public VNoteFilterOperate Operate { get; set; }
    }

    public class VNoteFilterRule
    {
        //
        // 摘要:
        //     获取或设置 属性名称
        public string Field { get; set; }
        //
        // 摘要:
        //     获取或设置 属性值
        public object Value { get; set; }
        //
        // 摘要:
        //     获取或设置 操作类型
        public VNoteFilterOperate Operate { get; set; }
        //
        // 摘要:
        //     获取或设置 是否将属性名称驼峰(lowerCase)写法转换为帕斯卡(UpperCase)写法
        public bool IsLowerCaseToUpperCase { get; set; }
    }

    public enum VNoteFilterOperate
    {
        //
        // 摘要:
        //     并且
        And = 1,
        //
        // 摘要:
        //     或者
        Or = 2,
        //
        // 摘要:
        //     等于
        Equal = 3,
        //
        // 摘要:
        //     不等于
        NotEqual = 4,
        //
        // 摘要:
        //     小于
        Less = 5,
        //
        // 摘要:
        //     小于或等于
        LessOrEqual = 6,
        //
        // 摘要:
        //     大于
        Greater = 7,
        //
        // 摘要:
        //     大于或等于
        GreaterOrEqual = 8,
        //
        // 摘要:
        //     开始于
        StartsWith = 9,
        //
        // 摘要:
        //     结束于
        EndsWith = 10,
        //
        // 摘要:
        //     包含（作用于字符串）
        Contains = 11,
        //
        // 摘要:
        //     不包含（作用于字符串）
        NotContains = 12
    }

    public class VNotePageCondition
    {
        public int PageIndex { get; set; }
        public int PageSize { get; set; }
        public List<VNoteSortCondition> SortConditions { get; set; }
    }

    public class VNoteSortCondition
    {
        public string SortField { get; set; }
        //
        // 摘要:
        //     获取或设置 排序方向
        public VNoteListSortDirection ListSortDirection { get; set; }
    }

    public enum VNoteListSortDirection
    {
        Ascending = 0,
        Descending = 1
    }

    public class VNotePatient
    {
        /// <summary>
        /// 获取或设置 编号
        /// </summary>
        public Guid Id { get; set; }

        ///<summary>
        /// 获取或设置 患者唯一编号
        ///</summary>
        public string PatientNo { get; set; }

        /// <summary>
        /// 登记时间
        /// </summary>
        public string RegistTime { get; set; }

        ///<summary>
        /// 获取或设置 患者姓名
        ///</summary>
        public string Name { get; set; }

        ///<summary>
        /// 获取或设置 身份证号
        ///</summary>
        public string CardNo { get; set; }

        /// <summary>
        /// 获取或设置 性别
        /// </summary>
        public string Gender { get; set; }

        /// <summary>
        /// 获取或设置 年龄
        /// </summary>
        public string Age { get; set; }

        ///<summary>
        /// 获取或设置 出生日期
        ///</summary>
        public string BirthDay { get; set; }

        ///<summary>
        /// 获取或设置 民族
        ///</summary>
        public string National { get; set; }

        ///<summary>
        /// 获取或设置 地址
        ///</summary>
        public string Address { get; set; }
    }

    public class VNoteDiagnosisData
    {
        ///<summary>
        /// 获取或设置 患者唯一编号
        ///</summary>
        public string PatientNo { get; set; }

        /// <summary>
        /// 获取或设置 血脂
        /// </summary>
        public string BloodFat { get; set; }

        /// <summary>
        /// 获取或设置 血糖
        /// </summary>
        public string BoolSugar { get; set; }

        /// <summary>
        /// 获取或设置 体脂
        /// </summary>
        public string BodyFat { get; set; }

        /// <summary>
        /// 获取或设置 心电
        /// </summary>
        public string Heart { get; set; }

        /// <summary>
        /// 获取或设置 肺活仪
        /// </summary>
        public string Lung { get; set; }

        /// <summary>
        /// 获取或设置 血压
        /// </summary>
        public string Nibp { get; set; }

        /// <summary>
        /// 获取或设置 血氧饱和
        /// </summary>
        public string Spo2 { get; set; }

        /// <summary>
        /// 获取或设置 体温
        /// </summary>
        public string Temp { get; set; }

        /// <summary>
        /// 获取或设置 12导联心电
        /// </summary>
        public string TwelveHeart { get; set; }

        /// <summary>
        /// 获取或设置 尿液分析仪
        /// </summary>
        public string Urine { get; set; }

        /// <summary>
        /// 获取或设置 体重身高比
        /// </summary>
        public string Weight { get; set; }

        /// <summary>
        /// 获取或设置 腰臀比
        /// </summary>
        public string WHB { get; set; }
    }

    public class VNoteHealthData
    {
        public string PatientNo { get; set; }
        public string CreatedTime { get; set; }
        public string RegistTime { get; set; }
        public string Name { get; set; }
        public string CardNo { get; set; }
        public string Gender { get; set; }
        public string Age { get; set; }
        public string BirthDay { get; set; }
        public string National { get; set; }
        public string Address { get; set; }

        /// <summary>
        /// 获取或设置 血脂
        /// </summary>
        public string BloodFat { get; set; }

        /// <summary>
        /// 获取或设置 血糖
        /// </summary>
        public string BoolSugar { get; set; }

        /// <summary>
        /// 获取或设置 体脂
        /// </summary>
        public string BodyFat { get; set; }

        /// <summary>
        /// 获取或设置 心电
        /// </summary>
        public string Heart { get; set; }

        /// <summary>
        /// 获取或设置 肺活仪
        /// </summary>
        public string Lung { get; set; }

        /// <summary>
        /// 获取或设置 血压
        /// </summary>
        public string Nibp { get; set; }

        /// <summary>
        /// 获取或设置 血氧饱和
        /// </summary>
        public string Spo2 { get; set; }

        /// <summary>
        /// 获取或设置 体温
        /// </summary>
        public string Temp { get; set; }

        /// <summary>
        /// 获取或设置 12导联心电
        /// </summary>
        public string TwelveHeart { get; set; }

        /// <summary>
        /// 获取或设置 尿液分析仪
        /// </summary>
        public string Urine { get; set; }

        /// <summary>
        /// 获取或设置 体重身高比
        /// </summary>
        public string Weight { get; set; }

        /// <summary>
        /// 获取或设置 腰臀比
        /// </summary>
        public string WHB { get; set; }
    }
    
    public class VNoteRecordDto
    {
        public VNotePatient Regist { get; set; }

        public VNoteDiagnosisData Detail { get; set; }
    }
}