using System.Collections.Generic;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Enum.NotificationEnum;
using WingInterfaceLibrary.LiveConsultation.Consultation;
using WingInterfaceLibrary.Notifications;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.LiveConsultation
{
    /// <summary>
    /// 接受会诊请求实体
    /// </summary>
    public class AcceptLiveConsultationRequest : TokenRequest
    {
        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;
        
        /// <summary>
        /// 仅验证，接受会诊前验证
        /// </summary>
        /// <value>false</value>
        /// <code>0</code>
        public bool CheckOnly { get; set; }
    }

    /// <summary>
    /// 接受会诊响应实体
    /// </summary>
    public class AcceptLiveConsultationResult
    {
        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;

        /// <summary>
        /// 用户编码
        /// </summary>
        /// <value>UserDO_123456789</value>
        public string UserCode { get; set; } = string.Empty;

        /// <summary>
        /// Room No. 
        /// </summary>
        /// <value></value>
        public int RoomNo { get; set; }
        
        /// <summary>
        /// 直播协议：TRTC、VRTC、Embedded
        /// </summary>
        /// <value>TRTC</value>
        public TransactionStatusEnum LiveProtocol { get; set; }

        /// <summary>
        /// Sdk app id
        /// </summary>
        /// <value></value>
        public int AppId { get; set; }

        /// <summary>
        /// User sign for rtc
        /// </summary>
        /// <value>123456</value>
        public string UserSign { get; set; } = string.Empty;

        public IList<LiveConsultationMember> MemberLiveDatas { get; set; } = new List<LiveConsultationMember>();

        /// <summary>
        /// 互动白板数据集合
        /// </summary>
        /// <typeparam name="InteractiveBoardDataDTO"></typeparam>
        /// <returns></returns>
        public IList<InteractiveBoardDataDTO> InteractiveBoardDatas { get; set; } = new List<InteractiveBoardDataDTO>();
    }
    /// <summary>
    /// 接受会诊通知
    /// </summary>
    /// <notificationDocFirstDirectory>通知服务</notificationDocFirstDirectory>
    /// <notificationDocSecondDirectory>客户端</notificationDocSecondDirectory>
    ///<notificationDocThirdDirectory>会诊</notificationDocThirdDirectory>
    public class AcceptLiveConsultationNotification : NotificationDTO
    {
        /// <summary>
        /// 通知类型枚举 接受会诊的通知
        /// </summary>
        /// <value>12</value>
        public override NotificationTypeEnum NotificationType => NotificationTypeEnum.AcceptLiveConsultationNotification;

        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;

        /// <summary>
        /// 会诊接受方信息
        /// </summary>
        /// <value></value>
        public LiveConsultatioAccepterInfo Accepter { get; set; }
    }
}
