using WingInterfaceLibrary.Request;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum.NotificationEnum;
using WingInterfaceLibrary.Notifications;

namespace WingInterfaceLibrary.LiveConsultation
{
    /// <summary>
    /// 取消会诊请求实体
    /// </summary>
    public class CancelLiveConsultationRequest : TokenRequest
    {
        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;
    }

    /// <summary>
    /// 取消会诊响应实体
    /// </summary>
    public class CancelLiveConsultationResult
    {
        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;
    }

    /// <summary>
    /// 取消会诊通知
    /// </summary>
    /// <notificationDocFirstDirectory>通知服务</notificationDocFirstDirectory>
    /// <notificationDocSecondDirectory>客户端</notificationDocSecondDirectory>
    ///<notificationDocThirdDirectory>会诊</notificationDocThirdDirectory>
    public class CancelLiveConsultationNotification : NotificationDTO
    {
        /// <summary>
        /// 通知类型枚举 结束会诊提醒通知
        /// </summary>
        /// <value>15</value>
        public override NotificationTypeEnum NotificationType => NotificationTypeEnum.CancelLiveConsultationNotification;

        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;

        /// <summary>
        /// 发起方编码
        /// </summary>
        /// <value>UserCode_123456789</value>
        public string InitiatorCode { get; set; }
    }

    /// <summary>
    /// 结束会诊通知
    /// </summary>
    /// <notificationDocFirstDirectory>通知服务</notificationDocFirstDirectory>
    /// <notificationDocSecondDirectory>客户端</notificationDocSecondDirectory>
    ///<notificationDocThirdDirectory>会诊</notificationDocThirdDirectory>
    public class CloseLiveConsultationNotification : NotificationDTO
    {

        /// <summary>
        /// 通知类型枚举 结束会诊提醒通知
        /// </summary>
        /// <value>16</value>
        public override NotificationTypeEnum NotificationType => NotificationTypeEnum.CloseLiveConsultationNotification;

        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;

        /// <summary>
        /// 发起方编码
        /// </summary>
        /// <value>UserCode_23</value>
        public string InitiatorCode { get; set; }
    }




}
