using System.Collections.Generic;
using WingInterfaceLibrary.Enum.NotificationEnum;
using WingInterfaceLibrary.Notifications;
using WingInterfaceLibrary.Request;
namespace WingInterfaceLibrary.LiveConsultation
{
    /// <summary>
    /// 切换会诊房间请求实体
    /// </summary>
    public class ChangeConsultationRequest : TokenRequest
    {
        /// <summary>
        /// 原先的会诊编码
        /// </summary>
        /// <value>GUID</value>
        public string OriginalCode { get; set; } = string.Empty;

        /// <summary>
        /// 新的会诊编码
        /// </summary>
        /// <value>GUID</value>
        public string CurrentCode { get; set; } = string.Empty;
    }

    /// <summary>
    /// 切换会诊房间响应实体
    /// </summary>
    public class ChangeConsultationResult
    {
        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;

        /// <summary>
        /// 发起人编码
        /// </summary>
        /// <value>UserDO_123456789</value>
        public string InitiatorCode { get; set; } = string.Empty;

        /// <summary>
        /// Room No. 
        /// </summary>
        /// <value></value>
        public int RoomNo { get; set; }

        /// <summary>
        /// 会诊房间成员集合
        /// </summary>
        /// <typeparam name="LiveConsultationMember"></typeparam>
        /// <returns></returns>
        public IList<LiveConsultationMember> MemberLiveDatas { get; set; } = new List<LiveConsultationMember>();
    }

    /// <summary>
    ///切换会诊房间通知
    /// </summary>
    /// <notificationDocFirstDirectory>通知服务</notificationDocFirstDirectory>
    /// <notificationDocSecondDirectory>客户端</notificationDocSecondDirectory>
    ///<notificationDocThirdDirectory>会诊</notificationDocThirdDirectory>
    public class ChangeConsultationNotification : NotificationDTO
    {
        /// <summary>
        /// 通知类型枚举 拒绝会诊的通知
        /// </summary>
        /// <value>52</value>
        public override NotificationTypeEnum NotificationType => NotificationTypeEnum.ChangeConsultationNotification;

        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;

        /// <summary>
        /// Room No. 
        /// </summary>
        /// <value></value>
        public int RoomNo { get; set; }

        /// <summary>
        /// 会诊房间成员集合
        /// </summary>
        /// <typeparam name="LiveConsultationMember"></typeparam>
        /// <returns></returns>
        public IList<LiveConsultationMember> MemberLiveDatas { get; set; } = new List<LiveConsultationMember>();
    }

    /// <summary>
    ///切换会诊房间通知
    /// </summary>
    /// <notificationDocFirstDirectory>通知服务</notificationDocFirstDirectory>
    /// <notificationDocSecondDirectory>设备端</notificationDocSecondDirectory>
    ///<notificationDocThirdDirectory>会诊</notificationDocThirdDirectory>
    public class ChangeConsultationToDeviceNotification : NotificationDTO
    {
        /// <summary>
        /// 通知类型枚举 拒绝会诊的通知
        /// </summary>
        /// <value>53</value>
        public override NotificationTypeEnum NotificationType => NotificationTypeEnum.ChangeConsultationToDeviceNotification;

        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;

        /// <summary>
        /// Room No. 
        /// </summary>
        /// <value></value>
        public int RoomNo { get; set; }

        /// <summary>
        /// 会诊房间成员集合
        /// </summary>
        /// <typeparam name="LiveConsultationMember"></typeparam>
        /// <returns></returns>
        public IList<LiveConsultationMember> MemberLiveDatas { get; set; } = new List<LiveConsultationMember>();
    }

    /// <summary>
    /// 更改调参状态请求实体
    /// </summary>
    public class ChangeConsultationControllingStateRequest : TokenRequest
    {
        /// <summary>
        /// 设备code
        /// </summary>
        /// <value>device_1234356</value>
        public string DeviceCode { get; set; }

        /// <summary>
        /// 用户code
        /// </summary>
        /// <value>user_1234356</value>
        public string UserCode { get; set; }

        /// <summary>
        /// 是否调参中
        /// </summary>
        /// <value>false</value>
        public bool IsControllingParameter { get; set; }

    }

}
