using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.LiveConsultation.Enums;
using WingInterfaceLibrary.DTO.Consultation;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Notifications;
using WingInterfaceLibrary.Enum.NotificationEnum;

namespace WingInterfaceLibrary.LiveConsultation.Consultation
{
    /// <summary>
    /// 发送互动白板数据请求
    /// </summary>
    public class SendInteractiveBoardDataRequest : TokenRequest
    {
        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;

        /// <summary>
        /// 是否清除
        /// </summary>
        /// <value></value>
        public bool IsClear { get; set; }

        /// <summary>
        /// 互动白板数据
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public string BoardData { get; set; }
    }

    /// <summary>
    /// 互动白板数据通知
    /// </summary>
    /// <notificationDocFirstDirectory>通知服务</notificationDocFirstDirectory>
    /// <notificationDocSecondDirectory>客户端</notificationDocSecondDirectory>
    ///<notificationDocThirdDirectory>会诊</notificationDocThirdDirectory>
    public class SendInteractiveBoardDataNotification : NotificationDTO
    {
        /// <summary>
        /// 通知类型枚举 互动白板数据通知
        /// </summary>
        /// <value>1</value>
        public override NotificationTypeEnum NotificationType => NotificationTypeEnum.SendInteractiveBoardDataNotification;

        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;

        /// <summary>
        /// 是否清除
        /// </summary>
        /// <value></value>
        public bool IsClear { get; set; }

        /// <summary>
        /// 用户编码
        /// </summary>
        /// <value></value>
        public string UserCode { get; set; }

        /// <summary>
        /// 互动白板数据
        /// </summary>
        /// <value></value>
        public string BoardData { get; set; }
    }

    /// <summary>
    /// 互动白板数据实体
    /// </summary>
    public class InteractiveBoardDataDTO
    {
        /// <summary>
        /// 用户编码
        /// </summary>
        /// <value></value>
        public string UserCode { get; set; }

        /// <summary>
        /// 互动白板数据
        /// </summary>
        public string BoardData { get; set; }

        /// <summary>
        /// 互动时间
        /// </summary>
        /// <value></value>
        public DateTime InteractiveTime { get; set; }
    }
}