using System;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Common;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.LiveConsultation.Enums;
namespace WingInterfaceLibrary.LiveConsultation.Consultation
{
    /// <summary>
    /// 修改会诊请求实体
    /// </summary>
    public class UpdateConsultationRequest : TokenRequest
    {
        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value></value>
        public string ConsultationCode { get; set; } = string.Empty;

        /// <summary>
        /// 会诊专家编码
        /// </summary>
        /// <value>UserDO_123456789</value>
        public string ExpertUserCode { get; set; } = string.Empty;

        /// <summary>
        /// 设备编码
        /// </summary>
        /// <value>DeviceDO_123456789</value>
        public string DeviceCode { get; set; } = string.Empty;

        /// <summary>
        /// 检查部位
        /// </summary>
        /// <value>肝脏 附件</value>        
        /// <code>0</code>
        public List<string> ScanPositions { get; set; }

        /// <summary>
        /// 期望会诊时间
        /// </summary>
        /// <value>2022-09-30 14:00:00</value>
        public DateTime ConsultationTime { get; set; } = DateTime.UtcNow.Date;

        /// <summary>
        /// 疾病名称
        /// </summary>
        /// <value>脂肪肝</value>
        public string Diseases { get; set; } = string.Empty;

        /// <summary>
        /// 扫查医生编码
        /// </summary>
        /// <value>UserDO_123456789</value>
        public string ScanUserCode { get; set; } = string.Empty;

        /// <summary>
        /// 会诊机构编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ExpertOrganizationCode { get; set; } = string.Empty;

        /// <summary>
        /// 申请人编码
        /// </summary>
        /// <value>UserDO_123456789</value>
        public string ApplyUserCode { get; set; } = string.Empty;

        /// <summary>
        /// 初步诊断
        /// </summary>
        /// <value>初步诊断结论</value>     
        /// <code>0</code>
        public string PrimaryDiagnosis { get; set; } = string.Empty;
    }
}