using System.Collections.Generic;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Enum.NotificationEnum;
using WingInterfaceLibrary.Notifications;

namespace WingInterfaceLibrary.LiveConsultation
{
    /// <summary>
    /// 输出画面集合
    /// </summary>
    public class VideoDeviceOutputInfo
    {
        /// <summary>
        /// 设备Id（比如超声机唯一码，用来表示这是超声机画面）
        /// </summary>
        /// <value>321</value>
        public string VideoDeviceId { get; set; }

        /// <summary>
        /// 视屏画面设备来源的类型（设备主屏或摄像头）
        /// </summary>
        /// <value>1</value>
        public VideoDeviceSourceTypeEnum VideoDeviceSourceType { get; set; }

        /// <summary>
        /// 设备设置的画面宽度
        /// </summary>
        /// <value>1920</value>
        public int OutputWidth { get; set; }

        /// <summary>
        /// 设备设置的画面高度
        /// </summary>
        /// <value>1080</value>
        public int OutputHeight { get; set; }

        /// <summary>
        /// 帧率
        /// </summary>
        /// <value></value>
        public int VideoFps { get; set; } = 20;

        /// <summary>
        /// 码率
        /// </summary>
        /// <value></value>
        public int VideoBitrate { get; set; } = 2000;

        /// <summary>
        /// 最小码率
        /// </summary>
        /// <value></value>
        public int MinVideoBitrate { get; set; } = 1000;

        /// <summary>
        /// 设备签名
        /// </summary>
        /// <value>SignCode</value>
        public string VideoDeviceSign { get; set; } = string.Empty;

        /// <summary>
        ///视频数据流信息
        /// </summary>
        /// <value></value>
        public LiveData LiveData { get; set; }
    }
}