
using WingInterfaceLibrary.Enum;
using System.Collections.Generic;

namespace WingInterfaceLibrary.LiveConsultation
{
    /// <summary>
    /// 会诊通知成员信息
    /// </summary>
    public abstract class LiveConsultationMemberInfo
    {
        /// <summary>
        /// 用户或者设备编码
        /// </summary>
        /// <value>test id</value>
        public string Id { get; set; }

        /// <summary>
        /// 用户或者设备名称
        /// </summary>
        /// <value>TestName</value>
        public string Name { get; set; }

        /// <summary>
        /// 用户或者设备头像地址
        /// </summary>
        /// <value>Url</value>
        public string HeadImageUrl { get; set; }
    }

    /// <summary>
    /// 会诊接受方信息
    /// </summary>
    public class LiveConsultatioAccepterInfo : LiveConsultationMemberInfo
    {
        /// <summary>
        ///是否在线
        /// </summary>
        /// <value>true</value>
        public bool IsOnline { get; set; }

        /// <summary>
        ///是否静音
        /// </summary>
        /// <value>false</value>
        public bool Mute { get; set; }

        /// <summary>
        /// 是否开启视频
        /// </summary>
        /// <value>true or false</value>
        public bool VideoOpend { get; set; }
        /// <summary>
        /// 登录类型
        /// </summary>
        /// <value>1</value>
        public LoginSource LoginSource { get; set; }

        /// <summary>
        /// 视频流信息
        /// </summary>
        /// <value></value>
        public LiveData LiveData { get; set; }

    }

    public class LiveConsultationRejecterInfo : LiveConsultationMemberInfo
    {

    }
    /// <summary>
    /// 会诊加入人信息
    /// </summary>
    public class LiveConsultationJoinerInfo : LiveConsultationMemberInfo
    {
        /// <summary>
        /// 是否在线
        /// </summary>
        /// <value>true</value>
        public bool IsOnline { get; set; }

        /// <summary>
        /// 是否静音
        /// </summary>
        /// <value>false</value>
        public bool Mute { get; set; }

        /// <summary>
        /// 是否开启视频
        /// </summary>
        /// <value>true or false</value>
        public bool VideoOpend { get; set; }

        /// <summary>
        /// 是否发起者
        /// </summary>
        /// <value>true</value>
        public bool IsInitiator { get; set; }

        /// <summary>
        ///登录方式
        /// </summary>
        /// <value>1</value>        
        public LoginSource LoginSource { get; set; }

        /// <summary>
        /// 视频流信息
        /// </summary>
        /// <value></value>
        public LiveData LiveData { get; set; }
        
        /// <summary>
        /// 参与人员位序
        /// </summary>
        /// <value></value>
        public int SortNumber { get; set; }
        
        /// <summary>
        /// 排序等级
        /// </summary>
        /// <value></value>
        public int SortLevel { get; set; }

        /// <summary>
        /// 会诊设备信息
        /// </summary>
        /// <value></value>
        public LiveConsultationJoinDeviceInfo ConsultationDeviceInfo  { get; set; }

        /// <summary>
        /// 是否老平台
        /// </summary>
        /// <value>true</value>
        public bool IsOldPlatform { get; set; }

        /// <summary>
        /// 是否支持Rtc
        /// </summary>
        /// <value></value>
        public bool SupportRtc { get; set; }
    }

    /// <summary>
    /// 会诊加入设备信息
    /// </summary>
    public class LiveConsultationJoinDeviceInfo 
    {       
        /// <summary>
        /// 直播协议：TRTC、VRTC、Embedded
        /// </summary>
        /// <value>TRTC</value>
        public TransactionStatusEnum LiveProtocol { get; set; }

        /// <summary>
        /// Sdk APP Id
        /// </summary>
        /// <value>2</value>
        public int AppId { get; set; }

        /// <summary>
        /// 是否把多路视屏合流
        /// </summary>
        /// <value>true</value>
        public bool MergedChannel { get; set; }

        /// <summary>
        /// 合流的画面宽度
        /// </summary>
        /// <value>1920</value>
        public int MergedVideoOutputWidth { get; set; }

        /// <summary>
        /// 合流的画面高度
        /// </summary>
        /// <value>1080</value>
        public int MergedVideoOutputHeight { get; set; }

        /// <summary>
        /// 多路画面时，设备输出信息
        /// </summary>
        /// <value></value>
        public IList<VideoDeviceOutputInfo> VideoDeviceOutputList { get; set; }
        
        /// <summary>
        /// 设备编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string DeviceCode { get; set; } = string.Empty;
        
        /// <summary>
        /// 设备签名
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string DeviceSign { get; set; } = string.Empty;

        /// <summary>
        /// 是否老平台
        /// </summary>
        /// <value>true</value>
        public bool IsOldPlatform { get; set; }

        /// <summary>
        /// 是否支持Rtc
        /// </summary>
        /// <value></value>
        public bool SupportRtc { get; set; }
    }

    public class LiveConsultationNetworkErrMemberInfo : LiveConsultationMemberInfo
    {
    }

    public class LiveConsultationLeaverInfo : LiveConsultationMemberInfo
    {
    }

    public class LiveConsultationMuterInfo : LiveConsultationMemberInfo
    {

    }

    public class LiveConsultationSwitcherInfo : LiveConsultationMemberInfo
    {

    }


}
