using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Device;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.LiveConsultation
{
    /// <summary>
    /// 上报设备画面尺寸相关信息请求实体
    /// </summary>
    public class ReportVideoDeviceInfoRequest : TokenRequest
    {
        /// <summary>
        /// 直播开关，true=开启，false=关闭
        /// </summary>
        /// <value></value>
        public bool LiveOpened { get; set; }

        /// <summary>
        /// 是否支持Rtc
        /// </summary>
        /// <value></value>
        public bool SupportRtc { get; set; }

        /// <summary>
        /// 是否支持合流
        /// </summary>
        /// <value></value>
        public bool MergedChannel { get; set; }

        /// <summary>
        /// 远程维护开关
        /// </summary>
        /// <value></value>
        public bool RemoteControlOpened { get; set; }

        /// <summary>
        /// 视屏设备画面信息
        /// </summary>
        /// <value></value>
        public IList<VideoDeviceInfo> VideoDeviceInfos { get; set; }

        /// <summary>
        /// update时使用sync类型的
        /// </summary>
        /// <value></value>
        public bool IsSync { get; set; } = false;
    }

    /// <summary>
    /// 视屏设备画面信息
    /// </summary>
    public class VideoDeviceInfo
    {
        /// <summary>
        /// 设备Id（比如超声机唯一码，用来表示这是超声机画面）
        /// </summary>
        /// <value></value>
        public string VideoDeviceId { get; set; }

        /// <summary>
        /// 视屏画面设备来源的类型（设备主屏或摄像头）
        /// </summary>
        /// <value></value>
        public VideoDeviceSourceTypeEnum VideoDeviceSourceType { get; set; }

        /// <summary>
        /// 设备设置的画面宽度
        /// </summary>
        /// <value></value>
        public int Width { get; set; }

        /// <summary>
        /// 设备设置的画面高度
        /// </summary>
        /// <value></value>
        public int Height { get; set; }

        /// <summary>
        /// 帧率
        /// </summary>
        /// <value></value>
        public int VideoFps { get; set; } = 20;

        /// <summary>
        /// 码率
        /// </summary>
        /// <value></value>
        public int VideoBitrate { get; set; } = 2000;

        /// <summary>
        /// 最小码率
        /// </summary>
        /// <value></value>
        public int MinVideoBitrate { get; set; } = 1000;
    }

    /// <summary>
    /// 上报设备画面尺寸相关信息请求结果
    /// </summary>
    public class ReportVideoDeviceInfoResult
    {
        /// <summary>
        /// 是否成功
        /// </summary>
        /// <value>true</value>
        public bool Success { get; set; }

        /// <summary>
        /// 设备输出尺寸信息
        /// </summary>
        /// <typeparam name="VideoDeviceDTO"></typeparam>
        /// <returns></returns>
        public List<VideoDeviceDTO> VideoDeviceOutputInfos { get; set; } = new List<VideoDeviceDTO>();
    }

}