using WingInterfaceLibrary.DTO.Comment;
using WingInterfaceLibrary.DTO.Measure;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Enum.NotificationEnum;
using WingInterfaceLibrary.Notifications;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.LiveConsultation
{
    /// <summary>
    /// 机器端上传会诊图像数据
    /// </summary>
    public class UploadConsultationDataRequest : TokenRequest
    {
        /// <summary>
        /// 会诊code
        /// </summary>
        /// <value>test</value>
        public string ConsultationCode { get; set; }

        /// <summary>
        /// 预览图地址token
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public string PreviewFileToken { get; set; }

        /// <summary>
        /// 高清图token
        /// </summary>
        /// <value>filetoken</value>
        public string FileToken { get; set; }

        /// <summary>
        /// 高清图文件大小
        /// </summary>
        /// <value>5832772</value>
        public long FileSize { get; set; }

        /// <summary>
        /// 第一帧大图token
        /// </summary>
        public string CoverImageToken { get; set; }

        /// <summary>
        /// ApplicationCategory
        /// </summary>
        /// <value>ABD</value>
        public string ApplicationCategory { get; set; }

        /// <summary>
        /// Application Name
        /// </summary>
        /// <value>Abd General</value>
        /// <code>0</code>
        public string Application { get; set; }

        /// <summary>
        /// 文件数据类型
        /// </summary>
        /// <value>0</value>
        public RemedicalFileDataTypeEnum FileDataType { get; set; }

        /// <summary>
        /// 测量结果数据
        /// </summary>
        /// <value></value>
        ///  <code>0</code>
        public MeasuredResultsDTO MeasuredResult { get; set; }
        /// <summary>
        /// 注释结果数据
        /// </summary>
        /// <value></value>
        ///  <code>0</code>
        public ScanImageDTO CommentResult { get; set; }

    }

    /// <summary>
    /// 会诊截图通知
    /// </summary>
    /// <notificationDocFirstDirectory>通知服务</notificationDocFirstDirectory>
    /// <notificationDocSecondDirectory>客户端</notificationDocSecondDirectory>
    ///<notificationDocThirdDirectory>会诊</notificationDocThirdDirectory>
    public class UploadConsultationDataNotification : NotificationDTO
    {
        /// <summary>
        /// 通知类型枚举 接受会诊的通知
        /// </summary>
        /// <value>12</value>
        public override NotificationTypeEnum NotificationType => NotificationTypeEnum.UploadConsultationDataNotification;

        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;

        /// <summary>
        /// 上传人UserCode
        /// </summary>
        /// <value>xxx</value>
        public string UserCode { get; set; } = string.Empty;
    }
}