using System.Collections.Generic;
using WingInterfaceLibrary.Enum.NotificationEnum;
using WingInterfaceLibrary.DTO.Device;

namespace WingInterfaceLibrary.Notifications
{
    /// <summary>
    /// 发送远程维护结果给客户端
    /// </summary>
    /// <notificationDocFirstDirectory>通知服务</notificationDocFirstDirectory>
    /// <notificationDocSecondDirectory>客户端</notificationDocSecondDirectory>
    /// <notificationDocThirdDirectory>远程维护</notificationDocThirdDirectory> 
    public class SendResultToClientNotification : NotificationDTO
    {
        /// <summary>
        /// This property returns the type of notification that this class sends.
        /// </summary>
        /// <value>SendResultToClientNotification| 79 | 发送远程维护结果到客户端</value>
        public override NotificationTypeEnum NotificationType => NotificationTypeEnum.SendResultToClientNotification;

        /// <summary>
        /// 结果编码
        /// </summary>
        /// <value></value>
        public string ResultCode { get; set; }

        /// <summary>
        /// Sender
        /// </summary>
        public string Sender { get; set; }
    }

    /// <summary>
    /// 系统设置保存并退出发送结果给客户端
    /// </summary>
    /// <notificationDocFirstDirectory>通知服务</notificationDocFirstDirectory>
    /// <notificationDocSecondDirectory>客户端</notificationDocSecondDirectory>
    /// <notificationDocThirdDirectory>远程维护</notificationDocThirdDirectory> 
    public class SystemSettingSaveAndExitToClientNotification : NotificationDTO
    {
        /// <summary>
        /// This property returns the type of notification that this class sends.
        /// </summary>
        /// <value>SystemSettingSaveAndExitToClientNotification| 101 | 系统设置保存并退出结果通知 to 客户端，等到这个通知，页面才能关闭</value>
        public override NotificationTypeEnum NotificationType => NotificationTypeEnum.SystemSettingSaveAndExitToClientNotification;

        /// <summary>
        /// 结果编码
        /// </summary>
        /// <value></value>
        public string ResultCode { get; set; }

        /// <summary>
        /// Sender
        /// </summary>
        public string Sender { get; set; }
    }
}