using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Enum.NotificationEnum;

namespace WingInterfaceLibrary.Notifications.AppletAPI
{
    /// <summary>
    /// 会诊过程中成员变化通知通知
    /// </summary>
    /// <notificationDocFirstDirectory>通知服务</notificationDocFirstDirectory>
    /// <notificationDocSecondDirectory>小程序</notificationDocSecondDirectory>
    ///<notificationDocThirdDirectory>会诊</notificationDocThirdDirectory> 
    public class MeetingMemberNotification : NotificationDTO
    {
        /// <summary>
        /// 通知类型枚举 会诊过程中成员变化通知通知
        /// </summary>
        /// <value>89</value>
        public override NotificationTypeEnum NotificationType => NotificationTypeEnum.MeetingMemberNotification;

        /// <summary>
        /// 会诊房间Id
        /// </summary>
        public string RoomId { get; set; }

        /// <summary>
        /// 会诊成员变化集合
        /// </summary>
        public IList<MeetingMemberInfo> Members { get; set; }

        /// <summary>
        ///会诊设备成员变化集合
        /// </summary>
        public IList<LiveTerminalInfo> LiveTerminals { get; set; }

    }

    public class MeetingMemberInfo
    {
        public string RoomId { get; set; }

        ///<summary>
        ///if OperationType.Delete, state is HangupReason, 
        ///HeartBeatDown: 异常/心跳超时 退出
        ///InitiativeExit: 主动退出
        ///Cancelled: 发起者取消会诊
        /// </summary>
        public LiveStates State { get; set; }

        public string Id { get; set; }

        public string DisplayName { get; set; }

        public string Avatar { get; set; }

        /// <summary>
        /// User Sign (From TRTC)
        /// </summary>
        public string UserSign { get; set; }

    }

    public class LiveTerminalInfo
    {

        public string Id { get; set; }

        /// <summary>
        /// The Uique integer id
        /// </summary>

        public string RoomId { get; set; }
        /// <summary>
        /// The Uique integer id
        /// </summary>

        public int IntegerRoomId { get; set; }

        /// <summary>
        /// Live state
        /// </summary>
        public LiveStates State { get; set; }

        /// <summary>
        /// Terminal pull url
        /// </summary>
        public string TerminalUrl { get; set; }

        /// <summary>
        /// Camera pull url
        /// </summary>
        public string CameraUrl { get; set; }

        /// <summary>
        /// Indicates terminal live enabled
        /// </summary>
        public bool TerminalLiveEnabled { get; set; }

        /// <summary>
        /// Indicates camera live enabled
        /// </summary>
        public bool CameraLiveEnabled { get; set; }

        /// <summary>
        /// Is merge living channel
        /// </summary>
        public bool IsMergeChannel { get; set; }

        /// <summary>
        /// Terminal screen width
        /// </summary>
        public int TerminalWidth { get; set; }

        /// <summary>
        /// Terminal screen height
        /// </summary>
        public int TerminalHeight { get; set; }

        /// <summary>
        /// Camera width
        /// </summary>
        public int CameraWidth { get; set; }

        /// <summary>
        /// Camera height
        /// </summary>
        public int CameraHeight { get; set; }

        /// <summary>
        /// Gets or sets terminal room integer id
        /// </summary>
        public int TerminalIntegerRoomId { get; set; }

        /// <summary>
        /// 是否是多路 新盒子
        /// </summary>
        public bool IsMultiChannels { get; set; }

        /// <summary>
        /// 直播拉流通道数组
        /// </summary>
        public IList<PullChannelUrl> Channels { get; set; }

    }

    /// <summary>
    /// 拉流通道信息
    /// </summary>
    public class PullChannelUrl
    {
        /// <summary>
        /// 拉流RTMP格式播放地址
        /// </summary>
        public string RtmpUrl { get; set; }

        /// <summary>
        /// 拉流FLv格式播放地址
        /// </summary>
        public string FlvUrl { get; set; }

        /// <summary>
        /// 拉流Hls格式播放地址
        /// </summary>
        public string HlsUrl { get; set; }

        /// <summary>
        /// 宽度分辨率
        /// </summary>
        public int Width { get; set; }

        /// <summary>
        /// 高度分辨率
        /// </summary>
        public int Height { get; set; }

        /// <summary>
        /// 名称
        /// </summary>
        public string Name { get; set; }

        /// <summary>
        /// 是否有效
        /// </summary>
        public bool Enable { get; set; }

        /// <summary>
        /// UserId
        /// </summary>
        public string UserId { get; set; }

    }

    /// <summary>
    /// 挂断通知
    /// </summary>
    /// <notificationDocFirstDirectory>通知服务</notificationDocFirstDirectory>
    /// <notificationDocSecondDirectory>小程序</notificationDocSecondDirectory>
    ///<notificationDocThirdDirectory>会诊</notificationDocThirdDirectory> 
    public class MeetingHangupNotification : NotificationDTO
    {
        /// <summary>
        /// 通知类型枚举 挂断通知
        /// </summary>
        /// <value>90</value>
        public override NotificationTypeEnum NotificationType => NotificationTypeEnum.MeetingHangupNotification;

        ///<summary>
        ///HangupReason, 
        ///HeartBeatDown: 异常/心跳超时 退出
        ///InitiativeExit: 主动退出
        ///Cancelled: 发起者取消会诊
        /// </summary>
        public LiveStates HangupReason { get; set; }

        /// <summary>
        ///房间 id
        /// </summary>
        public string RoomId { get; set; }

    }

    /// <summary>
    /// 拒绝通知
    /// </summary>
    /// <notificationDocFirstDirectory>通知服务</notificationDocFirstDirectory>
    /// <notificationDocSecondDirectory>小程序</notificationDocSecondDirectory>
    ///<notificationDocThirdDirectory>会诊</notificationDocThirdDirectory> 
    public class RejectMeetingNotification : NotificationDTO
    {
        /// <summary>
        /// 通知类型枚举 拒绝通知
        /// </summary>
        /// <value>91</value>
        public override NotificationTypeEnum NotificationType => NotificationTypeEnum.RejectMeetingNotification;

        /// <summary>
        /// 用户id
        /// </summary>
        /// <value></value>
        public string UserId { get; set; }

        /// <summary>
        ///房间 id
        /// </summary>
        public string RoomId { get; set; }

    }

    /// <summary>
    /// 发起者收到对方接受通知
    /// </summary>
    /// <notificationDocFirstDirectory>通知服务</notificationDocFirstDirectory>
    /// <notificationDocSecondDirectory>小程序</notificationDocSecondDirectory>
    ///<notificationDocThirdDirectory>会诊</notificationDocThirdDirectory> 
    public class AcceptMeetingNotification : NotificationDTO
    {
        /// <summary>
        /// 通知类型枚举 发起者收到对方接受通知
        /// </summary>
        /// <value>93</value>
        public override NotificationTypeEnum NotificationType => NotificationTypeEnum.AcceptMeetingNotification;

        /// <summary>
        /// The account id who  joined the chat room
        /// </summary>
        /// <value></value>
        public string SubscriberId { get; set; }

        /// <summary>
        ///房间 id
        /// </summary>
        public string RoomId { get; set; }

        /// <summary>
        /// 推流状态
        /// </summary>
        public LiveStates PushLiveState { get; set; }

    }

    /// <summary>
    /// 应答超时通知
    /// </summary>
    /// <notificationDocFirstDirectory>通知服务</notificationDocFirstDirectory>
    /// <notificationDocSecondDirectory>小程序</notificationDocSecondDirectory>
    ///<notificationDocThirdDirectory>会诊</notificationDocThirdDirectory> 
    public class MeetingPendingMemberTimeoutNotification : NotificationDTO
    {
        /// <summary>
        /// 通知类型枚举 应答超时通知
        /// </summary>
        /// <value>93</value>
        public override NotificationTypeEnum NotificationType => NotificationTypeEnum.MeetingPendingMemberTimeoutNotification;

        /// <summary>
        /// Room id = coversation id
        /// </summary>
        public string RoomId { get; set; }

        /// <summary>
        /// UserId
        /// </summary>
        public IList<string> UserIds { get; set; }

    }
}