using System.Collections.Generic;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Enum.NotificationEnum;
using WingInterfaceLibrary.Notifications;
using WingInterfaceLibrary.Result.Education;

namespace WingInterfaceLibrary.Notifications.Education
{    
    /// <summary>
    /// 结束直播通知
    /// </summary>
    /// <notificationDocFirstDirectory>通知服务</notificationDocFirstDirectory>
    /// <notificationDocSecondDirectory>客户端</notificationDocSecondDirectory>
    ///<notificationDocThirdDirectory>杏聆荟学院</notificationDocThirdDirectory>
    public class CloseLiveCourseNotification : NotificationDTO
    {

        /// <summary>
        /// 通知类型枚举 结束直播提醒通知
        /// </summary>
        /// <value>47</value>
        public override NotificationTypeEnum NotificationType => NotificationTypeEnum.CloseLiveCourseNotification;

        /// <summary>
        /// 课程编码
        /// </summary>
        /// <value>Course_123456789</value>
        public string CourseCode { get; set; } = string.Empty;

        /// <summary>
        /// 讲师编码[发起方]
        /// </summary>
        /// <value>UserCode_123456789</value>
        public string TeacherCode { get; set; }
    }

    /// <summary>
    /// 关闭课程心跳通知
    /// </summary>
    /// <notificationDocFirstDirectory>通知服务</notificationDocFirstDirectory>
    /// <notificationDocSecondDirectory>设备端</notificationDocSecondDirectory>
    ///<notificationDocThirdDirectory>杏聆荟学院</notificationDocThirdDirectory> 
    public class CloseCourseHeartRateToDeviceNotification : NotificationDTO
    {
        /// <summary>
        /// 通知类型枚举 开始会诊心跳通知
        /// </summary>
        /// <value>96</value>
        public override NotificationTypeEnum NotificationType => NotificationTypeEnum.CloseCourseHeartRateToDeviceNotification;

        /// <summary>
        /// 房间编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string LiveRoomCode { get; set; } = string.Empty;

    }

    /// <summary>
    /// 课程设备直播心跳通知
    /// </summary>
    /// <notificationDocFirstDirectory>通知服务</notificationDocFirstDirectory>
    /// <notificationDocSecondDirectory>设备端</notificationDocSecondDirectory>
    /// <notificationDocThirdDirectory>杏聆荟学院</notificationDocThirdDirectory> 
    public class StartEducationHeartRateToDeviceNotification : NotificationDTO
    {
        /// <summary>
        /// 通知类型枚举 课程设备直播心跳通知
        /// </summary>
        /// <value>92</value>
        public override NotificationTypeEnum NotificationType => NotificationTypeEnum.StartEducationHeartRateToDeviceNotification;

        /// <summary>
        /// 房间编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string LiveRoomCode { get; set; } = string.Empty;

        /// <summary>
        /// 直播协议：TRTC、VRTC、Embedded
        /// </summary>
        /// <value>TRTC</value>
        public TransactionStatusEnum LiveProtocol { get; set; }

        /// <summary>
        /// 心跳间隔时间
        /// </summary>
        /// <value>10</value>
        public int IntervalSeconds { get; set; }

    }
}