using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using WingInterfaceLibrary.Enum.NotificationEnum;
using WingInterfaceLibrary.Interface;

namespace WingInterfaceLibrary.Notifications
{
    /// <summary>
    /// 通知类接口
    /// </summary>
    public interface INotificationDTO
    {
        /// <summary>
        /// 通知类型枚举
        /// </summary>
        ///  <show>false</show>
        NotificationTypeEnum NotificationType { get; }

        /// <summary>
        /// 通知DB中的Code,与DB中Content的json字符串数据Code保持一致
        /// </summary>
        ///  <show>false</show>
        string Code { get; set; }
    }
    public abstract class NotificationDTO : INotificationDTO
    {
        /// <summary>
        /// 通知类型枚举
        /// </summary>
        /// <show>false</show>
        public abstract NotificationTypeEnum NotificationType { get; }

        /// <summary>
        /// 通知DB中的Code
        /// </summary>
        ///  <value>20220823031843Z816kN</value>
        public string Code { get; set; } = Guid.NewGuid().ToString("N");

        /// <summary>
        /// 是否需要回应
        /// </summary>
        /// <value>true</value>
        public bool IsResponse { get; set; }

    }

    /// <summary>
    /// 同步通知客户端账号信息
    /// </summary>
    public class NotificationClientInfo
    {

        /// <summary>
        /// 客户端账号Id
        /// </summary>
        /// <value></value>
        public string ClientId { get; set; }

        /// <summary>
        /// 登录服务器Url
        /// </summary>
        /// <value></value>
        public string LoginServerUrl { get; set; }

        /// <summary>
        /// 指定token
        /// </summary>
        /// <value></value>
        public IList<TokenDTO> Tokens { get; set; }

    }
}