
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Message;
using WingInterfaceLibrary.DTO.RTC;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Enum.NotificationEnum;
using WingInterfaceLibrary.LiveConsultation;

namespace WingInterfaceLibrary.Notifications.Live
{
    /// <summary>
    /// 开始直播通知
    /// </summary>
    /// <notificationDocFirstDirectory>通知服务</notificationDocFirstDirectory>
    /// <notificationDocSecondDirectory>设备端</notificationDocSecondDirectory>
    ///<notificationDocThirdDirectory>直播</notificationDocThirdDirectory> 
    public class StartLiveToDeviceNotification : NotificationDTO
    {
        /// <summary>
        /// 通知类型枚举
        /// </summary>
        /// <value>62</value>
        public override NotificationTypeEnum NotificationType => NotificationTypeEnum.StartLiveToDeviceNotification;  
        
        /// <summary>
        /// 直播房间编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string LiveRoomCode { get; set; } = string.Empty;

        /// <summary>
        /// 房间号码
        /// </summary>
        /// <value>1</value>
        public int RoomNo { get; set; }
        
        /// <summary>
        /// 直播协议：TRTC、VRTC、Embedded
        /// </summary>
        /// <value>TRTC</value>
        public TransactionStatusEnum LiveProtocol { get; set; }

        /// <summary>
        /// Sdk APP Id
        /// </summary>
        /// <value>2</value>
        public int AppId { get; set; }

        /// <summary>
        /// 是否把多路视屏合流
        /// </summary>
        /// <value>true</value>
        public bool MergedChannel { get; set; }

        /// <summary>
        /// 合流的画面宽度
        /// </summary>
        /// <value>1920</value>
        public int MergedVideoOutputWidth { get; set; }

        /// <summary>
        /// 合流的画面高度
        /// </summary>
        /// <value>1080</value>
        public int MergedVideoOutputHeight { get; set; }

        /// <summary>
        /// 多路画面时，设备输出信息
        /// </summary>
        /// <value></value>
        public IList<VideoDeviceOutputInfo> VideoDeviceOutputList { get; set; }
        
        /// <summary>
        /// 设备编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string DeviceCode { get; set; } = string.Empty;
        
        /// <summary>
        /// 设备签名
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string DeviceSign { get; set; } = string.Empty;

        /// <summary>
        /// 发起人编码
        /// </summary>
        /// <value>ub6414d24e3c347d46032b0496f1c4e4</value>
        public string InitiatorCode { get; set; } = string.Empty;
    }
}