using System.Collections.Generic;
using System.Linq;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.Recognition
{
    /// <summary>
    /// 人员搜索 请求
    /// </summary>
    public class SearchPersonsRequest : TokenRequest
    {
        /// <summary>
        /// 人员库ID，唯一标识，正式、测试、不同的项目都应该不同。支持英文、数字、-%@#&_，长度限制64B
        /// </summary>
        /// <value></value>
        public string GroupId { get; set; }
        
        /// <summary>
        /// 人脸文件地址
        /// </summary>
        /// <value></value>
        public string FaceUrl { get; set; }
    }

    /// <summary>
    /// 添人员搜索 响应
    /// </summary>
    public class SearchPersonsResult
    {
        /// <summary>
        /// 是否完成识别
        /// </summary>
        /// <value></value>
        public bool IsSearchSuccess { get; set; }

        /// <summary>
        /// 错误原因，当IsSearchSuccess为false时具体的失败原因
        /// </summary>
        /// <value></value>
        public string ErrMessage { get; set; }

        /// <summary>
        /// 是否识别到人员，当IsSearchSuccess为true时使用
        /// </summary>
        /// <value></value>
        public bool HasPerson => PersonInfo != null;

        /// <summary>
        /// 人员信息
        /// </summary>
        /// <value></value>
        public RecognitionPersonDTO PersonInfo => Persons?.FirstOrDefault();

        /// <summary>
        /// 人脸ID
        /// </summary>
        /// <value></value>
        public List<RecognitionPersonDTO> Persons { get; set; }
    }

    /// <summary>
    /// 人员信息
    /// </summary>
    public class RecognitionPersonDTO
    {
        /// <summary>
        /// 人员ID
        /// </summary>
        /// <value></value>
        public string PersonId { get; set; }

        /// <summary>
        /// 人脸ID
        /// </summary>
        /// <value></value>
        public string FaceId { get; set; }

        /// <summary>
        /// 相似度，一般80分左右可适用大部分场景
        /// </summary>
        /// <value>80</value>
        public float Score { get; set; }
    }
}
