using System.Collections.Generic;

namespace WingInterfaceLibrary.Request.AIDiagnosis
{
    /// <summary>
    /// 小鼠频谱包络请求实体
    /// </summary>
    public class VetAutoTraceImageRequest : TokenRequest
    {
        /// <summary>
        /// 图像信息
        /// </summary>
        /// <value></value>
        public VetAutoTraceImageDTO ImageInfo { get; set; }

        /// <summary>
        /// 矩形框信息
        /// </summary>
        /// <value></value>
        public VetAutoTraceRectDTO RectInfo { get; set; }
    }

    /// <summary>
    /// 图像信息
    /// </summary>
    public class VetAutoTraceImageDTO
    {
        /// <summary>
        /// 图像内容
        /// </summary>
        /// <value></value>
        public byte[] Data { get; set; }
        
        /// <summary>
        /// 图像内容
        /// </summary>
        /// <value></value>
        public string ImageBase64String { get; set; }

        /// <summary>
        /// 宽
        /// </summary>
        /// <value></value>
        public int Width { get; set; }

        /// <summary>
        /// 高
        /// </summary>
        /// <value></value>
        public int Height { get; set; }

        /// <summary>
        /// SkiaSharp-ColorType
        /// </summary>
        /// <value></value>
        public int SKColorType { get; set; }
    }

    /// <summary>
    /// 矩形框信息
    /// </summary>
    public class VetAutoTraceRectDTO
    {
        /// <summary>
        /// Top
        /// </summary>
        /// <value></value>
        public int Top { get; set; }

        /// <summary>
        /// Bottom
        /// </summary>
        /// <value></value>
        public int Bottom { get; set; }

        /// <summary>
        /// Left
        /// </summary>
        /// <value></value>
        public int Left { get; set; }

        /// <summary>
        /// Right
        /// </summary>
        /// <value></value>
        public int Right { get; set; }

        /// <summary>
        /// Width
        /// </summary>
        /// <value></value>
        public int Width { get; set; }

        /// <summary>
        /// Height
        /// </summary>
        /// <value></value>
        public int Height { get; set; }
    }

    /// <summary>
    /// 小鼠频谱包络响应实体
    /// </summary>
    public class VetAutoTraceImageResult
    {
        /// <summary>
        /// 频谱包络信息集合
        /// </summary>
        /// <value></value>
        public Dictionary<string, PWTraceDTO> PWTraceInfos { get; set; } = new Dictionary<string, PWTraceDTO>();
    }

    /// <summary>
    /// 频谱包络信息
    /// </summary>
    public class PWTraceDTO
    {
        /// <summary>
        /// EnableCalCycle
        /// </summary>
        /// <value></value>
        public bool EnableCalCycle { get; set; }

        /// <summary>
        /// 包络频谱的所有轮廓点坐标
        /// </summary>
        /// <value></value>
        public List<PWTracePointDTO> Contour { get; set; } = new List<PWTracePointDTO>();

        /// <summary>
        /// 周期信息
        /// </summary>
        /// <value></value>
        public List<PWTraceCycleDTO> CycleInfos { get; set; } = new List<PWTraceCycleDTO>();

        /// <summary>
        /// 最佳心动周期
        /// </summary>
        /// <value></value>
        public PWTraceBestCycleDTO BestCycles { get; set; } = new PWTraceBestCycleDTO();
    }

    /// <summary>
    /// 包络频谱坐标
    /// </summary>
    public class PWTracePointDTO
    {
        /// <summary>
        /// 2维点坐标的X坐标
        /// </summary>
        /// <value></value>
        public int X { get; set; }

        /// <summary>
        /// 2维点坐标的Y坐标
        /// </summary>
        /// <value></value>
        public int Y { get; set; }
    }

    /// <summary>
    /// 周期信息
    /// </summary>
    public class PWTraceCycleDTO
    {
        /// <summary>
        /// 单个周期起点index
        /// </summary>
        /// <value></value>
        public int CycleStart { get; set; }

        /// <summary>
        /// 单个周期止点index
        /// </summary>
        /// <value></value>
        public int CycleEnd { get; set; }

        /// <summary>
        /// 单个周期波峰index
        /// </summary>
        /// <value></value>
        public int Epeak { get; set; }

        /// <summary>
        /// 单个周期次波峰index
        /// </summary>
        /// <value></value>
        public int Apeak { get; set; }
    }

    /// <summary>
    /// 最佳心动周期
    /// </summary>
    public class PWTraceBestCycleDTO
    {
        public PWTraceBestCycleIndexDTO OneBestCycle { get; set; }
        public PWTraceBestCycleIndexDTO TwoBestCycle { get; set; }
        public PWTraceBestCycleIndexDTO ThreeBestCycle { get; set; }
        public PWTraceBestCycleIndexDTO FourBestCycle { get; set; }
        public PWTraceBestCycleIndexDTO FiveBestCycle { get; set; }
    }

    /// <summary>
    /// 最佳心动周期
    /// </summary>
    public class PWTraceBestCycleIndexDTO
    {        
        /// <summary>
        /// 最佳心动周期起点index
        /// </summary>
        /// <value></value>
        public int BestStart { get; set; }

        /// <summary>
        /// 最佳心动周期止点index
        /// </summary>
        /// <value></value>
        public int BestEnd { get; set; }
    }
}