using System.Collections.Generic;

namespace WingInterfaceLibrary.Request.AIDiagnosis
{
    /// <summary>
    /// 远程图像区域缩放请求实体
    /// </summary>
    public class VidImageZoomRequest : TokenRequest
    {
        /// <summary>
        /// 原始VID文件地址
        /// </summary>
        /// <value></value>
        public string FileToken { get; set; }

        /// <summary>
        /// 图像编码
        /// </summary>
        /// <value></value>
        public string RemedicalCode { get; set; }

        /// <summary>
        /// 第几帧
        /// </summary>
        /// <value></value>
        public int FrameIndex { get; set; }

        /// <summary>
        /// 单幅或双幅超声区域的外接框
        /// </summary>
        /// <value></value>
        public List<ImageRect> ImageRegion { get; set; }

        /// <summary>
        /// 取样框
        /// </summary>
        /// <value></value>
        public ImageRect SampleBox { get; set; }

        /// <summary>
        /// 图像缩放的方式：0：其它；1：双三次插值；2：Lanczos 插值；3：ESPCN模型；4：LapSRN模型
        /// </summary>
        /// <value></value>
        public int ResizeType { get; set; }

    }

    /// <summary>
    /// 远程图像区域缩放响应实体
    /// </summary>
    public class VidImageZoomResult
    {
        /// <summary>
        /// 图像Base64
        /// </summary>
        /// <value></value>
        public string Base64String { get; set; }
    }

    /// <summary>
    /// 单幅或双幅超声区域的外接框
    /// </summary>
    public class ImageRect
    {
        /// <summary>
        /// 矩形框左
        /// </summary>
        /// <value></value>
        public double Left { get; set; }

        /// <summary>
        /// 矩形框上
        /// </summary>
        /// <value></value>
        public double Top { get; set; }

        /// <summary>
        /// 矩形框宽
        /// </summary>
        /// <value></value>
        public double Width { get; set; }

        /// <summary>
        /// 矩形框高
        /// </summary>
        /// <value></value>
        public double Height { get; set; }
    }


    /// <summary>
    /// 取样框
    /// </summary>
    public class ImageGeometry
    {
        /// <summary>
        /// 2维点坐标的X坐标
        /// </summary>
        /// <value></value>
        public double X { get; }

        /// <summary>
        /// 2维点坐标的Y坐标
        /// </summary>
        /// <value></value>
        public double Y { get; }

        /// <summary>
        /// 矩形框宽
        /// </summary>
        /// <value></value>
        public double Width { get; set; }

        /// <summary>
        /// 矩形框高
        /// </summary>
        /// <value></value>
        public double Height { get; set; }
    }
}