using System;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Result.AppletAPI;

namespace WingInterfaceLibrary.Request.AppletAPI
{


    public class AppletAPIBaseRequest
    {
        /// <summary>
        /// openid
        /// </summary>
        /// <value>xxx</value>
        public string OpenId { get; set; }
    }

    public class AppletAPIPageRequest : AppletAPIBaseRequest
    {
        /// <summary>
        /// 页码
        /// </summary>
        /// <value>1</value>
        /// <code>0</code>
        public int PageIndex { get; set; } = 1;

        /// <summary>
        /// 页大小
        /// </summary>
        /// <value>10</value>
        /// <code>0</code>
        public int PageSize { get; set; } = 10;
    }

    /// <summary>
    /// 小程序挂断通知请求对象
    /// </summary>
    public class LiveMemberLeaveRequest : AppletAPIBaseRequest
    {
        /// <summary>
        /// 会诊记录Id
        /// </summary>
        /// <value></value>
        public string ConsultationId { get; set; }
    }

    /// <summary>
    /// 小程序拒绝通知请求对象
    /// </summary>
    public class LiveMemberRejectRequest : AppletAPIBaseRequest
    {
        /// <summary>
        /// 会诊记录Id
        /// </summary>
        /// <value></value>
        public string ConsultationId { get; set; }

        /// <summary>
        /// 用户编码
        /// </summary>
        /// <value></value>
        public string UserId { get; set; }
    }

    /// <summary>
    /// 小程序发起者收到对方接受通知请求对象
    /// </summary>
    public class LiveMemberAcceptRequest : AppletAPIBaseRequest
    {
        /// <summary>
        /// 会诊记录Id
        /// </summary>
        /// <value></value>
        public string ConsultationId { get; set; }

        /// <summary>
        /// 用户编码
        /// </summary>
        /// <value></value>
        public string UserId { get; set; }
    }

    /// <summary>
    /// 小程序接听超时请求对象
    /// </summary>
    public class LiveMemberTimeoutRequest : AppletAPIBaseRequest
    {
        /// <summary>
        /// 会诊记录Id
        /// </summary>
        /// <value></value>
        public string ConsultationId { get; set; }

        /// <summary>
        /// 用户编码
        /// </summary>
        /// <value></value>
        public string UserId { get; set; }
    }

    /// <summary>
    /// 根据openid获取用户详情
    /// </summary>
    public class GetUserInfoByOpenIdRequest : AppletAPIBaseRequest
    {

    }

    /// <summary>
    /// 绑定Openid和杏聆荟账号
    /// </summary>
    public class BindVcloudAccountAndOpenIdRequest
    {
        /// <summary>
        /// 账号
        /// </summary>
        /// <value>fly11</value>
        public string Account { get; set; }

        /// <summary>
        /// 密码
        /// </summary>
        /// <value></value>
        public string Password { get; set; }

        /// <summary>
        /// openid
        /// </summary>
        /// <value>xxx</value>
        public string OpenId { get; set; }
    }

    /// <summary>
    /// 查询分时诊断列表
    /// </summary>
    public class GetRemedicalRecordListRequest : AppletAPIPageRequest
    {
        /// <summary>
        /// 关键字
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public string KeyWord { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2022-02-28T09:21:38.861Z</value>
        /// <code>0</code>
        public DateTime StartTime { get; set; }

        /// <summary>
        /// 截至时间
        /// </summary>
        /// <value>2022-03-28T09:21:38.861Z</value>
        /// <code>0</code>
        public DateTime EndTime { get; set; }
    }

    /// <summary>
    /// 查询诊断报告列表
    /// </summary>
    public class GetRemedicalReportListRequest : AppletAPIBaseRequest
    {
        /// <summary>
        /// 诊断记录Id
        /// </summary>
        /// <value></value>
        public string RemedicalRecordId { get; set; }
    }

    /// <summary>
    /// 查询报告详情
    /// </summary>
    public class GetReportDetailRequest : AppletAPIBaseRequest
    {
        /// <summary>
        /// 报告Id
        /// </summary>
        /// <value></value>
        public string ReportId { get; set; }
    }

    /// <summary>
    /// 查询诊断图像列表
    /// </summary>
    public class GetRemedicalDataListRequest : AppletAPIBaseRequest
    {
        /// <summary>
        /// 诊断记录Id
        /// </summary>
        /// <value></value>
        public string RemedicalRecordId { get; set; }
    }

    /// <summary>
    /// 查询预约列表
    /// </summary>
    public class GetConsultationListRequest : AppletAPIPageRequest
    {
        /// <summary>
        /// 关键字
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public string KeyWord { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2022-02-28T09:21:38.861Z</value>
        /// <code>0</code>
        public DateTime StartTime { get; set; }

        /// <summary>
        /// 截至时间
        /// </summary>
        /// <value>2022-03-28T09:21:38.861Z</value>
        /// <code>0</code>
        public DateTime EndTime { get; set; }
    }

    // /// <summary>
    // /// 查询会诊详情
    // /// </summary>
    // public class GetConsultationDetailRequest : AppletAPIBaseRequest
    // {
    //     /// <summary>
    //     /// 会诊记录Id
    //     /// </summary>
    //     /// <value></value>
    //     public string ConsultationId { get; set; }
    // }

    // /// <summary>
    // /// 查询会诊图像列表
    // /// </summary>
    // public class GetConsultationDataRequest : AppletAPIBaseRequest
    // {
    //     /// <summary>
    //     /// 会诊记录Id
    //     /// </summary>
    //     /// <value></value>
    //     public string ConsultationId { get; set; }
    // }

    /// <summary>
    /// 查询会诊报告列表
    /// </summary>
    public class GetConsultationReportListRequest : AppletAPIBaseRequest
    {
        /// <summary>
        /// 诊断记录Id
        /// </summary>
        /// <value></value>
        public string ConsultationId { get; set; }
    }

    /// <summary>
    /// 新建预约
    /// </summary>
    public class CreateConsultationRequest : AppletAPIBaseRequest
    {
        /// <summary>
        /// 病人名称
        /// </summary>
        /// <value></value>
        public string PatientName { get; set; }

        /// <summary>
        /// 病人性别
        /// </summary>
        /// <value></value>
        public PatientGenderEnum PatientSex { get; set; }

        /// <summary>
        /// 病人年龄
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public string PatientAge { get; set; }

        /// <summary>
        /// 出生年月
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public DateTime Birthday { get; set; }

        /// <summary>
        /// 联系方式
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public string ContactInfo { get; set; }

        /// <summary>
        /// 病人ID
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public string PatientID { get; set; }

        /// <summary>
        /// 既往病史
        /// </summary>
        /// <value></value>
        public string History { get; set; }

        /// <summary>
        /// 初步诊断
        /// </summary>
        /// <value></value>
        public string PrimaryDiagnosis { get; set; }

        /// <summary>
        /// 预约医院
        /// </summary>
        /// <value></value>
        public string HospitalId { get; set; }

        /// <summary>
        /// 预约专家
        /// </summary>
        /// <value></value>
        public string ExpertId { get; set; }

        /// <summary>
        /// 预约日期
        /// </summary>
        /// <value></value>
        public DateTime ConsultationDate { get; set; }

        /// <summary>
        /// 检查部位
        /// </summary>
        /// <value></value>
        public string InspectionItems { get; set; }

        /// <summary>
        /// 扫查医生
        /// </summary>
        /// <value></value>
        public string ScanDoctorName { get; set; }

        /// <summary>
        /// 设备型号
        /// </summary>
        /// <value></value>
        public string DeviceModel { get; set; }

        /// <summary>
        /// 设备id
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public string TerminalId { get; set; }

    }

    /// <summary>
    /// 审批会诊
    /// </summary>
    public class ArrangeConsultationRequest : AppletAPIBaseRequest
    {
        /// <summary>
        /// 诊断记录Id
        /// </summary>
        /// <value></value>
        public string ConsultationId { get; set; }

        /// <summary>
        /// 会诊时间
        /// </summary>
        /// <value></value>
        public DateTime AppointDate { get; set; }

        /// <summary>
        /// 预约专家
        /// </summary>
        /// <value></value>
        public string ExpertId { get; set; }
    }

    /// <summary>
    /// 查询会诊医院
    /// </summary>
    public class GetHospitalsRequest : AppletAPIBaseRequest
    {

    }

    /// <summary>
    /// 查询会诊专家
    /// </summary>
    public class GetExpertsRequest : AppletAPIBaseRequest
    {
        /// <summary>
        /// 医院id
        /// </summary>
        /// <value></value>
        public string OrganizationId { get; set; }
    }

    /// <summary>
    /// 查询扫查部位
    /// </summary>
    public class GetScanLocationsRequest : AppletAPIBaseRequest
    {

    }

    /// <summary>
    /// 查询设备型号
    /// </summary>
    public class GetTerminalListRequest : AppletAPIBaseRequest
    {

    }

    /// <summary>
    /// 开始会诊
    /// </summary>
    public class StartConsultationRequest : AppletAPIBaseRequest
    {
        /// <summary>
        /// 诊断记录Id
        /// </summary>
        /// <value></value>
        public string ConsultationId { get; set; }
    }

    /// <summary>
    /// 取消开始会诊
    /// </summary>
    public class CancelStartConsultationRequest : AppletAPIBaseRequest
    {
        /// <summary>
        /// RoomId
        /// </summary>
        /// <value></value>
        public string RoomId { get; set; }
    }

    /// <summary>
    /// 退出会诊
    /// </summary>
    public class ExitConsultationRequest : AppletAPIBaseRequest
    {
        /// <summary>
        /// RoomId
        /// </summary>
        /// <value></value>
        public string RoomId { get; set; }

        /// <summary>
        /// ConsultationId
        /// </summary>
        /// <value></value>
        public string ConsultationId { get; set; }
    }

    /// <summary>
    /// 会诊心跳
    /// </summary>
    public class ConsultationHeartRateRequest : AppletAPIBaseRequest
    {
        /// <summary>
        /// 诊断记录Id
        /// </summary>
        /// <value></value>
        public string ConsultationId { get; set; }
    }

    /// <summary>
    /// 获取文件流
    /// </summary>
    public class DownloadFileRequest : AppletAPIBaseRequest
    {
        /// <summary>
        /// 文件token
        /// </summary>
        /// <value></value>
        public string FileToken { get; set; }
    }

    /// <summary>
    /// 查询系统默认报告模板 请求
    /// </summary>
    public class GetReportTemplatesRequest : AppletAPIBaseRequest
    {
        /// <summary>
        /// 国家地区语言编码：zh-CN、en-US
        /// </summary>
        /// <value></value>
        public string LanguageCode { get; set; }
    }

    /// <summary>
    /// 查询系统默认词条 请求
    /// </summary>
    public class GetThesaurusTemplatesRequest : AppletAPIBaseRequest
    {
        /// <summary>
        /// 国家地区语言编码：zh-CN、en-US
        /// </summary>
        /// <value></value>
        public string LanguageCode { get; set; }
    }

    /// <summary>
    /// 保存报告信息 请求
    /// </summary>
    public class SaveAppletReportRequest : ReportResultInfo
    {
        /// <summary>
        /// openid
        /// </summary>
        /// <value>xxx</value>
        public string OpenId { get; set; }

        /// <summary>
        /// TerminalRecordId
        /// </summary>
        /// <value>xxx</value>
        public string TerminalRecordId { get; set; }
    }

    /// <summary>
    /// 查询报告信息 请求
    /// </summary>
    public class GetAppletReportRequest : AppletAPIBaseRequest
    {
        /// <summary>
        /// RecordId
        /// </summary>
        /// <value>xxx</value>
        public string RecordId { get; set; }

        /// <summary>
        /// ReportId
        /// </summary>
        /// <value>xxx</value>
        public string ReportId { get; set; }
    }

    /// <summary>
    /// 保存会诊截图 请求
    /// </summary>
    public class UploadConsultationImageRequest : ReportResultInfo
    {
        /// <summary>
        /// openid
        /// </summary>
        /// <value>xxx</value>
        public string OpenId { get; set; }

        /// <summary>
        /// ConsultationId
        /// </summary>
        /// <value>xxx</value>
        public string ConsultationId { get; set; }

        /// <summary>
        /// ImageBase64
        /// </summary>
        /// <value>xxx</value>
        public string ImageBase64 { get; set; }
    }

}

