using System.Collections.Generic;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.DTO.Courses;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Enum.CourseEnum;

namespace WingInterfaceLibrary.Request.Courses
{
    /// <summary>
    /// 添加课程专辑请求
    /// </summary>
    public class AddCourseAlbumRequest : TokenRequest
    {
        /// <summary>
        /// 专辑名称
        /// </summary>
        public string Name { get; set; }
        /// <summary>
        /// 关联课程编码信息
        /// </summary>
        public IList<string> CourseCodes { get; set; }

        /// <summary>
        /// 专辑封面
        /// </summary>
        public string Cover { get; set; }

        /// <summary>
        /// 专辑简介
        /// </summary>
        /// <value></value>
        public string Introduction { get; set; }

        /// <summary>
        /// 课程标签列表
        /// </summary>
        public IList<string> CourseLabelCodes { get; set; }

        /// <summary>
        /// 排序
        /// </summary>
        /// <value></value>
        public int Sort { get; set; }

        /// <summary>
        /// 是否置顶
        /// </summary>
        /// <value></value>
        public bool IsStick { get; set; }

        /// <summary>
        /// 教师Code
        /// </summary>
        public string TeacherCode { get; set; }

        /// <summary>
        /// 教师名称
        /// </summary>
        public string TeacherName { get; set; }

        /// <summary>
        /// 可见范围：国内，国外，或者两者兼有 TODO
        /// </summary>
        public CourseViewRangeEnum ViewRange { get; set; }

        /// <summary>
        /// 专辑价格 TODO
        /// </summary>
        public decimal Price { get; set; }

        /// <summary>
        /// 语言
        /// </summary>
        public string LanguageCode { get; set; }
    }

    /// <summary>
    /// 更新课程专辑请求
    /// </summary>
    public class UpdateCourseAlbumRequest : TokenRequest
    {
        /// <summary>
        /// 专辑名称
        /// </summary>
        public string Name { get; set; }

        /// <summary>
        /// 专辑编码
        /// </summary>
        public string CourseAlbumCode { get; set; }

        /// <summary>
        /// 关联课程编码信息
        /// </summary>
        public IList<string> CourseCodes { get; set; }

        /// <summary>
        /// 专辑封面
        /// </summary>
        public string Cover { get; set; }

        /// <summary>
        /// 专辑简介
        /// </summary>
        /// <value></value>
        public string Introduction { get; set; }

        /// <summary>
        /// 课程标签列表
        /// </summary>
        public IList<string> CourseLabelCodes { get; set; }

        /// <summary>
        /// 排序
        /// </summary>
        /// <value></value>
        public int Sort { get; set; }

        /// <summary>
        /// 是否置顶
        /// </summary>
        /// <value></value>
        public bool IsStick { get; set; }

        /// <summary>
        /// 教师Code
        /// </summary>
        public string TeacherCode { get; set; }

        /// <summary>
        /// 教师名称
        /// </summary>
        public string TeacherName { get; set; }

        /// <summary>
        /// 可见范围：国内，国外，或者两者兼有 TODO
        /// </summary>
        public CourseViewRangeEnum ViewRange { get; set; }

        /// <summary>
        /// 专辑价格 TODO
        /// </summary>
        public decimal Price { get; set; }
        
        /// <summary>
        /// 语言
        /// </summary>
        public string LanguageCode { get; set; }
    }

    /// <summary>
    /// 删除课程专辑请求
    /// </summary>
    public class DeleteCourseAlbumRequest
    {
        /// <summary>
        /// 课程专辑编码
        /// </summary>
        /// <value></value>
        public string CourseAlbumCode { get; set; }
    }

    /// <summary>
    /// 查找课程专辑请求
    /// </summary>
    public class FindCourseAlbumPageRequest : PageRequest
    {
        /// <summary>
        /// 查询关键字，包含名称 
        /// </summary>
        /// <value></value>
        public string Keyword { get; set; }

        /// <summary>
        /// 学生课程报名状态
        /// </summary>
        /// <value></value>
        public StudentCourseStatusEnum QueryStatus { get; set; }
        /// 课程标签列表
        /// </summary>
        public IList<string> CourseLabelCodes { get; set; }

        /// <summary>
        /// 教师Code
        /// </summary>
        public string TeacherCode { get; set; }

        /// <summary>
        /// 教师名称
        /// </summary>
        public string TeacherName { get; set; }

        /// <summary>
        /// 可见范围：国内，国外，或者两者兼有 TODO
        /// </summary>
        public CourseViewRangeEnum ViewRange { get; set; }

        /// <summary>
        /// 专辑价格 TODO
        /// </summary>
        public decimal Price { get; set; }
    }

    /// <summary>
    /// 查询课程专辑详情请求
    /// </summary>
    public class FindCourseAlbumByCodeRequest : TokenRequest
    {
        /// <summary>
        /// 课程专辑编码
        /// </summary>
        /// <value></value>
        public string CourseAlbumCode { get; set; }

        /// <summary>
        /// 语言
        /// </summary>
        /// <value>zh-CN</value>
        public string LanguageCode { get; set; } = "en-US";
    }

    /// <summary>
    /// 课程专辑添加课程请求
    /// </summary>
    public class CourseAlbumAddCourseCodesRequest : TokenRequest
    {
        /// <summary>
        /// 关联课程编码信息
        /// </summary>
        public IList<string> CourseCodes { get; set; }
    }

    /// <summary>
    /// 课程专辑添加标签请求
    /// </summary>
    public class CourseAlbumAddCourseLabelCodesRequest : TokenRequest
    {
        /// <summary>
        /// 课程标签列表
        /// </summary>
        public IList<string> CourseLabelCodes { get; set; }
    }

    /// <summary>
    /// 报名课程专辑
    /// </summary>
    public class SignUpCourseAlbumRequest : TokenRequest
    {
        /// <summary>
        /// 课程专辑编码
        /// </summary>
        /// <value></value>
        public string CourseAlbumCode { get; set; }
    }
}