using System.Collections.Generic;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.Request.Courses
{
    /// <summary>
    /// 教培素材保存实体
    /// </summary>
    public class SaveVideoRequest : TokenRequest
    {
        /// <summary>
        /// 关联课程Code
        /// </summary>
        /// <value>04669519BF9544489E4DB547E1C01322</value>
        public string CourseCode { get; set; }

        /// <summary>
        /// 上传文件类型：1-课程播放视频/课件；2-资料
        /// </summary>
        /// <value>0</value>
        public int Category { get; set; }

        /// <summary>
        /// 视频Code
        /// </summary>
        /// <value>04669519BF9544489E4DB547E1C01322</value>
        public string Code { get; set; }

        /// <summary>
        /// 视频名称
        /// </summary>
        /// <value>XXXX_Video</value>
        public string Name { get; set; }

        /// <summary>
        /// 视频地址
        /// </summary>
        /// <value>https://flyinsono-bj-1300984704.cos.ap-beijing.myqcloud.com/video.mp4</value>
        public string VideoToken { get; set; }

        /// <summary>
        /// Vod云点播文件Id
        /// </summary>
        /// <value>12334e</value>
        public string VodFileId { get; set; }

        /// <summary>
        /// 封面图
        /// </summary>
        /// <value>https://flyinsono-bj-1300984704.cos.ap-beijing.myqcloud.com/0B7B494B7A7044F3ADE0FCF8C0422700.png</value>
        public string Poster { get; set; }

        /// <summary>
        /// 视频时长【秒】
        /// </summary>
        /// <value>120</value>
        public int Duration { get; set; }

        /// <summary>
        /// 视频大小【MB】
        /// </summary>
        /// <value>100</value>
        public double VideoSize { get; set; }

        /// <summary>
        /// 视频上传人
        /// </summary>
        public string CreatorCode { get; set; }

        /// <summary>
        /// 素材上传人
        /// </summary>
        public string CreatorName { get; set; }

        /// <summary>
        /// 素材分类：视频、图片、文件
        /// </summary>
        public UploadFileTypeEnum FodderType { get; set; } 

        /// <summary>
        /// 素材使用：公开的、私有的
        /// </summary>
        public bool IsPublic { get; set; } = true;

        /// <summary>
        /// 可见范围：国内，国外，或者两者兼有
        /// </summary>
        public CourseViewRangeEnum ViewRange { get; set; }

        /// <summary>
        /// 课程规模类型
        /// </summary>
        /// <value>1</value>
        public Enum.CourseEnum.CourseAudienceTypeEnum AudienceType { get; set; }

        /// <summary>
        /// 自动创建课程
        /// </summary>
        public bool AutoCreateCourse { get; set; }

        /// <summary>
        /// 课程标签列表
        /// </summary>
        public List<string> CourseLabelCodes { get; set; }

        /// <summary>
        /// 班级管理 
        /// </summary>
        public List<string> UserGroupCodes { get; set; }

        /// <summary>
        /// 简介
        /// </summary>
        public string Intro { get; set; }
    }

    /// <summary>
    /// 教培素材列表保存实体
    /// </summary>
    public class CreateVideosRequest : TokenRequest
    {
        /// <summary>
        /// 教培素材基础实体
        /// </summary>
        /// <value></value>
        public IList<SaveVideoRequest> VideoList { get; set; }
    }
}