using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using WingInterfaceLibrary.Request.Courses;
using WingInterfaceLibrary.Result;
using WingInterfaceLibrary.DTO.Courses;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Enum.CourseEnum;
using WingInterfaceLibrary.DTO.Education;

namespace WingInterfaceLibrary.Request.Courses
{
    /// <summary>
    /// 更新课程
    /// </summary>
    public class UpdateCourseRequest : TokenRequest
    {
        /// <summary>
        /// 课程编码
        /// </summary>
        /// <value>9BF9544489E4D</value>
        public string Code { get; set; }
        /// <summary>
        /// 课程名称
        /// </summary>
        /// <value>TestCourse</value>
        public string Name { get; set; }

        /// <summary>
        /// 课程简介
        /// </summary>
        ///  <value>Test course dec</value>
        /// <code>0</code>
        public string CourseIntro { get; set; }

        /// <summary>
        /// 教师编码
        /// </summary>
        /// <value>04669519BF9544489E4DB547E1C01322</value>       
        /// <code>0</code>
        public string TeacherCode { get; set; }

        /// <summary>
        /// 封面图，课程海报
        /// </summary>
        /// <value>https://flyinsono-bj-1300984704.cos.ap-beijing.myqcloud.com/0B7B494B7A7044F3ADE0FCF8C0422700.png</value>
        /// <code>0</code>
        public string Cover { get; set; }

        /// <summary>
        /// 课程预计开始时间
        /// </summary>
        /// <value>2022-03-15T12:53:29.889Z</value>
        public DateTime StartTime { get; set; }

        /// <summary>
        /// 课程时长【单位分钟】
        /// </summary>
        /// <value>120</value>
        public int Duration { get; set; }

        /// <summary>
        /// 课程分类
        /// </summary>
        /// <value>1</value>
        public CourseTypeEnum CourseType { get; set; }

        /// <summary>
        /// 课程规模类型
        /// </summary>
        /// <value>1</value>
        public CourseAudienceTypeEnum AudienceType { get; set; }

        /// <summary>
        /// 课件地址
        /// </summary>
        /// <value>https://flyinsono-bj-1300984704.cos.ap-beijing.myqcloud.com/0B7B494B7A7044F3ADE0FCF8C0422700.png</value>
        /// <code>0</code>
        public string CoursewareToken { get; set; }

        /// <summary>
        /// 病例标签
        /// </summary>
        /// <value>'12334e','12334e'</value>
        public IList<string> CaseLabelCodes { get; set; }

        /// <summary>
        /// 课程/视频标签
        /// </summary>
        /// <value>'12334e','12334e'</value>
        public IList<string> CourseLabelCodes { get; set; }

        /// <summary>
        /// 班级CodeList
        /// </summary>
        /// <value>'12334e','12334e'</value>        
        /// <code>0</code>
        public IList<string> UserGroupCodes { get; set; }

        /// <summary>
        /// 课程价格
        /// </summary>
        /// <value>10.0</value>
        /// <code>0</code>
        public decimal Price { get; set; }

        /// <summary>
        /// 视频课程CodeList
        /// </summary>
        /// <value>'12334e','12334e'</value>        
        /// <code>0</code>
        public IList<string> CourseVideoCodes { get; set; }

        /// <summary>
        /// 绑定试卷
        /// </summary>
        /// <value></value>     
        public IList<string> BindExams { get; set; }

        /// <summary>
        /// 是否小班化
        /// </summary>
        /// <value></value>
        public bool IsSmallClass { get; set; }

        /// <summary>
        /// 助教列表
        /// </summary>
        public IList<string> Assistants { get; set; }

        /// <summary>
        /// 参与互动专家
        /// </summary>
        public IList<string> Experts { get; set; }

        /// <summary>
        /// 是否代理商课程
        /// </summary>
        /// <value>false</value>  
        public bool IsAgentCourse { get; set; }

        /// <summary>
        /// 所属专辑
        /// </summary>
        /// <value></value>
        public IList<string> CourseAlbumCodes { get; set; }

        /// <summary>
        /// 课程呈现类型
        /// </summary>
        /// <value></value>
        public CourseAppearTypeEnum CourseAppearType { get; set; }

        /// <summary>
        /// 资料CodeList
        /// </summary>
        /// <value>'12334e','12334e'</value>        
        /// <code>0</code>
        public IList<string> CourseMaterialCodes { get; set; }

        /// <summary>
        /// 是否仅为视频课
        /// </summary>
        /// <value>false</value>  
        public bool IsJustVideoCourse { get; set; }
    }


    /// <summary>
    /// 课程禁言请求实体
    /// </summary>
    public class CourseLiveProhibitionRequest : TokenRequest
    {
        /// <summary>
        /// 课程编码
        /// </summary>
        /// <value>9BF9544489E4D</value>
        public string Code { get; set; }

        /// <summary>
        /// 是否禁言：true-禁言；false-不禁言
        /// </summary>
        /// <value>false</value>
        public bool IsProhibition { get; set; }
    }
}