using System;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Common;
using WingInterfaceLibrary.DTO.Consultation;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.Request.DBCopy
{

    public class SyncBatchConsultationRequest
    {
        public SyncDBEnum SyncType { get; set; } = SyncDBEnum.Migrate;
        
        public List<SyncConsultationRequest> SyncConsultations { get; set; }
    }

    /// <summary>
    /// 同步会诊详情信息
    /// </summary>
    public class SyncConsultationRequest
    {
        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;
        /// <summary>
        /// 创建时间
        /// </summary>
        /// <value></value>
        public DateTime CreateTime { get; set; }
        /// <summary>
        /// 修改时间
        /// </summary>
        /// <value></value>
        public DateTime UpdateTime { get; set; }

        /// <summary>
        /// 申请机构编码
        /// </summary>
        /// <value>OrganizationDO_123456789</value>
        public string ApplyOrganizationCode { get; set; } = string.Empty;

        /// <summary>
        /// 申请医生编码
        /// </summary>
        /// <value>UserDO_123456789</value>
        public string ApplyUserCode { get; set; } = string.Empty;

        /// <summary>
        /// 会诊医院编码
        /// </summary>
        /// <value>OrganizationDO_123456789</value>
        public string ExpertOrganizationCode { get; set; } = string.Empty;

        /// <summary>
        /// 会诊专家编码
        /// </summary>
        /// <value>UserDO_123456789</value>
        public string ExpertUserCode { get; set; } = string.Empty;

        /// <summary>
        /// 设备编码
        /// </summary>
        /// <value>DeviceDO_123456789</value>
        public string DeviceCode { get; set; } = string.Empty;

        /// <summary>
        /// 扫查医生编码
        /// </summary>
        /// <value>UserDO_123456789</value>
        public string ScanUser { get; set; } = string.Empty;

        /// <summary>
        /// 病人信息
        /// </summary>
        /// <value></value>
        public List<DataItemDTO> PatientInfo { get; set; }
        
        /// <summary>
        /// 检查部位
        /// </summary>
        /// <value>肝脏 附件</value>        
        /// <code>0</code>
        public List<string> ScanPositions { get; set; }

        /// <summary>
        /// 会诊开始时间
        /// </summary>
        /// <value>2022-09-30 14:00:00</value>
        public DateTime ConsultationTime { get; set; }

        /// <summary>
        /// 会诊截止时间
        /// </summary>
        /// <value></value>
        public DateTime ConsultationTimeEnd { get; set; }

        /// <summary>
        /// 会诊状态
        /// </summary>
        /// <value>1</value>
        public TransactionStatusEnum ConsultationStatus { get; set; } = TransactionStatusEnum.Applied;

        /// <summary>
        /// 会诊中保存的文件信息集合
        /// </summary>
        /// <returns></returns>
        public List<ConsultationFileDTO> ConsultationFileList { get; set; } = new List<ConsultationFileDTO>();

        /// <summary>
        /// 拒绝申请会诊原因
        /// </summary>
        /// <value></value>
        public string RejectReason { get; set; } = string.Empty;

        /// <summary>
        /// 会诊描述
        /// </summary>
        /// <value></value>
        public string Description { get; set; }

        /// <summary>
        /// 疾病名称
        /// </summary>
        /// <value></value>
        public string Diseases { get; set; }

        /// <summary>
        /// 初步诊断
        /// </summary>
        /// <value>初步诊断结论</value>   
        public string PrimaryDiagnosis { get; set; } = string.Empty;

        /// <summary>
        /// 评价
        /// </summary>
        /// <value>0</value>
        public SyncEvaluatesRequest Evaluates { get; set; } 

        /// <summary>
        /// 随访状态
        /// </summary>
        /// <value>0</value>
        public FollowUpVisitStatusEnum FollowUpVisitStatus { get; set; }

        /// <summary>
        /// 随访记录列表
        /// </summary>
        /// <value>0</value>
        public IList<SyncFollowUpVisitRequest> SyncFollowUpVisitList { get; set; }
    }

    /// <summary>
    /// 评价
    /// </summary>
    public class SyncEvaluatesRequest
    {
        /// <summary>
        /// 预约会诊记录编码
        /// </summary>
        public string ConsultationRecordCode { get; set; }

        /// <summary>
        /// 评价等级
        /// </summary>
        public EvaluateGradeEnum EvaluateGrade { get; set; }

        /// <summary>
        /// 评价等级
        /// </summary>
        public double EvaluateScore { get; set; }

        /// <summary>
        /// 评价反馈
        /// </summary>
        public string Feedback { get; set; }

        /// <summary>
        /// 是否删除
        /// </summary>
        /// <value>false</value>   
        public bool IsDelete { get; set; }
        /// <summary>
        /// 创建时间
        /// </summary>
        /// <value></value>
        public DateTime CreateTime { get; set; }
        /// <summary>
        /// 修改时间
        /// </summary>
        /// <value></value>
        public DateTime UpdateTime { get; set; }
        /// <summary>
        /// 评价code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }
    }

    /// <summary>
    /// 同步会诊详情信息
    /// </summary>
    public class SyncFollowUpVisitRequest : FollowUpVisitDTO
    {
        /// <summary>
        /// 是否删除
        /// </summary>
        /// <value>false</value>   
        public bool IsDelete { get; set; }
        /// <summary>
        /// 创建时间
        /// </summary>
        /// <value></value>
        public DateTime CreateTime { get; set; }
        /// <summary>
        /// 修改时间
        /// </summary>
        /// <value></value>
        public DateTime UpdateTime { get; set; }
    }
}