using System;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Common;
using WingInterfaceLibrary.DTO.Record;
using WingInterfaceLibrary.DTO.Report;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Request.AIDiagnosis;

namespace WingInterfaceLibrary.Request.DBCopy
{

    /// <summary>
    /// 远程诊断记录数据批量
    /// </summary>
    public class SyncBatchRemedicalRecordRequest
    {
        public SyncDBEnum SyncType { get; set; } = SyncDBEnum.Migrate;

        public IList<SyncRemedicalRecordRequest> RemedicalRecordList { get; set; }
    }

    /// <summary>
    /// 远程诊断记录数据
    /// </summary>
    public class SyncRemedicalRecordRequest
    {
        /// <summary>
        /// code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }
        /// <summary>
        /// 机构
        /// </summary>
        /// <value></value>
        public string OrganizationCode { get; set; }
        /// <summary>
        /// 设备
        /// </summary>
        /// <value></value>
        public string DeviceCode { get; set; }
        /// <summary>
        /// 是否上传报告
        /// </summary>
        /// <value></value>
        public bool IsUploadReport { get; set; }
        /// <summary>
        /// 病人信息
        /// </summary>
        /// <value></value>
        public List<DataItemDTO> PatientInfo { get; set; }
        /// <summary>
        /// AI诊断状态
        /// </summary>
        /// <value></value>
        public DiagnosisStatusEnum DiagnosisStatus { get; set; }
        /// <summary>
        /// AI诊断信息
        /// </summary>
        /// <value></value>
        public IList<DiagnosisInfoDTO> AIDiagnosisInfos { get; set; }
        /// <summary>
        /// 创建时间
        /// </summary>
        /// <value></value>
        public DateTime CreateTime { get; set; }
        /// <summary>
        /// 修改时间
        /// </summary>
        /// <value></value>
        public DateTime UpdateTime { get; set; }
        /// <summary>
        /// 创建人
        /// </summary>
        /// <value></value>
        public string Creator { get; set; }

        /// <summary>
        /// IsDelete
        /// </summary>
        /// <value></value>
        public bool IsDelete { get; set; }

        /// <summary>
        /// 国家脑卒中项目，掌超上传医生
        /// </summary>
        /// <value></value>
        public string CustomDoctor { get; set; }

        /// <summary>
        /// 国家脑卒中项目，掌超上传医院
        /// </summary>
        /// <value></value>
        public string CustomOrganzation { get; set; }

        /// <summary>
        /// 国家脑卒中项目，掌超上传设备SN
        /// </summary>
        /// <value></value>
        public string EquipmentSN { get; set; }

        /// <summary>
        /// 图像是否已质控
        /// </summary>
        /// <value></value>
        public bool IsImgQualityControlled { get; set; } = false;

        /// <summary>
        /// 报告是否已质控
        /// </summary>
        /// <value></value>
        public bool IsReportQualityControlled { get; set; } = false;

        /// <summary>
        /// 图像质控分
        /// </summary>
        /// <value></value>
        public double ImgScore { get; set; }

        /// <summary>
        /// 报告质控分
        /// </summary>
        /// <value></value>
        public double ReportScore { get; set; }
    }

    /// <summary>
    /// 远程诊断记录图像数据批量
    /// </summary>
    public class SyncBatchUploadRemedicalDatasRequest
    {
        public SyncDBEnum SyncType { get; set; } = SyncDBEnum.Migrate;

        public IList<SyncUploadRemedicalDataRequest> SyncUploadRemedicalDataList { get; set; }
    }

    /// <summary>
    /// 上传图像
    /// </summary>
    public class SyncUploadRemedicalDataRequest
    {
        /// <summary>
        /// code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }
        /// <summary>
        /// 创建时间
        /// </summary>
        /// <value></value>
        public DateTime CreateTime { get; set; }
        /// <summary>
        /// 修改时间
        /// </summary>
        /// <value></value>
        public DateTime UpdateTime { get; set; }
        /// <summary>
        /// 检查code
        /// </summary>
        /// <value></value>
        public string ExamCode { get; set; }
        /// <summary>
        /// 设备code
        /// </summary>
        /// <value></value>
        public string DeviceCode { get; set; }
        /// <summary>
        /// 预览图地址token
        /// </summary>
        /// <value></value>   
        public string PreviewFileToken { get; set; }
        /// <summary>
        /// 高清图token
        /// </summary>
        /// <value></value>
        public string FileToken { get; set; }
        /// <summary>
        /// CDNtoken
        /// </summary>
        /// <value></value>
        public string ImageUrl { get; set; }
        /// <summary>
        /// 高清图文件大小
        /// </summary>
        /// <value></value>
        public long FileSize { get; set; }
        /// <summary>
        /// 第一帧大图token
        /// </summary>
        /// <value></value>  
        public string CoverImageToken { get; set; }
        /// <summary>
        /// ApplicationCategory
        /// </summary>
        /// <value></value>
        public string ApplicationCategory { get; set; }
        /// <summary>
        /// Application Name
        /// </summary>
        /// <value></value>
        public string Application { get; set; }
        /// <summary>
        /// 文件数据类型
        /// </summary>
        /// <value></value>
        public RemedicalFileDataTypeEnum FileDataType { get; set; }
        /// <summary>
        /// AI识别部位及图像位置描述
        /// </summary>
        /// <value>0</value>
        public ImageLocationDTO ImageLocation { get; set; }

        /// <summary>
        /// 器官识别结果
        /// </summary>
        /// <value></value>
        public List<string> OrganDiagnosisInfos { get; set; } = new List<string>();

        /// <summary>
        /// 是否需要AI（优先处理）
        /// </summary>
        /// <value></value>
        public bool OldPlatformNeedAI { get; set; } = false;

        /// <summary>
        /// 质控结果
        /// </summary>
        /// <value></value>
        public ReportQualityControl QualityControlDatas { get; set; }
    }

    /// <summary>
    /// AI数据批量(非颈动脉)
    /// </summary>
    public class SyncBatchAIResultRequest
    {
        public SyncDBEnum SyncType { get; set; } = SyncDBEnum.Migrate;

        /// <summary>
        /// AI同步
        /// </summary>
        /// <value></value>
        public IList<SyncAIResultRequest> SyncAIResultList { get; set; }
    }

    /// <summary>
    /// AI数据
    /// </summary>
    public class SyncAIResultRequest
    {
        /// <summary>
        /// 图像code
        /// </summary>
        /// <value></value>
        public string RemedicalCode { get; set; }

        /// <summary>
        /// AI结果(非颈动脉)
        /// </summary>
        /// <value></value>
        public string DiagnosisResult { get; set; }
        /// <summary>
        /// 创建时间
        /// </summary>
        /// <value></value>
        public DateTime CreateTime { get; set; }
        /// <summary>
        /// 更新时间
        /// </summary>
        /// <value></value>
        public DateTime UpdateTime { get; set; }

    }

    /// <summary>
    /// 颈动脉AI
    /// </summary>
    public class SyncBatchCarotidResultRequest
    {
        public SyncDBEnum SyncType { get; set; } = SyncDBEnum.Migrate;

        /// <summary>
        /// 颈动脉AI数据
        /// </summary>
        /// <value></value>
        public List<GetCarotidResultRequest> SyncCarotidResultRequest { get; set; }
    }
}
