using System.Collections.Generic;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.DTO.Courses;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.DTO.Education;
using WingInterfaceLibrary.Enum.CourseEnum;
using System;

namespace WingInterfaceLibrary.DB.Request
{
    /// <summary>
    /// 添加课程专辑请求
    /// </summary>
    public class AddCourseAlbumDBRequest : TableDataItem<CourseAlbumDTO>
    {
    }

    /// <summary>
    /// 更新课程专辑请求
    /// </summary>
    public class UpdateCourseAlbumDBRequest
    {
        /// <summary>
        /// 专辑名称
        /// </summary>
        public string Name { get; set; }

        /// <summary>
        /// 教师Code
        /// </summary>
        public string TeacherCode { get; set; }

        /// <summary>
        /// 教师名称
        /// </summary>
        public string TeacherName { get; set; }

        /// <summary>
        /// 课程专辑编码
        /// </summary>
        /// <value></value>
        public string CourseAlbumCode { get; set; }

        /// <summary>
        /// 增加的关联课程编码信息
        /// </summary>
        public IList<string> AddCourseCodes { get; set; }

        /// <summary>
        /// 增加的关联课程编码信息
        /// </summary>
        public IList<string> RemoveCourseCodes { get; set; }

        /// <summary>
        /// 专辑封面
        /// </summary>
        public string Cover { get; set; }

        /// <summary>
        /// 专辑简介
        /// </summary>
        /// <value></value>
        public string Introduction { get; set; }

        /// <summary>
        /// 增加的课程标签列表
        /// </summary>
        public IList<string> AddCourseLabelCodes { get; set; }

        /// <summary>
        /// 可见范围：国内，国外，或者两者兼有 TODO
        /// </summary>
        public CourseViewRangeEnum ViewRange { get; set; }

        /// <summary>
        /// 专辑价格 TODO
        /// </summary>
        public decimal Price { get; set; }

        /// <summary>
        /// 排序
        /// </summary>
        /// <value></value>
        public int Sort { get; set; }

        /// <summary>
        /// 是否置顶
        /// </summary>
        /// <value></value>
        public bool IsStick { get; set; }

        /// <summary>
        /// 是否客户端提交
        /// </summary>
        /// <value></value>
        public bool IsClientSubmit{ get; set; }

        /// <summary>
        /// 语言
        /// </summary>
        /// <value></value>
        public string LanguageCode{ get; set; }
    }

    /// <summary>
    /// 更新课程专辑请求
    /// </summary>
    public class DeleteCourseAlbumDBRequest
    {
        /// <summary>
        /// 课程专辑编码
        /// </summary>
        /// <value></value>
        public string CourseAlbumCode { get; set; }
    }

    /// <summary>
    /// 查询课程专辑详情请求
    /// </summary>
    public class FindCourseAlbumByCodeDBRequest
    {
        /// <summary>
        /// 课程专辑编码
        /// </summary>
        /// <value></value>
        public string CourseAlbumCode { get; set; }

        /// <summary>
        /// 语言
        /// </summary>
        /// <value>zh-CN</value>
        public string LanguageCode { get; set; } = "en-US";
    }

    /// <summary>
    /// 更新课程专辑请求
    /// </summary>
    public class FindCourseAlbumPageDBRequest : PageRequest
    {
        /// <summary>
        /// 查询创建起始时间
        /// </summary>
        /// <value>2022-03-15T12:53:29.889Z</value>
        /// <code>0</code>
        public DateTime StartTime { get; set; } = DateTime.MinValue;

        /// <summary>
        /// 查询创建开始结束时间
        /// </summary>
        /// <value>2022-03-15T12:53:29.889Z</value>
        /// <code>0</code>
        public DateTime EndTime { get; set; } = DateTime.MinValue;

        /// <summary>
        /// 教师Code, 通用接口，当此值赋值是，表示老师查看自己创建的专辑，如果为空，则表示课程首页的筛选
        /// </summary>
        /// <value>04669519BF9544489E4DB547E1C01322</value>
        public string TeacherCode { get; set; }

        /// <summary>
        /// 查询关键字
        /// </summary>
        /// <value></value>
        public string Keyword { get; set; }

        /// <summary>
        /// 课程标签列表
        /// </summary>
        public IList<string> CourseLabelCodes { get; set; }
    }

    /// <summary>
    /// 报名课程
    /// </summary>
    public class SignUpCourseDBRequest
    {
        /// <summary>
        /// 呈现类型
        /// </summary>
        /// <value></value>
        public CourseAppearTypeEnum CourseAppearType { get; set; }

        /// <summary>
        /// 课程或专辑编码
        /// </summary>
        /// <value></value>
        public string CourseOrAlbumCode { get; set; }

        /// <summary>
        /// 学生编码
        /// </summary>
        /// <value></value>
        public string StudentCode { get; set; }
    }

    /// <summary>
    /// 取消报名课程
    /// </summary>
    public class CancelSignUpCourseDBRequest
    {
        /// <summary>
        /// 课程或专辑编码
        /// </summary>
        /// <value></value>
        public string CourseOrAlbumCode { get; set; }

        /// <summary>
        /// 学生编码
        /// </summary>
        /// <value></value>
        public string StudentCode { get; set; }
    }

    /// <summary>
    /// 查询学生的我的课程列表
    /// </summary>
    public class FindMyCoursePagesDBRequest : PageRequest
    {
        /// <summary>
        /// 关键字搜索
        /// </summary>
        /// <value></value>
        public string Keyword { get; set; }

        /// <summary>
        /// 学生编码
        /// </summary>
        /// <value></value>
        public string StudentCode { get; set; }

        /// <summary>
        /// 申请学生对应课程状态
        /// </summary>
        /// <value>1</value>
        /// <code>0</code>
        public StudentCourseStatusEnum QueryStatus { get; set; }

        /// <summary>
        /// 呈现类型
        /// </summary>
        /// <value></value>
        public CourseAppearTypeEnum CourseAppearType { get; set; }
    }
}