using System.Collections.Generic;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Request.Lab;
using System;

namespace WingInterfaceLibrary.DB.Request
{
    /// <summary>
    /// 创建实验室文件转换状态信息
    /// </summary>
    public class CreateLabConvertStateDBRequest
    {
        /// <summary>
        /// 创建人编码
        /// </summary>
        /// <value></value>
        public string CreatorCode { get; set; }

        /// <summary>
        /// 记录编码
        /// </summary>
        /// <value></value>
        public string RecordCode { get; set; }

        /// <summary>
        /// 是否模版方式上传
        /// </summary>
        /// <value></value>
        public bool IsTemplate { get; set; }

        /// <summary>
        /// 记录最后执行时间
        /// </summary>
        /// <value></value>
        public DateTime LastExecuteTime { get; set; }
    }

    /// <summary>
    /// 设置实验室文件转换状态信息
    /// </summary>
    public class SetLabConvertStateDBRequest
    {
        /// <summary>
        /// 编码
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 记录最后执行时间
        /// </summary>
        /// <value></value>
        public DateTime LastExecuteTime { get; set; }
    }

    /// <summary>
    /// 添加转换错误状态信息
    /// </summary>
    public class AddConvertErrorInfoStateDBRequest
    {
        /// <summary>
        /// 编码
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 下载错误文件列表
        /// </summary>
        /// <value></value>
        public List<ConvertFileInfoDTO> ConvertErrorFiles { get; set; }
    }

    /// <summary>
    /// 添加下载错误状态信息
    /// </summary>
    public class AddDownloadErrorInfoStateDBRequest
    {
        /// <summary>
        /// 编码
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 下载错误文件列表
        /// </summary>
        /// <value></value>
        public List<DownloadFileInfoDTO> DownloadErrorFiles { get; set; }
    }

    /// <summary>
    /// 删除转换错误状态信息
    /// </summary>
    public class RemoveConvertErrorInfoStateDBRequest
    {
        /// <summary>
        /// 编码
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 下载错误文件列表
        /// </summary>
        /// <value></value>
        public List<ConvertFileInfoDTO> ConvertErrorFiles { get; set; }
    }

    /// <summary>
    /// 删除下载错误状态信息
    /// </summary>
    public class RemoveDownloadErrorInfoStateDBRequest
    {
        /// <summary>
        /// 编码
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 下载错误文件列表
        /// </summary>
        /// <value></value>
        public List<DownloadFileInfoDTO> DownloadErrorFiles { get; set; }
    }

    /// <summary>
    /// 获取实验室文件处理记录
    /// </summary>
    public class GetLabConvertStateDBRequest
    {
        /// <summary>
        /// 创建者编码
        /// </summary>
        /// <value></value>
        public string CreatorCode { get; set; }
    }

    /// <summary>
    /// 下载错误文件信息
    /// </summary>
    public class DownloadFileInfoDTO
    {
        /// <summary>
        /// 文件地址信息
        /// </summary>
        /// <code>0</code>
        public List<FileUploadInfoDTO> FileUploadInfos { get; set; }

        /// <summary>
        /// 文件夹编码
        /// </summary>
        /// <value></value>
        public string FolderCode { get; set; }

        /// <summary>
        /// 文件名称
        /// </summary>
        /// <value></value>
        public string FileName { get; set; }
    }

    /// <summary>
    /// 转换错误文件信息
    /// </summary>
    public class ConvertFileInfoDTO
    {
        /// <summary>
        /// 记录code/文件夹code
        /// </summary>
        /// <value></value>
        public string RecordCode { get; set; }

        /// <summary>
        /// 文件路径
        /// </summary>
        /// <value></value>
        public string FilePath { get; set; }

        /// <summary>
        /// 文件夹编码
        /// </summary>
        /// <value></value>
        public string FolderCode { get; set; }

        /// <summary>
        /// 文件格式
        /// </summary>
        /// <value></value>
        public UploadFileTypeEnum FileType { get; set; }
    }
}
