using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.DB.Request
{
    /// <summary>
    /// 查询检查记录分页
    /// </summary>
    public class FindRecordInfoPagesRequest : PageFilterRequest
    {

        /// <summary>
        /// 设备code列表
        /// </summary>
        /// <value></value>
        public List<string> DeviceCodes { get; set; }

        /// <summary>
        /// 病人code列表
        /// </summary>
        /// <value></value>
        public List<string> PatientCodes { get; set; }

        /// <summary>
        /// 检查code列表
        /// </summary>
        /// <value></value>
        public List<string> RecordCodes { get; set; }

        /// <summary>
        /// 当前登陆人
        /// </summary>
        /// <value></value>
        public string UserCode { get; set; }

        public List<string> OrganizationCodes { get; set; }

        public RecordProcessStateEnum RecordProcessState { get; set; } = RecordProcessStateEnum.All;

        public string Language { get; set; } = "en-US";

        /// <summary>
        /// 是否不根据用户权限筛选
        /// </summary>
        /// <value></value>
        public bool NotFilterByFeature { get; set; }

    }

    /// <summary>
    /// 查询完整检查记录分页
    /// </summary>
    public class FindFullRecordInfoPagesRequest : FindRecordInfoPagesRequest
    {

    }

    /// <summary>
    /// 分页查询超声检查记录
    /// </summary>
    public class FindRecordByPageDBRequest : PageFilterRequest
    {
        /// <summary>
        /// 用户编码
        /// </summary>
        /// <value></value>
        public string UserCode { get; set; }
        
        /// <summary>
        /// 机构编码
        /// </summary>
        /// <value></value>
        public string OrganizationCode { get; set; }

        public RecordQueryStateEnum RecordQueryState { get; set; } = RecordQueryStateEnum.All;

        public RecordProcessStateEnum RecordProcessState { get; set; } = RecordProcessStateEnum.All;

        public string Language { get; set; } = "en-US";

        public string KeyWord { get; set; }

        public DateTime StartTime { get; set; }

        public DateTime EndTime { get; set; }
    }
}