using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.LiveConsultation.Enums;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.DTO.Patient;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.DB.Request
{
    /// <summary>
    /// 查询会诊记录分页
    /// </summary>
    public class GetConsultationRecordPagesDBRequest : PageFilterRequest
    {
        /// <summary>
        /// usercode
        /// </summary>
        /// <value></value>
        public string UserCode { get; set; }

        /// <summary>
        /// 关键字【姓名、申请单位、年龄、性别】
        /// </summary>
        /// <value>马丽</value>
        /// <code>0</code>
        public string Keyword { get; set; } = string.Empty;

        /// <summary>
        /// 会诊日期，起
        /// </summary>
        /// <value>2022-08-27</value>
        public DateTime StartDate { get; set; }

        /// <summary>
        /// 会诊日期，止
        /// </summary>
        /// <value>2022-08-27</value>
        public DateTime EndDate { get; set; }

        /// <summary>
        /// 状态
        /// </summary>
        /// <value></value>
        public QueryConsultationStatusEnum ConsultationStatus { get; set; }

        /// <summary>
        /// 评价等级
        /// </summary>
        /// <value>0</value>
        public QueryEvaluateGradeEnum EvaluateGrade { get; set; }

        /// <summary>
        /// 会诊查询类型枚举
        /// </summary>
        /// <value>0</value>
        public ConsultationQueryTypeEnum ConsultationQueryType { get; set; }

        /// <summary>
        /// 查询专家编码集合
        /// </summary>
        /// <value>Expert_123</value>
        /// <code>0</code>
        public List<string> ExpertCodes { get; set; }

        /// <summary>
        /// 申请机构编码集合
        /// </summary>
        /// <value>Org_123,Org_456</value>
        /// <code>0</code>
        public List<string> ApplyOrganizationCodes { get; set; }

        /// <summary>
        /// 会诊机构编码集合
        /// </summary>
        /// <value>ExpertOrg_123,Org_456</value>
        /// <code>0</code>
        public List<string> ExpertOrganizationCodes { get; set; }

        /// <summary>
        /// 患者性别，默认空
        /// </summary>
        /// <value>Female</value>
        /// <code>0</code>
        public string PatientSex { get; set; }

        /// <summary>
        /// 查询年龄范围
        /// </summary>
        /// <value></value>
        public QueryPatientAgeLimitDTO PatientAgeLimit { get; set; }

        /// <summary>
        /// 疾病名称
        /// </summary>
        /// <value>疾病</value>
        /// <code>0</code>
        public string PatientDiseases { get; set; }

        /// <summary>
        /// 初步诊断
        /// </summary>
        /// <value>初步诊断</value>
        /// <code>0</code>
        public string PatientPrimaryDiagnosis { get; set; }
    }

    /// <summary>
    /// 导出会诊数据
    /// </summary>
    public class ExportConsultationRecordsDBRequest
    {
        public string Language { get; set; } = "en-US";

        /// <summary>
        /// 是否导出报告
        /// </summary>
        /// <value>true</value>
        /// <code>0</code>
        public bool IsExportReport { get; set; } = false;

        /// <summary>
        /// 是否导出会诊记录
        /// </summary>
        /// <value>true</value>
        /// <code>0</code>
        public bool IsExportConsultation { get; set; } = false;

        /// <summary>
        /// 是否导出图像
        /// </summary>
        /// <value>true</value>
        /// <code>0</code>
        public bool IsExportConsultationFileData { get; set; } = false;

        /// <summary>
        /// usercode
        /// </summary>
        /// <value></value>
        public string UserCode { get; set; }

        /// <summary>
        /// 关键字【姓名、申请单位、年龄、性别】
        /// </summary>
        /// <value>马丽</value>
        /// <code>0</code>
        public string Keyword { get; set; } = string.Empty;

        /// <summary>
        /// 会诊日期，起
        /// </summary>
        /// <value>2022-08-27</value>
        public DateTime StartDate { get; set; }

        /// <summary>
        /// 会诊日期，止
        /// </summary>
        /// <value>2022-08-27</value>
        public DateTime EndDate { get; set; }

        /// <summary>
        /// 状态
        /// </summary>
        /// <value></value>
        public QueryConsultationStatusEnum ConsultationStatus { get; set; }

        /// <summary>
        /// 评价等级
        /// </summary>
        /// <value>0</value>
        public QueryEvaluateGradeEnum EvaluateGrade { get; set; }

        /// <summary>
        /// 会诊查询类型枚举
        /// </summary>
        /// <value>0</value>
        public ConsultationQueryTypeEnum ConsultationQueryType { get; set; }

        /// <summary>
        /// 查询专家编码集合
        /// </summary>
        /// <value>Expert_123</value>
        /// <code>0</code>
        public List<string> ExpertCodes { get; set; }

        /// <summary>
        /// 申请机构编码集合
        /// </summary>
        /// <value>Org_123,Org_456</value>
        /// <code>0</code>
        public List<string> ApplyOrganizationCodes { get; set; }

        /// <summary>
        /// 会诊机构编码集合
        /// </summary>
        /// <value>ExpertOrg_123,Org_456</value>
        /// <code>0</code>
        public List<string> ExpertOrganizationCodes { get; set; }

        /// <summary>
        /// 患者性别，默认空
        /// </summary>
        /// <value>Female</value>
        /// <code>0</code>
        public string PatientSex { get; set; }

        /// <summary>
        /// 查询年龄范围
        /// </summary>
        /// <value></value>
        public QueryPatientAgeLimitDTO PatientAgeLimit { get; set; }

        /// <summary>
        /// 疾病名称
        /// </summary>
        /// <value>疾病</value>
        /// <code>0</code>
        public string PatientDiseases { get; set; }

        /// <summary>
        /// 初步诊断
        /// </summary>
        /// <value>初步诊断</value>
        /// <code>0</code>
        public string PatientPrimaryDiagnosis { get; set; }
    }


}