using System.Collections.Generic;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.ResearchEdition;

namespace WingInterfaceLibrary.DB.Request
{
    /// <summary>
    /// 项目任务db请求实体
    /// </summary>
    public class ResearchProjectTaskDBRequest
    {
        /// <summary>
        /// 操作人code
        /// </summary>
        /// <value></value>
        public string UserCode { get; set; }

        /// <summary>
        /// 操作人
        /// </summary>
        /// <value></value>
        public string UserName { get; set; }
    }

    /// <summary>
    /// 创建项目任务db请求实体
    /// </summary>

    public class CreateResearchProjectTaskDBRequest : ResearchProjectTaskDBRequest
    {
        /// <summary>
        /// 业务code
        /// </summary>
        /// <value></value>
        public string BusinessCode { get; set; }

        /// <summary>
        /// 任务类型
        /// </summary>
        /// <value></value>
        public VTaskType TaskType { get; set; }

        /// <summary>
        /// 任务名称
        /// </summary>
        /// <value></value>
        public string Name { get; set; }

        /// <summary>
        /// 任务列表
        /// </summary>
        /// <value></value>
        public List<CreateTaskDetailInfo> TaskDetailList { get; set; }
    }

    /// <summary>
    /// 修改项目任务db及进度请求实体
    /// </summary>
    public class UpdateResearchProjectTaskDBRequest : ResearchProjectTaskDBRequest
    {
        /// <summary>
        /// 任务Code
        /// </summary>
        /// <value></value>
        public string MainTaskCode { get; set; }

        /// <summary>
        /// 子任务Id
        /// </summary>
        /// <value></value>
        public string Id { get; set; }

        /// <summary>
        /// 结果 成功、失败
        /// </summary>
        /// <value></value>
        public bool Result { get; set; } = false;

        /// <summary>
        /// 任务状态
        /// </summary>
        /// <value></value>
        public VTaskStatus Status { get; set; }

        /// <summary>
        /// 进度 %
        /// </summary>
        /// <value></value>
        public double Rate { get; set; }
    }

    /// <summary>
    /// 获取任务列表请求实体
    /// </summary>
    public class GetMainTaskListDBRequest : ResearchProjectTaskDBRequest
    {
        /// <summary>
        /// 关键字
        /// </summary>
        /// <value></value>
        public string KeyWord { get; set; }

        /// <summary>
        /// 任务状态   主任务只有进行中和已完成
        /// </summary>
        /// <value></value>
        public VTaskStatus Status { get; set; }

        /// <summary>
        /// 任务Code
        /// </summary>
        /// <value></value>
        public string TaskCode { get; set; }
    }
}