using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Record;
using WingInterfaceLibrary.DTO.Report;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.DB.Request
{
    /// <summary>
    /// 保存报告信息请求实体
    /// </summary>
    public class SaveReportDBRequest
    {
        /// <summary>
        /// 报告编码
        /// </summary>
        /// <value>ReportCode_20220107104236xiP0nz</value>
        public string ReportCode { get; set; } = string.Empty;

        /// <summary>
        /// 检查编码
        /// </summary>
        /// <value>RecordInfoDO_202205111056024lshF5</value>
        public string RecordCode { get; set; } = string.Empty;

        /// <summary>
        /// 报告医生
        /// </summary>
        /// <value>UserInfoDO_20220512085239q5PuMr</value>
        public string ReportUserCode { get; set; } = string.Empty;

        /// <summary>
        /// 设备编码
        /// </summary>
        /// <value>DeviceInfoDO_202203161140268N2afK</value>
        public string DeviceCode { get; set; } = string.Empty;

        /// <summary>
        /// 病人Code
        /// </summary>
        /// <value>PatientInfoDO_202203161140268N2afK</value>
        public string PatientCode { get; set; } = string.Empty;

        /// <summary>
        /// 报告模板Json
        /// </summary>
        /// <value>{"Id":"2013ff22-1147-4d67-9fb3-d6ec1f28d39e","Name":"常规"}</value>
        public string ReportTemplateJson { get; set; } = string.Empty;

        /// <summary>
        /// 报告内容Json
        /// </summary>
        /// <value>[{"Key":"PatientId","Value":"321283199103021215"},{"Key":"PatientName","Value":"苏灿"}]</value>
        public string ReportDatasJson { get; set; } = string.Empty;

        /// <summary>
        /// 报告测量项内容Json
        /// </summary>
        public string ReportMeasureDatasJson { get; set; } = string.Empty;

        /// <summary>
        /// 病人Id
        /// </summary>
        /// <value>321283199103021215</value>
        public string PatientId { get; set; } = string.Empty;

        /// <summary>
        /// 病人姓名
        /// </summary>
        /// <value>苏灿</value>
        public string PatientName { get; set; } = string.Empty;

        /// <summary>
        /// 报告标签
        /// </summary>
        /// <value>"良性","脂肪肝"</value>
        public List<string> ReportLabels { get; set; } = new List<string>();

        /// <summary>
        /// 来源标签
        /// </summary>
        /// <value>"Flyinsono","PC","RemoteDiagnosis"</value>
        public List<string> PlatformLabels { get; set; } = new List<string>();

        /// <summary>
        /// 诊断标签
        /// </summary>
        /// <value>"AI","Carcinoid"</value>
        public List<string> DiagnosisLabels { get; set; } = new List<string>();

        /// <summary>
        /// 检查器官
        /// </summary>
        /// <value>2</value>
        public DiagnosisOrganEnum ReportOrgan { get; set; }

        /// <summary>
        /// 转诊记录编码
        /// </summary>
        /// <value>ReferralRecordCode_***</value>
        public string ReferralRecordCode { get; set; } = string.Empty;

        /// <summary>
        /// 业务类型
        /// </summary>
        /// <value>0</value>
        public ReportTypeEnum ReportType { get; set; } = ReportTypeEnum.RemoteDiagnosis;

        /// <summary>
        /// 是否转诊报告
        /// </summary>
        /// <value></value>
        public bool IsReferral { get; set; }

        /// <summary>
        /// 报告模版Code
        /// </summary>
        /// <value></value>
        public string ReportTemplateCode { get; set; }

        /// <summary>
        /// 设备报告id
        /// </summary>
        /// <value></value>
        public string DeviceReportId { get; set; }

        /// <summary>
        /// 报告PDF地址
        /// </summary>
        /// <value></value>
        public string ReportPDFUrl { get; set; }

        /// <summary>
        /// 语言
        /// </summary>
        /// <value></value>
        public string LanguageCode { get; set; }

        /// <summary>
        /// 提交报告的原始信息数据
        /// </summary>
        /// <value></value>
        public string ReportExamDataJson { get; set; }

        /// <summary>
        /// 健康诊断 0：默认；1：正常；2：异常
        /// </summary>
        /// <value></value>
        public int HealthDiagnosis { get; set; }
    }

    /// <summary>
    /// 保存报告质控信息
    /// </summary>
    public class SaveReportQualityInfoDBRequest
    {
        /// <summary>
        /// 报告code
        /// </summary>
        /// <value></value>
        public string ReportCode { get; set; }

        /// <summary>
        /// 质控状态枚举
        /// </summary>
        /// <value></value>
        public QualityType QualityType { get; set; } = QualityType.None;

        /// <summary>
        /// 质控合格状态
        /// </summary>
        /// <value></value>
        public QualifiedState QualifiedState { get; set; } = QualifiedState.UnSet;

        /// <summary>
        /// 质控结果
        /// </summary>
        /// <value></value>
        public ReportQualityControl QualityControlDatas { get; set; }
    }
}