using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.DB.Request
{
    public class GetTaskListDBRequest
    {
        /// <summary>
        /// 任务状态
        /// </summary>
        /// <value></value>
        public VTaskStatus? TaskStatus { get; set; }

        /// <summary>
        /// 任务类型
        /// </summary>
        /// <value></value>
        public VTaskType? TaskType { get; set; }

        /// <summary>
        /// 是否队列处理
        /// </summary>
        /// <value></value>
        public bool? IsJoinQueue { get; set; }

        /// <summary>
        /// 主任务Code
        /// </summary>
        /// <value></value>
        public string MainTaskCode { get; set; }


    }


    /// <summary>
    /// 创建任务
    /// </summary>
    public class CreateTaskDBRequest
    {

        /// <summary>
        /// id(客户端任务标识)
        /// </summary>
        /// <value></value>
        public string BusinessId { get; set; }

        /// <summary>
        /// 任务类型
        /// </summary>
        /// <value></value>
        public VTaskType TaskType { get; set; }

        /// <summary>
        /// 任务名称
        /// </summary>
        /// <value></value>
        public string TaskName { get; set; }

        /// <summary>
        /// 描述
        /// </summary>
        /// <value></value>
        public string Description { get; set; }

        /// <summary>
        /// 业务code
        /// </summary>
        /// <value></value>
        public string BusinessCode { get; set; }

        /// <summary>
        /// 主任务Code
        /// </summary>
        /// <value></value>
        public string MainTaskCode { get; set; }

        /// <summary>
        /// 是否是插队任务
        /// </summary>
        /// <value></value>
        public bool IsJumpQueue { get; set; }

        /// <summary>
        /// 是否加入队列处理（如果是非加入队列处理的为false）
        /// </summary>
        /// <value></value>
        public bool IsJoinQueue { get; set; } = false;

        /// <summary>
        ///  操作人code
        /// </summary>
        /// <value></value>
        public string UserCode { get; set; }

        /// <summary>
        /// 作人
        /// </summary>
        /// <value></value>
        public string UserName { get; set; }

        /// <summary>
        /// 任务所需json数据
        /// </summary>
        /// <value></value>
        public string JsonData { get; set; }

        /// <summary>
        /// 样本编码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }
    }

    /// <summary>
    /// 修改任务
    /// </summary>
    public class UpdateTaskDBRequest : CreateTaskDBRequest
    {
        /// <summary>
        /// Code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 结果 成功、失败
        /// </summary>
        /// <value></value>
        public bool Result { get; set; }

        /// <summary>
        /// 任务进度（百分比）
        /// </summary>
        /// <value></value>
        public double Rate { get; set; }

        /// <summary>
        /// 任务状态
        /// </summary>
        /// <value></value>
        public VTaskStatus Status { get; set; }

    }

    /// <summary>
    /// 删除任务
    /// </summary>
    public class DeleteTaskDBRequest
    {

        /// <summary>
        /// Code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }
    }

    /// <summary>
    /// 查询任务
    /// </summary>
    public class GetTaskDBRequest
    {

        /// <summary>
        /// Code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }
    }
}