using WingInterfaceLibrary.Enum;
using System;
using WingInterfaceLibrary.DTO.Message;
using System.Collections.Generic;

namespace WingInterfaceLibrary.Request.DBRequest
{
    /// <summary>
    /// 分页获取健康检查预约数据 请求
    /// </summary>
    public class GetHealthExamBookingPageDBRequest : PageRequest
    {
        /// <summary>
        /// 查询关键字
        /// </summary>
        /// <value></value>
        public string Keyword { get; set; }

        /// <summary>
        /// 机构集合
        /// </summary>
        /// <value></value>
        public List<string> OrgCodes { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value></value>
        public DateTime StartTime { get; set; }
        
        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value></value>
        public DateTime EndTime { get; set; }
        
        /// <summary>
        /// 按照更新时间正序
        /// </summary>
        /// <value></value>
        public bool OrderByAscending { get; set; }
    }

    /// <summary>
    /// 根据编码获取健康体检预约数据请求
    /// </summary>
    public class GetHealthExamBookingDBRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 获取最近提交/获取时间 请求
    /// </summary>
    public class GetLatestSyncTimeDBRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 更新最近提交/获取时间 请求
    /// </summary>
    public class UpdateLatestSyncTimeDBRequest
    {
        public string Code { get; set; }
        public DateTime LatestSyncTime { get; set; }
    }

    /// <summary>
    /// 删除健康体检预约数据请求
    /// </summary>
    public class RemoveHealthExamBookingDBRequest
    {
        public string Code { get; set; }
        public DateTime UpdateTime { get; set; }
    }

    /// <summary>
    /// 删除多个健康体检预约数据请求
    /// </summary>
    public class RemoveHealthExamBookingListDBRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 获取健康体检预约数据列表请求
    /// </summary>
    public class GetHealthExamBookingListDBRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 健康体检预约报名数据请求
    /// </summary>
    public class HealthExamBookingSignUpDBRequest
    {
        /// <summary>
        /// 体检记录编码
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 姓名
        /// </summary>
        /// <value></value>
        public string Name { get; set; }

        /// <summary>
        /// 性别
        /// </summary>
        /// <value></value>
        public PatientGenderEnum Gender { get; set; }

        /// <summary>
        /// 证件号
        /// </summary>
        /// <value></value>
        public string IdentityCard { get; set; }

        /// <summary>
        /// 手机号
        /// </summary>
        /// <value></value>
        public string Phone { get; set; }
        
        public DateTime UpdateTime { get; set; }
    }
}