using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum.VitalEnum;

namespace WingInterfaceLibrary.Request.DBVitalRequest
{
    /// <summary>
    /// 创建接口解析配置数据请求
    /// </summary>
    public class CreateAnalyzeConfigDBRequest  : DBBaseRequest 
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();

        /// <summary>
        /// 输入的字段
        /// </summary>
        /// <value></value>
        public string InField { get; set; }

        /// <summary>
        /// 输出的字段
        /// </summary>
        /// <value></value>
        public string OutField  { get; set; }

        /// <summary>
        /// 解析方式
        /// </summary>
        /// <value></value>
        public string Mode { get; set; }

        /// <summary>
        /// 模版
        /// </summary>
        /// <value></value>
        public string Template { get; set; }

        /// <summary>
        /// 解析配置
        /// </summary>
        /// <value></value>
        public string AnalyzeConfigItems { get; set; }
    }

    /// <summary>
    /// 根据编码获取接口解析配置数据请求
    /// </summary>
    public class GetAnalyzeConfigDBRequest  : DBBaseRequest 
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取接口解析配置数据请求
    /// </summary>
    public class GetAnalyzeConfigByKeyDBRequest  : DBBaseRequest 
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除接口解析配置数据请求
    /// </summary>
    public class RemoveAnalyzeConfigDBRequest  : DBBaseRequest 
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 删除多个接口解析配置数据请求
    /// </summary>
    public class RemoveAnalyzeConfigListDBRequest   : DBBaseRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 获取接口解析配置数据列表请求
    /// </summary>
    public class GetAnalyzeConfigListDBRequest  : DBBaseRequest 
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取接口解析配置数据列表请求
    /// </summary>
    public class GetAnalyzeConfigListByKeyDBRequest  : DBBaseRequest 
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 更新接口解析配置数据请求
    /// </summary>
    public class UpdateAnalyzeConfigDBRequest  : DBBaseRequest 
    {
        public string Code { get; set; }
        /// <summary>
        /// 输入的字段
        /// </summary>
        /// <value></value>
        public string InField { get; set; }

        /// <summary>
        /// 输出的字段
        /// </summary>
        /// <value></value>
        public string OutField  { get; set; }

        /// <summary>
        /// 解析方式
        /// </summary>
        /// <value></value>
        public string Mode { get; set; }

        /// <summary>
        /// 模版
        /// </summary>
        /// <value></value>
        public string Template { get; set; }

        /// <summary>
        /// 解析配置
        /// </summary>
        /// <value></value>
        public string AnalyzeConfigItems { get; set; }
    }
}