using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum.VitalEnum;

namespace WingInterfaceLibrary.Request.DBVitalRequest
{
    /// <summary>
    /// 创建履约记录数据请求
    /// </summary>
    public class CreateCompletionRecordDBRequest:DBBaseRequest
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
		/// <summary>
		/// 履约医生
		/// </summary>
		/// <value></value>
		public string CompletionDoctor { get; set; }
		/// <summary>
		/// 居民代码
		/// </summary>
		/// <value></value>
		public string PatientCode { get; set; }
		/// <summary>
		/// 服务包装代码
		/// </summary>
		/// <value></value>
		public string ServicePackCode { get; set; }
		/// <summary>
		/// 服务包装名称
		/// </summary>
		/// <value></value>
		public string ServicePackName { get; set; }
		/// <summary>
		/// 服务商品代码
		/// </summary>
		/// <value></value>
		public string ServiceItemCode { get; set; }
		/// <summary>
		/// 服务商品名称
		/// </summary>
		/// <value></value>
		public string ServiceItemName { get; set; }
		/// <summary>
		/// 履约内容
		/// </summary>
		/// <value></value>
		public string CompletionContent { get; set; }
		/// <summary>
		/// 备注
		/// </summary>
		/// <value></value>
		public string Notes { get; set; }
		/// <summary>
		/// 履约时间
		/// </summary>
		/// <value></value>
		public DateTime CompletionTime { get; set; }
		/// <summary>
		/// 下一个履约时间
		/// </summary>
		/// <value></value>
		public DateTime NextCompletionTime { get; set; }
    }

    /// <summary>
    /// 根据编码获取履约记录数据请求
    /// </summary>
    public class GetCompletionRecordDBRequest :DBBaseRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取履约记录数据请求
    /// </summary>
    public class GetCompletionRecordByKeyDBRequest :DBBaseRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除履约记录数据请求
    /// </summary>
    public class RemoveCompletionRecordDBRequest :DBBaseRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 删除多个履约记录数据请求
    /// </summary>
    public class RemoveCompletionRecordListDBRequest :DBBaseRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 获取履约记录数据列表请求
    /// </summary>
    public class GetCompletionRecordListDBRequest :DBBaseRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取履约记录数据列表请求
    /// </summary>
    public class GetCompletionRecordListByKeyDBRequest :DBBaseRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 更新履约记录数据请求
    /// </summary>
    public class UpdateCompletionRecordDBRequest : DBBaseRequest
    {
        public string Code { get; set; }
		/// <summary>
		/// 履约医生
		/// </summary>
		/// <value></value>
		public string CompletionDoctor { get; set; }
		/// <summary>
		/// 居民代码
		/// </summary>
		/// <value></value>
		public string PatientCode { get; set; }
		/// <summary>
		/// 服务包装代码
		/// </summary>
		/// <value></value>
		public string ServicePackCode { get; set; }
		/// <summary>
		/// 服务包装名称
		/// </summary>
		/// <value></value>
		public string ServicePackName { get; set; }
		/// <summary>
		/// 服务商品代码
		/// </summary>
		/// <value></value>
		public string ServiceItemCode { get; set; }
		/// <summary>
		/// 服务商品名称
		/// </summary>
		/// <value></value>
		public string ServiceItemName { get; set; }
		/// <summary>
		/// 履约内容
		/// </summary>
		/// <value></value>
		public string CompletionContent { get; set; }
		/// <summary>
		/// 备注
		/// </summary>
		/// <value></value>
		public string Notes { get; set; }
		/// <summary>
		/// 履约时间
		/// </summary>
		/// <value></value>
		public DateTime CompletionTime { get; set; }
		/// <summary>
		/// 下一个履约时间
		/// </summary>
		/// <value></value>
		public DateTime NextCompletionTime { get; set; }

    }
}