using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum.VitalEnum;

namespace WingInterfaceLibrary.Request.DBVitalRequest
{
    /// <summary>
    /// 创建合约记录数据请求
    /// </summary>
    public class CreateContractRecordDBRequest : DBBaseRequest
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
        /// <summary>
        /// 合约记录编号
        /// </summary>
        /// <value></value>
        public string ContractRecordNo { get; set; }
        /// <summary>
        /// 合约是有效
        /// </summary>
        /// <value></value>
        public bool ContractIsValid { get; set; }
        /// <summary>
        /// 已签约医生
        /// </summary>
        /// <value></value>
        public string ContractedDoctor { get; set; }
        /// <summary>
        /// 已签约居民
        /// </summary>
        /// <value></value>
        public string ContractedPatient { get; set; }
        /// <summary>
        /// 已签约团队
        /// </summary>
        /// <value></value>
        public string ContractedTeam { get; set; }
        /// <summary>
        /// 已签约
        /// </summary>
        /// <value></value>
        public DateTime ContractedTime { get; set; }
        /// <summary>
        /// 审核状态
        /// </summary>
        /// <value></value>
        public AuditStateEnum AuditState { get; set; }
        /// <summary>
        /// 已签约文件URL
        /// </summary>
        /// <value></value>
        public string ContractedFileUrl { get; set; }
        /// <summary>
        /// 服务包
        /// </summary>
        /// <value></value>
        public List<string> ServicePacks { get; set; }
        /// <summary>
        /// 服务开始日期
        /// </summary>
        /// <value></value>
        public DateTime ServiceStartDate { get; set; }
        /// <summary>
        /// 服务结束日期
        /// </summary>
        /// <value></value>
        public DateTime ServiceEndDate { get; set; }
        /// <summary>
        /// 照片
        /// </summary>
        /// <value></value>
        public List<string> Photos { get; set; }
        /// <summary>
        /// 备注
        /// </summary>
        /// <value></value>
        public string Notes { get; set; }
        /// <summary>
		/// 合约状态
		/// </summary>
		/// <value></value>
		public ContractStateEnum? ContractState { get; set; } = null;
		/// <summary>
        /// 原因
        /// </summary>
        /// <value></value>
        public string Reason { get; set; } = string.Empty;

        /// <summary>
        /// 签约医生
        /// </summary>
        /// <value></value>
        public string ContractedDoctorName { get; set; }

        /// <summary>
        /// 医生电话
        /// </summary>
        /// <value></value>
        public string ContractedDoctorPhone { get; set; }

        /// <summary>
        /// 团队负责人
        /// </summary>
        /// <value></value>
        public string TeamLeaderName { get; set; }

        /// <summary>
        /// 指导医生
        /// </summary>
        /// <value></value>
        public string PreceptorName { get; set; }

        /// <summary>
        /// 续签签约编码
        /// </summary>
        /// <value></value>
        public string RenewalContractCode { get; set; }
    }

    /// <summary>
    /// 根据编码获取合约记录数据请求
    /// </summary>
    public class GetContractRecordDBRequest : DBBaseRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取合约记录数据请求
    /// </summary>
    public class GetContractRecordByKeyDBRequest : DBBaseRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除合约记录数据请求
    /// </summary>
    public class RemoveContractRecordDBRequest : DBBaseRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 删除多个合约记录数据请求
    /// </summary>
    public class RemoveContractRecordListDBRequest : DBBaseRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 获取合约记录数据列表请求
    /// </summary>
    public class GetContractRecordListDBRequest : DBBaseRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取合约记录数据列表请求
    /// </summary>
    public class GetContractRecordListByKeyDBRequest : DBBaseRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 查询医生最近签约记录数据请求
    /// </summary>
    public class GetDoctorContractRecordDBRequest : DBBaseRequest
    {
        public string CreatedDoctor { get; set; }
    }

    /// <summary>
    /// 查询续签关联的签约记录数据请求
    /// </summary>
    public class GetRenewalContractDBRequest : DBBaseRequest
    {
        public string RenewalContractCode { get; set; }
    }

    /// <summary>
    /// 更新合约记录数据请求
    /// </summary>
    public class UpdateContractRecordDBRequest : DBBaseRequest
    {
        public string Code { get; set; }
        /// <summary>
        /// 合约记录编号
        /// </summary>
        /// <value></value>
        public string ContractRecordNo { get; set; }
        /// <summary>
        /// 合约状态
        /// </summary>
        /// <value></value>
        public ContractStateEnum? ContractState { get; set; }
        /// <summary>
        /// 合约是有效
        /// </summary>
        /// <value></value>
        public bool? ContractIsValid { get; set; }
        /// <summary>
        /// 已签约医生
        /// </summary>
        /// <value></value>
        public string ContractedDoctor { get; set; }
        /// <summary>
        /// 已签约居民
        /// </summary>
        /// <value></value>
        public string ContractedPatient { get; set; }
        /// <summary>
        /// 已签约团队
        /// </summary>
        /// <value></value>
        public string ContractedTeam { get; set; }
        /// <summary>
        /// 已签约
        /// </summary>
        /// <value></value>
        public DateTime? ContractedTime { get; set; }
        /// <summary>
        /// 审核状态
        /// </summary>
        /// <value></value>
        public AuditStateEnum? AuditState { get; set; }
        /// <summary>
        /// 已签约文件URL
        /// </summary>
        /// <value></value>
        public string ContractedFileUrl { get; set; }
        /// <summary>
        /// 服务包
        /// </summary>
        /// <value></value>
        public List<string> ServicePacks { get; set; }
        /// <summary>
        /// 服务开始日期
        /// </summary>
        /// <value></value>
        public DateTime? ServiceStartDate { get; set; }
        /// <summary>
        /// 服务结束日期
        /// </summary>
        /// <value></value>
        public DateTime? ServiceEndDate { get; set; }
        /// <summary>
        /// 照片
        /// </summary>
        /// <value></value>
        public List<string> Photos { get; set; }
        /// <summary>
        /// 备注
        /// </summary>
        /// <value></value>
        public string Notes { get; set; }

    }

    /// <summary>
    /// 更新合约记录数据请求
    /// </summary>
    public class UpdateContractRecordStateDBRequest : DBBaseRequest
    {
        public string Code { get; set; }

        /// <summary>
        /// 合约状态
        /// </summary>
        /// <value></value>
        public ContractStateEnum? ContractState { get; set; } = null;

        /// <summary>
        /// 原因
        /// </summary>
        /// <value></value>
        public string Reason { get; set; }
    }

    /// <summary>
    /// 查询最后一次签约记录的信息
    /// </summary>
    public class GetPatientLastContractRecordDBRequest : DBPageRequest
    {
        /// <summary>
        /// 居民编码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }
    }
}