using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Net.Http;
using System.Threading;
using System.Threading.Tasks;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Enum.VitalEnum;

namespace WingInterfaceLibrary.Request.DBVitalRequest
{
    /// <summary>
    /// 创建设备请求
    /// </summary>
    public class CreateDeviceDBRequest : DBBaseRequest
    {
        /// <summary>
        /// 编码
        /// </summary>
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
        /// <summary>
        /// 序列号（物理唯一码）
        /// </summary>
        /// <value>0000-1234</value>
        public string SerialNumber { get; set; }

        /// <summary>
        /// 型号
        /// </summary>
        /// <value>健康一体机V2</value>
        public string Model { get; set; }

        /// <summary>
        /// 软件版本
        /// </summary>
        ///  <value>2.0.0.1</value>
        public string SoftwareVersion { get; set; }

        /// <summary>
        /// 系统版本
        /// </summary>
        ///  <value>1.0.0.1</value>
        public string OSVersion { get; set; }

        /// <summary>
        /// 描述
        /// </summary>
        ///  <value>第一个组织</value>
        public string Description { get; set; }

        /// <summary>
        /// 组织代码
        /// </summary>
        /// <value></value>
        /// <value>090990</value>
        public string OrganizationCode { get; set; }

        /// <summary>
        /// 团队代码
        /// </summary>
        /// <value></value>
        public string TeamCode { get; set; }

        /// <summary>
        /// 外设设备权限
        /// </summary>
        public List<PeripheralDeviceDTO> PeripheralPermissions { get; set; }

        /// <summary>
        /// 0-平板终端，1-心电
        /// </summary>
        /// <value></value>
        public int DeviceType { get; set; }
    }

    /// <summary>
    /// 获取设备详细信息
    /// </summary>
    public class GetDeviceDBRequest : DBBaseRequest
    {
        /// <summary>
        /// Code
        /// </summary>
        public string Code { get; set; }
    }

    /// <summary>
    /// 唯一码获取设备信息
    /// </summary>
    public class GetDeviceByUniqueCodeDBRequest : DBBaseRequest
    {
        /// <summary>
        /// UniqueCode
        /// </summary>
        public string UniqueCode { get; set; }
    }

    /// <summary>
    ///设置设备对应的医院和部门请求 
    /// </summary>
    public class SetDeviceOrganizationDBRequest : DBBaseRequest
    {

        /// <summary>
        /// Code
        /// </summary>
        public string Code { get; set; }

        /// <summary>
        /// 组织代码
        /// </summary>
        /// <value></value>
        /// <value>090990</value>
        public string OrganizationCode { get; set; }


        /// <summary>
        /// 团队代码
        /// </summary>
        /// <value></value>
        public string TeamCode { get; set; }
    }

    /// <summary>
    /// 删除设备请求
    /// </summary>
    public class RemoveDeviceDBRequest : DBBaseRequest
    {
        /// <summary>
        /// Code
        /// </summary>
        public string Code { get; set; }
    }

    /// <summary>
    /// 更新设备请求
    /// </summary>
    public class UpdateDeviceDBRequest : DBBaseRequest
    {
        /// <summary>
        /// Code
        /// </summary>
        public string Code { get; set; }
        /// <summary>
        /// 型号
        /// </summary>
        /// <value>健康一体机V2</value>
        public string Model { get; set; }

        /// <summary>
        /// 软件版本
        /// </summary>
        ///  <value>2.0.0.1</value>
        public string SoftwareVersion { get; set; }

        /// <summary>
        /// 系统版本
        /// </summary>
        ///  <value>1.0.0.1</value>
        public string OSVersion { get; set; }

        /// <summary>
        /// 描述
        /// </summary>
        ///  <value>第一个组织</value>
        public string Description { get; set; }

        /// <summary>
        /// 组织代码
        /// </summary>
        /// <value></value>
        /// <value>090990</value>
        public string OrganizationCode { get; set; }


        /// <summary>
        /// 团队代码
        /// </summary>
        /// <value></value>
        public string TeamCode { get; set; }
    }

    /// <summary>
    /// 上报设备信息
    /// </summary>
    public class ReportingDeviceInfoDBRequest : DBBaseRequest
    {
        /// <summary>
        /// 序列号（物理唯一码）
        /// </summary>
        /// <value>0000-1234</value>
        public string SerialNumber { get; set; }

        /// <summary>
        /// 型号
        /// </summary>
        /// <value>健康一体机V2</value>
        public string Model { get; set; }

        /// <summary>
        /// 软件版本
        /// </summary>
        ///  <value>2.0.0.1</value>
        public string SoftwareVersion { get; set; }

        /// <summary>
        /// 系统版本
        /// </summary>
        ///  <value>1.0.0.1</value>
        public string OSVersion { get; set; }
    }

    /// <summary>
    /// 创建外设设备请求
    /// </summary>
    public class CreatePeripheralDeviceDBRequest : DBBaseRequest
    {
        /// <summary>
        /// 主设备编码
        /// </summary>
        /// <value></value>
        public string DeviceCode { get; set; }

        /// <summary>
        /// 外设设备Key
        /// </summary>
        /// <value></value>
        public string Key { get; set; }

        /// <summary>
        /// 外设设备名称
        /// </summary>
        public string Name { get; set; }

        /// <summary>
        /// 使能
        /// </summary>
        public bool Enable { get; set; }
    }

    /// <summary>
    /// 删除外设设备请求
    /// </summary>
    public class RemovePeripheralDeviceDBRequest : DBBaseRequest
    {
        /// <summary>
        /// 主设备编码
        /// </summary>
        /// <value></value>
        public string DeviceCode { get; set; }

        /// <summary>
        /// 外设设备编码
        /// </summary>
        /// <value></value>
        public string PeripheralDeviceCode { get; set; }
    }

    /// <summary>
    /// 分页获取设备请求
    /// </summary>
    public class GetDevicePageDBPageRequest : DBPageRequest
    {
        /// <summary>
        /// 0-平板终端，1-心电
        /// </summary>
        /// <value></value>
        public int DeviceType { get; set; } = 0;

        /// <summary>
        /// 置顶的设备编码
        /// </summary>
        /// <value></value>
        public string TopByDeviceCode { get; set; }
    }

}
