using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum.VitalEnum;
using WingInterfaceLibrary.Request.Vital;

namespace WingInterfaceLibrary.Request.DBVitalRequest
{
    /// <summary>
    /// 创建诊疗数据请求
    /// </summary>
    public class CreateDiagnosisDBRequest : DBBaseRequest
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
        /// <summary>
        /// 键
        /// </summary>
        /// <value></value>
        public string Key { get; set; }
        /// <summary>
        /// 居民代码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }
        /// <summary>
        /// 医生代码
        /// </summary>
        /// <value></value>
        public string DoctorCode { get; set; }
        /// <summary>
        /// 检查数据
        /// </summary>
        /// <value></value>
        public Dictionary<string, string> DiagnosisData { get; set; }

        /// <summary>
        /// 诊疗时间
        /// </summary>
        /// <value></value>
        public DateTime DiagnosisTime { get; set; } = DateTime.UtcNow;

        /// <summary>
        /// 客户端对应诊疗数据的Id，此Id用于确认上传的数据属于那一份诊疗数据
        /// </summary>
        /// <value></value>
        public string AppDataId { get; set; }

        /// <summary>
        /// 体检号(健康体检专用)
        /// </summary>
        /// <value></value>
        public string PhysicalExamNumber { get; set; }

        /// <summary>
        /// 检查code
        /// </summary>
        /// <value></value>
        public string ExamCode { get; set; }
    }

    /// <summary>
    /// 根据编码获取诊疗数据请求
    /// </summary>
    public class GetDiagnosisDBRequest : DBBaseRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取诊疗数据请求
    /// </summary>
    public class GetDiagnosisByKeyDBRequest : DBBaseRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除诊疗数据请求
    /// </summary>
    public class RemoveDiagnosisDBRequest : DBBaseRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据AppDataId删除诊疗数据请求
    /// </summary>
    public class RemoveDiagnosisByAppDataIdDBRequest : DBBaseRequest
    {
        public string AppDataId { get; set; }
    }

    /// <summary>
    /// 删除多个诊疗数据请求
    /// </summary>
    public class RemoveDiagnosisListDBRequest : DBBaseRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 获取诊疗数据列表请求
    /// </summary>
    public class GetDiagnosisListDBRequest : DBBaseRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取诊疗数据列表请求
    /// </summary>
    public class GetDiagnosisListByKeyDBRequest : DBBaseRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 更新诊疗数据请求
    /// </summary>
    public class UpdateDiagnosisDBRequest : DBBaseRequest
    {
        public string Code { get; set; }
        /// <summary>
        /// 键
        /// </summary>
        /// <value></value>
        public string Key { get; set; } = "-1";
        /// <summary>
        /// 居民代码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; } = "-1";
        /// <summary>
        /// 医生代码
        /// </summary>
        /// <value></value>
        public string DoctorCode { get; set; } = "-1";
        /// <summary>
        /// 检查数据
        /// </summary>
        /// <value></value>
        public Dictionary<string, string> DiagnosisData { get; set; } = null;

        /// <summary>
        /// 诊疗时间
        /// </summary>
        /// <value></value>
        public DateTime? DiagnosisTime { get; set; } = null;

        /// <summary>
        /// 客户端对应诊疗数据的Id，此Id用于确认上传的数据属于那一份诊疗数据
        /// </summary>
        /// <value></value>
        public string AppDataId { get; set; } = "-1";
        
        /// <summary>
        /// 体检号(健康体检专用)
        /// </summary>
        /// <value></value>
        public string PhysicalExamNumber { get; set; }

        /// <summary>
        /// 检查code
        /// </summary>
        /// <value></value>
        public string ExamCode { get; set; }
    }

    /// <summary>
    /// 提交诊疗数据请求
    /// </summary>
    public class SubmitDiagnosisDBRequest : DBBaseRequest
    {
        /// <summary>
        /// 客户端对应诊疗数据的Id，此Id用于确认上传的数据属于那一份诊疗数据
        /// </summary>
        /// <value></value>
        public string AppDataId { get; set; }

        /// <summary>
        /// 诊疗时间
        /// </summary>
        /// <value></value>
        public DateTime? DiagnosisTime { get; set; } = null;

        /// <summary>
		/// 居民代码
		/// </summary>
		/// <value></value>
		public string PatientCode { get; set; }

        /// <summary>
        /// 医生代码
        /// </summary>
        /// <value></value>
        public string DoctorCode { get; set; }

        /// <summary>
        /// 诊疗数据列表
        /// </summary>
        /// <value></value>
        public List<DiagnosisDBItem> DiagnosisItems { get; set; }

        /// <summary>
        /// 体检号(健康体检专用)
        /// </summary>
        /// <value></value>
        public string PhysicalExamNumber { get; set; }

        /// <summary>
        /// 检查code
        /// </summary>
        /// <value></value>
        public string ExamCode { get; set; }
    }

    /// <summary>
    /// 重传诊疗数据请求
    /// </summary>
    public class ReinfusionDiagnosisDBRequest : DBBaseRequest
    {
        /// <summary>
        /// 客户端对应诊疗数据的Id，此Id用于确认上传的数据属于那一份诊疗数据
        /// </summary>
        /// <value></value>
        public string AppDataId { get; set; }
    }

    /// <summary>
    /// 设置诊疗时间
    /// </summary>
    public class SetDiagnosisTimeDBRequest : DBBaseRequest
    {
        /// <summary>
        /// 客户端对应诊疗数据的Id，此Id用于确认上传的数据属于那一份诊疗数据
        /// </summary>
        /// <value></value>
        public string AppDataId { get; set; }

        /// <summary>
        /// 需要设置的诊疗时间
        /// </summary>
        /// <value></value>
        public DateTime DiagnosisTime { get; set; }
    }

    /// <summary>
    /// 诊疗数据内容
    /// </summary>
    public class DiagnosisDBItem
    {
        /// <summary>
		/// 键
		/// </summary>
		/// <value></value>
		public string Key { get; set; } = "-1";

        /// <summary>
        /// 检查数据
        /// </summary>
        /// <value></value>
        public string DiagnosisData { get; set; } = "-1";
    }

    /// <summary>
    /// 同步居民和检测数据请求
    /// </summary>
    public class SyncPatientAndDiagnosisDataDBRequest : DBBaseRequest
    {
        /// <summary>
        /// 居民编码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }

        /// <summary>
        /// 居民名称
        /// </summary>
        /// <value></value>
        public string PatientName { get; set; }

        /// <summary>
        /// 电话
        /// </summary>
        /// <value></value>
        public string Phone { get; set; }

        /// <summary>
        /// 证件编号
        /// </summary>
        /// <value></value>
        public string CardNo { get; set; }

        /// <summary>
        /// 民族
        /// </summary>
        /// <value></value>
        public string Nationality { get; set; }

        /// <summary>
        /// 生日
        /// </summary>
        /// <value></value>
        public DateTime Birthday { get; set; }

        /// <summary>
        /// 人群标签
        /// </summary>
        /// <value></value>
        public List<string> CrowdLabels { get; set; }

        /// <summary>
        /// 卡片类型
        /// </summary>
        /// <value></value>
        public CardTypeEnum CardType { get; set; }

        /// <summary>
        /// 居民性别
        /// </summary>
        /// <value></value>
        public GenderEnum PatientGender { get; set; }

        /// <summary>
        /// 居民地址
        /// </summary>
        /// <value></value>
        public string PatientAddress { get; set; }

        /// <summary>
        /// 永久村/小区地址
        /// </summary>
        /// <value></value>
        public string PermanentResidenceAddress { get; set; }

        /// <summary>
        /// 客户端对应诊疗数据的Id，此Id用于确认上传的数据属于那一份诊疗数据
        /// </summary>
        /// <value></value>
        public string AppDataId { get; set; }

        /// <summary>
        /// 诊疗时间
        /// </summary>
        /// <value></value>
        public DateTime? DiagnosisTime { get; set; } = null;

        /// <summary>
        /// 医生代码
        /// </summary>
        /// <value></value>
        public string DoctorCode { get; set; }

        /// <summary>
        /// 诊疗数据列表
        /// </summary>
        /// <value></value>
        public List<DiagnosisItem> DiagnosisItems { get; set; }
    }

    /// <summary>
    /// 同步居民和检测数据请求
    /// </summary>
    public class OldPlatformDiagnosisDataCountDBRequest : DBBaseRequest
    {
    }
    
}