using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum.VitalEnum;
using WingInterfaceLibrary.Request.Vital;

namespace WingInterfaceLibrary.Request.DBVitalRequest
{
    /// <summary>
    /// 创建字典数据请求
    /// </summary>
    public class CreateDictionaryDBRequest : DBBaseRequest
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
        /// <summary>
        /// 键
        /// </summary>
        /// <value></value>
        public string Key { get; set; }
        /// <summary>
        /// 名称
        /// </summary>
        /// <value></value>
        public string Name { get; set; }
        /// <summary>
        /// 类型
        /// </summary>
        /// <value></value>
        public VitalDictionaryTypeEnum Type { get; set; }
        /// <summary>
        /// 描述
        /// </summary>
        /// <value></value>
        public string Description { get; set; }


    }

    /// <summary>
    /// 根据编码获取字典数据请求
    /// </summary>
    public class GetDictionaryDBRequest : DBBaseRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取字典数据请求
    /// </summary>
    public class GetDictionaryByKeyDBRequest : DBBaseRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除字典数据请求
    /// </summary>
    public class RemoveDictionaryDBRequest : DBBaseRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 删除多个字典数据请求
    /// </summary>
    public class RemoveDictionaryListDBRequest : DBBaseRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 获取字典数据列表请求
    /// </summary>
    public class GetDictionaryListDBRequest : DBBaseRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取字典数据列表请求
    /// </summary>
    public class GetDictionaryListByKeyDBRequest : DBBaseRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取字典数据列表请求
    /// </summary>
    public class GetDictionaryNameAndUnitByKeysDBRequest : DBBaseRequest
    {
        public List<string> Keys { get; set; }
    }

    /// <summary>
    /// 更新字典数据请求
    /// </summary>
    public class UpdateDictionaryDBRequest : DBBaseRequest
    {
        public string Code { get; set; }
        /// <summary>
        /// 键
        /// </summary>
        /// <value></value>
        public string Key { get; set; }
        /// <summary>
        /// 名称
        /// </summary>
        /// <value></value>
        public string Name { get; set; }
        /// <summary>
        /// 类型
        /// </summary>
        /// <value></value>
        public VitalDictionaryTypeEnum Type { get; set; }
        /// <summary>
        /// 描述
        /// </summary>
        /// <value></value>
        public string Description { get; set; }

    }
}