using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum.VitalEnum;
using WingInterfaceLibrary.Request.Vital;

namespace WingInterfaceLibrary.Request.DBVitalRequest
{
    /// <summary>
    /// 创建心电数据请求
    /// </summary>
    public class CreateElectrocardiogramDBRequest : DBBaseRequest
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();

        /// <summary>
        /// 居民代码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }
        /// <summary>
        /// 心电数据
        /// </summary>
        /// <value></value>
        public Dictionary<string, string> ExamData { get; set; }
        /// <summary>
		/// 居民姓名
		/// </summary>
		/// <value></value>
		public string PatientName { get; set; }
        /// <summary>
        /// 证件号码
        /// </summary>
        /// <value></value>
        public string CardNo { get; set; }
        /// <summary>
        /// 居民性别
        /// </summary>
        /// <value></value>
        public GenderEnum PatientGender { get; set; }
        /// <summary>
        /// 居民地址
        /// </summary>
        /// <value></value>
        public string PatientAddress { get; set; }
        /// <summary>
        /// 生日
        /// </summary>
        /// <value></value>
        public DateTime Birthday { get; set; }
        /// <summary>
        /// 体检状态
        /// </summary>
        /// <value></value>
        public ExamStateEnum ExamState { get; set; }
        /// <summary>
		/// 检查时间
		/// </summary>
		/// <value></value>
		public DateTime ExamTime { get; set; }
        /// <summary>
        /// 体检医生
        /// </summary>
        /// <value></value>
        public string ExamDoctor { get; set; }
        /// <summary>
        /// 体检号(健康体检专用)
        /// </summary>
        /// <value></value>
        public string PhysicalExamNumber { get; set; }

        /// <summary>
        /// 所属机构
        /// </summary>
        /// <value></value>
        public string OrganizationCode { get; set; }

        /// <summary>
        /// 手机号
        /// </summary>
        /// <value></value>
        public string Phone { get; set; }
    }


    /// <summary>
    /// 更新心电数据请求
    /// </summary>
    public class UpdateElectrocardiogramDBRequest : DBBaseRequest
    {
        public string Code { get; set; }

        /// <summary>
        /// 心电检查数据
        /// </summary>
        /// <value></value>
        public Dictionary<string, string> ExamData { get; set; }

        /// <summary>
        /// 报告状态枚举
        /// </summary>
        /// <value></value>
        public ExamStateEnum ExamState { get; set; }
    }

    /// <summary>
    /// 获取心电数据分页请求
    /// </summary>
    public class GetElectrocardiogramDBPageRequest : DBPageRequest
    {
        public string OrgCode { get; set; }

        /// <summary>
        /// 是否查询下级提交记录
        /// </summary>
        /// <value></value>
        public bool IsQuerySubordinate { get; set; }

        /// <summary>
        /// 下级机构列表（远程心电使用）
        /// </summary>
        /// <value></value>
        public List<string> ChildrenOrgCodes { get; set; }

        /// <summary>
        /// 查询状态
        /// </summary>
        /// <value>1</value>
        public List<ExamStateEnum> States { get; set; }
    }


}