using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum.VitalEnum;
using WingInterfaceLibrary.Request.Vital;

namespace WingInterfaceLibrary.Request.DBVitalRequest
{
    /// <summary>
    /// 创建检查数据请求
    /// </summary>
    public class CreateExamDBRequest : DBBaseRequest
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
        /// <summary>
        /// 批次号
        /// </summary>
        /// <value></value>
        public string BatchNumber { get; set; }
        /// <summary>
        /// 键
        /// </summary>
        /// <value></value>
        public string Key { get; set; }
        /// <summary>
        /// 居民代码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }
        /// <summary>
        /// 签约医生
        /// </summary>
        /// <value></value>
        public string ContractedDoctor { get; set; }
        /// <summary>
        /// 检查数据
        /// </summary>
        /// <value></value>
        public Dictionary<string, string> ExamData { get; set; }
        /// <summary>
        /// 模版编码
        /// </summary>
        /// <value></value>
        public string TemplateCode { get; set; }
        /// <summary>
        /// 体检医生
        /// </summary>
        /// <value></value>
        public string ExamDoctor { get; set; }

        /// <summary>
        /// 体检号(健康体检专用)
        /// </summary>
        /// <value></value>
        public string PhysicalExamNumber { get; set; }

        /// <summary>
        /// 无需验证
        /// </summary>
        /// <value></value>
        public bool NoValidate { get; set; }

        /// <summary>
        /// 是否需要转存体检表数据
        /// </summary>
        /// <value></value>
        public bool NeedConvert { get; set; } = true;
    }

    /// <summary>
    /// 根据编码获取检查数据请求
    /// </summary>
    public class GetExamDBRequest : DBBaseRequest
    {
        public string Key { get; set; }
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取检查数据请求
    /// </summary>
    public class GetExamByKeyDBRequest : DBBaseRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 查询检查记录集合请求
    /// </summary>
    public class GetExamInfosDBRequest : DBBaseRequest
    {
        public string IDCardNo { get; set; }
        public string PhysicalExamNumber { get; set; }
        public string ExamKey { get; set; }
        public DateTime StartDate { get; set; }
        public DateTime EndDate { get; set; }
    }

    /// <summary>
    /// 删除检查数据请求
    /// </summary>
    public class RemoveExamDBRequest : DBBaseRequest
    {
        public string Key { get; set; }
        public string Code { get; set; }
    }

    /// <summary>
    /// 删除多个检查数据请求
    /// </summary>
    public class RemoveExamListDBRequest : DBBaseRequest
    {
        public string Key { get; set; }
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 获取检查数据列表请求
    /// </summary>
    public class GetExamListDBRequest : DBBaseRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取检查数据列表请求
    /// </summary>
    public class GetExamListByKeyDBRequest : DBBaseRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 更新检查数据请求
    /// </summary>
    public class UpdateExamDBRequest : DBBaseRequest
    {
        public string Code { get; set; }
        /// <summary>
        /// 键
        /// </summary>
        /// <value></value>
        public string Key { get; set; }
        /// <summary>
        /// 检查数据
        /// </summary>
        /// <value></value>
        public Dictionary<string, string> ExamData { get; set; }

        /// <summary>
        /// 报告状态枚举
        /// </summary>
        /// <value></value>
        public ExamStateEnum ExamState { get; set; }

        /// <summary>
        /// 检查医生
        /// </summary>
        /// <value></value>
        public string ExamDoctor { get; set; }
    }

    /// <summary>
    /// 更新检查数据请求
    /// </summary>
    public class UpdateExamByBatchNumberDBRequest : DBBaseRequest
    {
        /// <summary>
        /// 批次号
        /// </summary>
        /// <value></value>
        public string BatchNumber { get; set; }
        /// <summary>
        /// 键
        /// </summary>
        /// <value></value>
        public string Key { get; set; }
        /// <summary>
        /// 居民编码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }
        /// <summary>
        /// 检查数据
        /// </summary>
        /// <value></value>
        public Dictionary<string, string> ExamData { get; set; }
    }

    /// <summary>
    /// 查询是否存在已检查的居民
    /// </summary>
    public class ExistsPatientExamDBRequest : DBBaseRequest
    {
        /// <summary>
        /// 关键字
        /// </summary>
        /// <value></value>
        public string Key { get; set; }

        /// <summary>
        /// 居民编码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }
    }

    /// <summary>
    /// 查询居民最后一次体检信息
    /// </summary>
    public class GetPatientLastExamDBRequest : DBBaseRequest
    {
        /// <summary>
        /// 关键字
        /// </summary>
        /// <value></value>
        public string Key { get; set; }

        /// <summary>
        /// 居民编码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }
    }

    /// <summary>
    /// 获取体检记录居民分页
    /// </summary>
    public class GetExamRecordPageDBRequest : DBPageRequest
    {
        /// <summary>
        /// 查询的体检项目Key
        /// </summary>
        /// <value></value>
        public List<string> Keys { get; set; }
    }

    /// <summary>
    /// 分页查询检查数据 请求
    /// </summary>
    public class GetExamInfoByPageDBRequest : DBPageRequest
    {
        /// <summary>
        /// 检查类型
        /// </summary>
        /// <value></value>
        public string ExamKey { get; set; }

        /// <summary>
        /// 居民编码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }

        /// <summary>
        /// 查询的体检项目Key
        /// </summary>
        /// <value></value>
        public List<string> OrganizationCodes { get; set; }
    }

    /// <summary>
    /// 查询居民对应的体检记录信息
    /// </summary>
    public class GetExamRecordListDBRequest : DBBaseRequest
    {
        /// <summary>
        /// 查询的体检项目Key
        /// </summary>
        /// <value></value>
        public List<string> Keys { get; set; }

        /// <summary>
        /// 居民编码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }

        /// <summary>
        /// 体检编号
        /// </summary>
        /// <value></value>
        public string PhysicalExamNumber { get; set; }

        /// <summary>
        /// 编号列表
        /// </summary>
        /// <value></value>
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 根据批次号查询体检结果请求
    /// </summary>
    public class GetExamByBatchNumberDBRequest
    {
        /// <summary>
        /// 健康体检批次号
        /// </summary>
        /// <value></value>
        public string BatchNumber { get; set; }
    }

    /// <summary>
    /// 保存快捷检查
    /// </summary>
    public class SaveQuickCheckRecordDBRequest : DBBaseRequest
    {
        /// <summary>
        /// 居民编码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }

        /// <summary>
        /// 查询的体检项目Key
        /// </summary>
        /// <value></value>
        public List<string> Keys { get; set; }

        /// <summary>
        /// 快捷检查数据
        /// </summary>
        /// <value></value>
        public string QuickData { get; set; }
    }
}