using System;
using System.Collections.Generic;

namespace WingInterfaceLibrary.Request.DBVitalRequest
{
    /// <summary>
    /// 创建第三方厂商推送记录
    /// </summary>
    public class CreateFacturyPostHistoryDBRequest : DBBaseRequest
    {
        /// <summary>
        /// 厂商标识
        /// </summary>
        /// <value></value>
        public string FacturyUniqueCode { get; set; }

        /// <summary>
        /// 厂商接口地址
        /// </summary>
        /// <value></value>
        public string FacturyUrl { get; set; }

        /// <summary>
        /// 病人身份证
        /// </summary>
        /// <value></value>
        public string IDCardNo { get; set; }

        /// <summary>
        /// 病人姓名
        /// </summary>
        /// <value></value>
        public string PatientName { get; set; }

        /// <summary>
        /// 接口类型
        /// </summary>
        /// <value></value>
        public string ApiType { get; set; }

        /// <summary>
        /// 状态 1：待发送；2：发送成功；3：发送失败
        /// </summary>
        /// <value></value>
        public int Status { get; set; }

        /// <summary>
        /// 发送时间
        /// </summary>
        /// <value></value>
        public DateTime PostTime { get; set; }

        /// <summary>
        /// 请求头部信息
        /// </summary>
        /// <value></value>
        public Dictionary<string, string> Headers { get; set; }

        /// <summary>
        /// 请求内容
        /// </summary>
        /// <value></value>
        public string Content { get; set; }

        /// <summary>
        /// 响应内容
        /// </summary>
        /// <value></value>
        public string Result { get; set; }
    }

    /// <summary>
    /// 修改第三方厂商推送记录
    /// </summary>
    public class UpdateFacturyPostHistoryDBRequest : DBBaseRequest
    {
        /// <summary>
        /// Code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 厂商标识
        /// </summary>
        /// <value></value>
        public string FacturyUniqueCode { get; set; }

        /// <summary>
        /// 厂商接口地址
        /// </summary>
        /// <value></value>
        public string FacturyUrl { get; set; }

        /// <summary>
        /// 病人身份证
        /// </summary>
        /// <value></value>
        public string IDCardNo { get; set; }

        /// <summary>
        /// 病人姓名
        /// </summary>
        /// <value></value>
        public string PatientName { get; set; }

        /// <summary>
        /// 接口类型
        /// </summary>
        /// <value></value>
        public string ApiType { get; set; }

        /// <summary>
        /// 状态 1：待发送；2：发送成功；3：发送失败
        /// </summary>
        /// <value></value>
        public int Status { get; set; }

        /// <summary>
        /// 发送时间
        /// </summary>
        /// <value></value>
        public DateTime PostTime { get; set; }

        /// <summary>
        /// 请求头部信息
        /// </summary>
        /// <value></value>
        public Dictionary<string, string> Headers { get; set; }

        /// <summary>
        /// 请求内容
        /// </summary>
        /// <value></value>
        public string Content { get; set; }

        /// <summary>
        /// 响应内容
        /// </summary>
        /// <value></value>
        public string Result { get; set; }
    }

    /// <summary>
    /// 根据编码获取第三方厂商推送记录
    /// </summary>
    public class GetFacturyPostHistoryDBRequest : DBBaseRequest
    {
        /// <summary>
        /// Code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }
    }

    /// <summary>
    /// 分页获取第三方厂商数据推送记录
    /// </summary>
    public class GetFacturyPostHistoryByPageDBRequest : DBPageRequest
    {
        /// <summary>
        /// 状态 1：待发送；2：发送成功；3：发送失败
        /// </summary>
        /// <value></value>
        public int Status { get; set; }
    }

    /// <summary>
    /// 获取所有未推送数据记录
    /// </summary>
    public class GetNonPostHistoryDBRequest : DBBaseRequest
    {
    }

    /// <summary>
    /// 删除第三方厂商推送记录
    /// </summary>
    public class RemoveFacturyPostHistoryDBRequest : DBBaseRequest
    {
        /// <summary>
        /// Code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }
    }
}