using System.Collections.Generic;

namespace WingInterfaceLibrary.Request.DBVitalRequest
{
    /// <summary>
    /// 创建第三方厂商信息
    /// </summary>
    public class CreateFacturyUserDBRequest : DBBaseRequest
    {
        /// <summary>
        /// 厂商标识
        /// </summary>
        /// <value></value>
        public string FacturyUniqueCode { get; set; }

        /// <summary>
        /// 数据类型 1：医院，2：工号
        /// </summary>
        /// <value></value>
        public int FacturyType { get; set; }

        /// <summary>
        /// 医院编码、工号
        /// </summary>
        /// <value></value>
        public string FacturyCode { get; set; }

        /// <summary>
        /// 名称（医院名称、员工姓名）
        /// </summary>
        /// <value></value>
        public string FacturyName { get; set; }

        /// <summary>
        /// 上级编码，记录医院-工号关系
        /// </summary>
        /// <value></value>
        public string FatherCode { get; set; }

        /// <summary>
        /// 其它扩展信息
        /// </summary>
        /// <value></value>
        public Dictionary<string, string> FacturyData { get; set; }
    }
    
    /// <summary>
    /// 修改第三方厂商信息
    /// </summary>
    public class UpdateFacturyUserDBRequest : DBBaseRequest
    {
        /// <summary>
        /// Code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 厂商标识
        /// </summary>
        /// <value></value>
        public string FacturyUniqueCode { get; set; }

        /// <summary>
        /// 数据类型 1：医院，2：工号
        /// </summary>
        /// <value></value>
        public int FacturyType { get; set; }

        /// <summary>
        /// 医院编码、工号
        /// </summary>
        /// <value></value>
        public string FacturyCode { get; set; }

        /// <summary>
        /// 名称（医院名称、员工姓名）
        /// </summary>
        /// <value></value>
        public string FacturyName { get; set; }

        /// <summary>
        /// 上级编码，记录医院-工号关系
        /// </summary>
        /// <value></value>
        public string FatherCode { get; set; }

        /// <summary>
        /// 其它扩展信息
        /// </summary>
        /// <value></value>
        public Dictionary<string, string> FacturyData { get; set; }
    }
    
    /// <summary>
    /// 根据编码获取第三方厂商信息
    /// </summary>
    public class GetFacturyUserDBRequest : DBBaseRequest
    {
        /// <summary>
        /// Code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }
    }

    /// <summary>
    /// 分页获取厂商数据
    /// </summary>
    public class GetFacturyOrgByPageDBRequest : DBPageRequest
    {

    }

    /// <summary>
    /// 分页获取厂商员工数据
    /// </summary>
    public class GetFacturyUserByPageDBRequest : DBPageRequest
    {
        /// <summary>
        /// 第三方厂商编码
        /// </summary>
        /// <value></value>
        public string FacturyOrgCode { get; set; }
    }

    /// <summary>
    /// 获取厂商员工列表
    /// </summary>
    public class GetFacturyUserInfosDBRequest : DBBaseRequest
    {
        /// <summary>
        /// 第三方厂商编码
        /// </summary>
        /// <value></value>
        public string FacturyOrgCode { get; set; }
    }

    /// <summary>
    /// 获取所有厂商数据
    /// </summary>
    public class GetFacturyTreeDBDBRequest : DBBaseRequest
    {
    }
    
    /// <summary>
    /// 删除第三方厂商信息
    /// </summary>
    public class RemoveFacturyUserDBRequest : DBBaseRequest
    {
        /// <summary>
        /// Code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }
    }
}