using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum.VitalEnum;
using WingInterfaceLibrary.Request.Vital;

namespace WingInterfaceLibrary.Request.DBVitalRequest
{
    /// <summary>
    /// 创建随访数据请求
    /// </summary>
    public class CreateFollowUpDBRequest : DBBaseRequest
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
        /// <summary>
        /// 键
        /// </summary>
        /// <value></value>
        public string Key { get; set; }
        /// <summary>
        /// 居民代码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }
        /// <summary>
        /// 已签约医生
        /// </summary>
        /// <value></value>
        public string ContractedDoctor { get; set; }
        /// <summary>
        /// 跟进更新数据
        /// </summary>
        /// <value></value>
        public Dictionary<string, string> FollowUpData { get; set; }
        /// <summary>
        /// 随访状态
        /// </summary>
        /// <value></value>
        public FollowUpStateEnum FollowUpState { get; set; }
        /// <summary>
        /// 模版编码
        /// </summary>
        /// <value></value>
        public string TemplateCode { get; set; }

        /// <summary>
        /// 本次随访时间
        /// </summary>
        /// <value></value>
        public DateTime? FollowUpTime { get; set; }

        /// <summary>
        /// 下次随访时间
        /// </summary>
        /// <value></value>
        public DateTime? NextFollowUpTime { get; set; }

        /// <summary>
        /// 随访方式
        /// </summary>
        /// <value></value>
        public FollowUpModeEnum FollowUpMode { get; set; }

        /// <summary>
        /// 随访照片
        /// </summary>
        /// <value></value>
        public List<string> FollowUpPhotos { get; set; }

        /// <summary>
        /// 随访医生
        /// </summary>
        /// <value></value>
        public string FollowUpDoctor { get; set; }

        /// <summary>
        /// 体检号(健康体检专用)
        /// </summary>
        /// <value></value>
        public string PhysicalExamNumber { get; set; }
    }

    /// <summary>
    /// 根据编码获取随访数据请求
    /// </summary>
    public class GetFollowUpDBRequest : DBBaseRequest
    {
        public string Key { get; set; }
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据编码获取随访数据请求
    /// </summary>
    public class GetFollowUpByPhysicalExamNumberDBRequest : DBBaseRequest
    {
        /// <summary>
        /// 体检号(健康体检专用)
        /// </summary>
        /// <value></value>
        public string PhysicalExamNumber { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取随访数据请求
    /// </summary>
    public class GetFollowUpByKeyDBRequest : DBBaseRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除随访数据请求
    /// </summary>
    public class RemoveFollowUpDBRequest : DBBaseRequest
    {
        public string Key { get; set; }
        public string Code { get; set; }
    }

    /// <summary>
    /// 删除多个随访数据请求
    /// </summary>
    public class RemoveFollowUpListDBRequest : DBBaseRequest
    {
        public string Key { get; set; }
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 获取随访数据列表请求
    /// </summary>
    public class GetFollowUpListDBRequest : DBBaseRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取随访数据列表请求
    /// </summary>
    public class GetFollowUpListByKeyDBRequest : DBBaseRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 更新随访数据请求
    /// </summary>
    public class UpdateFollowUpDBRequest : DBBaseRequest
    {
        public string Code { get; set; }
        /// <summary>
        /// 键
        /// </summary>
        /// <value></value>
        public string Key { get; set; } = "-1";
        /// <summary>
        /// 跟进更新数据
        /// </summary>
        /// <value></value>
        public Dictionary<string, string> FollowUpData { get; set; } = null;
        /// <summary>
        /// 随访状态
        /// </summary>
        /// <value></value>
        public FollowUpStateEnum? FollowUpState { get; set; } = null;

        /// <summary>
        /// 本次随访时间
        /// </summary>
        /// <value></value>
        public DateTime? FollowUpTime { get; set; } = null;

        /// <summary>
        /// 下次随访时间
        /// </summary>
        /// <value></value>
        public DateTime? NextFollowUpTime { get; set; } = null;

        /// <summary>
        /// 随访方式
        /// </summary>
        /// <value></value>
        public FollowUpModeEnum? FollowUpMode { get; set; } = null;

        /// <summary>
        /// 随访照片
        /// </summary>
        /// <value></value>
        public List<string> FollowUpPhotos { get; set; } = null;
    }

    /// <summary>
    /// 查询是否存在已随访的居民
    /// </summary>
    public class ExistsPatientFollowUpDBRequest : DBBaseRequest
    {
        /// <summary>
        /// 关键字
        /// </summary>
        /// <value></value>
        public string Key { get; set; }

        /// <summary>
        /// 居民编码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }
    }

    /// <summary>
    /// 查询居民最后一次体检信息
    /// </summary>
    public class GetPatientLastFollowUpDBRequest : DBBaseRequest
    {
        /// <summary>
        /// 关键字
        /// </summary>
        /// <value></value>
        public string Key { get; set; }

        /// <summary>
        /// 居民编码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }

        /// <summary>
        /// 随访状态
        /// </summary>
        /// <value></value>
        public FollowUpStateEnum? FollowUpState { get; set; } = null;
    }

    /// <summary>
    /// 查询居民对应的随访记录信息
    /// </summary>
    public class GetFollowUpRecordListDBRequest : DBBaseRequest
    {
        /// <summary>
        /// 查询的随访项目Key
        /// </summary>
        /// <value></value>
        public List<string> Keys { get; set; }

        /// <summary>
        /// 居民编码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }
    }

    /// <summary>
    /// 查询居民对应的随访记录信息（按年）
    /// </summary>
    public class GetFollowUpRecordListByYearDBRequest : DBBaseRequest
    {
        /// <summary>
        /// 查询的随访项目Key
        /// </summary>
        /// <value></value>
        public List<string> Keys { get; set; }

        /// <summary>
        /// 居民编码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }

        /// <summary>
        /// 年份
        /// </summary>
        /// <value></value>
        public string Year { get; set; }
    }

    /// <summary>
    /// 获取已随访的居民列表
    /// </summary>
    public class GetHasFollowUpPatientListDBRequest
    {
        /// <summary>
        /// 查询的随访项目Key
        /// </summary>
        /// <value></value>
        public string Key { get; set; }

        /// <summary>
        /// 随访状态
        /// </summary>
        /// <value></value>
        public FollowUpStateEnum FollowUpState { get; set; }
    }
}