using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum.VitalEnum;
using WingInterfaceLibrary.Request.Vital;

namespace WingInterfaceLibrary.Request.DBVitalRequest
{
    /// <summary>
    /// 创建数据请求
    /// </summary>
    public class CreateNotificationDBRequest  : DBBaseRequest 
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
		/// <summary>
		/// 版本
		/// </summary>
		/// <value></value>
		public string Version { get; set; }
		/// <summary>
		/// 适用设备
		/// </summary>
		/// <value></value>
		public List<string> ApplicableEquipment { get; set; }
		/// <summary>
		/// 内容
		/// </summary>
		/// <value></value>
		public string NotificationContent { get; set; }
		/// <summary>
		/// 类型
		/// </summary>
		/// <value></value>
		public NotificationTypeEnum NotificationType { get; set; }


    }

    /// <summary>
    /// 根据编码获取数据请求
    /// </summary>
    public class GetNotificationDBRequest  : DBBaseRequest 
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取数据请求
    /// </summary>
    public class GetNotificationByKeyDBRequest  : DBBaseRequest 
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除数据请求
    /// </summary>
    public class RemoveNotificationDBRequest  : DBBaseRequest 
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 删除多个数据请求
    /// </summary>
    public class RemoveNotificationListDBRequest  : DBBaseRequest 
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 获取数据列表请求
    /// </summary>
    public class GetNotificationListDBRequest  : DBBaseRequest 
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取数据列表请求
    /// </summary>
    public class GetNotificationListByKeyDBRequest  : DBBaseRequest 
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 更新数据请求
    /// </summary>
    public class UpdateNotificationDBRequest  : DBBaseRequest 
    {
        public string Code { get; set; }
		/// <summary>
		/// 编号
		/// </summary>
		/// <value></value>
		public long NotificationNo { get; set; }
		/// <summary>
		/// 版本
		/// </summary>
		/// <value></value>
		public string Version { get; set; }
		/// <summary>
		/// 适用设备
		/// </summary>
		/// <value></value>
		public List<string> ApplicableEquipment { get; set; }
		/// <summary>
		/// 内容
		/// </summary>
		/// <value></value>
		public string NotificationContent { get; set; }
		/// <summary>
		/// 类型
		/// </summary>
		/// <value></value>
		public NotificationTypeEnum NotificationType { get; set; }

    }

    /// <summary>
    /// 查询分页请求
    /// </summary>
    public class NotificationDBPageRequest : DBPageRequest
    {
		/// <summary>
		/// 最后一个接受到的通知的序号
		/// </summary>
		/// <value></value>
		public long LastNotificationNo { get; set; }
        /// <summary>
		/// 版本
		/// </summary>
		/// <value></value>
		public string Version { get; set; } = "0.0.0.0";
		/// <summary>
		/// 适用设备
		/// </summary>
		/// <value></value>
		public List<string> ApplicableEquipment { get; set; }
		/// <summary>
		/// 类型
		/// </summary>
		/// <value></value>
		public NotificationTypeEnum? NotificationType { get; set; }
    }
}