using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum.VitalEnum;
using WingInterfaceLibrary.Request.Vital;

namespace WingInterfaceLibrary.Request.DBVitalRequest
{
    /// <summary>
    /// 创建组织数据请求
    /// </summary>
    public class CreateOrganizationDBRequest  : DBBaseRequest
	{
		public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
		/// <summary>
		/// 省份代码
		/// </summary>
		/// <value></value>
		public string ProvinceCode { get; set; }
		/// <summary>
		/// 城市代码
		/// </summary>
		/// <value></value>
		public string CityCode { get; set; }
		/// <summary>
		/// 区域代码
		/// </summary>
		/// <value></value>
		public string DistrictCode { get; set; }
		/// <summary>
		/// 乡镇代码
		/// </summary>
		/// <value></value>
		public string TownCode { get; set; }
		/// <summary>
		/// 村/小区代码
		/// </summary>
		/// <value></value>
		public string ResidenceCode { get; set; }
		/// <summary>
		/// 组织名称
		/// </summary>
		/// <value></value>
		public string OrganizationName { get; set; }
		/// <summary>
		/// 联系方式号码
		/// </summary>
		/// <value></value>
		public string ContactNumber { get; set; }
		/// <summary>
		/// logoURL
		/// </summary>
		/// <value></value>
		public string LogoUrl { get; set; }
		/// <summary>
		/// 地址
		/// </summary>
		/// <value></value>
		public string Address { get; set; }
		/// <summary>
        /// 父级编码
        /// </summary>
        /// <value></value>
        public string FatherCode { get; set;}
		/// <summary>
        /// 权限编码集合
        /// </summary>
        public List<string> FeatureCodes { get; set; }
		/// <summary>
		/// 顾客类型
		/// </summary>
		/// <value></value>
		public CustomTypeEnum CustomType { get; set; }
		/// <summary>
        /// 可使用的设备Key集合
        /// </summary>
        public List<string> PeripheralDeviceKeys { get; set; }
        /// <summary>
		/// 动态参数配置
		/// </summary>
		/// <value></value>
		public string DynamicParameter { get; set; }

        /// <summary>
        /// 体检地区码（3位）
        /// </summary>
        /// <value></value>
        public string OrganizationUniqueCode { get; set; }

        /// <summary>
        /// 体检项目集合
        /// </summary>
        /// <value></value>
        public List<string> ExamItemCodes { get; set; }

        /// <summary>
        /// 超声医师电子签名
        /// </summary>
        /// <value></value>
        public string UltrasonicSignature { get; set; }

        /// <summary>
        /// 尿常规检测医师电子签名
        /// </summary>
        /// <value></value>
        public string UrinalysisSignature { get; set; }
        
        /// <summary>
        /// 生化解析模板
        /// </summary>
        /// <value></value>
        public string BiochemicalTemplateKey { get; set; }
        
        /// <summary>
        /// 血常规解析模板
        /// </summary>
        /// <value></value>
        public string BloodRoutineTemplateKey { get; set; }
        
        /// <summary>
        /// 是否自动创建报告
        /// </summary>
        /// <value></value>
        public bool IsAutoCreateReport { get; set; }
    }

	/// <summary>
	/// 根据编码获取组织数据请求
	/// </summary>
	public class GetOrganizationDBRequest  : DBBaseRequest
	{
		public string Code { get; set; }
	}

	/// <summary>
	/// 根据关键字段获取组织数据请求
	/// </summary>
	public class GetOrganizationByKeyDBRequest  : DBBaseRequest
	{
		public string Key { get; set; }
		public string Value { get; set; }
	}

	/// <summary>
	/// 删除组织数据请求
	/// </summary>
	public class RemoveOrganizationDBRequest  : DBBaseRequest
	{
		public string Code { get; set; }
	}

	/// <summary>
	/// 删除多个组织数据请求
	/// </summary>
	public class RemoveOrganizationListDBRequest  : DBBaseRequest
	{
		public List<string> Codes { get; set; }
	}

	/// <summary>
	/// 获取组织数据列表请求
	/// </summary>
	public class GetOrganizationListDBRequest  : DBBaseRequest
	{
		public List<string> Codes { get; set; }
	}

	/// <summary>
	/// 根据关键字段获取组织数据列表请求
	/// </summary>
	public class GetOrganizationListByKeyDBRequest  : DBBaseRequest
	{
		public string Key { get; set; }
		public string Value { get; set; }
	}

	/// <summary>
	/// 更新组织数据请求
	/// </summary>
	public class UpdateOrganizationDBRequest  : DBBaseRequest
	{
		public string Code { get; set; }
		/// <summary>
		/// 省份代码
		/// </summary>
		/// <value></value>
		public string ProvinceCode { get; set; }
		/// <summary>
		/// 城市代码
		/// </summary>
		/// <value></value>
		public string CityCode { get; set; }
		/// <summary>
		/// 区域代码
		/// </summary>
		/// <value></value>
		public string DistrictCode { get; set; }
		/// <summary>
		/// 乡镇代码
		/// </summary>
		/// <value></value>
		public string TownCode { get; set; }
		/// <summary>
		/// 村/小区代码
		/// </summary>
		/// <value></value>
		public string ResidenceCode { get; set; }
		/// <summary>
		/// 组织名称
		/// </summary>
		/// <value></value>
		public string OrganizationName { get; set; }
		/// <summary>
		/// 联系方式号码
		/// </summary>
		/// <value></value>
		public string ContactNumber { get; set; }
		/// <summary>
		/// logoURL
		/// </summary>
		/// <value></value>
		public string LogoUrl { get; set; }
		/// <summary>
		/// 地址
		/// </summary>
		/// <value></value>
		public string Address { get; set; }
		/// <summary>
        /// 父级编码
        /// </summary>
        /// <value></value>
        public string FatherCode { get; set;}
		/// <summary>
        /// 权限编码集合
        /// </summary>
        public List<string> FeatureCodes { get; set; }
		/// <summary>
		/// 顾客类型
		/// </summary>
		/// <value></value>
		public CustomTypeEnum CustomType { get; set; }
		/// <summary>
        /// 可使用的设备Key集合
        /// </summary>
        public List<string> PeripheralDeviceKeys { get; set; }

		/// <summary>
		/// 动态参数配置
		/// </summary>
		/// <value></value>
		public string DynamicParameter { get; set; }

        /// <summary>
        /// 体检地区码（3位）
        /// </summary>
        /// <value></value>
        public string OrganizationUniqueCode { get; set; }

        /// <summary>
        /// 体检项目集合
        /// </summary>
        /// <value></value>
        public List<string> ExamItemCodes { get; set; }

        /// <summary>
        /// 超声医师电子签名
        /// </summary>
        /// <value></value>
        public string UltrasonicSignature { get; set; }

        /// <summary>
        /// 尿常规检测医师电子签名
        /// </summary>
        /// <value></value>
        public string UrinalysisSignature { get; set; }
        
        /// <summary>
        /// 生化解析模板
        /// </summary>
        /// <value></value>
        public string BiochemicalTemplateKey { get; set; }
        
        /// <summary>
        /// 血常规解析模板
        /// </summary>
        /// <value></value>
        public string BloodRoutineTemplateKey { get; set; }
        
        /// <summary>
        /// 是否自动创建报告
        /// </summary>
        /// <value></value>
        public bool IsAutoCreateReport { get; set; }
    }
	
	public class GetEnableDeviceKeysDBRequest : DBBaseRequest
	{
		/// <summary>
		/// 组织代码
		/// </summary>
		/// <value></value>
		public string OrganizationCode { get; set; }
	}

	public class GetDynamicParameterDBRequest : DBBaseRequest
	{
		/// <summary>
		/// 组织代码
		/// </summary>
		/// <value></value>
		public string OrganizationCode { get; set; }
	}
}