using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum.VitalEnum;
using WingInterfaceLibrary.Request.Vital;

namespace WingInterfaceLibrary.Request.DBVitalRequest
{
    /// <summary>
    /// 创建居民数据请求
    /// </summary>
    public class CreatePatientDBRequest : DBBaseRequest
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
        /// <summary>
        /// 居民名称
        /// </summary>
        /// <value></value>
        public string PatientName { get; set; }
        /// <summary>
        /// 电话
        /// </summary>
        /// <value></value>
        public string Phone { get; set; }
        /// <summary>
        /// 联系人姓名
        /// </summary>
        /// <value></value>
        public string EmergencyName { get; set; }
        /// <summary>
        /// 紧急联系人手机号
        /// </summary>
        public string EmergencyPhone { get; set; }
        /// <summary>
        /// 证件编号
        /// </summary>
        /// <value></value>
        public string CardNo { get; set; }
        /// <summary>
        /// 民族
        /// </summary>
        /// <value></value>
        public string Nationality { get; set; }
        /// <summary>
        /// 生日
        /// </summary>
        /// <value></value>
        public DateTime Birthday { get; set; }
        /// <summary>
        /// 人群标签
        /// </summary>
        /// <value></value>
        public List<string> CrowdLabels { get; set; }
        /// <summary>
        /// 卡片类型
        /// </summary>
        /// <value></value>
        public CardTypeEnum CardType { get; set; }
        /// <summary>
        /// 居民性别
        /// </summary>
        /// <value></value>
        public GenderEnum PatientGender { get; set; }
        /// <summary>
        /// 居民地址
        /// </summary>
        /// <value></value>
        public string PatientAddress { get; set; }
        /// <summary>
        /// 永久村/小区地址
        /// </summary>
        /// <value></value>
        public string PermanentResidenceAddress { get; set; }
        /// <summary>
        /// 团队区域代码
        /// </summary>
        /// <value></value>
        public string TeamRegionCode { get; set; }
        /// <summary>
        /// 已签约医生
        /// </summary>
        /// <value></value>
        public string ContractedDoctor { get; set; }
    }

    /// <summary>
    /// 根据编码获取居民数据请求
    /// </summary>
    public class GetPatientDBRequest : DBBaseRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据编码获取居民数据请求
    /// </summary>
    public class GetPatientByCodeDBRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取居民数据请求
    /// </summary>
    public class GetPatientByKeyDBRequest : DBBaseRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除居民数据请求
    /// </summary>
    public class RemovePatientDBRequest : DBBaseRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 删除多个居民数据请求
    /// </summary>
    public class RemovePatientListDBRequest : DBBaseRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 获取居民数据列表请求
    /// </summary>
    public class GetPatientListDBRequest : DBBaseRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取居民数据列表请求
    /// </summary>
    public class GetPatientListByKeyDBRequest : DBBaseRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 更新居民数据请求
    /// </summary>
    public class UpdatePatientDBRequest : DBBaseRequest
    {
        public string Code { get; set; }
        /// <summary>
        /// 居民名称
        /// </summary>
        /// <value></value>
        public string PatientName { get; set; } = "-1";
        /// <summary>
        /// 电话
        /// </summary>
        /// <value></value>
        public string Phone { get; set; } = "-1";
        /// <summary>
        /// 联系人姓名
        /// </summary>
        /// <value></value>
        public string EmergencyName { get; set; } = "-1";
        /// <summary>
        /// 紧急联系人手机号
        /// </summary>
        public string EmergencyPhone { get; set; } = "-1";
        /// <summary>
        /// 证件编号
        /// </summary>
        /// <value></value>
        public string CardNo { get; set; } = "-1";
        /// <summary>
        /// 民族
        /// </summary>
        /// <value></value>
        public string Nationality { get; set; } = "-1";
        /// <summary>
        /// 生日
        /// </summary>
        /// <value></value>
        public DateTime? Birthday { get; set; } = null;
        /// <summary>
        /// 人群标签
        /// </summary>
        /// <value></value>
        public List<string> CrowdLabels { get; set; } = null;
        /// <summary>
        /// 卡片类型
        /// </summary>
        /// <value></value>
        public CardTypeEnum? CardType { get; set; } = null;
        /// <summary>
        /// 居民性别
        /// </summary>
        /// <value></value>
        public GenderEnum? PatientGender { get; set; } = null;
        /// <summary>
        /// 居民地址
        /// </summary>
        /// <value></value>
        public string PatientAddress { get; set; } = "-1";
        /// <summary>
        /// 永久村/小区地址
        /// </summary>
        /// <value></value>
        public string PermanentResidenceAddress { get; set; } = "-1";
        /// <summary>
        /// 团队区域代码
        /// </summary>
        /// <value></value>
        public string TeamRegionCode { get; set; } = "-1";
        /// <summary>
        /// 已签约医生
        /// </summary>
        /// <value></value>
        public string ContractedDoctor { get; set; } = "-1";
    }

    /// <summary>
    /// 获取居民档案分页请求
    /// </summary>
    public class PatientPageDBRequest : DBPageRequest
    {
        /// <summary>
        /// 人群标签
        /// </summary>
        /// <value></value>
        public List<string> CrowdLabels { get; set; }

        /// <summary>
        /// 居民编码集合
        /// </summary>
        /// <value></value>
        public List<string> PatientCodes { get; set; }

        /// <summary>
		/// 仅查询建档人是自己的
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public bool CreatedBySelf { get; set; }

        /// <summary>
        /// 签约状态
        /// </summary>
        /// <value></value>
        public ContractStateEnum? ContractState { get; set; }
    }

    /// <summary>
    /// 获取居民档案分页请求
    /// </summary>
    public class UpdatePatientPhotosDBRequest : DBPageRequest
    {
        public string Code { get; set; }
        /// <summary>
        /// 照片
        /// </summary>
        /// <value></value>
        public List<string> Photos { get; set; } = null;
    }

    /// <summary>
    /// 获取居民档案统计信息请求
    /// </summary>
    public class GetPatientStatisticDBRequest : DBPageRequest
    {
        /// <summary>
        /// 人群标签
        /// </summary>
        /// <value></value>
        public List<string> CrowdLabels { get; set; }
        
        /// <summary>
		/// 仅查询建档人是自己的
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public bool CreatedBySelf { get; set; }

        /// <summary>
        /// 签约状态
        /// </summary>
        /// <value></value>
        public ContractStateEnum? ContractState { get; set; }
    }
}