using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Net.Http;
using System.Threading;
using System.Threading.Tasks;
using WingInterfaceLibrary.Enum.VitalEnum;
using WingInterfaceLibrary.Request.Vital;

namespace WingInterfaceLibrary.Request.DBVitalRequest
{
    /// <summary>
    /// 创建居民扩展信息数据请求
    /// </summary>
    public class CreatePatientExtensionDBRequest  : DBBaseRequest
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
		/// <summary>
		/// 居民代码
		/// </summary>
		/// <value></value>
		public string PatientCode { get; set; }
		/// <summary>
		/// 键
		/// </summary>
		/// <value></value>
		public string Key { get; set; }
		/// <summary>
		/// 扩展数据
		/// </summary>
		/// <value></value>
		public Dictionary<string,string> ExtensionData { get; set; }
    }

    /// <summary>
    /// 根据编码获取居民扩展信息数据请求
    /// </summary>
    public class GetPatientExtensionDBRequest  : DBBaseRequest 
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取居民扩展信息数据请求
    /// </summary>
    public class GetPatientExtensionByCodeAndKeyDBRequest  : DBBaseRequest 
    {
        /// <summary>
        /// 字典值
        /// </summary>
        /// <value></value>
        public string Key { get; set; }

        /// <summary>
        /// 居民编码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }
    }


    /// <summary>
    /// 删除居民扩展信息数据请求
    /// </summary>
    public class RemovePatientExtensionDBRequest  : DBBaseRequest 
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 删除多个居民扩展信息数据请求
    /// </summary>
    public class RemovePatientExtensionListDBRequest  : DBBaseRequest 
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 获取居民扩展信息数据列表请求
    /// </summary>
    public class GetPatientExtensionListDBRequest  : DBBaseRequest 
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取居民扩展信息数据列表请求
    /// </summary>
    public class GetPatientExtensionListByKeyDBRequest  : DBBaseRequest 
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 更新居民扩展信息数据请求
    /// </summary>
    public class UpdatePatientExtensionDBRequest  : DBBaseRequest 
    {
        public string Code { get; set; }
		/// <summary>
		/// 居民代码
		/// </summary>
		/// <value></value>
		public string PatientCode { get; set; }
		/// <summary>
		/// 键
		/// </summary>
		/// <value></value>
		public string Key { get; set; }
		/// <summary>
		/// 扩展数据
		/// </summary>
		/// <value></value>
		public Dictionary<string,string> ExtensionData { get; set; }

    }

    /// <summary>
    /// 查询居民扩展信息分页请求
    /// </summary>
    public class PatientExtensionDBPageRequest : DBPageRequest
    {
    }
}