using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum.VitalEnum;
using WingInterfaceLibrary.Request.Vital;

namespace WingInterfaceLibrary.Request.DBVitalRequest
{
    /// <summary>
    /// 创建处方数据请求
    /// </summary>
    public class CreatePrescriptionDBRequest  : DBBaseRequest 
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
		/// <summary>
		/// 键
		/// </summary>
		/// <value></value>
		public string Key { get; set; }
		/// <summary>
		/// 居民代码
		/// </summary>
		/// <value></value>
		public string PatientCode { get; set; }

        /// <summary>
        /// 体检号(健康体检专用)
        /// </summary>
        /// <value></value>
        public string PhysicalExamNumber { get; set; }

        /// <summary>
        /// 随访编码
        /// </summary>
        public string FollowUpCode { get; set; }

        /// <summary>
        /// 处方信息
        /// </summary>
        /// <value></value>
        public string PrescriptionData { get; set; }
    }

    /// <summary>
    /// 根据编码获取处方数据请求
    /// </summary>
    public class GetPrescriptionDBRequest  : DBBaseRequest 
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据随访编码和居民编码获取处方数据请求
    /// </summary>
    public class GetPrescriptionDetailByFollowAnPatientDBRequest : DBBaseRequest
    {
        /// <summary>
        /// 随访编码
        /// </summary>
        /// <value></value>
        public string FollowUpCode { get; set; }

        /// <summary>
        /// 随访编码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取处方数据请求
    /// </summary>
    public class GetPrescriptionByKeyDBRequest  : DBBaseRequest 
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除处方数据请求
    /// </summary>
    public class RemovePrescriptionDBRequest  : DBBaseRequest 
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 删除多个处方数据请求
    /// </summary>
    public class RemovePrescriptionListDBRequest  : DBBaseRequest 
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 获取处方数据列表请求
    /// </summary>
    public class GetPrescriptionListDBRequest  : DBBaseRequest 
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取处方数据列表请求
    /// </summary>
    public class GetPrescriptionListByKeyDBRequest  : DBBaseRequest 
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 更新处方数据请求
    /// </summary>
    public class UpdatePrescriptionDBRequest  : DBBaseRequest 
    {
        public string Code { get; set; }
		/// <summary>
		/// 键
		/// </summary>
		/// <value></value>
		public string Key { get; set; } = "-1";
		/// <summary>
		/// 居民代码
		/// </summary>
		/// <value></value>
		public string PatientCode { get; set; } = "-1";

        /// <summary>
        /// 体检号(健康体检专用)
        /// </summary>
        /// <value></value>
        public string PhysicalExamNumber { get; set; } = "-1";

        /// <summary>
        /// 随访编码
        /// </summary>
        public string FollowUpCode { get; set; } = "-1";

        /// <summary>
        /// 处方信息
        /// </summary>
        /// <value></value>
        public string PrescriptionData { get; set; }
    }

    /// <summary>
    /// 查询处方分页请求
    /// </summary>
    public class PrescriptionDBPageRequest : DBPageRequest
    {
        /// <summary>
		/// 居民代码
		/// </summary>
		/// <value></value>
		public string PatientCode { get; set; }

        /// <summary>
        /// 体检号
        /// </summary>
        public string PhysicalExamNumber { get; set; }
        
        /// <summary>
        /// 随访编码
        /// </summary>
        public string FollowUpCode { get; set; }

        /// <summary>
		/// 键
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Key { get; set; }
    }

    public class SetPrescriptionPreviewInfoDBRequest: DBBaseRequest
    {
        /// <summary>
        /// 处方编码
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 预览地址
        /// </summary>
        /// <value></value>
        public string PreviewUrl { get; set; }
    }
}