using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum.VitalEnum;
using WingInterfaceLibrary.Request.Vital;

namespace WingInterfaceLibrary.Request.DBVitalRequest
{
    /// <summary>
    /// 创建报告数据请求
    /// </summary>
    public class CreateReportDBRequest  : DBBaseRequest 
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
		/// <summary>
		/// 键
		/// </summary>
		/// <value></value>
		public string Key { get; set; }
		/// <summary>
		/// 居民代码
		/// </summary>
		/// <value></value>
		public string PatientCode { get; set; }
		/// <summary>
		/// 已签约医生
		/// </summary>
		/// <value></value>
		public string ContractedDoctor { get; set; }
		/// <summary>
        /// 体检信息数据
        /// </summary>
        /// <value></value>
        public string ReportDataJson { get; set; }

        /// <summary>
        /// 体检模板数据
        /// </summary>
        /// <value></value>
        public string ReportTemplateJson { get; set; }

		/// <summary>
		/// 报告状态
		/// </summary>
		/// <value></value>
		public ReportStateEnum ReportState { get; set; }

        /// <summary>
        /// 模版编码
        /// </summary>
        /// <value></value>
        public string TemplateCode { get; set; }

        /// <summary>
        /// 预览信息
        /// </summary>
        /// <value></value>
        public PreviewDTO PreviewInfo { get; set; }        

        /// <summary>
        /// 体检号(健康体检专用)
        /// </summary>
        /// <value></value>
        public string PhysicalExamNumber { get; set; }

        /// <summary>
        /// 检查code
        /// </summary>
        /// <value></value>
        public string ExamCode { get; set; }        
        
        /// <summary>
        /// 体检信息
        /// </summary>
        /// <value></value>
        public Dictionary<string,string> ReportData { get; set; }

        /// <summary>
        /// 报告信息列表
        /// </summary>
        /// <value></value>
        public IList<PreviewDTO> PreviewList { get; set; }    

        /// <summary>
        /// 医生报告签名
        /// </summary>
        /// <value></value>
        public string DoctorSign { get; set; }    

        /// <summary>
        /// 报告医师
        /// </summary>
        /// <value></value>
        public string DoctorName { get; set; }
    }

    /// <summary>
    /// 根据编码获取报告数据请求
    /// </summary>
    public class GetReportDBRequest  : DBBaseRequest 
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取报告数据请求
    /// </summary>
    public class GetReportByKeyDBRequest  : DBBaseRequest 
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除报告数据请求
    /// </summary>
    public class RemoveReportDBRequest  : DBBaseRequest 
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 删除多个报告数据请求
    /// </summary>
    public class RemoveReportListDBRequest  : DBBaseRequest 
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 获取报告数据列表请求
    /// </summary>
    public class GetReportListDBRequest  : DBBaseRequest 
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取报告数据列表请求
    /// </summary>
    public class GetReportListByKeyDBRequest  : DBBaseRequest 
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 更新报告数据请求
    /// </summary>
    public class UpdateReportDBRequest  : DBBaseRequest 
    {
        public string Code { get; set; }
		/// <summary>
		/// 键
		/// </summary>
		/// <value></value>
		public string Key { get; set; } = "-1";
		/// <summary>
		/// 居民代码
		/// </summary>
		/// <value></value>
		public string PatientCode { get; set; } = "-1";
		/// <summary>
		/// 已签约医生
		/// </summary>
		/// <value></value>
		public string ContractedDoctor { get; set; } = "-1";
		/// <summary>
        /// 体检信息数据
        /// </summary>
        /// <value></value>
        public string ReportDataJson { get; set; }

        /// <summary>
        /// 体检模板数据
        /// </summary>
        /// <value></value>
        public string ReportTemplateJson { get; set; }

		/// <summary>
		/// 报告状态
		/// </summary>
		/// <value></value>
		public ReportStateEnum ReportState { get; set; }

        /// <summary>
        /// 模版编码
        /// </summary>
        /// <value></value>
        public string TemplateCode { get; set; }

        /// <summary>
        /// 预览信息
        /// </summary>
        /// <value></value>
        public PreviewDTO PreviewInfo { get; set; }        

        /// <summary>
        /// 体检号(健康体检专用)
        /// </summary>
        /// <value></value>
        public string PhysicalExamNumber { get; set; }

        /// <summary>
        /// 检查code
        /// </summary>
        /// <value></value>
        public string ExamCode { get; set; }

        /// <summary>
        /// 体检信息
        /// </summary>
        /// <value></value>
        public Dictionary<string,string> ReportData { get; set; }

        /// <summary>
        /// 报告信息列表
        /// </summary>
        /// <value></value>
        public IList<PreviewDTO> PreviewList { get; set; }    

        /// <summary>
        /// 医生报告签名
        /// </summary>
        /// <value></value>
        public string DoctorSign { get; set; }    

        /// <summary>
        /// 报告医师
        /// </summary>
        /// <value></value>
        public string DoctorName { get; set; }

    }

    /// <summary>
    /// 查询报告分页请求
    /// </summary>
    public class ReportDBPageRequest : DBPageRequest
    {
    }

    public class SetReportPreviewInfoDBRequest: DBBaseRequest
    {
        /// <summary>
        /// 报告编码
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 预览图信息
        /// </summary>
        /// <value></value>
        public PreviewDTO PreviewInfo { get; set; }
    }

    public class PreviewDTO
    {
        /// <summary>
        /// 文件地址
        /// </summary>
        /// <value>http://*****.jpg</value>
        public string FileToken { get; set; }

        /// <summary>
        /// 缩略图
        /// </summary>
        /// <value>http://*****.jpg</value>
        public string ThumbnailToken { get; set; }

        /// <summary>
        /// 语言，可为空-医师报告
        /// </summary>
        /// <value></value>
        public string Language { get; set; }

        /// <summary>
        /// 文件类型
        /// </summary>
        /// <value>10</value>
        public int FileType { get; set; }
    }
}