using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum.VitalEnum;
using WingInterfaceLibrary.Request.Vital;

namespace WingInterfaceLibrary.Request.DBVitalRequest
{
    /// <summary>
    /// 创建统计数据请求
    /// </summary>
    public class CreateStatisticDBRequest  : DBBaseRequest 
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
		/// <summary>
		/// 统计键
		/// </summary>
		/// <value></value>
		public string StatisticKey { get; set; }
		/// <summary>
		/// 统计类型
		/// </summary>
		/// <value></value>
		public StatisticTypeEnum StatisticType { get; set; }
		/// <summary>
		/// 时间
		/// </summary>
		/// <value></value>
		public string Time { get; set; }
		/// <summary>
		/// 统计数据
		/// </summary>
		/// <value></value>
		public string StatisticData { get; set; }


    }

    /// <summary>
    /// 根据编码获取统计数据请求
    /// </summary>
    public class GetStatisticDBRequest  : DBBaseRequest 
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取统计数据请求
    /// </summary>
    public class GetStatisticByKeyDBRequest  : DBBaseRequest 
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取今日统计数据请求
    /// </summary>
    public class GetTodayStatisticDBRequest  : DBBaseRequest 
    {
        /// <summary>
        /// 字典
        /// </summary>
        /// <value></value>
        public string Key { get; set; }

        /// <summary>
        /// 日期
        /// </summary>
        /// <value></value>
        public string Time { get; set; }
    }

    /// <summary>
    /// 删除统计数据请求
    /// </summary>
    public class RemoveStatisticDBRequest  : DBBaseRequest 
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 删除多个统计数据请求
    /// </summary>
    public class RemoveStatisticListDBRequest  : DBBaseRequest 
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 获取统计数据列表请求
    /// </summary>
    public class GetStatisticListDBRequest  : DBBaseRequest 
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取统计数据列表请求
    /// </summary>
    public class GetStatisticListByKeyDBRequest  : DBBaseRequest 
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 更新统计数据请求
    /// </summary>
    public class UpdateStatisticDBRequest  : DBBaseRequest 
    {
        public string Code { get; set; }
		/// <summary>
		/// 统计键
		/// </summary>
		/// <value></value>
		public string StatisticKey { get; set; }
		/// <summary>
		/// 统计类型
		/// </summary>
		/// <value></value>
		public StatisticTypeEnum StatisticType { get; set; }
		/// <summary>
		/// 时间
		/// </summary>
		/// <value></value>
		public string Time { get; set; }
		/// <summary>
		/// 统计数据
		/// </summary>
		/// <value></value>
		public string StatisticData { get; set; }

    }
}