using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Net.Http;
using System.Threading;
using System.Threading.Tasks;
using WingInterfaceLibrary.Enum.VitalEnum;
using WingInterfaceLibrary.Request.Vital;

namespace WingInterfaceLibrary.Request.DBVitalRequest
{
    /// <summary>
    /// 创建团队数据请求
    /// </summary>
    public class CreateTeamDBRequest  : DBBaseRequest
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
        /// <summary>
        /// 团队名称
        /// </summary>
        /// <value></value>
        public string TeamName { get; set; }
        /// <summary>
        /// 描述
        /// </summary>
        /// <value></value>
        public string Description { get; set; }
        /// <summary>
        /// 组织代码
        /// </summary>
        /// <value></value>
        public string OrganizationCode { get; set; }
        /// <summary>
        /// 成员
        /// </summary>
        /// <value></value>
        public List<string> Members { get; set; }
        /// <summary>
        /// 负责人
        /// </summary>
        /// <value></value>
        public string Principal { get; set; }

        /// <summary>
        /// 创建医生
        /// </summary>
        /// <value></value>
        public string CreatedDoctor { get; set; }

        /// <summary>
        /// 创建机构编码
        /// </summary>
        /// <value></value>
        public string CreatedOrgCode { get; set; }
    }

    /// <summary>
    /// 根据编码获取团队数据请求
    /// </summary>
    public class GetTeamDBRequest  : DBBaseRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取团队数据请求
    /// </summary>
    public class GetTeamByKeyDBRequest  : DBBaseRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取团队数据请求
    /// </summary>
    public class GetTeamByUserDBRequest  : DBBaseRequest
    {
        /// <summary>
        /// 用户编码
        /// </summary>
        /// <value></value>
        public string UserCode { get; set; }
    }

    /// <summary>
    /// 删除团队数据请求
    /// </summary>
    public class RemoveTeamDBRequest  : DBBaseRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 删除多个团队数据请求
    /// </summary>
    public class RemoveTeamListDBRequest  : DBBaseRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 获取团队数据列表请求
    /// </summary>
    public class GetTeamListDBRequest  : DBBaseRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取团队数据列表请求
    /// </summary>
    public class GetTeamListByKeyDBRequest  : DBBaseRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 更新团队数据请求
    /// </summary>
    public class UpdateTeamDBRequest  : DBBaseRequest
    {
        public string Code { get; set; }
        /// <summary>
        /// 团队名称
        /// </summary>
        /// <value></value>
        public string TeamName { get; set; }
        /// <summary>
        /// 描述
        /// </summary>
        /// <value></value>
        public string Description { get; set; }
        /// <summary>
        /// 组织代码
        /// </summary>
        /// <value></value>
        public string OrganizationCode { get; set; }
        /// <summary>
        /// 成员
        /// </summary>
        /// <value></value>
        public List<string> Members { get; set; }
        /// <summary>
        /// 负责人
        /// </summary>
        /// <value></value>
        public string Principal { get; set; }
    }
}