using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum.VitalEnum;
using WingInterfaceLibrary.Request.Vital;

namespace WingInterfaceLibrary.Request.DBVitalRequest
{
    /// <summary>
    /// 创建模板数据请求
    /// </summary>
    public class CreateTemplateDBRequest  : DBBaseRequest
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
		/// <summary>
		/// 模板名称
		/// </summary>
		/// <value></value>
		public string TemplateName { get; set; }
		/// <summary>
		/// 模板类型
		/// </summary>
		/// <value></value>
		public TemplateTypeEnum TemplateType { get; set; }
		/// <summary>
		/// 键
		/// </summary>
		/// <value></value>
		public string Key { get; set; }
		/// <summary>
		/// 模板内容
		/// </summary>
		/// <value></value>
		public string TemplateContent { get; set; }


    }

    /// <summary>
    /// 根据编码获取模板数据请求
    /// </summary>
    public class GetTemplateDBRequest  : DBBaseRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取模板数据请求
    /// </summary>
    public class GetTemplateByKeyDBRequest  : DBBaseRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除模板数据请求
    /// </summary>
    public class RemoveTemplateDBRequest  : DBBaseRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 删除多个模板数据请求
    /// </summary>
    public class RemoveTemplateListDBRequest  : DBBaseRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 获取模板数据列表请求
    /// </summary>
    public class GetTemplateListDBRequest  : DBBaseRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取模板数据列表请求
    /// </summary>
    public class GetTemplateListByKeyDBRequest  : DBBaseRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 更新模板数据请求
    /// </summary>
    public class UpdateTemplateDBRequest  : DBBaseRequest
    {
        public string Code { get; set; }
		/// <summary>
		/// 模板名称
		/// </summary>
		/// <value></value>
		public string TemplateName { get; set; }
		/// <summary>
		/// 模板类型
		/// </summary>
		/// <value></value>
		public TemplateTypeEnum TemplateType { get; set; }
		/// <summary>
		/// 键
		/// </summary>
		/// <value></value>
		public string Key { get; set; }
		/// <summary>
		/// 模板内容
		/// </summary>
		/// <value></value>
		public string TemplateContent { get; set; }

    }

    /// <summary>
    /// 获取最新的模版编码
    /// </summary>
    public class GetLastTemplateCodesByKeysDBRequest : DBBaseRequest
    {
        /// <summary>
        /// Keys
        /// </summary>
        /// <value></value>
        public List<string> Keys { get; set; }
    }

    /// <summary>
    /// 查询模板集合 请求
    /// </summary>
    public class GetTemplateInfosDBRequest : DBBaseRequest
    {
        /// <summary>
        /// TemplateCode
        /// </summary>
        /// <value></value>
        public string TemplateCode { get; set; }
        
        /// <summary>
        /// TemplateKey
        /// </summary>
        /// <value></value>
        public string TemplateKey { get; set; }
        
        /// <summary>
        /// TemplateType
        /// </summary>
        /// <value></value>
        public TemplateTypeEnum? TemplateType { get; set; }
    }
}