using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Net.Http;
using System.Threading;
using System.Threading.Tasks;
using WingInterfaceLibrary.Enum.VitalEnum;
using WingInterfaceLibrary.Request.Vital;

namespace WingInterfaceLibrary.Request.DBVitalRequest
{
    /// <summary>
    /// 创建城镇数据请求
    /// </summary>
    public class CreateTownDBRequest  : DBBaseRequest
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
		/// <summary>
		/// 省份代码
		/// </summary>
		/// <value></value>
		public string ProvinceCode { get; set; }
		/// <summary>
		/// 城市代码
		/// </summary>
		/// <value></value>
		public string CityCode { get; set; }
		/// <summary>
		/// 区域代码
		/// </summary>
		/// <value></value>
		public string DistrictCode { get; set; }
		/// <summary>
		/// 名称
		/// </summary>
		/// <value></value>
		public string Name { get; set; }
    }

    /// <summary>
    /// 根据编码获取城镇数据请求
    /// </summary>
    public class GetTownDBRequest  : DBBaseRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取城镇数据请求
    /// </summary>
    public class GetTownByKeyDBRequest  : DBBaseRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除城镇数据请求
    /// </summary>
    public class RemoveTownDBRequest  : DBBaseRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 删除多个城镇数据请求
    /// </summary>
    public class RemoveTownListDBRequest  : DBBaseRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 获取城镇数据列表请求
    /// </summary>
    public class GetTownListDBRequest  : DBBaseRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取城镇数据列表请求
    /// </summary>
    public class GetTownListByKeyDBRequest  : DBBaseRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 更新城镇数据请求
    /// </summary>
    public class UpdateTownDBRequest  : DBBaseRequest
    {
        public string Code { get; set; }
		/// <summary>
		/// 省份代码
		/// </summary>
		/// <value></value>
		public string ProvinceCode { get; set; }
		/// <summary>
		/// 城市代码
		/// </summary>
		/// <value></value>
		public string CityCode { get; set; }
		/// <summary>
		/// 区域代码
		/// </summary>
		/// <value></value>
		public string DistrictCode { get; set; }
		/// <summary>
		/// 名称
		/// </summary>
		/// <value></value>
		public string Name { get; set; }

    }
}