using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum.VitalEnum;
using WingInterfaceLibrary.Request.Vital;

namespace WingInterfaceLibrary.Request.DBVitalRequest
{
    /// <summary>
    /// 创建更新数据请求
    /// </summary>
    public class CreateUpgradeDBRequest  : DBBaseRequest
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
		/// <summary>
		/// 版本
		/// </summary>
		/// <value></value>
		public string Version { get; set; }
		/// <summary>
		/// 更新备注
		/// </summary>
		/// <value></value>
		public string UpgradeNotes { get; set; }
		/// <summary>
		/// 更新文件URL
		/// </summary>
		/// <value></value>
		public string UpgradeFileUrl { get; set; }
		/// <summary>
		/// 适用设备
		/// </summary>
		/// <value></value>
		public List<string> ApplicableEquipment { get; set; }
		/// <summary>
		/// 是灰度发布
		/// </summary>
		/// <value></value>
		public bool IsGatedLaunch { get; set; }


    }

    /// <summary>
    /// 根据编码获取更新数据请求
    /// </summary>
    public class GetUpgradeDBRequest  : DBBaseRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取更新数据请求
    /// </summary>
    public class GetUpgradeByKeyDBRequest  : DBBaseRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除更新数据请求
    /// </summary>
    public class RemoveUpgradeDBRequest  : DBBaseRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 删除多个更新数据请求
    /// </summary>
    public class RemoveUpgradeListDBRequest  : DBBaseRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 获取更新数据列表请求
    /// </summary>
    public class GetUpgradeListDBRequest  : DBBaseRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取更新数据列表请求
    /// </summary>
    public class GetUpgradeListByKeyDBRequest  : DBBaseRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 更新更新数据请求
    /// </summary>
    public class UpdateUpgradeDBRequest  : DBBaseRequest
    {
        public string Code { get; set; }
		/// <summary>
		/// 版本
		/// </summary>
		/// <value></value>
		public string Version { get; set; }
		/// <summary>
		/// 更新备注
		/// </summary>
		/// <value></value>
		public string UpgradeNotes { get; set; }
		/// <summary>
		/// 更新文件URL
		/// </summary>
		/// <value></value>
		public string UpgradeFileUrl { get; set; }
		/// <summary>
		/// 适用设备
		/// </summary>
		/// <value></value>
		public List<string> ApplicableEquipment { get; set; }
		/// <summary>
		/// 是灰度发布
		/// </summary>
		/// <value></value>
		public bool IsGatedLaunch { get; set; }

    }

    /// <summary>
	/// 查询最新的更新
	/// </summary>
	public class GetLastUpgradeDBRequest
	{
		/// <summary>
		/// 客户端当前版本
		/// </summary>
		/// <value></value>
		public string ClientVersion { get; set; }

        /// <summary>
		/// 设备物理唯一码
		/// </summary>
		/// <value></value>
		public string DeviceSerialNumber { get; set; }
	}
}