using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum.VitalEnum;
using WingInterfaceLibrary.Request.Vital;

namespace WingInterfaceLibrary.Request.DBVitalRequest
{
    /// <summary>
    /// 创建用户数据请求
    /// </summary>
    public class CreateUserDBRequest  : DBBaseRequest
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
		/// <summary>
		/// 用户名称
		/// </summary>
		/// <value></value>
		public string UserName { get; set; }
		/// <summary>
		/// 电话
		/// </summary>
		/// <value></value>
		public string Phone { get; set; }
		/// <summary>
		/// 证件编号
		/// </summary>
		/// <value></value>
		public string CardNo { get; set; }
		/// <summary>
		/// 真实姓名名称
		/// </summary>
		/// <value></value>
		public string RealName { get; set; }
		/// <summary>
		/// 头像图片令牌
		/// </summary>
		/// <value></value>
		public string HeadImageToken { get; set; }
		/// <summary>
		/// 组织代码
		/// </summary>
		/// <value></value>
		public string OrganizationCode { get; set; }
		/// <summary>
		/// 团队代码
		/// </summary>
		/// <value></value>
		public string TeamCode { get; set; }
		/// <summary>
		/// 角色代码
		/// </summary>
		/// <value></value>
		public string RoleCode { get; set; }
        /// <summary>
        /// 职位职称
        /// </summary>
        /// <value></value>
        public string RankName { get; set; }

		/// <summary>
		/// 医生签名
		/// </summary>
		/// <value></value>
		public string Signature { get; set; }
        
        /// <summary>
        /// 超声机编码，超声工作站使用
        /// </summary>
        /// <value></value>
        public string UltrasoundCode { get; set; }
        
        /// <summary>
        /// 心电编码，心电工作站使用
        /// </summary>
        /// <value></value>
        public string EcgCode { get; set; }
        
        /// <summary>
        /// FacturyUserCode
        /// </summary>
        /// <value></value>
        public string FacturyUserCode { get; set; }
    }

    /// <summary>
    /// 根据编码获取用户数据请求
    /// </summary>
    public class GetUserDBRequest  : DBBaseRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取用户数据请求
    /// </summary>
    public class GetUserByKeyDBRequest  : DBBaseRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除用户数据请求
    /// </summary>
    public class RemoveUserDBRequest  : DBBaseRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 删除多个用户数据请求
    /// </summary>
    public class RemoveUserListDBRequest  : DBBaseRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 获取用户数据列表请求
    /// </summary>
    public class GetUserListDBRequest  : DBBaseRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取用户数据列表请求
    /// </summary>
    public class GetUserListByKeyDBRequest  : DBBaseRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 更新用户数据请求
    /// </summary>
    public class UpdateUserDBRequest  : DBBaseRequest
    {
        public string Code { get; set; }
		/// <summary>
		/// 电话
		/// </summary>
		/// <value></value>
		public string Phone { get; set; } = "-1";
		/// <summary>
		/// 证件编号
		/// </summary>
		/// <value></value>
		public string CardNo { get; set; } = "-1";
		/// <summary>
		/// 真实姓名名称
		/// </summary>
		/// <value></value>
		public string RealName { get; set; } = "-1";
		/// <summary>
		/// 头像图片令牌
		/// </summary>
		/// <value></value>
		public string HeadImageToken { get; set; } = "-1";
		/// <summary>
		/// 组织代码
		/// </summary>
		/// <value></value>
		public string OrganizationCode { get; set; } = "-1";
		/// <summary>
		/// 团队代码
		/// </summary>
		/// <value></value>
		public string TeamCode { get; set; } = "-1";
		/// <summary>
		/// 角色代码
		/// </summary>
		/// <value></value>
		public string RoleCode { get; set; } = "-1";
        /// <summary>
        /// 职位职称
        /// </summary>
        /// <value></value>
        public string RankName { get; set; } = "-1";
		/// <summary>
		/// 医生签名
		/// </summary>
		/// <value></value>
		public string Signature { get; set; } = "-1";
        
        /// <summary>
        /// 超声机编码，超声工作站使用
        /// </summary>
        /// <value></value>
        public string UltrasoundCode { get; set; }
        
        /// <summary>
        /// 心电编码，心电工作站使用
        /// </summary>
        /// <value></value>
        public string EcgCode { get; set; }
        
        /// <summary>
        /// FacturyUserCode
        /// </summary>
        /// <value></value>
        public string FacturyUserCode { get; set; }
    }

	/// <summary>
	/// 重新设置用户名
	/// </summary>
    public class ResetUserNameDBRequest  : DBBaseRequest
    {
		public string Code { get; set; }

		/// <summary>
		/// 用户名
		/// </summary>
		/// <value></value>
		public string UserName { get; set; }
	}

	/// <summary>
	/// 设备用户关联的超声机 DB请求
	/// </summary>
    public class BindUltrasoundCodeDBRequest  : DBBaseRequest
    {
		/// <summary>
		/// 用户编码
		/// </summary>
		/// <value></value>
		public string UserCode { get; set; }

		/// <summary>
		/// 超声机编码
		/// </summary>
		/// <value></value>
		public string UltrasoundCode { get; set; }
	}

	/// <summary>
	/// 设备用户关联的心电 DB请求
	/// </summary>
    public class BindEcgCodeDBRequest  : DBBaseRequest
    {
		/// <summary>
		/// 用户编码
		/// </summary>
		/// <value></value>
		public string UserCode { get; set; }

		/// <summary>
		/// 心电编码
		/// </summary>
		/// <value></value>
		public string EcgCode { get; set; }
	}

	/// <summary>
	/// 设置负责区域
	/// </summary>
	public class SetAreaOfResponsibilityDBRequest
	{
		/// <summary>
		/// 用户编码
		/// </summary>
		/// <value></value>
        public string Code { get; set; }

		/// <summary>
		/// 村、小区编码
		/// </summary>
		/// <value></value>
		public List<string> ResidenceCodes { get; set; }
	}

	/// <summary>
	/// 关联晶奇工号 DB请求
	/// </summary>
	public class SetJingQiUserDBRequest
	{
		/// <summary>
		/// 用户编码
		/// </summary>
		/// <value></value>
        public string Code { get; set; }

		/// <summary>
		/// 厂商信息编号
		/// </summary>
		/// <value></value>
		public string FacturyUserCode { get; set; }
	}

	/// <summary>
	/// 获取菜单权限
	/// </summary>
	public class GetMenuPermissionDBRequest
	{
		/// <summary>
		/// 用户编码
		/// </summary>
		/// <value></value>
        public string Code { get; set; }

		/// <summary>
        /// 应用类型
        /// </summary>
        /// <value></value>
        public ApplicationTypeEnum AppType { get; set; }
	}

	/// <summary>
	/// 获取菜单权限
	/// </summary>
	public class GetOperationPermissionDBRequest
	{
		/// <summary>
		/// 用户编码
		/// </summary>
		/// <value></value>
        public string Code { get; set; }

		/// <summary>
        /// 应用类型
        /// </summary>
        /// <value></value>
        public ApplicationTypeEnum AppType { get; set; }
	}
}