using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using WingInterfaceLibrary.DTO.Device;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.Request.Device
{

    /// <summary>
    /// 增加打印机系统版本请求
    /// </summary>
    public class AddDevicePrinterVersionRequest : TokenRequest
    {
        /// <summary>
        /// 版本号
        /// </summary>
        /// <value>Win10</value>
        public string Version { get; set; }

        /// <summary>
        /// 版本类型
        /// </summary>
        /// <value>1</value>
        public DeviceVersionEnum VersionTypeEnum { get; set; }
    }

    /// <summary>
    /// 查询打印机系统版本列表请求
    /// </summary>
    public class FindDevicePrinterVersionListRequest : TokenRequest
    {
        /// <summary>
        /// 版本类型
        /// </summary>
        /// <value></value>
        public DeviceVersionEnum VersionTypeEnum { get; set; }
    }

    /// <summary>
    /// 删除打印机系统版本请求
    /// </summary>
    public class DeleteDevicePrinterVersionRequest : TokenRequest
    {
        /// <summary>
        /// 编码
        /// </summary>
        /// <value>123</value>
        public string Code { get; set; }
    }

    /// <summary>
    /// 增加打印机更新包请求
    /// </summary>
    public class AddDevicePrinterRequest : TokenRequest
    {
        /// <summary>
        /// 打印机名称
        /// </summary>
        /// <value>打印机Test</value>
        public string Name { get; set; }
        /// <summary>
        /// 描述
        /// </summary>
        /// <value>补丁包Test描述</value>
        /// <code>0</code>
        public string Description { get; set; }
        /// <summary>
        /// 适配系统版本
        /// </summary>
        /// <value>Win10</value>
        public string OsVersion { get; set; }

        /// <summary>
        /// 文件地址集合
        /// </summary>
        /// <value></value>
        public IList<UploadDeviceFileInfoDTO> FileUploadInfoList { get; set; }

        /// <summary>
        /// 文件大小
        /// </summary>
        /// <value>1024</value>
        public long FileSize { get; set; }

        /// <summary>
        /// 打印机品牌
        /// </summary>
        /// <value>hp</value>
        public string PrinterBrands { get; set; }

        /// <summary>
        /// 支持打印机型号
        /// </summary>
        /// <value>hp</value>
        public IList<string> PrinterModels { get; set; }

        /// <summary>
        /// 文件名称
        /// </summary>
        /// <value>打印机文件名称</value>
        public string FileName { get; set; }
    }

    /// <summary>
    /// 查询打印机更新包请求
    /// </summary>
    public class FindDevicePrinterPageRequest : PageRequest
    {
        /// <summary>
        /// 查询关键字
        /// </summary>
        /// <value>hp</value>
        /// <code>0</code>
        public string Keyword { get; set; }
    }

    /// <summary>
    /// 查询打印机驱动名称是否存在请求
    /// </summary>
    public class ExistsDevicePrinterRequest : TokenRequest
    {
        /// <summary>
        /// 打印机驱动名
        /// </summary>
        /// <value>hp</value>
        /// <code>0</code>
        public string Name { get; set; }
    }

    /// <summary>
    /// 删除打印机更新包请求
    /// </summary>
    public class DeleteDevicePrinterByCodeRequest : TokenRequest
    {
        /// <summary>
        /// 编码
        /// </summary>
        /// <value>123</value>
        public string Code { get; set; }
    }

    /// <summary>
    /// 更新打印机更新包请求
    /// </summary>
    public class UpdateDevicePrinterRequest : TokenRequest
    {
        /// <summary>
        /// 更新包名称
        /// </summary>
        /// <value>补丁包Test</value>
        public string Name { get; set; }

        /// <summary>
        /// 描述
        /// </summary>
        /// <value>补丁包Test描述</value>
        /// <code>0</code>
        public string Description { get; set; }

        /// <summary>
        /// 适配系统版本
        /// </summary>
        /// <value>Win10</value>
        public string OsVersion { get; set; }

        /// <summary>
        /// 编码
        /// </summary>
        /// <value>123</value>
        public string Code { get; set; }
    }
}