using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Device;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.Request.Device
{
    /// <summary>
    /// 查询个人名下所有设备列表请求实体
    /// </summary>
    public class GetPersonDeviceRequest : PageRequest
    {
        /// <summary>
        /// 关键字
        /// </summary>
        /// <value>演示超声机</value>
        /// <code>0</code>
        public string KeyWord { get; set; }

        /// <summary>
        /// 设备类型
        /// </summary>
        /// <value>US</value>
        /// <code>0</code>
        public string DeviceType { get; set; }

        /// <summary>
        /// 设备型号
        /// </summary>
        /// <value>E30</value>
        /// <code>0</code>
        public string DeviceModel { get; set; }

        /// <summary>
        /// 机构Code
        /// </summary>
        /// <value>'BCXXXXXXX0DXXXXXXXX4B1C87CCBBE','BCXXXXXXX0DXXXXXXXX4B1C87CCBBE'</value>
        /// <code>0</code>
        public IList<string> OrganizationCodes { get; set; }


        /// <summary>
        /// 是否在线：true-在线；false-离线；null-全部
        /// </summary>
        /// <value>true</value>
        /// <code>0</code>
        public bool? IsOnline { get; set; }
    }

    /// <summary>
    /// 查询设备列表请求实体
    /// </summary>
    public class GetPersonRoleDeviceRequest : PageRequest
    {
        /// <summary>
        /// 关键字
        /// </summary>
        /// <value>演示超声机</value>
        /// <code>0</code>
        public string KeyWord { get; set; }

        /// <summary>
        /// 设备类型
        /// </summary>
        /// <value>US</value>
        /// <code>0</code>
        public string DeviceType { get; set; }

        /// <summary>
        /// 设备型号
        /// </summary>
        /// <value>E30</value>
        /// <code>0</code>
        public string DeviceModel { get; set; }

    }

    /// <summary>
    /// 获取个人设备请求
    /// </summary>
    public class GetPersonDeviceDropdownPageRequest : PageRequest
    {
        /// <summary>
        /// 关键字
        /// </summary>
        /// <value>演示超声机</value>
        /// <code>0</code>
        public string KeyWord { get; set; }

        /// <summary>
        /// 指定机构编码集合
        /// </summary>
        /// <value>US</value>
        /// <code>0</code>
        public List<string> RestrictOrgCodes { get; set; }

        /// <summary>
        /// 是否包含转诊申请设备
        /// </summary>
        /// <value></value>
        public bool IsIncloudReferral { get; set; } = false;
    }
}