using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using WingInterfaceLibrary.DTO.LiveRoom;
using WingInterfaceLibrary.DTO.RemoteParameters;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Enum.NotificationEnum;

namespace WingInterfaceLibrary.Request.Device
{
    /// <summary>
    /// 用户进入设备直播房间（无token）请求
    /// </summary>
    public class JoinDeviceLiveRoomByShareRequest
    {
        /// <summary>
        /// 分享码
        /// </summary>
        /// <value>9527</value>
        public string ShareCode { get; set; }
    }
    
    /// <summary>
    /// 用户进入设备直播房间结果
    /// </summary>
    public class JoinDeviceLiveRoomByShareResult
    {
        /// <summary>
        /// 房间号码
        /// </summary>
        /// <value>1</value>
        public int RoomNo { get; set; }

        /// <summary>
        /// 直播协议：TRTC、VRTC、Embedded
        /// </summary>
        /// <value>TRTC</value>
        public TransactionStatusEnum LiveProtocol { get; set; } 

        /// <summary>
        /// 设备编码
        /// </summary>
        /// <value>1</value>
        public string DeviceCode { get; set; }

        /// <summary>
        /// 是否把多路视屏合流
        /// </summary>
        /// <value>true</value>
        public bool MergedChannel { get; set; }

        /// <summary>
        /// 合流的画面宽度
        /// </summary>
        /// <value>1920</value>
        public int MergedVideoOutputWidth { get; set; }

        /// <summary>
        /// 合流的画面高度
        /// </summary>
        /// <value>1080</value>
        public int MergedVideoOutputHeight { get; set; }
        
        /// <summary>
        /// 设备画面信息
        /// </summary>
        /// <typeparam name="VideoDeviceInfoDO"></typeparam>
        /// <returns></returns>
        public List<VideoDeviceInfoDTO> VideoDeviceInfos { get; set; } = new List<VideoDeviceInfoDTO>();
        
        /// <summary>
        /// 上报观看状态间隔时间（秒），0=无需上报
        /// </summary>
        /// <value>600</value>
        public int ReportStateIntervalSeconds { get; set; }

        /// <summary>
        /// 是否老平台，为true时【mergedVideoOutputWidth / mergedVideoOutputHeight】参数不可用
        /// </summary>
        /// <value>true</value>
        public bool IsOldPlatform { get; set; }

        /// <summary>
        /// 是否支持Rtc
        /// </summary>
        /// <value></value>
        public bool SupportRtc { get; set; }
    }
}