using WingInterfaceLibrary.Enum.NotificationEnum;
using WingInterfaceLibrary.Notifications;
using WingInterfaceLibrary.DTO.AfterSales;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Device;

namespace WingInterfaceLibrary.Request.Device
{
    /// <summary>
    /// 远程维护通用请求泛型类，用于表示多种类型的通知请求。
    /// </summary>
    public class TransportAfterSalesCommonRequest
    {
        /// <summary>
        /// 通知对象，类型由泛型参数 T 指定。
        /// </summary>
        public string ReqJson { get; set; }

        /// <summary>
        /// 接收者 ID，用于标识请求的目标组件或服务。
        /// </summary>
        public string ReceiverId { get; set; }

        /// <summary>
        /// 通知类型
        /// </summary>
        /// <value></value>
        public NotificationTypeEnum NotificationType { get; set; }
    }

    /// <summary>
    /// 发送远程维护指令到设备
    /// </summary>
    public class SendCommandToDeviceRequest : TokenRequest
    {
        /// <summary>
        /// 超声机编码
        /// </summary>
        /// <value></value>
        public string DeviceCode { get; set; }

        /// <summary>
        /// 指令类型
        /// </summary>
        /// <value></value>
        public string ActionType { get; set; }

        /// <summary>
        /// 配置信息
        /// </summary>
        /// <value></value>
        public string Settings { get; set; }
    }

    /// <summary>
    /// 发送结果到客户端
    /// </summary>
    public class SendResultToClientRequest : TokenRequest
    {
        /// <summary>
        /// 客户端用户编码
        /// </summary>
        /// <value></value>
        public string UserCode { get; set; }

        /// <summary>
        /// 配置信息
        /// </summary>
        /// <value></value>
        public string Settings { get; set; }
    }

    /// <summary>
    /// 从server获取远程维护结果
    /// </summary>
    public class GetResultFromServerRequest : TokenRequest
    {
        /// <summary>
        /// 结果的Id编码
        /// </summary>
        public string ResultCode { get; set; }
    }
}