using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Education;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.Request.Education
{
    /// <summary>
    /// 题目列表分页查询请求实体
    /// </summary>
    public class FindExaminationQuestionPagesRequest : PageRequest
    {
        /// <summary>
        /// 查询关键字
        /// </summary>
        /// <value></value>
        public string SearchKey { get; set; }

        /// <summary>
        /// 病例标签
        /// </summary>
        /// <value></value>
        public IList<string> CaseLabelCodes { get; set; }

        /// <summary>
        /// 课程标签
        /// </summary>
        /// <value></value>
        public IList<string> CourseLabelCodes { get; set; }

        /// <summary>
        /// 题目codes
        /// </summary>
        /// <value></value>
        public IList<string> Codes { get; set; }

        /// <summary>
        /// NotInCodes
        /// </summary>
        /// <value></value>
        public IList<string> NotInCodes { get; set; }

    }

    /// <summary>
    /// 题目列表分页查询请求实体
    /// </summary>
    public class FindExaminationQuestionsByCodesRequest : TokenRequest
    {

        /// <summary>
        /// 题目codes
        /// </summary>
        /// <value></value>
        public IList<string> Codes { get; set; }

    }

    /// <summary>
    /// 创建题目请求实体
    /// </summary>
    public class CreateExaminationQuestionRequest : TokenRequest
    {

        /// <summary>
        /// 题干
        /// </summary>
        /// <value></value>
        public string Stem { get; set; }

        /// <summary>
        /// 题目类型
        /// </summary>
        /// <value></value>
        public QuestionTypeEnum QuestionType { get; set; }

        /// <summary>
        /// 题目选项
        /// </summary>
        /// <value></value>
        public IList<QuestionOptionDTO> QuestionOptionList { get; set; } = new List<QuestionOptionDTO>();

        /// <summary>
        /// 图像列表
        /// </summary>
        /// <value></value>
        public IList<QuestionFileDTO> FileList { get; set; } = new List<QuestionFileDTO>();

        /// <summary>
        /// 病例标签
        /// </summary>
        /// <value></value>
        public IList<string> CaseLabelCodes { get; set; } = new List<string>();

        /// <summary>
        /// 课程标签
        /// </summary>
        /// <value></value>
        public IList<string> CourseLabelCodes { get; set; } = new List<string>();

        /// <summary>
        /// 判断题对错
        /// </summary>
        /// <value></value>
        public bool TrueOrFalse { get; set; } = false;
    }

    /// <summary>
    /// 获取题目详情请求实体
    /// </summary>
    public class GetExaminationQuestionRequest : TokenRequest
    {
        /// <summary>
        /// 题目code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }
    }

    /// <summary>
    /// 修改题目请求实体
    /// </summary>
    public class UpdateExaminationQuestionRequest : TokenRequest
    {
        /// <summary>
        /// 题目Code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 题干
        /// </summary>
        /// <value></value>
        public string Stem { get; set; }

        /// <summary>
        /// 题目类型
        /// </summary>
        /// <value></value>
        public QuestionTypeEnum QuestionType { get; set; }

        /// <summary>
        /// 题目选项
        /// </summary>
        /// <value></value>
        public IList<QuestionOptionDTO> QuestionOptionList { get; set; } = new List<QuestionOptionDTO>();

        /// <summary>
        /// 图像列表
        /// </summary>
        /// <value></value>
        public IList<QuestionFileDTO> FileList { get; set; } = new List<QuestionFileDTO>();

        /// <summary>
        /// 病例标签
        /// </summary>
        /// <value></value>
        public IList<string> CaseLabelCodes { get; set; } = new List<string>();

        /// <summary>
        /// 课程标签
        /// </summary>
        /// <value></value>
        public IList<string> CourseLabelCodes { get; set; } = new List<string>();

        /// <summary>
        /// 判断题对错
        /// </summary>
        /// <value></value>
        public bool TrueOrFalse { get; set; } = false;
    }

    /// <summary>
    /// 删除题目详情请求实体
    /// </summary>
    public class DeleteExaminationQuestionRequest : TokenRequest
    {
        /// <summary>
        /// 题目code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }
    }

}