using System;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Comment;
using WingInterfaceLibrary.DTO.Measure;
using WingInterfaceLibrary.DTO.Record;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.Request.Examine
{
    /// <summary>
    /// 机器端上传检查数据
    /// </summary>
    public class UploadExamDataRequest : TokenRequest
    {
        /// <summary>
        /// 检查code
        /// </summary>
        /// <value>test</value>
        public string ExamCode { get; set; }

        /// <summary>
        /// 预览图地址token
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public string PreviewFileToken { get; set; }

        /// <summary>
        /// 高清图token
        /// </summary>
        /// <value>filetoken</value>
        public string FileToken { get; set; }

        /// <summary>
        /// 高清图文件大小
        /// </summary>
        /// <value>5832772</value>
        public long FileSize { get; set; }

        /// <summary>
        /// 第一帧大图token
        /// </summary>
        public string CoverImageToken { get; set; }

        /// <summary>
        /// ApplicationCategory
        /// </summary>
        /// <value>ABD</value>
        public string ApplicationCategory { get; set; }

        /// <summary>
        /// Application Name
        /// </summary>
        /// <value>Abd General</value>
        /// <code>0</code>
        public string Application { get; set; }

        /// <summary>
        /// 文件数据类型
        /// </summary>
        /// <value>0</value>
        public RemedicalFileDataTypeEnum FileDataType { get; set; }

        /// <summary>
        /// 测量结果数据
        /// </summary>
        /// <value></value>
        ///  <code>0</code>
        public MeasuredResultsDTO MeasuredResult { get; set; }
        /// <summary>
        /// 注释结果数据
        /// </summary>
        /// <value></value>
        ///  <code>0</code>
        public ScanImageDTO CommentResult { get; set; }

        /// <summary>
        /// AI识别部位及图像位置描述
        /// </summary>
        /// <value>0</value>
        public ImageLocationDTO ImageLocation { get; set; }

        /// <summary>
        /// 检查时间
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public DateTime? ExamTime { get; set; }

        /// <summary>
        /// 科研项目code
        /// </summary>
        /// <value></value>
        public string ProjectCode { get; set; }

        /// <summary>
        /// URM分析参数
        /// </summary>
        /// <value></value>
        public Dictionary<string, string> UrmParameters { get; set; } = new Dictionary<string, string>();

        /// <summary>
        /// 上传图像集合
        /// </summary>
        /// <returns></returns>
        public List<ImgItem> ImgList { get; set; } = new List<ImgItem>();

        /// <summary>
        /// URM分析Pos参数值
        /// </summary>
        /// <value></value>
        public string UrmPosition { get; set; }

        /// <summary>
        /// URM原图编码
        /// </summary>
        /// <value></value>
        public string UrmOriginalCode { get; set; }

        /// <summary>
        /// URM分析/测量图像编码
        /// </summary>
        /// <value></value>
        public string RemedicalOriginalCode { get; set; }

        /// <summary>
        /// URMSrcWidth
        /// </summary>
        /// <value></value>
        public int URMSrcWidth { get; set; }

        /// <summary>
        /// URMSrcHeight
        /// </summary>
        /// <value></value>
        public int URMSrcHeight { get; set; }

        /// <summary>
        /// URMRes
        /// </summary>
        /// <value></value>
        public double URMRes { get; set; }
    }


    /// <summary>
    /// 上传图像分类实体
    /// </summary>
    public class ImgItem
    {
        /// <summary>
        /// 文件类型  0-URM源文件，4-URM视频，5-URM分析单帧VID，10-srcDenArray.bin，11-srcDirArray.bin，12-srcVelArray.bin，13-srcAngleArray.bin，14-srcMaskArray.bin，15-URMPoints.bin，16-URMPointNums.bin
        /// </summary>
        /// <value></value>
        public int ImgType { get; set; }

        /// <summary>
        /// 文件地址
        /// </summary>
        /// <value></value>
        public string FileToken { get; set; }

        /// <summary>
        /// 文件大小
        /// </summary>文件
        /// <value></value>
        public long FileSize { get; set; }

        /// <summary>
        /// 是否显示
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public bool IsShow { get; set; } = false;

        /// <summary>
        /// 缩略图
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public string PreviewFileUrl { get; set; }

        /// <summary>
        /// 首帧大图地址
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public string CoverImgUrl { get; set; }

        /// <summary>
        /// 宽，像素
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public int Width { get; set; }

        /// <summary>
        /// 高，像素
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public int Height { get; set; }

        /// <summary>
        /// 创建时间
        /// </summary>
        /// <value></value>
        public DateTime CreateTime { get; set; }

    }
}