using System;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Device;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.Request.IOTDevice
{
    /// <summary>
    /// IOT设备资讯信息请求实体
    /// </summary>
    public class GetIOTDeviceNewsPageRequest : PageRequest
    {
        /// <summary>
        /// 查询 关键字
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public string Keyword { get; set; }
    }

    /// <summary>
    /// 保存数据原始数据请求实体
    /// </summary>
    public class SaveIOTDeviceDataRequest : TokenRequest
    {
        /// <summary>
        /// 治疗时间
        /// </summary>
        public DateTime TreatTime { get; set; } = DateTime.UtcNow;

        /// <summary>
        /// 数据类型描述
        /// </summary>
        public string DataDesc { get; set; }

        /// <summary>
        /// 文件数据
        /// </summary>
        public byte[] FileData { get; set; }
        
        /// <summary>
        /// 文件数据
        /// </summary>
        public bool IsNeedReturnFileUrl { get; set; }        
        
        /// <summary>
        /// 文件夹名称
        /// </summary>
        public string FolderName { get; set; }

        /// <summary>
        /// 原始文件名，带后缀   例如：00000000.evt
        /// </summary>
        public string OriginalFileName { get; set; }

        /// <summary>
        /// 设备编号
        /// </summary>
        /// <value></value>
        public string DeviceSN { get; set; }

        /// <summary>
        /// 设备mac地址
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public string DeviceMac { get; set; }

        /// <summary>
        /// 用户code或者用户信息
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public string UserCode { get; set; }
    }

    /// <summary>
    /// 分页查询呼吸机设备原始数据列表请求实体
    /// </summary>
    public class GetIOTDeviceFileDataRequest : TokenRequest
    {
        /// <summary>
        /// 设备编号
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public string DeviceSN { get; set; }

        /// <summary>
        /// 用户名
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public string UserInfo { get; set; }

        /// <summary>
        /// 治疗开始时间
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public DateTime BeginTreatTime { get; set; } = DateTime.MinValue;

        /// <summary>
        /// 治疗结束时间
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public DateTime EndTreatTime { get; set; } = DateTime.MinValue;

        /// <summary>
        /// 创建开始时间
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public DateTime CreateTimeFrom { get; set; } = DateTime.MinValue;

        /// <summary>
        /// 创建结束时间
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public DateTime CreateTimeTo { get; set; } = DateTime.MinValue;
    }

    /// <summary>
    /// IOT设备数据标记列表分页请求实体
    /// </summary>
    public class GetIOTDeviceUserDataPageRequest : PageRequest
    {
        /// <summary>
        /// 设备编号
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public string DeviceSN { get; set; }

        /// <summary>
        /// 治疗开始时间
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public DateTime BeginTreatTime { get; set; }

        /// <summary>
        /// 治疗结束时间
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public DateTime EndTreatTime { get; set; }

        /// <summary>
        /// 用户名
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public string Name { get; set; }

        /// <summary>
        /// 最小年龄
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public int BeginAge { get; set; }

        /// <summary>
        /// 最大年龄
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public int EndAge { get; set; }

        /// <summary>
        /// 性别：0-未知；1-男；2-女
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public int Gender { get; set; }

        /// <summary>
        /// 体重指数开始
        /// </summary>
        public double BeginBMI { get; set; }

        /// <summary>
        /// 体重指数结束
        /// </summary>
        public double EndBMI { get; set; }

        /// <summary>
        /// 身高，厘米
        /// </summary>
        public int Height { get; set; }

        /// <summary>
        /// 体重 kg
        /// </summary>
        public double Weight { get; set; }

        /// <summary>
        /// 颈围 厘米
        /// </summary>
        public double Neck { get; set; }
    }

    /// <summary>
    /// IOT设备用户信息请求实体
    /// </summary>
    public class GetIOTDeviceUsersRequest : TokenRequest
    {
        /// <summary>
        /// 设备sn码列表
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public List<string> DeviceSNList { get; set; }

        /// <summary>
        /// 病人姓名
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public List<string> UserList { get; set; }

        // /// <summary>
        // /// 设备mac地址
        // /// </summary>
        // /// <value></value>
        // /// <code>0</code>
        // public string DeviceMac { get; set; }

    }

    /// <summary>
    /// 保存设备用户信息
    /// </summary>
    public class SaveIOTDeviceUserDataRequest : TokenRequest
    {
        /// <summary>
        /// 设备用户code
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public string DeviceUserCode { get; set; }

        /// <summary>
        /// 用户姓名
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public string Name { get; set; }

        /// <summary>
        /// 生日
        /// </summary>
        public DateTime Birthday { get; set; }

        /// <summary>
        /// 性别：0-未知；1-男；2-女
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public int Gender { get; set; }

        /// <summary>
        /// 体重指数
        /// </summary>
        public double BMI { get; set; }

        /// <summary>
        /// 身高，厘米
        /// </summary>
        public int Height { get; set; }

        /// <summary>
        /// 体重 kg
        /// </summary>
        public double Weight { get; set; }

        /// <summary>
        /// 颈围 厘米
        /// </summary>
        public double Neck { get; set; }
    }


    /// <summary>
    /// 保存设备绑定用户信息实体
    /// </summary>
    public class IOTDeviceBindUserDataRequest : TokenRequest
    {
        /// <summary>
        /// 设备绑定用户code
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public string DeviceBindUserCode { get; set; }

        /// <summary>
        /// 用户code
        /// </summary>
        public string UserCode { get; set; }

        /// <summary>
        /// 设备code
        /// </summary>
        public string DeviceCode { get; set; }
    }

    /// <summary>
    /// IOT设备绑定用户列表分页请求实体
    /// </summary>
    public class GetIOTDeviceBindUserDataPageRequest : PageRequest
    {
        /// <summary>
        /// 数据名称
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public string DeviceSN { get; set; }

        /// <summary>
        /// 用户姓名
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public string UserName { get; set; }
    }
}