using System;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO;
using WingInterfaceLibrary.DTO.Education;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Enum.CourseEnum;

namespace WingInterfaceLibrary.Request.Management
{
    /// <summary>
    /// 批量新增课程请求实体
    /// </summary>
    public class BatchInsertCourseRequest : TokenRequest
    {
        public SyncDBEnum SyncType { get; set; } = SyncDBEnum.Migrate;
        
        /// <summary>
        /// 迁移数据-课程标签列表
        /// </summary>
        /// <value></value>
        public IList<CourseMigratoryInfo> CourseMigratorys { get; set; }

         /// <summary>
        /// 迁移数据-素材列表
        /// </summary>
        /// <value></value>
        public IList<VideoMigratoryInfo> VideoMigratorys { get; set; }

        /// <summary>
        /// 迁移数据-考试列表
        /// </summary>
        /// <value></value>
        public IList<ExamMigratoryInfo> ExamMigratorys { get; set; }

        /// <summary>
        /// 迁移数据-个人上传图像
        /// </summary>
        /// <value></value>
        public IList<RemoteExaminationDTO> RemoteExaminationMigratorys { get; set; }
    }

    /// <summary>
    /// 考试
    /// </summary>
    public class ExamMigratoryInfo : ExaminationPaperDTO
    {                
        /// <summary>
        /// 是否删除
        /// </summary>
        /// <value>false</value>
        public bool IsDelete { get; set; }
        /// <summary>
        /// 题目列表
        /// </summary>
        /// <value></value>
        public IList<ExaminationQuestionDTO> ExaminationQuestions { get; set; }
        
        /// <summary>
        /// 学生考试列表
        /// </summary>
        /// <value></value>
        public IList<StudentExaminationDTO> StudentExamination { get; set; }
    }

    /// <summary>
    /// 素材
    /// </summary>
    public class VideoMigratoryInfo : BaseDTO
    {
        /// <summary>
        /// 是否删除
        /// </summary>
        /// <value>false</value>
        public bool IsDelete { get; set; }
        /// <summary>
        /// 视频Code
        /// </summary>
        /// <value>04669519BF9544489E4DB547E1C01322</value>
        public string Code { get; set; }

        /// <summary>
        /// 视频名称
        /// </summary>
        /// <value>XXXX_Video</value>
        public string Name { get; set; }

        /// <summary>
        /// 视频地址
        /// </summary>
        /// <value>https://flyinsono-bj-1300984704.cos.ap-beijing.myqcloud.com/video.mp4</value>
        public string VideoToken { get; set; }

        /// <summary>
        /// Vod云点播文件Id
        /// </summary>
        /// <value>12334e</value>
        public string VodFileId { get; set; }

        /// <summary>
        /// 封面图
        /// </summary>
        /// <value>https://flyinsono-bj-1300984704.cos.ap-beijing.myqcloud.com/0B7B494B7A7044F3ADE0FCF8C0422700.png</value>
        public string Poster { get; set; }

        /// <summary>
        /// 视频时长【分钟】
        /// </summary>
        /// <value>120</value>
        public int Duration { get; set; }

        /// <summary>
        /// 视频大小【MB】
        /// </summary>
        /// <value>100</value>
        public double VideoSize { get; set; }

        /// <summary>
        /// 视频上传人
        /// </summary>
        public string CreatorCode { get; set; }

        /// <summary>
        /// 素材上传人
        /// </summary>
        public string CreatorName { get; set; }

        /// <summary>
        /// 素材分类：视频、图片、文件
        /// </summary>
        public UploadFileTypeEnum FodderType { get; set; } 

        /// <summary>
        /// 素材使用：公开的、私有的
        /// </summary>
        public bool IsPublic { get; set; } = true;

        /// <summary>
        /// 可见范围：国内，国外，或者两者兼有
        /// </summary>
        public CourseViewRangeEnum ViewRange { get; set; }
        
        /// <summary>
        /// 播放次数
        /// </summary>
        /// <value>100</value>
        public int PlayCount { get; set; }

        /// <summary>
        /// 原始文件地址 
        /// </summary>
        /// <value>100</value>
        public string SrcFileToken { get; set; }
    }

    /// <summary>
    /// 课程
    /// </summary>
    public class CourseMigratoryInfo : BaseDTO
    {        
        /// <summary>
        /// 是否删除
        /// </summary>
        /// <value>false</value>
        public bool IsDelete { get; set; }
        /// <summary>
        /// 课程名称
        /// </summary>
        /// <value>TestCourse</value>
        public string Code { get; set; }

        /// <summary>
        /// 课程名称
        /// </summary>
        /// <value>TestCourse</value>
        public string Name { get; set; }

        /// <summary>
        /// 课程简介
        /// </summary>
        ///  <value>Test course dec</value>
        /// <code>0</code>
        public string CourseIntro { get; set; }

        /// <summary>
        /// 教师编码
        /// </summary>
        /// <value>04669519BF9544489E4DB547E1C01322</value>
        public string TeacherCode { get; set; }

        /// <summary>
        /// 封面图，课程海报
        /// </summary>
        /// <value>https://flyinsono-bj-1300984704.cos.ap-beijing.myqcloud.com/0B7B494B7A7044F3ADE0FCF8C0422700.png</value>
        /// <code>0</code>
        public string Poster { get; set; }

        /// <summary>
        /// 课程状态
        /// </summary>
        /// <value>1</value>
        public CourseStatusEnum Status { get; set; }

        /// <summary>
        /// 课程预计开始时间
        /// </summary>
        /// <value>2022-03-15T12:53:29.889Z</value>
        public DateTime StartTime { get; set; }

        /// <summary>
        /// 课程时长【单位分钟】
        /// </summary>
        /// <value>120</value>
        public int Duration { get; set; }

        /// <summary>
        /// 结束注册时间
        /// </summary>
        public DateTime Deadline { get; set; }
        /// <summary>
        /// 实际开始时间
        /// </summary>
        public DateTime ActualStartTime { get; set; }

        /// <summary>
        /// 实际结束时间
        /// </summary>
        public DateTime ActualEndTime { get; set; }

        /// <summary>
        /// 课程地址，邀请码
        /// </summary>
        public string CourseToken { get; set; }

        /// <summary>
        /// 创建人
        /// </summary>
        /// <value>12345</value>
        public string CreatorCode { get; set; }

        /// <summary>
        /// 创建人
        /// </summary>
        /// <value>12345</value>
        public string OrganizationCode { get; set; }

        /// <summary>
        /// 课程分类
        /// </summary>
        /// <value>1</value>
        public CourseTypeEnum CourseType { get; set; }

        /// <summary>
        /// 课程规模类型
        /// </summary>
        /// <value>1</value>
        public CourseAudienceTypeEnum AudienceType { get; set; }

        /// <summary>
        /// 课件地址
        /// </summary>
        /// <value>https://flyinsono-bj-1300984704.cos.ap-beijing.myqcloud.com/0B7B494B7A7044F3ADE0FCF8C0422700.png</value>
        /// <code>0</code>
        public string CoursewareToken { get; set; }

        /// <summary>
        /// 老师名称
        /// </summary>
        /// <value></value>
        public string TeacherName { get; set; }

        /// <summary>
        /// 课程可见范围，默认所有
        /// </summary>
        /// <value>0</value>
        public CourseViewRangeEnum ViewRange { get; set; }

        /// <summary>
        /// 病例标签
        /// </summary>
        /// <value>'12334e','12334e'</value>
        public IList<string> CaseLabelCodes { get; set; } 

        /// <summary>
        /// 课程/视频标签
        /// </summary>
        /// <value>'12334e','12334e'</value>
        public IList<string> CourseLabelCodes { get; set; } 

        /// <summary>
        /// 班级CodeList
        /// </summary>
        /// <value>'12334e','12334e'</value>        
        /// <code>0</code>
        public IList<string> UserGroupCodes { get; set; } 

        /// <summary>
        /// 课程价格
        /// </summary>
        /// <value>10.0</value>
        /// <code>0</code>
        public decimal Price { get; set; }

        /// <summary>
        /// 视频课程CodeList
        /// </summary>
        /// <value>'12334e','12334e'</value>        
        /// <code>0</code>
        public IList<string> CourseVideoCodes { get; set; } 

        /// <summary>
        /// 助教列表
        /// </summary>
        public IList<StudentInfoDTO> Assistants { get; set; } = new List<StudentInfoDTO>();

        /// <summary>
        /// 参与互动专家
        /// </summary>
        public IList<StudentInfoDTO> Experts { get; set; } = new List<StudentInfoDTO>();       
        
        /// <summary>
        /// 是否代理商课程
        /// </summary>
        /// <value>false</value>  
        public bool IsAgentCourse { get; set; }

        /// <summary>
        /// 所属专辑
        /// </summary>
        /// <value></value>
        public IList<string> CourseAlbumCodes { get;set;}

        /// <summary>
        /// 是否置顶
        /// </summary>
        /// <value></value>
        public bool IsStick { get;set;}

        /// <summary>
        /// 推荐星级
        /// </summary>
        /// <value></value>
        public int Sort { get;set;}

        /// <summary>
        /// 资料CodeList
        /// </summary>
        /// <value>'12334e','12334e'</value>        
        /// <code>0</code>
        public IList<string> CourseMaterialCodes { get; set; } 

        /// <summary>
        /// 绑定试卷
        /// </summary>
        /// <value></value>     
        public IList<CourseExaminationDTO> BindExams { get; set; } 

        /// <summary>
        /// 课程呈现类型
        /// </summary>
        /// <value></value>
        public CourseAppearTypeEnum CourseAppearType { get; set; }

        /// <summary>
        /// 报名学生列表
        /// </summary>
        /// <value></value>
        public IList<StudentInfoDTO> Students { get; set; } = new List<StudentInfoDTO>();
        
        /// <summary>
        /// 播放次数
        /// </summary>
        /// <value>0</value>     
        public int PlayCount { get; set; } 
    }
}