using System;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Organization;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.Request.Management
{
    /// <summary>
    /// 批量新增机构请求实体
    /// </summary>
    public class BatchInsertOrganizationRequest : TokenRequest
    {
        public SyncDBEnum SyncType { get; set; } = SyncDBEnum.Migrate;
        
        /// <summary>
        /// 迁移数据-机构列表
        /// </summary>
        /// <value></value>
        public IList<OrganizationMigratoryInfo> OrganizationMigratorys { get; set; }
    }

    /// <summary>
    /// 机构数据迁移请求实体
    /// </summary>
    public class OrganizationMigratoryInfo : OrganizationDTO
    {
        /// <summary>
        /// 是否删除
        /// </summary>
        /// <value>false</value>
        public bool IsDelete { get; set; }
        /// <summary>
        /// AI诊断枚举列表
        /// </summary>
        public IList<DiagnosisModuleEnum> DiagnosisModule { get; set; }

        /// <summary>
        /// 最小区域名称
        /// </summary>
        public string RegionName { get; set; }
        /// <summary>
        /// 默认模板
        /// </summary>
        public string DefaultTemplateId { get; set; }
        /// <summary>
        /// 模板列表
        /// </summary>
        public IList<string> ReportTemplateIds { get; set; }
    }

    /// <summary>
    /// 批量处理医联体
    /// </summary>
    public class BatchInsertMedicalConsortiumRequest
    {
        /// <summary>
        /// 医联体
        /// </summary>
        /// <value></value>
        public IList<MedicalConsortiumDetail> MedicalConsortiumDetails { get; set; }
    }

    public class MedicalConsortiumDetail
    {
        /// <summary>
        /// 关键字
        /// </summary>
        public string Name { get; set; }

        /// <summary>
        /// 顶级Code
        /// </summary>
        public string Code { get; set; }

        /// <summary>
        /// 检查服务病人对象类型
        /// </summary>
        /// <value>0</value>
        public OrganizationPatientTypeEnum PatientType { get; set; }
    }
}