
using System;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.ReportTemplate;
using WingInterfaceLibrary.DTO.Report;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.Request.Management
{
    /// <summary>
    /// 批量新增报告模板请求实体
    /// </summary>
    public class BatchInsertReportTemplateRequest : TokenRequest
    {
        public SyncDBEnum SyncType { get; set; } = SyncDBEnum.Migrate;
        
        /// <summary>
        /// 迁移数据
        /// </summary>
        /// <value></value>
        public IList<ReportTemplateMigratoryInfo> ReportTemplateMigratorys { get; set; }
    }

    /// <summary>
    /// 报告模板数据迁移请求实体
    /// </summary>
    public class ReportTemplateMigratoryInfo : ReportTemplateDTO
    {
        /// <summary>
        /// 是否删除
        /// </summary>
        /// <value>false</value>
        public bool IsDelete { get; set; }
        /// <summary>
        /// 创建时间 
        /// </summary>
        /// <value></value>
        public DateTime CreateTime { get; set; }

        /// <summary>
        /// 修改时间
        /// </summary>
        /// <value></value>
        public DateTime UpdateTime { get; set; }
    }

    /// <summary>
    /// 报告标签
    /// </summary>
    public class BatchInsertReportLabelRequest : TokenRequest
    {
        public SyncDBEnum SyncType { get; set; } = SyncDBEnum.Migrate;
        
        /// <summary>
        /// 迁移数据
        /// </summary>
        /// <value></value>
        public IList<ReportLabelMigratoryInfo> ReportLabelData { get; set; }
    }

    /// <summary>
    /// 迁移报告标签
    /// </summary>
    public class ReportLabelMigratoryInfo:ReportLabelDTO
    {
        /// <summary>
        /// 是否删除
        /// </summary>
        /// <value>false</value>
        public bool IsDelete { get; set; }
    }

    /// <summary>
    /// 批量调整报告模板请求实体
    /// </summary>
    public class BatchModifyReportTemplateRequest : TokenRequest
    {
        /// <summary>
        /// 迁移数据
        /// </summary>
        /// <value></value>
        public IList<ReportTemplateMigratoryInfo> ReportTemplateMigratorys { get; set; }

        /// <summary>
        /// 机构默认模板列表
        /// </summary>
        /// <value></value>
        public IList<OrganizationDefaultTemplate> OrganizationDefaultTemplates { get; set; }
    }

    /// <summary>
    /// 机构默认模板
    /// </summary>
    public class OrganizationDefaultTemplate
    {
        /// <summary>
        /// 组织编码
        /// </summary>
        public string OrganizationCode { get; set; }
        /// <summary>
        /// 默认模板
        /// </summary>
        public string DefaultTemplateId { get; set; }
        /// <summary>
        /// 模板列表
        /// </summary>
        public IList<string> ReportTemplateIds { get; set; }
        /// <summary>
        /// 机构对应的用户
        /// </summary>
        public IList<string> UserCodes { get; set; }
    }
}