using System.Collections.Generic;
using WingInterfaceLibrary.DTO.DistributedServerInfo;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.Request.Management
{
    /// <summary>
    /// 查询机构详情
    /// </summary>
    public class DistributedServerInfoRequest : TokenRequest
    {
        /// <summary>
        /// 组织编码
        /// </summary>
        public string Code { get; set; }

        /// <summary>
        /// 组织编码列表
        /// </summary>
        public List<string> Codes { get; set; }

        /// <summary>
        /// 是否主服务器
        /// </summary>
        public bool IsMaster { get; set; }
        /// <summary>
        /// 服务器名称
        /// </summary>
        public string Name { get; set; }
        /// <summary>
        /// 描述
        /// </summary>
        public string Description { get; set; }
        /// <summary>
        /// 启用
        /// </summary>
        public bool Enable { get; set; }
        /// <summary>
        /// 功能区分 官方或私有服务器
        /// </summary>
        public DistributedServerTypeEnum ServerType { get; set; }
        /// <summary>
        /// 云服务地址
        /// </summary>
        public string ServerUrl { get; set; }
        /// <summary>
        /// 纬度
        /// </summary>
        /// <value></value>
        public string Lat { get; set; }
        /// <summary>
        /// 经度
        /// </summary>
        /// <value></value>
        public string Lng { get; set; }
        /// <summary>
        /// 指定客户端IP访问此服务器
        /// </summary>
        /// <value></value>
        public List<IPAddressInfoDTO> AssignClientIPList { get; set; }
        /// <summary>
        /// rtc 初始房间id
        /// </summary>
        /// <value></value>
        public int RTCStartingRoomId { get; set; }
        /// <summary>
        /// 分享前缀code
        /// </summary>
        /// <value></value>
        public string ShareCodePrefix { get; set; }
        /// <summary>
        /// 默认存储节点
        /// </summary>
        /// <value></value>
        public string DefaultStorageNode { get; set; }

        /// <summary>
        /// 存储服务配置
        /// </summary>
        /// <value></value>
        public string StorageServerConfig { get; set; }
        
        /// <summary>
        /// 局域网服务器地址包含端口
        /// </summary>
        /// <value></value>
        public string LANHost{ get; set; }
    }

    public class SaveDistributedServerIpRequest : TokenRequest
    {
        /// <summary>
        /// 起始IP段
        /// </summary>
        /// <value></value>
        public string StartIp { get; set; }
        /// <summary>
        /// 结束IP段
        /// </summary>
        /// <value></value>
        public string EndIp { get; set; }

        /// <summary>
        /// Code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }
    }

    public class GetDistributedServerIpListRequest : PageRequest
    {
        /// <summary>
        /// 配置code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 关键字
        /// </summary>
        /// <value></value>
        public string Keyword { get; set; }
    }
}