using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Report;

namespace WingInterfaceLibrary.Request.QualityControl
{
    /// <summary>
    /// 获取会诊报告质控项
    /// </summary>
    public class GetConsultationReportQualityTypeRequest : TokenRequest
    {
        /// <summary>
        /// 语言地区码
        /// </summary>
        /// <value>zh-CN;en-US</value>
        public string Language { get; set; }
    }

    /// <summary>
    /// 新增会诊报告质控
    /// </summary>
    public class AddConsultationReportQualityRequest : TokenRequest
    {

        /// <summary>
        /// 会诊记录Code
        /// </summary>
        /// <value></value>
        public string ConsultationRecordCode { get; set; }

        /// <summary>
        /// 报告code
        /// </summary>
        /// <value></value>
        public string ReportCode { get; set; }

        /// <summary>
        /// 质控类型key
        /// </summary>
        /// <value></value>
        public int QualityTypeKey { get; set; }
    }

    /// <summary>
    /// 修改会诊报告质控
    /// </summary>
    public class ModifyConsultationReportQualityRequest : TokenRequest
    {
        /// <summary>
        /// 会诊记录Code
        /// </summary>
        /// <value></value>
        public string ConsultationRecordCode { get; set; }

        /// <summary>
        /// 报告code
        /// </summary>
        /// <value></value>
        public string ReportCode { get; set; }

        /// <summary>
        /// 质控类型key
        /// </summary>
        /// <value></value>
        public int QualityTypeKey { get; set; }
    }

    /// <summary>
    /// 删除会诊报告质控
    /// </summary>
    public class DeleteConsultationReportQualityRequest : TokenRequest
    {
        /// <summary>
        /// 会诊记录Code
        /// </summary>
        /// <value></value>
        public string ConsultationRecordCode { get; set; }

        /// <summary>
        /// 报告code
        /// </summary>
        /// <value></value>
        public string ReportCode { get; set; }
    }

    /// <summary>
    /// 新增图像质控
    /// </summary>
    public class AddRemedicalQualityRequest : TokenRequest
        {
            /// <summary>
            /// 检查code
            /// </summary>
            /// <value></value>
            public string RecordCode { get; set; }

            /// <summary>
            /// 图像code
            /// </summary>
            /// <value></value>
            public string RemedicalCode { get; set; }

            /// <summary>
            /// 质控评分
            /// </summary>
            /// <value></value>
            public IList<QualityControlScoreItem> QualityControlScoreList { get; set; }

            /// <summary>
            /// 质控意见
            /// </summary>
            /// <value></value>
            public string Opinion { get; set; }

        }

        /// <summary>
        /// 修改图像质控
        /// </summary>
        public class ModifyRemedicalQualityRequest : TokenRequest
        {
            /// <summary>
            /// 检查code
            /// </summary>
            /// <value></value>
            public string RecordCode { get; set; }

            /// <summary>
            /// 图像code
            /// </summary>
            /// <value></value>
            public string RemedicalCode { get; set; }

            /// <summary>
            /// 质控评分
            /// </summary>
            /// <value></value>
            public IList<QualityControlScoreItem> QualityControlScoreList { get; set; }

            /// <summary>
            /// 质控意见
            /// </summary>
            /// <value></value>
            public string Opinion { get; set; }

        }

        /// <summary>
        /// 删除图像质控
        /// </summary>
        public class DeleteRemedicalQualityRequest : TokenRequest
        {
            /// <summary>
            /// 检查code
            /// </summary>
            /// <value></value>
            public string RecordCode { get; set; }

            /// <summary>
            /// 图像code
            /// </summary>
            /// <value></value>
            public string RemedicalCode { get; set; }



        }

        /// <summary>
        /// 新增检查报告质控
        /// </summary>
        public class AddRecordReportQualityRequest : TokenRequest
        {
            /// <summary>
            /// 检查code
            /// </summary>
            /// <value></value>
            public string RecordCode { get; set; }

            /// <summary>
            /// 图像code
            /// </summary>
            /// <value></value>
            public string ReportCode { get; set; }

            /// <summary>
            /// 质控评分
            /// </summary>
            /// <value></value>
            public IList<QualityControlScoreItem> QualityControlScoreList { get; set; }

            /// <summary>
            /// 质控意见
            /// </summary>
            /// <value></value>
            public string Opinion { get; set; }

        }

        /// <summary>
        /// 修改检查报告质控
        /// </summary>
        public class ModifyRecordReportQualityRequest : TokenRequest
        {
            /// <summary>
            /// 检查code
            /// </summary>
            /// <value></value>
            public string RecordCode { get; set; }

            /// <summary>
            /// 图像code
            /// </summary>
            /// <value></value>
            public string ReportCode { get; set; }

            /// <summary>
            /// 质控评分
            /// </summary>
            /// <value></value>
            public IList<QualityControlScoreItem> QualityControlScoreList { get; set; }

            /// <summary>
            /// 质控意见
            /// </summary>
            /// <value></value>
            public string Opinion { get; set; }

        }

        /// <summary>
        /// 删除检查报告质控
        /// </summary>
        public class DeleteRecordReportQualityRequest : TokenRequest
        {
            /// <summary>
            /// 检查code
            /// </summary>
            /// <value></value>
            public string RecordCode { get; set; }

            /// <summary>
            /// 图像code
            /// </summary>
            /// <value></value>
            public string ReportCode { get; set; }

        }

}