using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Common;
using WingInterfaceLibrary.DTO.Record;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Request.Examine;

namespace WingInterfaceLibrary.Request.Record
{
    /// <summary>
    /// 创建检查请求实体
    /// </summary>
    public class CreateRecordRequest : TokenRequest
    {
        /// <summary>
        /// 病人编码
        /// </summary>
        /// <value>PatientCode_20220107104236xiP0nz</value>
        public string PatientCode { get; set; }

        /// <summary>
        /// 设备编码
        /// </summary>
        /// <value>DeviceCode_20220107104236xiP0nz</value>
        public string DeviceCode { get; set; }

        /// <summary>
        /// 病人信息
        /// </summary>
        /// <value></value>        
        /// <code>0</code>
        public List<DataItemDTO> PatientDatas { get; set; } = new List<DataItemDTO>();

        /// <summary>
        /// 病人额外信息列表(扫查信息)
        /// </summary>
        /// <value></value>
        public List<PatientInfoExt> PatientInfoExtList { get; set; }

        /// <summary>
        /// 科研项目code,科研使用，非必填
        /// </summary>
        /// <value></value>
        public string ProjectCode { get; set; }

        /// <summary>
        /// examid(非必填)
        /// </summary>
        /// <value></value>
        public string ExamId { get; set; }

    }

    /// <summary>
    /// 客户端上传检查图像请求实体
    /// </summary>
    public class CreateExamDataRequest : TokenRequest
    {
        /// <summary>
        /// 检查编码
        /// </summary>
        /// <value>RecordCode_20220107104236xiP0nz</value>
        public string RecordCode { get; set; }

        /// <summary>
        /// 高清图token
        /// </summary>
        /// <value>filetoken</value>
        public string FileToken { get; set; }

        /// <summary>
        /// 高清图文件大小
        /// </summary>
        /// <value>5832772</value>
        public long FileSize { get; set; }

        /// <summary>
        /// 文件数据类型
        /// </summary>
        /// <value>0</value>
        public RemedicalFileDataTypeEnum FileDataType { get; set; }

        /// <summary>
        /// 预览图地址token
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public string PreviewFileToken { get; set; }

        /// <summary>
        /// 第一帧大图token
        /// </summary>
        public string CoverImageToken { get; set; }

        /// <summary>
        /// 科研项目code,科研使用，非必填
        /// </summary>
        /// <value></value>
        public string ProjectCode { get; set; }

        /// <summary>
        /// URM分析参数
        /// </summary>
        /// <value></value>
        public Dictionary<string, string> UrmParameters { get; set; } = new Dictionary<string, string>();

        /// <summary>
        /// 上传图像集合
        /// </summary>
        /// <typeparam name="ImgItem"></typeparam>
        /// <returns></returns>
        public List<ImgItem> ImgList { get; set; } = new List<ImgItem>();

        /// <summary>
        /// URM分析Pos参数值
        /// </summary>
        /// <value></value>
        public string UrmPosition { get; set; }

        /// <summary>
        /// URM原图编码
        /// </summary>
        /// <value></value>
        public string UrmOriginalCode { get; set; }

        /// <summary>
        /// URM分析/测量图像编码
        /// </summary>
        /// <value></value>
        public string RemedicalOriginalCode { get; set; }

        /// <summary>
        /// URMSrcWidth
        /// </summary>
        /// <value></value>
        public int URMSrcWidth { get; set; }

        /// <summary>
        /// URMSrcHeight
        /// </summary>
        /// <value></value>
        public int URMSrcHeight { get; set; }

        /// <summary>
        /// URMRes
        /// </summary>
        /// <value></value>
        public double URMRes { get; set; }

    }

    /// <summary>
    /// 创建检查请求实体(大列表)
    /// </summary>
    public class CreateRecordNewRequest : TokenRequest
    {
        /// <summary>
        /// 病人编码
        /// </summary>
        /// <value>PatientCode_20220107104236xiP0nz</value>
        public string PatientCode { get; set; }

        /// <summary>
        /// 病人信息
        /// </summary>
        /// <value></value>        
        /// <code>0</code>
        public List<DataItemDTO> PatientDatas { get; set; } = new List<DataItemDTO>();

        /// <summary>
        /// 设备编码
        /// </summary>
        /// <value>DeviceCode_20220107104236xiP0nz</value>
        public string DeviceCode { get; set; }

        /// <summary>
        /// 扫查信息
        /// </summary>
        /// <value></value>
        public List<PatientInfoExt> PatientInfoExtList { get; set; }



    }

    /// <summary>
    /// 开始采图请求实体
    /// </summary>
    public class StartCollectingImgRequest : TokenRequest
    {
        /// <summary>
        /// 检查code
        /// </summary>
        /// <value></value>
        public string RecordCode { get; set; }

        /// <summary>
        /// 是否健康平台
        /// </summary>
        /// <value></value>
        public bool IsVital { get; set; }
    }

    /// <summary>
    /// 检查采图请求实体
    /// </summary>
    public class CheckCollectingImgRequest : TokenRequest
    {
        /// <summary>
        /// 设备code
        /// </summary>
        /// <value></value>
        public string DeviceCode { get; set; }

        /// <summary>
        /// 是否健康平台
        /// </summary>
        /// <value></value>
        public bool IsVital { get; set; }
    }

}