using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.Request.Record
{
    /// <summary>
    /// 查询检查记录分页请求实体
    /// </summary>
    public class GetRecordsPageRequest : PageRequest
    {
        /// <summary>
        /// 病人编码
        /// </summary>
        /// <value>PatientCode_20220107104236xiP0nz</value>
        public string PatientCode { get; set; }

        /// <summary>
        /// 查询状态
        /// </summary>
        /// <value></value>
        public QueryRecordStatusEnum QueryRecordStatus { get; set; } = QueryRecordStatusEnum.All;

        /// <summary>
        /// 查询创建类型
        /// </summary>
        /// <value></value>
        public QueryRecordCreateTypeEnum QueryRecordCreateType { get; set; } = QueryRecordCreateTypeEnum.All;
    }

    /// <summary>
    /// 查询检查记录大列表分页请求实体
    /// </summary>
    public class FindRecordPagesRequest : PageRequest
    {

        /// <summary>
        /// 机构code列表
        /// </summary>
        /// <value></value>
        public List<string> OrganizationCodes { get; set; }

        /// <summary>
        /// 设备code列表
        /// </summary>
        /// <value></value>
        public List<string> DeviceCodes { get; set; }

        /// <summary>
        /// 检查状态
        /// </summary>
        /// <value></value>
        public RecordQueryStateEnum RecordQueryState { get; set; } = RecordQueryStateEnum.All;

        /// <summary>
        /// tab 0-全部，1-待处理，2-已处理，3-已转出
        /// </summary>
        /// <value></value>
        public RecordProcessStateEnum RecordProcessState { get; set; } = RecordProcessStateEnum.All;

        /// <summary>
        /// 语言 zh-CN
        /// </summary>
        /// <value></value>
        public string Language { get; set; } = "en-US";

        /// <summary>
        /// 关键字查询
        /// </summary>
        /// <value></value>
        public string KeyWord { get; set; } = string.Empty;

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2022-02-28T09:21:38.861Z</value>
        public DateTime StartTime { get; set; }

        /// <summary>
        /// 截至时间
        /// </summary>
        /// <value>2022-03-28T09:21:38.861Z</value>
        public DateTime EndTime { get; set; }

        /// <summary>
        /// 病人code
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }

    }

    /// <summary>
    /// 根据体检号查询远程超声详情请求实体
    /// </summary>
    public class VitalGetRecordByNumberRequest : TokenRequest
    {
        /// <summary>
        /// 体检号
        /// </summary>
        /// <value>PatientCode_20220107104236xiP0nz</value>
        public string PhysicalExamNumber { get; set; }
    }

    /// <summary>
    /// 通过设备检查代码和项目查找记录请求实体
    /// </summary>
    public class FindRecordInfoByDeviceExamIdAndProjectCodeRequest
    {
        /// <summary>
        /// DeviceExamId
        /// </summary>
        /// <value></value>
        public string DeviceExamId { get; set; }

        /// <summary>
        /// ProjectCode
        /// </summary>
        /// <value></value>
        public string ProjectCode { get; set; }

    }

    public class FindRecordInfoByDeviceExamIdAndPatientCodeRequest
    {
        /// <summary>
        /// DeviceExamId
        /// </summary>
        /// <value></value>
        public string DeviceExamId { get; set; }

        /// <summary>
        /// PatientCode
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }

    }
}
