using System;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Comment;
using WingInterfaceLibrary.DTO.Record;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.Request.RemedicalAISelected
{
    /// <summary>
    /// 拖动光标，查询所有轮廓点和关键点请求
    /// </summary>
    public class ContourAndKeyPointsAfterDragRequest : TokenRequest
    {
        /// <summary>
        /// 拖拽前的轮廓上的所有点
        /// </summary>
        /// <value>[{X:0,Y:0}]</value>
        public List<AIDiagnosisPoint2D> Contours { get; set; }

        /// <summary>
        /// 拖拽前的轮廓上的关键点
        /// </summary>
        /// <value>[{X:0,Y:0}]</value>
        public List<DiagnosisKeyPointDTO> KeyPoints { get; set; }

        /// <summary>
        /// 拖拽起点（在图像上的像素坐标）
        /// </summary>
        /// <value>{X:0,Y:0}</value>
        public AIDiagnosisPoint2D StartPoint { get; set; }

        /// <summary>
        /// 拖拽终点（在图像上的像素坐标）
        /// </summary>
        /// <value>{X:0,Y:0}</value>
        public AIDiagnosisPoint2D EndPoint { get; set; }
    }


    /// <summary>
    /// 拖动光标，查询所有轮廓点和关键点响应
    /// </summary>
    public class ContourAndKeyPointsAfterDragResult
    {
        /// <summary>
        /// 拖拽后轮廓上所有点
        /// </summary>
        /// <value>[{X:0,Y:0}]</value>
        public List<AIDiagnosisPoint2D> DstContours { get; set; }

        /// <summary>
        /// 拖拽后轮廓上的关键点
        /// </summary>
        /// <value>[{X:0,Y:0}]</value>
        public List<DiagnosisKeyPointDTO> DstKeyPoints { get; set; }

        /// <summary>
        /// 拖拽过程中受到影响的关键点的序号
        /// </summary>
        /// <value>[0,1,2]</value>
        public List<int> AffectedKeyPointIndexes { get; set; }
    }
}