using System;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Comment;
using WingInterfaceLibrary.DTO.Record;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.Request.RemedicalAISelected
{
    /// <summary>
    /// 画轮廓模式，合并新旧轮廓请求
    /// </summary>
    public class ContourMergeRequest : TokenRequest
    {
        /// <summary>
        /// 旧轮廓上所有点
        /// </summary>
        /// <value>[{X:0,Y:0}]</value>
        public List<AIDiagnosisPoint2D> ContourPoints { get; set; }

        /// <summary>
        /// 旧轮廓上的横纵径尺寸测量结果
        /// </summary>
        /// <value>{HorizontalPoint1:0,HorizontalPoint2:0}</value>
        public AIDiagnosisLesionSize LesionSize { get; set; }

        /// <summary>
        /// 新绘制的轮廓线
        /// </summary>
        /// <value>[{X:0,Y:0}]</value>
        public List<AIDiagnosisPoint2D> DrawingNewContourPoints { get; set; }
    }
    
    /// <summary>
    /// 画轮廓模式，合并新旧轮廓响应
    /// </summary>
    public class ContourMergeResult
    {
        /// <summary>
        /// 合并后的完整轮廓线
        /// </summary>
        /// <value>[{X:0,Y:0}]</value>
        public List<AIDiagnosisPoint2D> DstContours { get; set; }

        /// <summary>
        /// 合并后的横纵径尺寸结果
        /// </summary>
        /// <value>{HorizontalPoint1:0,HorizontalPoint2:0}</value>
        public AIDiagnosisLesionSize DstLesionSize { get; set; }
    }
}