using System;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Comment;
using WingInterfaceLibrary.DTO.Record;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Request.Examine;

namespace WingInterfaceLibrary.Request.RemedicalAISelected
{
    /// <summary>
    /// 获取SRCurvature测量结果请求
    /// </summary>
    public class GetSRCurvatureRequest : TokenRequest
    {
        /// <summary>
        /// 图像编码
        /// </summary>
        /// <value></value>
        public string RemedicalCode { get; set; }
        /// <summary>
        /// 5-URM测量Den，6-URM测量Vel
        /// </summary>
        /// <value></value>
        public int MeasureMode { get; set; }
        /// <summary>
        /// 宽
        /// </summary>
        /// <value></value>
        public int DataWidth { get; set; }
        /// <summary>
        /// 高
        /// </summary>
        /// <value></value>
        public int DataHeight { get; set; }
        /// <summary>
        /// 开始位置X
        /// </summary>
        /// <value></value>
        public double StartPointX { get; set; }
        /// <summary>
        /// 开始位置Y
        /// </summary>
        /// <value></value>
        public double StartPointY { get; set; }
        /// <summary>
        /// 结束位置X
        /// </summary>
        /// <value></value>
        public double EndPointX { get; set; }
        /// <summary>
        /// 结束位置Y
        /// </summary>
        /// <value></value>
        public double EndPointY { get; set; }
    }

    /// <summary>
    /// SRCurvature测量结果
    /// </summary>
    public class GetSRCurvatureResult
    {
        /// <summary>
        /// 输出点集
        /// </summary>
        /// <typeparam name="UrmPoint"></typeparam>
        /// <returns></returns>
        public List<UrmPoint> OutPoints { get; set; } = new List<UrmPoint>();

        /// <summary>
        /// 弯曲度
        /// </summary>
        /// <value></value>
        public double Curvature { get; set; }

        /// <summary>
        /// 点集数量
        /// </summary>
        /// <value></value>
        public int OutPointsNum { get; set; }
    }

    /// <summary>
    /// 获取SRRoiDensity测量结果请求
    /// </summary>
    public class GetSRRoiVelRequest : TokenRequest
    {
        /// <summary>
        /// 图像编码
        /// </summary>
        /// <value></value>
        public string RemedicalCode { get; set; }
        /// <summary>
        /// 5-URM测量Den，6-URM测量Vel
        /// </summary>
        /// <value></value>
        public int MeasureMode { get; set; }
        /// <summary>
        /// 宽
        /// </summary>
        /// <value></value>
        public int DataWidth { get; set; }
        /// <summary>
        /// 高
        /// </summary>
        /// <value></value>
        public int DataHeight { get; set; }
        /// <summary>
        /// 开始位置X
        /// </summary>
        /// <value></value>
        public double StartPointX { get; set; }
        /// <summary>
        /// 开始位置Y
        /// </summary>
        /// <value></value>
        public double StartPointY { get; set; }
        /// <summary>
        /// 结束位置X
        /// </summary>
        /// <value></value>
        public double EndPointX { get; set; }
        /// <summary>
        /// 结束位置Y
        /// </summary>
        /// <value></value>
        public double EndPointY { get; set; }
    }

    /// <summary>
    /// SRRoiDensity测量结果
    /// </summary>
    public class GetSRRoiVelResult
    {
        /// <summary>
        /// 数值
        /// </summary>
        /// <value></value>
        public double Output { get; set; }
    }

    /// <summary>
    /// 获取SRRoiFractalDim测量结果请求
    /// </summary>
    public class GetSRRoiFractalDimRequest : TokenRequest
    {
        /// <summary>
        /// 图像编码
        /// </summary>
        /// <value></value>
        public string RemedicalCode { get; set; }
        /// <summary>
        /// 5-URM测量Den，6-URM测量Vel
        /// </summary>
        /// <value></value>
        public int MeasureMode { get; set; }
        /// <summary>
        /// 宽
        /// </summary>
        /// <value></value>
        public int DataWidth { get; set; }
        /// <summary>
        /// 高
        /// </summary>
        /// <value></value>
        public int DataHeight { get; set; }
        /// <summary>
        /// 开始位置X
        /// </summary>
        /// <value></value>
        public double StartPointX { get; set; }
        /// <summary>
        /// 开始位置Y
        /// </summary>
        /// <value></value>
        public double StartPointY { get; set; }
        /// <summary>
        /// 结束位置X
        /// </summary>
        /// <value></value>
        public double EndPointX { get; set; }
        /// <summary>
        /// 结束位置Y
        /// </summary>
        /// <value></value>
        public double EndPointY { get; set; }
    }

    /// <summary>
    /// SRRoiFractalDim测量结果
    /// </summary>
    public class GetSRRoiFractalDimResult
    {
        /// <summary>
        /// 数值
        /// </summary>
        /// <value></value>
        public double Output { get; set; }
    }

    /// <summary>
    /// 获取SRTraceDensity测量结果请求
    /// </summary>
    public class GetSRTraceVelRequest : TokenRequest
    {
        /// <summary>
        /// 图像编码
        /// </summary>
        /// <value></value>
        public string RemedicalCode { get; set; }
        /// <summary>
        /// 5-URM测量Den，6-URM测量Vel
        /// </summary>
        /// <value></value>
        public int MeasureMode { get; set; }
        /// <summary>
        /// 宽
        /// </summary>
        /// <value></value>
        public int DataWidth { get; set; }
        /// <summary>
        /// 高
        /// </summary>
        /// <value></value>
        public int DataHeight { get; set; }
        /// <summary>
        /// 点集
        /// </summary>
        /// <typeparam name="UrmPoint"></typeparam>
        /// <returns></returns>
        public List<UrmPoint> InputPoints { get; set; } = new List<UrmPoint>();
    }

    /// <summary>
    /// SRRoiDensity Trace测量结果
    /// </summary>
    public class GetSRTraceVelResult
    {
        /// <summary>
        /// 数值
        /// </summary>
        /// <value></value>
        public double Output { get; set; }
    }

    /// <summary>
    /// 获取SRTraceFD测量结果请求
    /// </summary>
    public class GetSRTraceFractalDimRequest : TokenRequest
    {
        /// <summary>
        /// 图像编码
        /// </summary>
        /// <value></value>
        public string RemedicalCode { get; set; }
        /// <summary>
        /// 5-URM测量Den，6-URM测量Vel
        /// </summary>
        /// <value></value>
        public int MeasureMode { get; set; }
        /// <summary>
        /// 宽
        /// </summary>
        /// <value></value>
        public int DataWidth { get; set; }
        /// <summary>
        /// 高
        /// </summary>
        /// <value></value>
        public int DataHeight { get; set; }
        /// <summary>
        /// 点集
        /// </summary>
        /// <typeparam name="UrmPoint"></typeparam>
        /// <returns></returns>
        public List<UrmPoint> InputPoints { get; set; } = new List<UrmPoint>();
    }

    /// <summary>
    /// SRTraceFD测量结果
    /// </summary>
    public class GetSRTraceFractalDimResult
    {
        /// <summary>
        /// 数值
        /// </summary>
        /// <value></value>
        public double Output { get; set; }
    }

    /// <summary>
    /// 获取SRLoactionVel测量结果请求
    /// </summary>
    public class GetSRLoactionVelRequest : TokenRequest
    {
        /// <summary>
        /// 图像编码
        /// </summary>
        /// <value></value>
        public string RemedicalCode { get; set; }
        /// <summary>
        /// 5-URM测量Den，6-URM测量Vel
        /// </summary>
        /// <value></value>
        public int MeasureMode { get; set; }
        /// <summary>
        /// 宽
        /// </summary>
        /// <value></value>
        public int DataWidth { get; set; }
        /// <summary>
        /// 高
        /// </summary>
        /// <value></value>
        public int DataHeight { get; set; }
        /// <summary>
        /// 开始位置X
        /// </summary>
        /// <value></value>
        public double StartPointX { get; set; }
        /// <summary>
        /// 开始位置Y
        /// </summary>
        /// <value></value>
        public double StartPointY { get; set; }
    }

    /// <summary>
    /// SRLoactionVel测量结果
    /// </summary>
    public class GetSRLoactionVelResult
    {
        /// <summary>
        /// 数值
        /// </summary>
        /// <value></value>
        public double Output { get; set; }
    }

    /// <summary>
    /// 获取SRRoiVel测量结果请求
    /// </summary>
    public class GetSRRoiSpeedRequest : TokenRequest
    {
        /// <summary>
        /// 图像编码
        /// </summary>
        /// <value></value>
        public string RemedicalCode { get; set; }
        /// <summary>
        /// 5-URM测量Den，6-URM测量Vel
        /// </summary>
        /// <value></value>
        public int MeasureMode { get; set; }
        /// <summary>
        /// 宽
        /// </summary>
        /// <value></value>
        public int DataWidth { get; set; }
        /// <summary>
        /// 高
        /// </summary>
        /// <value></value>
        public int DataHeight { get; set; }
        /// <summary>
        /// 开始位置X
        /// </summary>
        /// <value></value>
        public double StartPointX { get; set; }
        /// <summary>
        /// 开始位置Y
        /// </summary>
        /// <value></value>
        public double StartPointY { get; set; }
        /// <summary>
        /// 结束位置X
        /// </summary>
        /// <value></value>
        public double EndPointX { get; set; }
        /// <summary>
        /// 结束位置Y
        /// </summary>
        /// <value></value>
        public double EndPointY { get; set; }
    }

    /// <summary>
    /// SRRoiVel测量结果
    /// </summary>
    public class GetSRRoiSpeedResult
    {
        /// <summary>
        /// 数值
        /// </summary>
        /// <value></value>
        public double Output { get; set; }
    }

    /// <summary>
    /// 获取URMDensityMeasure测量结果请求
    /// </summary>
    public class GetURMDenMeasureRequest : TokenRequest
    {
        /// <summary>
        /// 图像编码
        /// </summary>
        /// <value></value>
        public string RemedicalCode { get; set; }
        /// <summary>
        /// 5-URM测量Den，6-URM测量Vel
        /// </summary>
        /// <value></value>
        public int MeasureMode { get; set; }
        /// <summary>
        /// 宽
        /// </summary>
        /// <value></value>
        public int DataWidth { get; set; }
        /// <summary>
        /// 高
        /// </summary>
        /// <value></value>
        public int DataHeight { get; set; }
        /// <summary>
        /// 开始位置X
        /// </summary>
        /// <value></value>
        public double StartPointX { get; set; }
        /// <summary>
        /// 开始位置Y
        /// </summary>
        /// <value></value>
        public double StartPointY { get; set; }
        /// <summary>
        /// 结束位置X
        /// </summary>
        /// <value></value>
        public double EndPointX { get; set; }
        /// <summary>
        /// 结束位置Y
        /// </summary>
        /// <value></value>
        public double EndPointY { get; set; }
        /// <summary>
        /// 缩放比例
        /// </summary>
        /// <value></value>
        public double AreaScaler { get; set; }
    }

    /// <summary>
    /// URMDensityMeasure测量结果
    /// </summary>
    public class GetURMDenMeasureResult
    {
        public double RoiDen { get; set; }

        public double RoiFractalDim { get; set; }

        public double MaxDensity { get; set; }

        public double MinDensity { get; set; }

        public double MeanDensity { get; set; }

        public double VarianceDensity { get; set; }

        public double RoiArea { get; set; }

        public double InRoiDen { get; set; }

        public double InRoiFractalDim { get; set; }

        public double InMaxDensity { get; set; }

        public double InMinDensity { get; set; }

        public double InMeanDensity { get; set; }

        public double InVarianceDensity { get; set; }

        public double InRoiArea { get; set; }

        public double OutRoiDen { get; set; }

        public double OutRoiFractalDim { get; set; }

        public double OutMaxDensity { get; set; }

        public double OutMinDensity { get; set; }

        public double OutMeanDensity { get; set; }

        public double OutVarianceDensity { get; set; }

        public double OutRoiArea { get; set; }
    }

    /// <summary>
    /// 获取URMVelMeasure测量结果请求
    /// </summary>
    public class GetURMVelMeasureRequest : TokenRequest
    {
        /// <summary>
        /// 图像编码
        /// </summary>
        /// <value></value>
        public string RemedicalCode { get; set; }
        /// <summary>
        /// 5-URM测量Den，6-URM测量Vel
        /// </summary>
        /// <value></value>
        public int MeasureMode { get; set; }
        /// <summary>
        /// 宽
        /// </summary>
        /// <value></value>
        public int DataWidth { get; set; }
        /// <summary>
        /// 高
        /// </summary>
        /// <value></value>
        public int DataHeight { get; set; }
        /// <summary>
        /// 开始位置X
        /// </summary>
        /// <value></value>
        public double StartPointX { get; set; }
        /// <summary>
        /// 开始位置Y
        /// </summary>
        /// <value></value>
        public double StartPointY { get; set; }
        /// <summary>
        /// 结束位置X
        /// </summary>
        /// <value></value>
        public double EndPointX { get; set; }
        /// <summary>
        /// 结束位置Y
        /// </summary>
        /// <value></value>
        public double EndPointY { get; set; }
        /// <summary>
        /// 缩放比例
        /// </summary>
        /// <value></value>
        public double AreaScaler { get; set; }
    }

    /// <summary>
    /// URMVelMeasure测量结果
    /// </summary>
    public class GetURMVelMeasureResult
    {
        public double MaxVel { get; set; }

        public double MinVel { get; set; }

        public double MeanVel { get; set; }

        public double VarianceVel { get; set; }

        public double RoiArea { get; set; }

        public double InMaxVel { get; set; }

        public double InMinVel { get; set; }

        public double InMeanVel { get; set; }

        public double InVarianceVel { get; set; }

        public double InRoiArea { get; set; }

        public double OutMaxVel { get; set; }

        public double OutMinVel { get; set; }

        public double OutMeanVel { get; set; }

        public double OutVarianceVel { get; set; }

        public double OutRoiArea { get; set; }
    }

    /// <summary>
    /// 获取URMVessMeasure测量结果请求
    /// </summary>
    public class GetUrmVessMeasureRequest : TokenRequest
    {
        /// <summary>
        /// 图像编码
        /// </summary>
        /// <value></value>
        public string RemedicalCode { get; set; }
        /// <summary>
        /// 5-URM测量Den，6-URM测量Vel
        /// </summary>
        /// <value></value>
        public int MeasureMode { get; set; }
        /// <summary>
        /// 宽
        /// </summary>
        /// <value></value>
        public int DataWidth { get; set; }
        /// <summary>
        /// 高
        /// </summary>
        /// <value></value>
        public int DataHeight { get; set; }
        /// <summary>
        /// 开始位置X
        /// </summary>
        /// <value></value>
        public double StartPointX { get; set; }
        /// <summary>
        /// 开始位置Y
        /// </summary>
        /// <value></value>
        public double StartPointY { get; set; }
        /// <summary>
        /// 结束位置X
        /// </summary>
        /// <value></value>
        public double EndPointX { get; set; }
        /// <summary>
        /// 结束位置Y
        /// </summary>
        /// <value></value>
        public double EndPointY { get; set; }
        /// <summary>
        /// 缩放比例
        /// </summary>
        /// <value></value>
        public double AreaScaler { get; set; }
        /// <summary>
        /// 连线的物理长度（cm）
        /// </summary>
        /// <value></value>
        public double CmLength { get; set; }
    }

    /// <summary>
    /// URMVelMeasure测量结果
    /// </summary>
    public class GetUrmVessMeasureResult
    {
        public double MaxVessDistance { get; set; }

        public double MinVessDistance { get; set; }

        public double MeanVessDistacne { get; set; }

        public double VarianceVessDistance { get; set; }

        public double MaxVessDiameter { get; set; }

        public double MinVessDiameter { get; set; }

        public double MeanVessDiameter { get; set; }

        public double VarianceVessDiameter { get; set; }

        public int MaxPos { get; set; }

        public int MinPos { get; set; }

        public int OutPointsNum { get; set; }
        /// <summary>
        /// 点集
        /// </summary>
        /// <typeparam name="UrmPoint"></typeparam>
        /// <returns></returns>
        public List<UrmPoint> OutputPoints { get; set; } = new List<UrmPoint>();
    }

    /// <summary>
    /// 点集实体
    /// </summary>
    public class UrmPoint
    {
        /// <summary>
        /// 坐标X值
        /// </summary>
        /// <value></value>
        public double X { get; set; }

        /// <summary>
        /// 坐标Y值
        /// </summary>
        /// <value></value>
        public double Y { get; set; }
    }
}