using System;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Comment;
using WingInterfaceLibrary.DTO.Record;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Request.Examine;

namespace WingInterfaceLibrary.Request.RemedicalAISelected
{
    /// <summary>
    /// 保存AI图像详情请求
    /// </summary>
    public class SaveRemedicalAISelectedInfoRequest : TokenRequest
    {
        /// <summary>
        /// 记录编码
        /// </summary>
        /// <value>4914352a75f645279f6b4ad6764cc288</value>
        /// <code>0</code>
        public string Code { get; set; }

        /// <summary>
        /// 扫查图像编码
        /// </summary>
        /// <value>4914352a75f645279f6b4ad6764cc288</value>
        public string RemedicalCode { get; set; } = string.Empty;

        /// <summary>
        /// 第几帧，默认0
        /// </summary>
        /// <value>0</value>
        public int FrameIndex { get; set; }

        /// <summary>
        /// AI图地址
        /// </summary>
        /// <value>4914352a75f645279f6b4ad6764cc288</value>
        public string AIFileToken { get; set; } = string.Empty;

        /// <summary>
        /// 缩略图地址
        /// </summary>
        /// <value>4914352a75f645279f6b4ad6764cc288</value>
        public string PreviewFileToken { get; set; } = string.Empty;

        /// <summary>
        /// AI诊断详情，不抽帧
        /// </summary>
        /// <value></value>
        public string DiagnosisData { get; set; } = string.Empty;

        /// <summary>
        /// AI诊断结论
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public DiagnosisConclusionEnum DiagnosisConclusion { get; set; }

        /// <summary>
        /// AI识别的器官
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public List<DiagnosisOrganEnum> DiagnosisOrgans { get; set; } = new List<DiagnosisOrganEnum>();
    }

    /// <summary>
    /// URM分析请求实体
    /// </summary>
    public class URMAnalysisRequest : TokenRequest
    {

        /// <summary>
        /// X轴坐标
        /// </summary>
        /// <value></value>
        public double X { get; set; }

        /// <summary>
        /// Y轴坐标
        /// </summary>
        /// <value></value>
        public double Y { get; set; }

        /// <summary>
        /// 高度
        /// </summary>
        /// <value></value>
        public double Width { get; set; }

        /// <summary>
        /// 宽度
        /// </summary>
        /// <value></value>
        public double Height { get; set; }

        /// <summary>
        /// 图像code
        /// </summary>
        /// <value></value>
        public string RemedicalCode { get; set; }

    }

    /// <summary>
    /// URM分析结果
    /// </summary>
    public class URMAnalysisResult
    {
        /// <summary>
        /// 是否成功
        /// </summary>
        /// <value></value>
        public bool IsSuccess { get; set; }

        /// <summary>
        /// 分析结果
        /// </summary>
        /// <value></value>
        public IList<ImgItem> URMAnalysisDetails { get; set; }

        /// <summary>
        /// URM分析Pos参数值
        /// </summary>
        /// <value></value>
        public string UrmPosition { get; set; }

    }

    /// <summary>
    /// URM分析V2请求实体
    /// </summary>
    public class URMAnalysisV2Request : TokenRequest
    {
        /// <summary>
        /// 异常通知用户编码
        /// </summary>
        /// <value></value>
        public string NotifyUserCode { get; set; }

        /// <summary>
        /// X轴坐标
        /// </summary>
        /// <value></value>
        public double X { get; set; }

        /// <summary>
        /// Y轴坐标
        /// </summary>
        /// <value></value>
        public double Y { get; set; }

        /// <summary>
        /// 高度
        /// </summary>
        /// <value></value>
        public double Width { get; set; }

        /// <summary>
        /// 宽度
        /// </summary>
        /// <value></value>
        public double Height { get; set; }

        /// <summary>
        /// CustomizedStartFrame
        /// </summary>
        /// <value></value>
        public int? CustomizedStartFrame { get; set; }

        /// <summary>
        /// CustomizedEndFrame
        /// </summary>
        /// <value></value>
        public int? CustomizedEndFrame { get; set; }

        /// <summary>
        /// 图像code
        /// </summary>
        /// <value></value>
        public string RemedicalCode { get; set; }

        /// <summary>
        /// RoiXPercent
        /// </summary>
        /// <value></value>
        public double RoiXPercent { get; set; }

        /// <summary>
        /// RoiYPercent
        /// </summary>
        /// <value></value>
        public double RoiYPercent { get; set; }

        /// <summary>
        /// RoiWPercent
        /// </summary>
        /// <value></value>
        public double RoiWPercent { get; set; }

        /// <summary>
        /// RoiHPercent
        /// </summary>
        /// <value></value>
        public double RoiHPercent { get; set; }

    }

    /// <summary>
    /// URM分析结果V2
    /// </summary>
    public class URMAnalysisV2Result
    {
        /// <summary>
        /// 是否成功
        /// </summary>
        /// <value></value>
        public bool IsSuccess { get; set; }

        /// <summary>
        /// 分析结果
        /// </summary>
        /// <value></value>
        public IList<ImgItem> URMAnalysisDetails { get; set; }

        /// <summary>
        /// URM分析Pos参数值
        /// </summary>
        /// <value></value>
        public string UrmPosition { get; set; }

        /// <summary>
        /// URMSrcWidth
        /// </summary>
        /// <value></value>
        public int URMSrcWidth { get; set; }

        /// <summary>
        /// URMSrcHeight
        /// </summary>
        /// <value></value>
        public int URMSrcHeight { get; set; }

        /// <summary>
        /// URMRes
        /// </summary>
        /// <value></value>
        public double URMRes { get; set; }
        
        public double URMScaleOfPixel_x { get; set; }
        public double URMScaleOfPixel_y { get; set; }

        /// <summary>
        /// ConverImageUrl
        /// </summary>
        /// <value></value>
        public string ConverImageUrl { get; set; }

    }

    /// <summary>
    /// URM Colorbar 请求实体
    /// </summary>
    public class URMColorbarRequest : URMProcessRequest
    {
        /// <summary>
        /// urmcolorbar类型：0-视频（无需传其他任何参数），1-后处理，2-灌注图（无需传其他任何参数）
        /// </summary>
        /// <value></value>
        public int ProcessType { get; set; }

    }

    /// <summary>
    /// URM Colorbar 返回实体
    /// </summary>
    public class URMColorbarResult
    {
        /// <summary>
        /// colorbar
        /// </summary>
        /// <value></value>
        public string ColorbarBase64 { get; set; }
        /// <summary>
        /// logo
        /// </summary>
        /// <value></value>
        public string LogoBase64 { get; set; }
    }

    /// <summary>
    /// URM后处理请求实体
    /// </summary>
    public class URMProcessRequest : URMProcessBaseRequest
    {
        /// <summary>
        /// 请求token
        /// </summary>
        /// <value>0126f5d7ef044088b075246c65a410ba</value>
        public string Token { get; set; }

        /// <summary>
        /// 图像编码
        /// </summary>
        /// <value></value>
        public string RemedicalCode { get; set; }

        public UrmPoint[] UrmTraceDPoints { get; set; } = new UrmPoint[0];
    }

    public class UrmProcessConfigDTO
    {
        public float DownsampleIndex { get; set; } = 3f;
        public float IntPowerDen { get; set; } = 4f;
        public float IntPowerDir { get; set; } = 4f;
        public float SigmaGauss { get; set; } = 2.4f;
        public float VessScale { get; set; } = 1f;
        public float VelMaxScaler { get; set; } = 1f;
        public float VelMinScaler { get; set; } = 0f;
        public float Iterations { get; set; } = 1f;
        public float URMVideoParameter { get; set; } = 2f;
        public float URMVideoType { get; set; } = 1f;
    }

    public class URMProcessBaseRequest
    {
        // 图像配置
        /// <summary>
        /// Den 0, Dir 1, Vel 2, Angle 3
        /// </summary>
        /// <value></value>
        public string UrmImageType { get; set; } = "0";
        public int UrmBlend { get; set; }

        // 用于后处理计算的算法参数（需要传入）
        public float DownsampleIndex { get; set; } = 3f;
        public float IntPowerDen { get; set; } = 4f;
        public float IntPowerDir { get; set; } = 4f;
        public float SigmaGauss { get; set; } = 2.4f;
        public float VessScale { get; set; } = 1f;
        public float VelMaxScaler { get; set; } = 1f;
        public float VelMinScaler { get; set; } = 0f;
        public float Iterations { get; set; } = 1f;
        /// <summary>
        /// 后处理算法版本  0 Ver2(<2.7) 1 Ver3(2.7)
        /// </summary>
        /// <value></value>
        public int ImgProcessVer { get; set; } = 1;

        // URM的绘制参数 
        public bool ZoomOn { get; set; } = false; // 是否开启 zoom
        public double ZoomRoix { get; set; } = 0; // zoom 区域在 ROI 中的归一化坐标
        public double ZoomRoiy { get; set; } = 0; // zoom 区域在 ROI 中的归一化坐标
        public double ZoomRoiwidth { get; set; } = 1; // zoom 区域在 ROI 中的归一化坐标
        public double ZoomRoiheight { get; set; } = 1; // zoom 区域在 ROI 中的归一化坐标
        public int Roix { get; set; } = 274;// Roi 区域在整个图像中的像素位置
        public int Roiy { get; set; } = 16;// Roi 区域在整个图像中的像素位置
        public int Roiwidth { get; set; } = 243; // Roi 区域在整个图像中的像素位置
        public int Roiheight { get; set; } = 616; // Roi 区域在整个图像中的像素位置
        public bool LeftRight { get; set; } = false;
        public bool UpDown { get; set; } = false;
        public int ScreenWidth { get; set; } = 666;// 输出的图像的尺寸
        public int ScreenHeight { get; set; } = 650; // 输出的图像的尺寸
    }

    /// <summary>
    /// URM后处理结果
    /// </summary>
    public class URMProcessResult
    {
        public string Base64String { get; set; }

        public double UrmMinVal { get; set; }

        public double UrmMaxVal { get; set; }
    }

    /// <summary>
    /// URM视频后处理请求实体
    /// </summary>
    public class URMVideoProcessRequest : URMProcessRequest
    {
        /// <summary>
        /// 异常通知用户编码
        /// </summary>
        /// <value></value>
        public string NotifyUserCode { get; set; }
        public int VideoFrame { get; set; } = 0;
        // 视频配置
        public float URMVideoScaler { get; set; } = 3;
        public float URMVideoParameter { get; set; } = 2;
        public float URMVideoType { get; set; } = 1;
    }

    /// <summary>
    /// URM视频后处理结果
    /// </summary>
    public class URMVideoProcessResult
    {
        public string Base64String { get; set; }

        public double UrmMinVal { get; set; }

        public double UrmMaxVal { get; set; }
    }

    /// <summary>
    /// URM测量请求实体
    /// </summary>
    public class URMMeasureProcessRequest : URMProcessRequest
    {
        /// <summary>
        /// 测量项枚举
        /// </summary>
        public URMMeasureType UrmMeasureType { get; set; }
        /// <summary>
        /// 点集
        /// </summary>
        public List<UrmPoint> SrcDPoints { get; set; }

        /// <summary>
        /// 两点物理距离
        /// </summary>
        public double? CMlength { get; set; }

        /// <summary>
        /// 画布物理宽度
        /// </summary>
        public double Phywidth { get; set; }

        /// <summary>
        /// ROI 类型
        /// </summary>
        public URMROIType ROIType { get; set; }

        /// <summary>
        /// Rim 宽度
        /// </summary>
        public double ShellWidth { get; set; }
    }

    /// <summary>
    /// URM测量结果
    /// </summary>
    public class URMMeasureProcessResult
    {
        public bool ResultFlag { get; set; }

        public double ResultData { get; set; }

        public List<UrmPoint> ResultDPoints { get; set; }

        public URMDenMeasureResult DenMeasureResult { get; set; }

        public URMVelMeasureResult VelMeasureResult { get; set; }

        public URMVessMeasureResult VessMeasureResult { get; set; }

        public List<UrmPoint> OuterExterPoints { get; set; }

        public DRect PerfusionScaleDRect { get; set; }

        public IntRect PerfusionPiexlRect { get; set; }

        public string PerfusionImgBase64 { get; set; }

        public double UrmMinVal { get; set; }

        public double UrmMaxVal { get; set; }
    }

    /// <summary>
    /// URM生成后处理视频请求实体
    /// </summary>
    public class URMGenerateVideoRequest : URMVideoProcessRequest
    {
        /// <summary>
        /// 底图Base64
        /// </summary>
        /// <value></value>
        public string BackgroundImage { get; set; }

        /// <summary>
        /// RoiXPercent
        /// </summary>
        /// <value></value>
        public double RoiXPercent { get; set; }

        /// <summary>
        /// RoiYPercent
        /// </summary>
        /// <value></value>
        public double RoiYPercent { get; set; }

        /// <summary>
        /// RoiWPercent
        /// </summary>
        /// <value></value>
        public double RoiWPercent { get; set; }

        /// <summary>
        /// RoiHPercent
        /// </summary>
        /// <value></value>
        public double RoiHPercent { get; set; }

        /// <summary>
        /// 左侧图像左上角X坐标
        /// </summary>
        /// <value></value>
        public double LeftImgTopLeftCornerXPercent { get; set; }

        /// <summary>
        /// 左侧图像左上角Y坐标
        /// </summary>
        /// <value></value>
        public double LeftImgTopLeftCornerYPercent { get; set; }

        /// <summary>
        /// 右侧图像左上角X坐标
        /// </summary>
        /// <value></value>
        public double RightImgTopLeftCornerXPercent { get; set; }

        /// <summary>
        /// 右侧图像左上角Y坐标
        /// </summary>
        /// <value></value>
        public double RightImgTopLeftCornerYPercent { get; set; }

        /// <summary>
        /// colorbar X坐标
        /// </summary>
        /// <value></value>
        public double ColorBarXPercent { get; set; }

        /// <summary>
        /// colorbar Y坐标
        /// </summary>
        /// <value></value>
        public double ColorBarYPercent { get; set; }
    }

    /// <summary>
    /// URM生成后处理视频响应实体
    /// </summary>
    public class URMGenerateVideoResult
    {
        /// <summary>
        /// 视频地址
        /// </summary>
        /// <value></value>
        public string VideoUrl { get; set; }

        /// <summary>
        /// 视频大小
        /// </summary>
        /// <value></value>
        public long VideoSize { get; set; }

        /// <summary>
        /// 视频预览图
        /// </summary>
        /// <value></value>
        public string CoverImgUrl { get; set; }
    }

    public class URMDenMeasureResult
    {
        public double RoiDen { get; set; }

        public double RoiFractalDim { get; set; }

        public double MaxDensity { get; set; }

        public double MinDensity { get; set; }

        public double MeanDensity { get; set; }

        public double VarianceDensity { get; set; }

        public double RoiArea { get; set; }

        public double OutRoiDen { get; set; }

        public double OutRoiFractalDim { get; set; }

        public double OutMaxDensity { get; set; }

        public double OutMinDensity { get; set; }

        public double OutMeanDensity { get; set; }

        public double OutVarianceDensity { get; set; }

        public double OutRoiArea { get; set; }

        public double InRoiDen { get; set; }

        public double InRoiFractalDim { get; set; }

        public double InMaxDensity { get; set; }

        public double InMinDensity { get; set; }

        public double InMeanDensity { get; set; }

        public double InVarianceDensity { get; set; }

        public double InRoiArea { get; set; }
    }

    public class URMVelMeasureResult
    {
        public double MaxVel { get; set; }

        public double MinVel { get; set; }

        public double MeanVel { get; set; }

        public double VarianceVel { get; set; }

        public double RoiArea { get; set; }

        public double OutMaxVel { get; set; }

        public double OutMinVel { get; set; }

        public double OutMeanVel { get; set; }

        public double OutVarianceVel { get; set; }

        public double OutRoiArea { get; set; }

        public double InMaxVel { get; set; }

        public double InMinVel { get; set; }

        public double InMeanVel { get; set; }

        public double InVarianceVel { get; set; }

        public double InRoiArea { get; set; }
    }

    public class URMVessMeasureResult
    {
        public double MaxVessDistance { get; set; }

        public double MinVessDistance { get; set; }

        public double MeanVessDistacne { get; set; }

        public double VarianceVessDistance { get; set; }

        public double MaxVessDiameter { get; set; }

        public double MinVessDiameter { get; set; }

        public double MeanVessDiameter { get; set; }

        public double VarianceVessDiameter { get; set; }

        public int MaxPos { get; set; }

        public int MinPos { get; set; }

        public int vesselCount { get; set; }
    }

    public class NativeArray
    {
        public long Length { get; set; }


    }

    public class DRect
    {
        public double X { get; set; }
        public double Y { get; set; }
        public double Width { get; set; }
        public double Height { get; set; }
        public double Left { get; set; }
        public double Top { get; set; }
        public double Right { get; set; }
        public double Bottom { get; set; }
        public UrmPoint Location { get; set; }
        public UrmPoint TopLeft { get; set; }
        public UrmPoint TopRight { get; set; }
        public UrmPoint BottomLeft { get; set; }
        public UrmPoint BottomRight { get; set; }
        public DSize Size { get; set; }
    }

    public class DSize
    {
        public double Width { get; set; }
        public double Height { get; set; }
    }
    public class IntRect
    {
        public int X { get; set; }
        public int Y { get; set; }
        public int Width { get; set; }
        public int Height { get; set; }
        public int Left { get; set; }
        public int Top { get; set; }
        public int Right { get; set; }
        public int Bottom { get; set; }
    }
}