using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Request.Authentication;

namespace WingInterfaceLibrary.Request.Storage
{
    /// <summary>
    /// 检测存储服务请求接口
    /// </summary>
    public class CheckStorageRequest
    {
        /// <summary>
        /// 自定义文件名【同文件名会覆盖源文件】,兼容系统自定义filename
        /// </summary>
        /// <value>Flyinsono_Windows_1.7.43.24131.apk</value>
        public string FileName { get; set; }
    }

    /// <summary>
    /// 删除存储服务文件请求接口
    /// </summary>
    public class DeleteStorageRequest
    {
        /// <summary>
        /// 文件地址
        /// </summary>
        /// <value>http://192.168.6.103:7315/FlyinsonoStorage/20240627/72D50E0D9A264F449CD52FA69A7E1359.vid</value>
        public string FileUrl { get; set; }
    }

    /// <summary>
    /// 拷贝到其他节点请求实体
    /// </summary>
    public class CopyToOtherNodeRequest : TokenRequest
    {
        /// <summary>
        /// FileName
        /// </summary>
        /// <value></value>
        public string FileName { get; set; }

        /// <summary>
        /// FileUrl
        /// </summary>
        /// <value></value>
        public string FileUrl { get; set; }

    }

    /// <summary>
    /// 检查文件是否存在请求实体
    /// </summary>
    public class CheckFileIsExistRequest
    {
        /// <summary>
        /// 源文件
        /// </summary>
        public string OriFileName { get; set; }

        /// <summary>
        /// 文件大小
        /// </summary>
        public long FileSize { get; set; }

        /// <summary>
        /// 分块上传
        /// </summary>
        public bool IsNeedPartUpload { get; set; }

        /// <summary>
        /// 是否升级包文件夹
        /// </summary>
        /// <value>false</value>
        public bool IsUpgradePackage { get; set; } = false;
    }

    /// <summary>
    /// 可分块上传文件请求实体
    /// </summary>
    public class UploadFileTransferRequest: TokenRequest
    {
        /// <summary>
        /// 源文件物理路径
        /// </summary>
        /// <value>E:\XXX.PNG</value>
        public string SourceFilePath { get; set; }

        /// <summary>
        /// 是否重命名
        /// </summary>
        /// <value>false</value>
        public bool IsRechristen { get; set; }

        /// <summary>
        /// 是否需要分块上传
        /// </summary>
        /// <value>false</value>
        public bool IsNeedPartUpload { get; set; }

        /// <summary>
        /// 是否copy到其他节点
        /// </summary>
        /// <value>false</value>
        public bool IsCopy { get; set; } = false;
    }

}