using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Common;

namespace WingInterfaceLibrary.Request.Storage
{
    /// <summary>
    /// 文件上传配置请求实体
    /// </summary>
    public class FileServiceRequest : TokenRequest
    {
        /// <summary>
        /// 自定义文件名【同文件名会覆盖源文件】,兼容系统自定义filename
        /// </summary>
        /// <value>Flyinsono_Windows_1.7.43.24131.apk</value>
        public string FileName { get; set; }   

        /// <summary>
        /// 默认是否重命名
        /// </summary>
        /// <value>true</value>
        public bool IsRechristen { get; set; } = true;

        /// <summary>
        /// 是否升级包【如果上传文件是升级包，则本地云存储为指定升级包目录】
        /// </summary>
        /// <value>false</value>
        public bool IsUpgradePackage { get; set; } = false;

        /// <summary>
        /// 针对分块上传时，将url后面的uploadId等参数进行签名，普通上传无需传参
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public IList<DataItemDTO> UrlParams { get; set; }

        /// <summary>
        /// 针对分块上传时，如需header参数进行签名，则添加，普通上传无需传参
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public IList<DataItemDTO> HeaderParams { get; set; }

        /// <summary>
        /// 数据提交到云存储的请求方式【put,post,head等等】，默认是put
        /// </summary>
        /// <value>put</value>
        public string RequestMethod { get; set; } = "put";

        /// <summary>
        /// 是否分块传输时，完成签名
        /// </summary>
        /// <value>put</value>
        public bool IsCompleted { get; set; } = false;
    }
}