
using System;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.User;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.Request.User
{
    /// <summary>
    /// 批量新增用户请求实体
    /// </summary>
    public class BatchInsertUserRequest : TokenRequest
    {
        public SyncDBEnum SyncType { get; set; } = SyncDBEnum.Migrate;
        
        /// <summary>
        /// 迁移数据-用户列表
        /// </summary>
        /// <value></value>
        public IList<UserMigratoryInfo> UserMigratorys { get; set; }
    }

    /// <summary>
    /// 用户数据迁移请求实体
    /// </summary>
    public class UserMigratoryInfo: UserDTO
    {
        /// <summary>
        /// 是否删除
        /// </summary>
        /// <value>false</value>
        public bool IsDelete { get; set; }
        /// <summary>
        /// 密码
        /// </summary>
        /// <value>ServerSalt_00A542E0B67ADC9</value>
        public string SecretPassword { get; set; }

        /// <summary>
        /// 上次修改密码时间
        /// </summary>
        /// <value>ServerSalt_00A542E0B67ADC9</value>
        public DateTime PasswordUpdateTime { get; set; }

        /// <summary>
        /// 密码列表
        /// </summary>
        /// <value>ServerSalt_00A542E0B67ADC9</value>
        public IList<string> PasswordRecords { get; set; }

        /// <summary>
        /// 用户角色
        /// </summary>
        /// <value>ServerSalt_00A542E0B67ADC9</value>
        public UserMigratoryRoleEnum UserRole { get; set; }

        /// <summary>
        /// 远程管理权限
        /// </summary>
        /// <value></value>
        public string RemoteMainFeature { get; set; }

        /// <summary>
        /// 是否认证讲师
        /// </summary>
        /// <value></value>
        public bool IsCertifiedInstructor { get; set; }
    }

    /// <summary>
    /// 角色枚举，如果开了远程会诊，则走这一套，如果没开远程会诊，则默认为医师，如果长期未登录，则默认医师
    /// </summary>
    public enum UserMigratoryRoleEnum
    {
        /// <summary>
        /// 助理-会诊助理
        /// </summary>
        Role_ExpertAssistant = 0,
        /// <summary>
        /// 专家-医师
        /// </summary>
        Role_CertifiedExpert = 1,
        /// <summary>
        /// 医生-报告录入员
        /// </summary>
        Role_CertifiedPhysician = 2,
        /// <summary>
        /// 远程维护管理员
        /// </summary>
        Role_RemoteManager = 3,
        /// <summary>
        /// 未设置
        /// </summary>
        Role_UnSet = 4,
    }
}