using System;
using System.Collections.Generic;

namespace WingInterfaceLibrary.Request.Vital
{
    /// <summary>
    /// 创建接口解析配置数据请求
    /// </summary>
    public class CreateAnalyzeConfigRequest : TokenRequest
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();

        /// <summary>
        /// 输入的字段
        /// </summary>
        /// <value></value>
        public string InField { get; set; }

        /// <summary>
        /// 输出的字段
        /// </summary>
        /// <value></value>
        public string OutField  { get; set; }

        /// <summary>
        /// 解析方式
        /// </summary>
        /// <value></value>
        public string Mode { get; set; }

        /// <summary>
        /// 模版
        /// </summary>
        /// <value></value>
        public string Template { get; set; }

        /// <summary>
        /// 解析配置
        /// </summary>
        /// <value></value>
        public string AnalyzeConfigItems { get; set; }
    }

    /// <summary>
    /// 根据编码获取接口解析配置数据请求
    /// </summary>
    public class GetAnalyzeConfigRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取接口解析配置数据请求
    /// </summary>
    public class GetAnalyzeConfigByKeyRequest : TokenRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除接口解析配置数据请求
    /// </summary>
    public class RemoveAnalyzeConfigRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 获取接口解析配置数据列表请求
    /// </summary>
    public class GetAnalyzeConfigListRequest : TokenRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 更新接口解析配置数据请求
    /// </summary>
    public class UpdateAnalyzeConfigRequest : TokenRequest
    {
        public string Code { get; set; }

        /// <summary>
        /// 输入的字段
        /// </summary>
        /// <value></value>
        public string InField { get; set; }

        /// <summary>
        /// 输出的字段
        /// </summary>
        /// <value></value>
        public string OutField  { get; set; }

        /// <summary>
        /// 解析方式
        /// </summary>
        /// <value></value>
        public string Mode { get; set; }

        /// <summary>
        /// 模版
        /// </summary>
        /// <value></value>
        public string Template { get; set; }

        /// <summary>
        /// 解析配置
        /// </summary>
        /// <value></value>
        public string AnalyzeConfigItems { get; set; }

    }

	/// <summary>
    /// 查询接口解析配置分页请求
    /// </summary>
    public class AnalyzeConfigPageRequest : PageRequest
    {
        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;
    }
}