using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Net.Http;
using System.Threading;
using System.Threading.Tasks;

namespace WingInterfaceLibrary.Request.Vital
{
    /// <summary>
    /// 创建履约记录数据请求
    /// </summary>
    public class CreateCompletionRecordRequest : TokenRequest
    {
		public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
		/// <summary>
		/// 履约医生
		/// </summary>
		/// <value></value>
		public string CompletionDoctor { get; set; }
		/// <summary>
		/// 居民代码
		/// </summary>
		/// <value></value>
		public string PatientCode { get; set; }
		/// <summary>
		/// 服务包装代码
		/// </summary>
		/// <value></value>
		public string ServicePackCode { get; set; }
		/// <summary>
		/// 服务包装名称
		/// </summary>
		/// <value></value>
		public string ServicePackName { get; set; }
		/// <summary>
		/// 服务商品代码
		/// </summary>
		/// <value></value>
		public string ServiceItemCode { get; set; }
		/// <summary>
		/// 服务商品名称
		/// </summary>
		/// <value></value>
		public string ServiceItemName { get; set; }
		/// <summary>
		/// 履约内容
		/// </summary>
		/// <value></value>
		public string CompletionContent { get; set; }
		/// <summary>
		/// 备注
		/// </summary>
		/// <value></value>
		public string Notes { get; set; }
		/// <summary>
		/// 履约时间
		/// </summary>
		/// <value></value>
		public DateTime CompletionTime { get; set; }
		/// <summary>
		/// 下一个履约时间
		/// </summary>
		/// <value></value>
		public DateTime NextCompletionTime { get; set; }


    }

    /// <summary>
    /// 根据编码获取履约记录数据请求
    /// </summary>
    public class GetCompletionRecordRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取履约记录数据请求
    /// </summary>
    public class GetCompletionRecordByKeyRequest : TokenRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除履约记录数据请求
    /// </summary>
    public class RemoveCompletionRecordRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 获取履约记录数据列表请求
    /// </summary>
    public class GetCompletionRecordListRequest : TokenRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 更新履约记录数据请求
    /// </summary>
    public class UpdateCompletionRecordRequest : TokenRequest
    {
        public string Code { get; set; }
		/// <summary>
		/// 履约医生
		/// </summary>
		/// <value></value>
		public string CompletionDoctor { get; set; }
		/// <summary>
		/// 居民代码
		/// </summary>
		/// <value></value>
		public string PatientCode { get; set; }
		/// <summary>
		/// 服务包装代码
		/// </summary>
		/// <value></value>
		public string ServicePackCode { get; set; }
		/// <summary>
		/// 服务包装名称
		/// </summary>
		/// <value></value>
		public string ServicePackName { get; set; }
		/// <summary>
		/// 服务商品代码
		/// </summary>
		/// <value></value>
		public string ServiceItemCode { get; set; }
		/// <summary>
		/// 服务商品名称
		/// </summary>
		/// <value></value>
		public string ServiceItemName { get; set; }
		/// <summary>
		/// 履约内容
		/// </summary>
		/// <value></value>
		public string CompletionContent { get; set; }
		/// <summary>
		/// 备注
		/// </summary>
		/// <value></value>
		public string Notes { get; set; }
		/// <summary>
		/// 履约时间
		/// </summary>
		/// <value></value>
		public DateTime CompletionTime { get; set; }
		/// <summary>
		/// 下一个履约时间
		/// </summary>
		/// <value></value>
		public DateTime NextCompletionTime { get; set; }

    }

    /// <summary>
    /// 查询履约记录分页请求
    /// </summary>
    public class CompletionRecordPageRequest : PageRequest
    {
        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;
    }
}