using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Net.Http;
using System.Threading;
using System.Threading.Tasks;
using WingInterfaceLibrary.Enum.VitalEnum;

namespace WingInterfaceLibrary.Request.Vital
{
    /// <summary>
    /// 创建合约记录数据请求
    /// </summary>
    public class CreateContractRecordRequest : TokenRequest
    {
		public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
		/// <summary>
		/// 合约记录编号
		/// </summary>
		/// <value></value>
		public string ContractRecordNo { get; set; }
		/// <summary>
		/// 已签约医生
		/// </summary>
		/// <value></value>
		public string ContractedDoctor { get; set; }
		/// <summary>
		/// 已签约居民
		/// </summary>
		/// <value></value>
		public string ContractedPatient { get; set; }
		/// <summary>
		/// 已签约团队
		/// </summary>
		/// <value></value>
		public string ContractedTeam { get; set; }
		/// <summary>
		/// 已签约时间
		/// </summary>
		/// <value></value>
		public DateTime ContractedTime { get; set; }
		/// <summary>
		/// 已签约文件URL
		/// </summary>
		/// <value></value>
		public string ContractedFileUrl { get; set; }
		/// <summary>
		/// 服务包
		/// </summary>
		/// <value></value>
		public List<string> ServicePacks { get; set; }
		/// <summary>
		/// 服务开始日期
		/// </summary>
		/// <value></value>
		public DateTime ServiceStartDate { get; set; }
		/// <summary>
		/// 服务结束日期
		/// </summary>
		/// <value></value>
		public DateTime ServiceEndDate { get; set; }
        /// <summary>
        /// 照片
        /// </summary>
        /// <value></value>
        public List<string> Photos { get; set; } 
        /// <summary>
        /// 备注
        /// </summary>
        /// <value></value>
        public string Notes { get; set; } 
		/// <summary>
		/// 合约状态
		/// </summary>
		/// <value></value>
		public ContractStateEnum? ContractState { get; set; } = null;
		/// <summary>
        /// 原因
        /// </summary>
        /// <value></value>
        public string Reason { get; set; } = string.Empty;

        /// <summary>
        /// 签约医生
        /// </summary>
        /// <value></value>
        public string ContractedDoctorName { get; set; }

        /// <summary>
        /// 医生电话
        /// </summary>
        /// <value></value>
        public string ContractedDoctorPhone { get; set; }

        /// <summary>
        /// 团队负责人
        /// </summary>
        /// <value></value>
        public string TeamLeaderName { get; set; }

        /// <summary>
        /// 指导医生
        /// </summary>
        /// <value></value>
        public string PreceptorName { get; set; }

        /// <summary>
        /// 续签签约编码
        /// </summary>
        /// <value></value>
        public string RenewalContractCode { get; set; }

    }

    /// <summary>
    /// 根据编码获取合约记录数据请求
    /// </summary>
    public class GetContractRecordRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取合约记录数据请求
    /// </summary>
    public class GetContractRecordByKeyRequest : TokenRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除合约记录数据请求
    /// </summary>
    public class RemoveContractRecordRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 获取合约记录数据列表请求
    /// </summary>
    public class GetContractRecordListRequest : TokenRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 更新合约记录数据请求
    /// </summary>
    public class UpdateContractRecordStateRequest : TokenRequest
    {
        public string Code { get; set; }

		/// <summary>
		/// 合约状态
		/// </summary>
		/// <value></value>
		public ContractStateEnum? ContractState { get; set; } = null;

		/// <summary>
        /// 原因
        /// </summary>
        /// <value></value>
        public string Reason { get; set; }
	}

    /// <summary>
    /// 更新合约记录数据请求
    /// </summary>
    public class UpdateContractRecordRequest : TokenRequest
    {
        public string Code { get; set; }
		/// <summary>
		/// 合约记录编号
		/// </summary>
		/// <value></value>
		public string ContractRecordNo { get; set; } = "-1";
		/// <summary>
		/// 合约状态
		/// </summary>
		/// <value></value>
		public ContractStateEnum? ContractState { get; set; } = null;
		/// <summary>
		/// 合约是有效
		/// </summary>
		/// <value></value>
		public bool? ContractIsValid { get; set; } = null;
		/// <summary>
		/// 已签约医生
		/// </summary>
		/// <value></value>
		public string ContractedDoctor { get; set; } = "-1";
		/// <summary>
		/// 已签约居民
		/// </summary>
		/// <value></value>
		public string ContractedPatient { get; set; } = "-1";
		/// <summary>
		/// 已签约团队
		/// </summary>
		/// <value></value>
		public string ContractedTeam { get; set; } = "-1";
		/// <summary>
		/// 已签约
		/// </summary>
		/// <value></value>
		public DateTime? ContractedTime { get; set; } = null;
		/// <summary>
		/// 审核状态
		/// </summary>
		/// <value></value>
		public AuditStateEnum? AuditState { get; set; } = null;
		/// <summary>
		/// 已签约文件URL
		/// </summary>
		/// <value></value>
		public string ContractedFileUrl { get; set; } = "-1";
		/// <summary>
		/// 服务包
		/// </summary>
		/// <value></value>
		public List<string> ServicePacks { get; set; } = null;
		/// <summary>
		/// 服务开始日期
		/// </summary>
		/// <value></value>
		public DateTime? ServiceStartDate { get; set; } = null;
		/// <summary>
		/// 服务结束日期
		/// </summary>
		/// <value></value>
		public DateTime? ServiceEndDate { get; set; } = null;
        /// <summary>
        /// 照片
        /// </summary>
        /// <value></value>
        public List<string> Photos { get; set; } =null;
        /// <summary>
        /// 备注
        /// </summary>
        /// <value></value>
        public string Notes { get; set; } ="-1";
    }

	/// <summary>
	/// 获取分页请求
	/// </summary>
	public class ContractRecordPageRequest : PageRequest
	{

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;

		/// <summary>
		/// 审核状态
		/// </summary>
		/// <value></value>
		public AuditStateEnum AuditState { get; set; }
	}

	/// <summary>
	/// 签约审核
	/// </summary>
	public class AuditContractRecordRequest : TokenRequest
	{
        public string Code { get; set; }

		/// <summary>
		/// 审核状态
		/// </summary>
		/// <value></value>
		public AuditStateEnum AuditState { get; set; }
	}

	/// <summary>
    /// 根据居民获取签约记录分页
    /// </summary>
    public class GetContractRecordPageByPatientCodeRequest : PageRequest
    {

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;

        /// <summary>
        /// 居民编码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }
    }

    /// <summary>
    /// 获取签约居民分页
    /// </summary>
    public class GetContractPatientPageRequest : PageRequest
    {
        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;
    }

	/// <summary>
	/// 续约请求
	/// </summary>
	public class RenewalContractRecordRequest : TokenRequest
	{
		/// <summary>
		/// 签约编号
		/// </summary>
		/// <value></value>
		public string Code { get; set; }
		/// <summary>
		/// 服务开始日期
		/// </summary>
		/// <value></value>
		public DateTime? ServiceStartDate { get; set; } = null;
		/// <summary>
		/// 服务结束日期
		/// </summary>
		/// <value></value>
		public DateTime? ServiceEndDate { get; set; } = null;
	}

	/// <summary>
	/// 查询医生最近签约记录请求
	/// </summary>
	public class GetDoctorContractRecordRequest : TokenRequest
	{
	}
}