using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Net.Http;
using System.Threading;
using System.Threading.Tasks;
using WingInterfaceLibrary.Enum.VitalEnum;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.Request.Vital
{
    /// <summary>
    /// 创建诊疗数据请求
    /// </summary>
    public class CreateDiagnosisRequest : TokenRequest
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
		/// <summary>
		/// 键
		/// </summary>
		/// <value></value>
		public string Key { get; set; }
		/// <summary>
		/// 居民代码
		/// </summary>
		/// <value></value>
		public string PatientCode { get; set; }
		/// <summary>
		/// 医生代码
		/// </summary>
		/// <value></value>
		public string DoctorCode { get; set; }
		/// <summary>
		/// 检查数据
		/// </summary>
		/// <value></value>
		public string DiagnosisData { get; set; }

        /// <summary>
        /// 诊疗时间
        /// </summary>
        /// <value></value>
        public DateTime DiagnosisTime { get; set; } = DateTime.UtcNow;

        /// <summary>
        /// 客户端对应诊疗数据的Id，此Id用于确认上传的数据属于那一份诊疗数据
        /// </summary>
        /// <value></value>
        public string AppDataId { get; set; }
    }

    /// <summary>
    /// 根据编码获取诊疗数据请求
    /// </summary>
    public class GetDiagnosisRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取诊疗数据请求
    /// </summary>
    public class GetDiagnosisByKeyRequest : TokenRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除诊疗数据请求
    /// </summary>
    public class RemoveDiagnosisRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 获取诊疗数据列表请求
    /// </summary>
    public class GetDiagnosisListRequest : TokenRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 更新诊疗数据请求
    /// </summary>
    public class UpdateDiagnosisRequest : TokenRequest
    {
        public string Code { get; set; }
		/// <summary>
		/// 键
		/// </summary>
		/// <value></value>
		public string Key { get; set; } = "-1";
		/// <summary>
		/// 居民代码
		/// </summary>
		/// <value></value>
		public string PatientCode { get; set; }  = "-1";
		/// <summary>
		/// 医生代码
		/// </summary>
		/// <value></value>
		public string DoctorCode { get; set; }  = "-1";
		/// <summary>
		/// 检查数据
		/// </summary>
		/// <value></value>
		public string DiagnosisData { get; set; } = "-1";

        /// <summary>
        /// 诊疗时间
        /// </summary>
        /// <value></value>
        public DateTime? DiagnosisTime { get; set; } = null;

        /// <summary>
        /// 客户端对应诊疗数据的Id，此Id用于确认上传的数据属于那一份诊疗数据
        /// </summary>
        /// <value></value>
        public string AppDataId { get; set; } = "-1";
    }

    /// <summary>
    /// 查询诊疗分页请求
    /// </summary>
    public class DiagnosisPageRequest : PageRequest
    {
        /// <summary>
        /// 客户端对应诊疗数据的Id，此Id用于确认上传的数据属于那一份诊疗数据
        /// </summary>
        /// <value></value>
        public string AppDataId { get; set; }

        /// <summary>
        /// 证件号
        /// </summary>
        public string CardNo { get; set; }

		/// <summary>
		/// 居民代码
		/// </summary>
		/// <value></value>
		public string PatientCode { get; set; }

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;
    }

    /// <summary>
    /// 提交诊疗数据请求
    /// </summary>
    public class SubmitDiagnosisRequest : TokenRequest
    {
        /// <summary>
        /// 客户端对应诊疗数据的Id，此Id用于确认上传的数据属于那一份诊疗数据
        /// </summary>
        /// <value></value>
        public string AppDataId { get; set; }

        /// <summary>
        /// 诊疗时间
        /// </summary>
        /// <value></value>
        public DateTime? DiagnosisTime { get; set; } = null;

        /// <summary>
		/// 居民代码
		/// </summary>
		/// <value></value>
		public string PatientCode { get; set; }

		/// <summary>
		/// 医生代码
		/// </summary>
		/// <value></value>
		public string DoctorCode { get; set; }

        /// <summary>
        /// 诊疗数据列表
        /// </summary>
        /// <value></value>
        public List<DiagnosisItem> DiagnosisItems { get; set; }
    }

    /// <summary>
    /// 重传诊疗数据请求
    /// </summary>
    public class ReinfusionDiagnosisRequest : TokenRequest
    {
        /// <summary>
        /// 客户端对应诊疗数据的Id，此Id用于确认上传的数据属于那一份诊疗数据
        /// </summary>
        /// <value></value>
        public string AppDataId { get; set; }
    }

    /// <summary>
    /// 设置诊疗时间
    /// </summary>
    public class SetDiagnosisTimeRequest : TokenRequest
    {
        /// <summary>
        /// 客户端对应诊疗数据的Id，此Id用于确认上传的数据属于那一份诊疗数据
        /// </summary>
        /// <value></value>
        public string AppDataId { get; set; }

        /// <summary>
        /// 需要设置的诊疗时间
        /// </summary>
        /// <value></value>
        public DateTime DiagnosisTime { get; set; }
    }

    /// <summary>
    /// 诊疗数据内容
    /// </summary>
    public class DiagnosisItem
    {
        /// <summary>
		/// 键
		/// </summary>
		/// <value></value>
		public string Key { get; set; } = "-1";

		/// <summary>
		/// 检查数据
		/// </summary>
		/// <value></value>
		public string DiagnosisData { get; set; } = "-1";
    }

    /// <summary>
    /// 同步居民和检测数据请求
    /// </summary>
    public class SyncPatientAndDiagnosisDataRequest : TokenRequest
    {
		/// <summary>
		/// 居民编码
		/// </summary>
		/// <value></value>
		public string PatientCode { get; set; }

		/// <summary>
		/// 居民名称
		/// </summary>
		/// <value></value>
		public string PatientName { get; set; }

		/// <summary>
		/// 电话
		/// </summary>
		/// <value></value>
		public string Phone { get; set; }

		/// <summary>
		/// 证件编号
		/// </summary>
		/// <value></value>
		public string CardNo { get; set; }

		/// <summary>
		/// 民族
		/// </summary>
		/// <value></value>
		public string Nationality { get; set; }

		/// <summary>
		/// 生日
		/// </summary>
		/// <value></value>
		public DateTime Birthday { get; set; }

		/// <summary>
		/// 人群标签
		/// </summary>
		/// <value></value>
		public List<string> CrowdLabels { get; set; }

		/// <summary>
		/// 卡片类型
		/// </summary>
		/// <value></value>
		public CardTypeEnum CardType { get; set; }

		/// <summary>
		/// 居民性别
		/// </summary>
		/// <value></value>
		public GenderEnum PatientGender { get; set; }

		/// <summary>
		/// 居民地址
		/// </summary>
		/// <value></value>
		public string PatientAddress { get; set; }

		/// <summary>
		/// 永久村/小区地址
		/// </summary>
		/// <value></value>
		public string PermanentResidenceAddress { get; set; }

		/// <summary>
		/// 已签约医生
		/// </summary>
		/// <value></value>
		public string ContractedDoctor { get; set; }

        /// <summary>
        /// 客户端对应诊疗数据的Id，此Id用于确认上传的数据属于那一份诊疗数据
        /// </summary>
        /// <value></value>
        public string AppDataId { get; set; }

        /// <summary>
        /// 诊疗时间
        /// </summary>
        /// <value></value>
        public DateTime? DiagnosisTime { get; set; } = null;

		/// <summary>
		/// 医生代码
		/// </summary>
		/// <value></value>
		public string DoctorCode { get; set; }

        /// <summary>
        /// 诊疗数据列表
        /// </summary>
        /// <value></value>
        public List<DiagnosisItem> DiagnosisItems { get; set; }
    }

    /// <summary>
    /// 同步居民和检测数据请求
    /// </summary>
    public class OldPlatformDiagnosisDataCountRequest : TokenRequest
    {
    }

    /// <summary>
    /// 根据AppDataId删除诊疗数据请求
    /// </summary>
    public class RemoveDiagnosisByAppDataIdRequest : TokenRequest
    {
        public string AppDataId { get; set; }
    }
}