using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum.VitalEnum;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.Request.Vital
{
    /// <summary>
    /// 创建字典数据请求
    /// </summary>
    public class CreateDictionaryRequest : TokenRequest
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
		/// <summary>
		/// 键
		/// </summary>
		/// <value></value>
		public string Key { get; set; }
		/// <summary>
		/// 名称
		/// </summary>
		/// <value></value>
		public string Name { get; set; }
		/// <summary>
		/// 类型
		/// </summary>
		/// <value></value>
		public VitalDictionaryTypeEnum Type { get; set; }
		/// <summary>
		/// 描述
		/// </summary>
		/// <value></value>
		public string Description { get; set; }


    }

    /// <summary>
    /// 根据编码获取字典数据请求
    /// </summary>
    public class GetDictionaryRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取字典数据请求
    /// </summary>
    public class GetDictionaryByKeyRequest : TokenRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除字典数据请求
    /// </summary>
    public class RemoveDictionaryRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 获取字典数据列表请求
    /// </summary>
    public class GetDictionaryListRequest : TokenRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 更新字典数据请求
    /// </summary>
    public class UpdateDictionaryRequest : TokenRequest
    {
        public string Code { get; set; }
		/// <summary>
		/// 键
		/// </summary>
		/// <value></value>
		public string Key { get; set; }
		/// <summary>
		/// 名称
		/// </summary>
		/// <value></value>
		public string Name { get; set; }
		/// <summary>
		/// 类型
		/// </summary>
		/// <value></value>
		public VitalDictionaryTypeEnum Type { get; set; }
		/// <summary>
		/// 描述
		/// </summary>
		/// <value></value>
		public string Description { get; set; }

    }

    /// <summary>
    /// 查询字典分页请求
    /// </summary>
    public class DictionaryPageRequest : PageRequest
    {
        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;
    }

    /// <summary>
    /// 根据关键字获取字典数据列表
    /// </summary>
    public class GetDictionaryNameAndUnitByKeysRequest : TokenRequest
    {
        public List<string> Keys { get; set; }
    }
}