using System;
using System.Collections.Generic;

namespace WingInterfaceLibrary.Request.Vital
{
    /// <summary>
    /// 创建数据请求
    /// </summary>
    public class CreateDynamicTypeRequest : TokenRequest
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
		/// <summary>
		/// 类型名称
		/// </summary>
		/// <value></value>
		public string TypeName { get; set; }
		/// <summary>
		/// 标签类型键
		/// </summary>
		/// <value></value>
		public string TypeKey { get; set; }


    }

    /// <summary>
    /// 根据编码获取数据请求
    /// </summary>
    public class GetDynamicTypeRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取数据请求
    /// </summary>
    public class GetDynamicTypeByKeyRequest : TokenRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除数据请求
    /// </summary>
    public class RemoveDynamicTypeRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 获取数据列表请求
    /// </summary>
    public class GetDynamicTypeListRequest : TokenRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 更新数据请求
    /// </summary>
    public class UpdateDynamicTypeRequest : TokenRequest
    {
        public string Code { get; set; }
		/// <summary>
		/// 类型名称
		/// </summary>
		/// <value></value>
		public string TypeName { get; set; }
		/// <summary>
		/// 标签类型键
		/// </summary>
		/// <value></value>
		public string TypeKey { get; set; }

    }

    /// <summary>
    /// 通过字典键获取动态类型列表
    /// </summary>
    public class GetDynamicTypeListByKeyRequest : TokenRequest
    {
        /// <summary>
        /// 字典键
        /// </summary>
        /// <value></value>
        public string Key { get; set; }
    }

    /// <summary>
    /// 查询动态类型分页请求
    /// </summary>
    public class DynamicTypePageRequest : PageRequest
    {

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;
    }
}