using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum.VitalEnum;

namespace WingInterfaceLibrary.Request.Vital
{
    /// <summary>
    /// 分页查询体检记录 请求
    /// </summary>
    public class GetRegisterInfoPageRequest : PageRequest
    {
        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;
    }

    /// <summary>
    /// 查询体检结果详情 请求
    /// </summary>
    public class GetExamInfoByPhysicalExamNumberRequest : TokenRequest
    {
        /// <summary>
        /// 体检号
        /// </summary>
        /// <value></value>
        public string PhysicalExamNumber { get; set; }
    }

    /// <summary>
    /// 查询体检详情 请求
    /// </summary>
    public class GetRegisterInfoByPhysicalExamNumberRequest : TokenRequest
    {
        /// <summary>
        /// 体检号
        /// </summary>
        /// <value></value>
        public string PhysicalExamNumber { get; set; }
    }

    /// <summary>
    /// 查询体检报告 请求
    /// </summary>
    public class GetVitalReportInfoRequest : TokenRequest
    {
        /// <summary>
        /// 体检号
        /// </summary>
        /// <value></value>
        public string PhysicalExamNumber { get; set; }
    }

    /// <summary>
    /// 分页查询中医体质辨识和老年人自理能力随访 请求
    /// </summary>
    public class GetExamByPatientPageRequest : PageRequest
    {
        /// <summary>
		/// 居民编码
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string PatientCode { get; set; }

        /// <summary>
		/// 检测类型
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string ExamKey { get; set; }

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;
    }

    /// <summary>
    /// 查询体检结果详情 响应
    /// </summary>
    public class GetExamInfoByPhysicalExamNumberResult
    {
        /// <summary>编码</summary>
        public string Code { get; set; }

        /// <summary>创建时间，UTC</summary>
        public DateTime CreateTime { get; set; }

        /// <summary>更新时间，UTC</summary>
        public DateTime UpdateTime { get; set; }

        /// <summary>居民姓名</summary>
        public string PatientName { get; set; }

        /// <summary>证件号码</summary>
        public string CardNo { get; set; }

        /// <summary>居民性别</summary>
        public string PatientGender { get; set; }

        /// <summary>居民地址</summary>
        public string PatientAddress { get; set; }

        /// <summary>生日，UTC</summary>
        public DateTime Birthday { get; set; }

        /// <summary>检查时间，UTC</summary>
        public DateTime ExamTime { get; set; }

        /// <summary>体检号</summary>
        public string PhysicalExamNumber { get; set; }

        /// <summary>症状 1:无症状;2:头痛;3:头晕;4:心悸;5:胸闷;6:胸痛;7:慢性咳嗽;8:咳痰;9:呼吸困难;10:多饮;11:多尿;12:体重下降;13:乏力;14:关节肿痛;15:视力模糊;16:手脚麻木;17:尿急;18:尿痛;19:便秘;20:腹泻;21:恶心呕吐;22:眼花;23:耳鸣;24:乳房胀痛;25:其他;</summary>
        public List<string> Symptom { get; set; } = new List<string>();

        /// <summary>体温</summary>
        public string Temperature { get; set; }

        /// <summary>呼吸频率</summary>
        public string Breathe { get; set; }

        /// <summary>血氧饱和度</summary>
        public string Spo2 { get; set; }

        /// <summary>脉率</summary>
        public string Pulse_Frequency { get; set; }

        /// <summary>身高</summary>
        public string Height { get; set; }

        /// <summary>体重</summary>
        public string Weight { get; set; }

        /// <summary>体质指数</summary>
        public string Bmi { get; set; }

        /// <summary>腰围</summary>
        public string WAISTLINE { get; set; }

        /// <summary>左侧血压</summary>
        public List<string> BloodPressureLeft { get; set; } = new List<string>();

        /// <summary>右侧血压</summary>
        public List<string> BloodPressureRight { get; set; } = new List<string>();

        /// <summary>老年人健康状态自我评估 1:满意;2:基本满意;3:说不清楚;4:不太满意;5:不满意;</summary>
        public string Older_Health_State { get; set; }

        /// <summary>老年人生活自理能力自我评估 1:可自理（0～3分）;2:轻度依赖（4～8分）;3:中度依赖（9～18分);4:不能自理（≥19分）</summary>
        public string Older_Living_Ability { get; set; }

        /// <summary>老年人认知功能 1:粗筛阴性;2:粗筛阳性;</summary>
        public string Older_Cognitive { get; set; }

        /// <summary>老年人认知功能总分</summary>
        public string Older_Intelligence { get; set; }

        /// <summary>老年人情感状态 1:粗筛阴性;2:粗筛阳性;</summary>
        public string Older_Emotional { get; set; }

        /// <summary>老年人情感状态总分</summary>
        public string Older_Depression { get; set; }

        /// <summary>血红蛋白,g/L</summary>
        public string Blood_Hgb { get; set; }

        /// <summary>白细胞,×10⁹/L</summary>
        public string Blood_Wbc { get; set; }

        /// <summary>血小板,×10⁹/L</summary>
        public string Blood_Rlt { get; set; }

        /// <summary>其他血常规数据</summary>
        public string Blood_Routine_Other { get; set; }

        /// <summary>LEU(尿白蛋白)</summary>
        public string Urinary_Pro_LEU { get; set; }

        /// <summary>BLD(红细胞/潜血)</summary>
        public string Urinary_Pro_BLD { get; set; }

        /// <summary>NIT(尿亚硝酸盐)</summary>
        public string Urinary_Pro_NIT { get; set; }

        /// <summary>KET(酮体)</summary>
        public string Urinary_Pro_KET { get; set; }

        /// <summary>UBG(尿胆原)</summary>
        public string Urinary_Pro_UBG { get; set; }

        /// <summary>BIL(胆红素)</summary>
        public string Urinary_Pro_BIL { get; set; }

        /// <summary>PRO(尿蛋白)</summary>
        public string Urinary_Pro_PRO { get; set; }

        /// <summary>GLU(葡萄糖)</summary>
        public string Urinary_Pro_GLU { get; set; }

        /// <summary>PH(酸碱度)</summary>
        public string Urinary_Pro_PH { get; set; }

        /// <summary>SG(尿比重)</summary>
        public string Urinary_Pro_SG { get; set; }

        /// <summary>VC(维生素C)</summary>
        public string Urinary_Pro_VC { get; set; }

        /// <summary>大便潜血 1:阴性;2:阳性;</summary>
        public string Fecal_Bld { get; set; }

        /// <summary>乙型肝炎表面抗原 1:阴性;2:阳性;</summary>
        public string Hbsag { get; set; }

        /// <summary>糖化血红蛋白,%</summary>
        public string Hbalc { get; set; }

        /// <summary>空腹血糖,mmol/L</summary>
        public string Fasting_Glucose_Mmol { get; set; }

        /// <summary>心电图 1:正常;2:异常;</summary>
        public string Ecg_Img { get; set; }

        /// <summary>血清谷丙转氨酶,U/L</summary>
        public string Liver_Alt { get; set; }

        /// <summary>血清谷草转氨酶,U/L</summary>
        public string Liver_Ast { get; set; }

        /// <summary>白蛋白,g/L</summary>
        public string Liver_Alb { get; set; }

        /// <summary>总胆红素,μmol/L</summary>
        public string Liver_Tbil { get; set; }

        /// <summary>结合胆红素,μmol/L</summary>
        public string Liver_Dbil { get; set; }

        /// <summary>血清肌酐,μmol/L</summary>
        public string Renal_Cr { get; set; }

        /// <summary>血尿素氮,mmol/L</summary>
        public string Renal_Bun { get; set; }

        /// <summary>血钾浓度,mmol/L</summary>
        public string Renal_Spc { get; set; }

        /// <summary>血钠浓度,mmol/L</summary>
        public string Renal_Ssc { get; set; }

        /// <summary>总胆固醇,mmol/L</summary>
        public string Lipid_Cho { get; set; }

        /// <summary>甘油三酯,mmol/L</summary>
        public string Lipid_Tg { get; set; }

        /// <summary>血清低密度脂蛋白胆固醇,mmol/L</summary>
        public string Lipid_Ldl { get; set; }

        /// <summary>血清高密度脂蛋白胆固醇,mmol/L</summary>
        public string Lipid_Hdl { get; set; }

        /// <summary>胸部X线片 1:正常;2:异常;</summary>
        public string Chest_X_Ray { get; set; }

        /// <summary>腹部B超 1:正常;2:异常;3:脂肪肝</summary>
        public string B_Ultrasonic { get; set; }

        /// <summary>其他B超 1:正常;2:异常;</summary>
        public string B_Us_Other { get; set; }

        /// <summary>宫颈涂片 1:正常;2:异常;</summary>
        public string Cervical_Smear { get; set; }

        /// <summary>其他B超数据</summary>
        public string B_Us_Others { get; set; }

        /// <summary>锻炼频率 1:每天;2:每周一次以上;3:偶尔;4:不锻炼;</summary>
        public string Exercise_Frequency { get; set; }

        /// <summary>每次锻炼时间,分钟</summary>
        public string Exercise_Daily_Time { get; set; }

        /// <summary>坚持锻炼时间,年</summary>
        public string Exercise_Time { get; set; }

        /// <summary>锻炼方式</summary>
        public string Exercise_Way { get; set; }

        /// <summary>饮食习惯 1:荤素均衡;2:荤食为主;3:素食为主;4:嗜盐;5:嗜油;6:嗜糖;</summary>
        public List<string> Diet { get; set; }

        /// <summary>吸烟状况 1:从不吸烟;2:已戒烟;3:吸烟;</summary>
        public string Smoking_State { get; set; }

        /// <summary>日吸烟量,支</summary>
        public string Smoking_Daily { get; set; }

        /// <summary>开始吸烟年龄,岁</summary>
        public string Smoking_Start_Age { get; set; }

        /// <summary>戒烟年龄,岁</summary>
        public string Smoking_Quit_Age { get; set; }

        /// <summary>饮酒频率 1:从不;2:偶尔;3:经常;4:每天;</summary>
        public string Drinking_Frequency { get; set; }

        /// <summary>日饮酒量,两</summary>
        public string Drinking_Daily { get; set; }

        /// <summary>开始饮酒年龄,岁</summary>
        public string Drinking_Start_Age { get; set; }

        /// <summary>是否戒酒 1:未戒酒;2:已戒酒;</summary>
        public string Drinking_Is_Quit { get; set; }

        /// <summary>戒酒年龄,岁</summary>
        public string Drinking_Quit_Age { get; set; }

        /// <summary>近一年内是否曾醉酒 1:是;2:否;</summary>
        public string Drinking_Is_Drunk { get; set; }

        /// <summary>饮酒种类 1:白酒;2:啤酒;3:红酒;4:黄酒;5:其他;</summary>
        public List<string> Drinking_Type { get; set; } = new List<string>();

        /// <summary>职业病危害因素接触史 1:无;2:有;</summary>
        public string Risk_Working_State { get; set; }

        /// <summary>工种</summary>
        public string Risk_Working_Type { get; set; }

        /// <summary>从业时间,年</summary>
        public string Risk_Working_Time { get; set; }

        /// <summary>粉尘</summary>
        public string Risk_Dust { get; set; }

        /// <summary>粉尘防护措施 1:无；2:有;</summary>
        public string Risk_Dust_Protect_Type { get; set; }

        /// <summary>粉尘防护措施描述</summary>
        public string Risk_Dust_Protect_Label { get; set; }

        /// <summary>放射物质</summary>
        public string Risk_Radiate { get; set; }

        /// <summary>放射物质防护措施 1:无；2:有;</summary>
        public string Risk_Radiate_Protect_Type { get; set; }

        /// <summary>放射物质防护措施描述</summary>
        public string Risk_Radiate_Protect_Label { get; set; }

        /// <summary>物理因素</summary>
        public string Risk_Physics { get; set; }

        /// <summary>物理因素防护措施 1:无；2:有;</summary>
        public string Risk_Physics_Protect_Type { get; set; }

        /// <summary>物理因素防护措施描述</summary>
        public string Risk_Physics_Protect_Label { get; set; }

        /// <summary>化学物质</summary>
        public string Risk_Chemical { get; set; }

        /// <summary>化学物质防护措施 1:无；2:有;</summary>
        public string Risk_Chemical_Protect_Type { get; set; }

        /// <summary>化学物质防护措施描述</summary>
        public string Risk_Chemical_Protect_Label { get; set; }

        /// <summary>其他</summary>
        public string Risk_Other { get; set; }

        /// <summary>其他防护措施 1:无；2:有;</summary>
        public string Risk_Other_Protect_Type { get; set; }

        /// <summary>其他防护措施描述</summary>
        public string Risk_Other_Protect_Label { get; set; }

        /// <summary>口唇 1:红润;2:苍白;3:发绀;4:皲裂;5:疱疹;</summary>
        public string Lip { get; set; }

        /// <summary>齿列 1:正常;2:缺齿;3:龋齿;4:义齿（假牙）;</summary>
        public List<string> Dentition { get; set; } = new List<string>();

        /// <summary>缺齿</summary>
        public List<string> Dentition_A { get; set; } = new List<string>();

        /// <summary>龋齿</summary>
        public List<string> Dentition_B { get; set; } = new List<string>();

        /// <summary>义齿</summary>
        public List<string> Dentition_C { get; set; } = new List<string>();

        /// <summary>咽部 1:无充血;2:充血;3:淋巴滤泡增生;</summary>
        public string Pharynx { get; set; }

        /// <summary>左眼</summary>
        public string Vision_Left { get; set; }

        /// <summary>右眼</summary>
        public string Vision_Right { get; set; }

        /// <summary>矫正视力-左眼</summary>
        public string Vision_Corrective_Left { get; set; }

        /// <summary>矫正视力-右眼</summary>
        public string Vision_Corrective_Right { get; set; }

        /// <summary>听力 1:听见;2:听不清或无法听见;</summary>
        public string Hearing { get; set; }

        /// <summary>运动功能 1:可顺利完成;2:无法独立完成任何一个动作;</summary>
        public string Athletic { get; set; }

        /// <summary>眼底 1:正常;2:异常;</summary>
        public string Eye_Ground { get; set; }

        /// <summary>皮肤 1:正常;2:潮红;3:苍白;4:发绀;5:黄染;6:色素沉着;7:其他;</summary>
        public string Skin { get; set; }

        /// <summary>巩膜 1:正常;2:黄染;3:充血;4:其他;</summary>
        public string Sclera { get; set; }

        /// <summary>淋巴结 1:未触及;2:锁骨上;3:腋窝;4:其他;</summary>
        public string Lymph_Node { get; set; }

        /// <summary>桶状胸 1:否;2:是;</summary>
        public string Barrel_Chest { get; set; }

        /// <summary>呼吸音 1:正常;2:异常;</summary>
        public string Breath_Sounds { get; set; }

        /// <summary>罗音 1:无;2:干罗音;3:湿罗音;4:其他;</summary>
        public string Rale { get; set; }

        /// <summary>杂音 1:无;2:有;</summary>
        public string Heart_Murmur { get; set; }

        /// <summary>心律 1:齐;2:不齐;3:绝对不齐;</summary>
        public string Heart_Rhythm { get; set; }

        /// <summary>心率,次/分钟</summary>
        public string Heart_Rate { get; set; }

        /// <summary>压痛 1:无;2:有;</summary>
        public string Abdominal_Tenderness { get; set; }

        /// <summary>包块 1:无;2:有;</summary>
        public string Abdominal_Mass { get; set; }

        /// <summary>肝大 1:无;2:有;</summary>
        public string Hepatomegaly { get; set; }

        /// <summary>脾大 1:无;2:有;</summary>
        public string Splenomegalia { get; set; }

        /// <summary>移动性浊音 1:无;2:有;</summary>
        public string Shifting_Dullness { get; set; }

        /// <summary>下肢水肿 1:无;2:单侧;3:双侧不对称;4:双侧对称;</summary>
        public string Lower_Limb_Edema { get; set; }

        /// <summary>足背动脉搏动 1:未触及;2:触及双侧对称;3:触及左侧弱或消失;4:触及右侧弱或消失;</summary>
        public string Pedal_Artery { get; set; }

        /// <summary>肛门指诊 1:未及异常;2:触痛;3:包块;4:前列腺异常;5:其他;</summary>
        public string Rectal_Touch { get; set; }

        /// <summary>乳腺 1:未见异常;2:乳房切除;3:异常泌乳;4:乳腺包块;5:其他;</summary>
        public List<string> Mammary { get; set; } = new List<string>();

        /// <summary>外阴 1:未见异常;2:异常;</summary>
        public string Vulvar { get; set; }

        /// <summary>阴道 1:未见异常;2:异常;</summary>
        public string Vagina { get; set; }

        /// <summary>宫颈 1:未见异常;2:异常;</summary>
        public string Cervical { get; set; }

        /// <summary>宫体 1:未见异常;2:异常;</summary>
        public string Uteri_Body { get; set; }

        /// <summary>附件 1:未见异常;2:异常;</summary>
        public string Uteri_Adnexa { get; set; }

        /// <summary>其他检查</summary>
        public string Examination_Other { get; set; }

        /// <summary>脑血管疾病 1:未发现;2:缺血性卒中;3:脑出血;4:蛛网膜下腔出血;5:短暂性脑缺血;6:其他;</summary>
        public List<string> Health_Cranial { get; set; } = new List<string>();

        /// <summary>肾脏疾病 1:未发现;2:糖尿病肾病;3:肾功能衰竭;4:急性肾炎;5:慢性肾炎;6:其他;</summary>
        public List<string> Health_Renal { get; set; } = new List<string>();

        /// <summary>心脏疾病 1:未发现;2:心肌梗死;3:心绞痛;4:冠状动脉血运重建;5:充血性心力衰竭;6:心前区疼痛;7:其他;</summary>
        public List<string> Health_Cardiac { get; set; } = new List<string>();

        /// <summary>血管疾病 1:未发现;2:夹层动脉瘤;3:动脉闭塞性疾病;4:其他;</summary>
        public List<string> Health_Vascular { get; set; } = new List<string>();

        /// <summary>眼部疾病 1:未发现;2:视网膜出血或渗出;3:视乳头水肿;4:白内障;5:其他;</summary>
        public List<string> Health_Eye { get; set; } = new List<string>();

        /// <summary>神经系统疾病 1:未发现;2:有;</summary>
        public string Health_Nervous { get; set; }

        /// <summary>神经系统疾病描述</summary>
        public string Health_Nervous_Pro { get; set; }

        /// <summary>其他系统疾病</summary>
        public string Health_Other { get; set; }

        /// <summary>其他系统疾病描述</summary>
        public string Health_Other_Pro { get; set; }

        /// <summary>住院史</summary>
        /// <typeparam name="Hospitalization_History"></typeparam>
        /// <returns></returns>
        public List<HospitalizationHistory> Hospitalization_History { get; set; } = new List<HospitalizationHistory>();

        /// <summary>家庭病床史</summary>
        /// <typeparam name="Hospital_At_Home"></typeparam>
        /// <returns></returns>
        public List<HospitalAtHome> Hospital_At_Home { get; set; } = new List<HospitalAtHome>();

        /// <summary>主要用药情况</summary>
        /// <typeparam name="Drug_Usage"></typeparam>
        /// <returns></returns>
        public List<DrugUsage> Drug_Usage { get; set; } = new List<DrugUsage>();

        /// <summary>非免疫预防接种史</summary>
        /// <typeparam name="Inoculate_History"></typeparam>
        /// <returns></returns>
        public List<InoculateHistory> Inoculate_History { get; set; } = new List<InoculateHistory>();

        /// <summary>健康评价 1:体检无异常;2:有异常;</summary>
        public string Appraisal_Flag { get; set; }

        /// <summary>异常</summary>
        public List<string> Appraisal { get; set; } = new List<string>();

        /// <summary>健康指导 1:纳入慢性病患者健康管理;2:建议复查;3:建议转诊;</summary>
        public List<string> Guidance { get; set; } = new List<string>();

        /// <summary>危险因素控制 1:戒烟;2:健康饮酒;3:饮食;4:锻炼;5:减体重;6:建议接种疫苗;7:其他;</summary>
        public List<string> Risk_Control_Values { get; set; } = new List<string>();

        /// <summary>减体重，目标**Kg</summary>
        public string Risk_Control_WeightLoss { get; set; }

        /// <summary>建议接种疫苗详情</summary>
        public string Risk_Control_Vaccinations { get; set; }

        /// <summary>其他建议</summary>
        public string Risk_Control_Other { get; set; }
    }

    /// <summary>
    /// 住院史
    /// </summary>
    public class HospitalizationHistory
    {
        /// <summary>序号</summary>
        public string id { get; set; }

        /// <summary>入院日期</summary>
        public DateTime Admission_Date { get; set; }

        /// <summary>出院日期</summary>
        public DateTime Discharge_Date { get; set; }

        /// <summary>原因</summary>
        public string Reason { get; set; }

        /// <summary>医疗机构名称</summary>
        public string Name_Of_Medical_Institution { get; set; }

        /// <summary>病案号</summary>
        public string Patient_Number { get; set; }

    }

    /// <summary>
    /// 家庭病床史
    /// </summary>
    public class HospitalAtHome
    {
        /// <summary>序号</summary>
        public string id { get; set; }

        /// <summary>建床日期</summary>
        public DateTime Bed_Construction_Date { get; set; }

        /// <summary>撤床日期</summary>
        public DateTime Discharge_Date { get; set; }

        /// <summary>原因</summary>
        public string Reason { get; set; }

        /// <summary>医疗机构名称</summary>
        public string Name_Of_Medical_Institution { get; set; }

        /// <summary>病案号</summary>
        public string Patient_Number { get; set; }

    }

    /// <summary>
    /// 主要用药情况
    /// </summary>
    public class DrugUsage
    {
        /// <summary>序号</summary>
        public string id { get; set; }

        /// <summary>药物名称</summary>
        public string Medicine_Name { get; set; }

        /// <summary>用法</summary>
        public string Medicine_Usage { get; set; }

        /// <summary>用量</summary>
        public string Medicine_Dosage { get; set; }

        /// <summary>用药时间</summary>
        public string Medicine_Time { get; set; }

        /// <summary>药物依从性 1:规律;2:简短;3:不服药;</summary>
        public string Medicine_Compliance { get; set; }

    }

    /// <summary>
    /// 非免疫预防接种史
    /// </summary>
    public class InoculateHistory
    {
        /// <summary>序号</summary>
        public string id { get; set; }

        /// <summary>接种日期</summary>
        public DateTime Vaccination_Date { get; set; }

        /// <summary>接种机构</summary>
        public string Vaccination_Facility { get; set; }

        /// <summary>疫苗名称</summary>
        public string Vaccine_Name { get; set; }

    }

    /// <summary>
    /// 上传心电报告请求实体
    /// </summary>
    public class UploadElectrocardiogramReportRequest : TokenRequest
    {
        /// <summary>
        /// 体检号
        /// </summary>
        /// <value></value>
        public string PhysicalExamNumber { get; set; }

        /// <summary>
        /// 心电报告
        /// </summary>
        /// <value></value>
        public string ReportBase64 { get; set; }

        /// <summary>
        /// 报告PDF地址,可外网访问
        /// </summary>
        /// <value></value>
        public string ReportPdfUrl { get; set; }

        /// <summary>
        /// 报告JPG地址,可外网访问
        /// </summary>
        /// <value></value>
        public string ReportJpgUrl { get; set; }

        /// <summary>
        /// 心率
        /// </summary>
        /// <value></value>
        public string HR { get; set; }

        /// <summary>
        /// P宽度
        /// </summary>
        /// <value></value>
        public string PWidth { get; set; }

        /// <summary>
        /// P轴
        /// </summary>
        /// <value></value>
        public string PAxis { get; set; }

        /// <summary>
        /// QRS轴
        /// </summary>
        /// <value></value>
        public string QRSAxis { get; set; }

        /// <summary>
        /// 	PR期间
        /// </summary>
        /// <value></value>
        public string PRInterval { get; set; }

        /// <summary>
        /// QT间期
        /// </summary>
        /// <value></value>
        public string QTInterval { get; set; }

        /// <summary>
        /// QTC间期
        /// </summary>
        /// <value></value>
        public string QTCInterval { get; set; }

        /// <summary>
        /// QRS时限
        /// </summary>
        /// <value></value>
        public string QRSDuration { get; set; }

        /// <summary>
        /// RV5/SV
        /// </summary>
        /// <value></value>
        public string RV5SV { get; set; }

        /// <summary>
        /// RV5+SV1
        /// </summary>
        /// <value></value>
        public string RV5SV1 { get; set; }

        /// <summary>
        /// T轴
        /// </summary>
        /// <value></value>
        public string TAxis { get; set; }

        /// <summary>
        /// 诊断
        /// </summary>
        /// <value></value>
        public string Diagnosis { get; set; }

        /// <summary>
        /// P波时长
        /// </summary>
        /// <value></value>
        public string PDuration { get; set; }

        /// <summary>
        /// T波时长
        /// </summary>
        /// <value></value>
        public string TDuration { get; set; }

        /// <summary>
        /// 报告图像,5s
        /// </summary>
        /// <value></value>
        public string EcgImgBase64 { get; set; }

        /// <summary>
        /// 图像JPG地址,可外网访问
        /// </summary>
        /// <value></value>
        public string EcgImgJpgUrl { get; set; }

        /// <summary>
        /// 报告图像,30s
        /// </summary>
        /// <value></value>
        public string EcgLongImgBase64 { get; set; }

        /// <summary>
        /// 图像JPG地址,可外网访问
        /// </summary>
        /// <value></value>
        public string EcgLongImgJpgUrl { get; set; }

        /// <summary>
        /// 诊断医生电子签名
        /// </summary>
        /// <value></value>
        public string DiagnosticEleSignature { get; set; }

        /// <summary>
        /// 审核医生电子签名
        /// </summary>
        /// <value></value>
        public string ReviewEleSignature { get; set; }
    }

    /// <summary>
    /// 创建检查数据请求
    /// </summary>
    public class CreateExamRequest : TokenRequest
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
        /// <summary>
        /// 批次号
        /// </summary>
        /// <value></value>
        public string BatchNumber { get; set; }
        /// <summary>
        /// 键
        /// </summary>
        /// <value></value>
        public string Key { get; set; }
        /// <summary>
        /// 居民代码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }
        /// <summary>
        /// 签约医生
        /// </summary>
        /// <value></value>
        public string ContractedDoctor { get; set; }
        /// <summary>
        /// 检查数据（json）
        /// </summary>
        /// <value></value>
        public string ExamData { get; set; }
        /// <summary>
        /// 模版编码
        /// </summary>
        /// <value></value>
        public string TemplateCode { get; set; }

        /// <summary>
        /// 体检号(健康体检专用)
        /// </summary>
        /// <value></value>
        public string PhysicalExamNumber { get; set; }

        /// <summary>
        /// 是否远程心电检查
        /// </summary>
        /// <value></value>
        public bool IsRemoteEcgExam { get; set; }
    }

    /// <summary>
    /// 批量保存检测结果请求
    /// </summary>
    public class BatchAddExamRequest : TokenRequest
    {
        /// <summary>
        /// 检测结果集合
        /// </summary>
        /// <typeparam name="AddExamDTO"></typeparam>
        /// <returns></returns>
        public List<AddExamDTO> ExamInfos { get; set; } = new List<AddExamDTO>();
    }

    /// <summary>
    /// 检测结果实体
    /// </summary>
    public class AddExamDTO
    {
        /// <summary>
        /// 体检号(健康体检专用)
        /// </summary>
        /// <value></value>
        public string PhysicalExamNumber { get; set; }

        /// <summary>
        /// 检测编号，5位，序号（5位）
        /// </summary>
        /// <value></value>
        public string ExamNumber { get; set; }

        /// <summary>
        /// 体检时间
        /// </summary>
        /// <value></value>
        public DateTime ExamTime { get; set; }

        /// <summary>
        /// 键
        /// </summary>
        /// <value></value>
        public string Key { get; set; }

        /// <summary>
        /// 检查数据（json）
        /// </summary>
        /// <value></value>
        public string ExamData { get; set; }
    }

    /// <summary>
    /// 根据编码获取检查数据请求
    /// </summary>
    public class GetExamRequest : TokenRequest
    {
        public string Key { get; set; }
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取检查数据请求
    /// </summary>
    public class GetExamByKeyRequest : TokenRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除检查数据请求
    /// </summary>
    public class RemoveExamRequest : TokenRequest
    {
        public string Key { get; set; }
        public string Code { get; set; }
    }

    /// <summary>
    /// 获取检查数据列表请求
    /// </summary>
    public class GetExamListRequest : TokenRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 更新检查数据请求
    /// </summary>
    public class UpdateExamRequest : TokenRequest
    {
        public string Code { get; set; }
        /// <summary>
        /// 键
        /// </summary>
        /// <value></value>
        public string Key { get; set; } = "-1";
        /// <summary>
        /// 检查数据
        /// </summary>
        /// <value></value>
        public string ExamData { get; set; } = "-1";
    }


    /// <summary>
    /// 更新检查数据请求
    /// </summary>
    public class UpdateExamByBatchNumberRequest : TokenRequest
    {
        /// <summary>
        /// 批次号
        /// </summary>
        /// <value></value>
        public string BatchNumber { get; set; }
        /// <summary>
        /// 居民编码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }
        /// <summary>
        /// 键
        /// </summary>
        /// <value></value>
        public string Key { get; set; } = "-1";
        /// <summary>
        /// 检查数据
        /// </summary>
        /// <value></value>
        public string ExamData { get; set; } = "-1";
    }


    /// <summary>
    /// 根据字典键获取体检分页
    /// </summary>
    public class GetExamPageByKeyRequest : PageRequest
    {

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;

        /// <summary>
        /// 字典键
        /// </summary>
        /// <value></value>
        public string Key { get; set; }

        /// <summary>
        /// 居民编码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }
    }

    /// <summary>
    /// 根据字典键获取体检居民分页
    /// </summary>
    public class GetExamPatientPageByKeyRequest : PageRequest
    {

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;

        /// <summary>
        /// 字典键
        /// </summary>
        /// <value></value>
        public string Key { get; set; }
    }

    /// <summary>
    /// 查询检查分页请求
    /// </summary>
    public class ExamPageRequest : PageRequest
    {

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;
    }

    /// <summary>
    /// 查询检查分页请求
    /// </summary>
    public class GetPatientExamByPageRequest : PageRequest
    {
        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string PatientCode { get; set; }

        /// <summary>
		/// 体检关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string ExamKey { get; set; }
    }

    /// <summary>
    /// 查询体检记录
    /// </summary>
    public class GetExamRecordPageRequest : PageRequest
    {

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;

        /// <summary>
        /// 查询的体检项目Key
        /// </summary>
        /// <value></value>
        public List<string> Keys { get; set; }
    }

    /// <summary>
    /// 根据批次号查询体检结果请求
    /// </summary>
    public class GetExamByBatchNumberRequest : TokenRequest
    {
        /// <summary>
        /// 健康体检批次号
        /// </summary>
        /// <value></value>
        public string BatchNumber { get; set; }
    }


    /// <summary>
    /// 查询居民对应的体检记录信息
    /// </summary>
    public class GetExamRecordListRequest : TokenRequest
    {
        /// <summary>
        /// 查询的体检项目Key
        /// </summary>
        /// <value></value>
        public List<string> Keys { get; set; }

        /// <summary>
        /// 居民编码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }
    }

    /// <summary>
    /// 保存快捷检查
    /// </summary>
    public class SaveQuickCheckRecordRequest : TokenRequest
    {
        /// <summary>
        /// 居民编码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }

        /// <summary>
        /// 查询的体检项目Key
        /// </summary>
        /// <value></value>
        public List<string> Keys { get; set; }

        /// <summary>
        /// 快捷检查数据
        /// </summary>
        /// <value></value>
        public string QuickData { get; set; }
    }

    /// <summary>
    /// 根据体检号查询检查记录
    /// </summary>
    public class GetExamListByPhysicalExamNumberRequest : TokenRequest
    {
        /// <summary>
        /// 体检号
        /// </summary>
        /// <value></value>
        public string PhysicalExamNumber { get; set; }
    }

    /// <summary>
    /// 根据编码获取心电记录请求
    /// </summary>
    public class GetElectrocardiogramRecordRequest : TokenRequest
    {
        /// <summary>
        /// 记录code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }
    }

    /// <summary>
    /// 修改心电数据请求实体
    /// </summary>
    public class UpdateElectrocardiogramExamInfoRecordRequest : TokenRequest
    {
        /// <summary>
        /// 记录code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 检查数据
        /// </summary>
        /// <value></value>
        public string ExamData { get; set; } = "-1";
    }

    /// <summary>
    /// 查询心电记录分页请求
    /// </summary>
    public class ElectrocardiogramRecordPageRequest : PageRequest
    {
        /// <summary>
        /// 查询状态
        /// </summary>
        /// <value>1</value>
        public List<ExamStateEnum> States { get; set; }

        /// <summary>
        /// 关键字查询
        /// </summary>
        /// <value></value>
        public string KeyWord { get; set; } = string.Empty;

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2022-02-28T09:21:38.861Z</value>
        public DateTime StartTime { get; set; }

        /// <summary>
        /// 截至时间
        /// </summary>
        /// <value>2022-03-28T09:21:38.861Z</value>
        public DateTime EndTime { get; set; }

        /// <summary>
        /// 是否查询下级提交记录
        /// </summary>
        /// <value></value>
        public bool IsQuerySubordinate { get; set; }
    }

    /// <summary>
    /// 根据体检号查询检查记录
    /// </summary>
    public class GetElectrocardiogramRecordByPhysicalExamNumberRequest : TokenRequest
    {
        /// <summary>
        /// 体检号
        /// </summary>
        /// <value></value>
        public string PhysicalExamNumber { get; set; }
    }

    /// <summary>
    /// 查询居民检测结果请求
    /// </summary>
    public class GetPatientExamInfoRequest : TokenRequest
    {
        /// <summary>
        /// 居民证件号
        /// </summary>
        /// <value></value>
        public string IDCardNo { get; set; }

        /// <summary>
        /// 体检号
        /// </summary>
        /// <value></value>
        public string PhysicalExamNumber { get; set; }

        /// <summary>
        /// 检查类型
        /// </summary>
        /// <value></value>
        public string ExamKey { get; set; }

        /// <summary>
        /// 检查日期
        /// </summary>
        /// <value></value>
        public DateTime ExamDate { get; set; }
    }

    /// <summary>
    /// 查询居民生化结果请求
    /// </summary>
    public class GetBiochemicalExamInfoRequest : TokenRequest
    {
        /// <summary>
        /// 居民证件号
        /// </summary>
        /// <value></value>
        public string IDCardNo { get; set; }

        /// <summary>
        /// 体检号
        /// </summary>
        /// <value></value>
        public string PhysicalExamNumber { get; set; }
    }

    /// <summary>
    /// 查询居民检测HL7结果请求
    /// </summary>
    public class GetHl7PatientExamInfoRequest : GetPatientExamInfoRequest
    {
        /// <summary>
        /// HL7版本
        /// </summary>
        /// <value></value>
        public string HL7Version { get; set; }
    }

    /// <summary>
    /// 查询居民生化HL7结果请求
    /// </summary>
    public class GetHl7BiochemicalExamInfoRequest : GetBiochemicalExamInfoRequest
    {
    }

}