using System;
using System.Collections.Generic;

namespace WingInterfaceLibrary.Request.Vital
{
    /// <summary>
    /// 创建第三方厂商推送记录
    /// </summary>
    public class CreateFacturyPostHistoryRequest : TokenRequest
    {
        /// <summary>
        /// 厂商标识
        /// </summary>
        /// <value></value>
        public string FacturyUniqueCode { get; set; }

        /// <summary>
        /// 厂商接口地址
        /// </summary>
        /// <value></value>
        public string FacturyUrl { get; set; }

        /// <summary>
        /// 病人身份证
        /// </summary>
        /// <value></value>
        public string IDCardNo { get; set; }

        /// <summary>
        /// 病人姓名
        /// </summary>
        /// <value></value>
        public string PatientName { get; set; }

        /// <summary>
        /// 接口类型
        /// </summary>
        /// <value></value>
        public string ApiType { get; set; }

        /// <summary>
        /// 状态 1：待发送；2：发送成功；3：发送失败
        /// </summary>
        /// <value></value>
        public int Status { get; set; }

        /// <summary>
        /// 发送时间
        /// </summary>
        /// <value></value>
        public DateTime PostTime { get; set; }

        /// <summary>
        /// 请求头部信息
        /// </summary>
        /// <value></value>
        public Dictionary<string, string> Headers { get; set; }

        /// <summary>
        /// 请求内容
        /// </summary>
        /// <value></value>
        public string Content { get; set; }

        /// <summary>
        /// 响应内容
        /// </summary>
        /// <value></value>
        public string Result { get; set; }
    }

    /// <summary>
    /// 根据编码获取第三方厂商推送记录
    /// </summary>
    public class GetFacturyPostHistoryRequest : TokenRequest
    {
        /// <summary>
        /// Code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }
    }

    /// <summary>
    /// 分页获取厂商推送记录
    /// </summary>
    public class GetFacturyPostHistoryByPageRequest : PageRequest
    {
        /// <summary>
        /// 关键字
        /// </summary>
        /// <value>张三</value>
        /// <code>0</code>      
        public string Keyword { get; set; }

        /// <summary>
        /// 状态 0：全部；1：待发送；2：发送成功；3：发送失败
        /// </summary>
        /// <value></value>
        public int Status { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;
    }

    /// <summary>
    /// 删除第三方厂商信息
    /// </summary>
    public class RemoveFacturyPostHistoryRequest : TokenRequest
    {
        /// <summary>
        /// Code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }
    }

    /// <summary>
    /// 重发厂商推送记录
    /// </summary>
    public class ResendFacturyPostHistoryRequest : TokenRequest
    {
        /// <summary>
        /// Code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }
    }

    /// <summary>
    /// 晶奇数据推送 中医体质、老年人自理能力评估
    /// </summary>
    public class CreateJingQiExamPostHistoryRequest : TokenRequest
    {
        /// <summary>
        /// PhysicalExamNumber
        /// </summary>
        /// <value></value>
        public string PhysicalExamNumber { get; set; }
        
        /// <summary>
        /// ExamKey
        /// </summary>
        /// <value></value>
        public string ExamKey { get; set; }
        
        /// <summary>
        /// ExamData
        /// </summary>
        /// <value></value>
        public Dictionary<string, string> ExamData { get; set; }
        
        /// <summary>
        /// ExamTime
        /// </summary>
        /// <value></value>
        public DateTime ExamTime { get; set; }
    }

    /// <summary>
    /// 晶奇数据推送 超声、心电报告
    /// </summary>
    public class CreateJingQiReportPostHistoryRequest : TokenRequest
    {
        /// <summary>
        /// ReportCode
        /// </summary>
        /// <value></value>
        public string ReportCode { get; set; }
    }
}