using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum.VitalEnum;

namespace WingInterfaceLibrary.Request.Vital
{
    /// <summary>
    /// 创建第三方厂商信息
    /// </summary>
    public class CreateFacturyUserRequest : TokenRequest
    {
        /// <summary>
        /// 厂商标识
        /// </summary>
        /// <value></value>
        public string FacturyUniqueCode { get; set; }

        /// <summary>
        /// 数据类型 1：医院，2：工号
        /// </summary>
        /// <value></value>
        public int FacturyType { get; set; }

        /// <summary>
        /// 医院编码、工号
        /// </summary>
        /// <value></value>
        public string FacturyCode { get; set; }

        /// <summary>
        /// 名称（医院名称、员工姓名）
        /// </summary>
        /// <value></value>
        public string FacturyName { get; set; }

        /// <summary>
        /// 上级编码，记录医院-工号关系
        /// </summary>
        /// <value></value>
        public string FatherCode { get; set; }

        /// <summary>
        /// 其它扩展信息
        /// </summary>
        /// <value></value>
        public Dictionary<string, string> FacturyData { get; set; }
    }

    /// <summary>
    /// 修改第三方厂商信息
    /// </summary>
    public class UpdateFacturyUserRequest : TokenRequest
    {
        /// <summary>
        /// Code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 厂商标识
        /// </summary>
        /// <value></value>
        public string FacturyUniqueCode { get; set; }

        /// <summary>
        /// 数据类型 1：医院，2：工号
        /// </summary>
        /// <value></value>
        public int FacturyType { get; set; }

        /// <summary>
        /// 医院编码、工号
        /// </summary>
        /// <value></value>
        public string FacturyCode { get; set; }

        /// <summary>
        /// 名称（医院名称、员工姓名）
        /// </summary>
        /// <value></value>
        public string FacturyName { get; set; }

        /// <summary>
        /// 上级编码，记录医院-工号关系
        /// </summary>
        /// <value></value>
        public string FatherCode { get; set; }

        /// <summary>
        /// 其它扩展信息
        /// </summary>
        /// <value></value>
        public Dictionary<string, string> FacturyData { get; set; }
    }

    /// <summary>
    /// 根据编码获取第三方厂商信息
    /// </summary>
    public class GetFacturyUserRequest : TokenRequest
    {
        /// <summary>
        /// Code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }
    }

    /// <summary>
    /// 分页获取厂商数据
    /// </summary>
    public class GetFacturyOrgByPageRequest : PageRequest
    {
        /// <summary>
        /// 关键字
        /// </summary>
        /// <value>张三</value>
        /// <code>0</code>      
        public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;
    }

    /// <summary>
    /// 分页获取厂商员工数据
    /// </summary>
    public class GetFacturyUserByPageRequest : PageRequest
    {
        /// <summary>
        /// 第三方厂商编码
        /// </summary>
        /// <value></value>
        public string FacturyOrgCode { get; set; }
        
        /// <summary>
        /// 关键字
        /// </summary>
        /// <value>张三</value>
        /// <code>0</code>      
        public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;
    }

    /// <summary>
    /// 获取厂商员工列表
    /// </summary>
    public class GetFacturyUserInfosRequest : TokenRequest
    {
        /// <summary>
        /// 第三方厂商编码
        /// </summary>
        /// <value></value>
        public string FacturyOrgCode { get; set; }
    }

    /// <summary>
    /// 获取所有厂商数据
    /// </summary>
    public class GetFacturyTreeRequest : TokenRequest
    {
    }

    /// <summary>
    /// 删除第三方厂商信息
    /// </summary>
    public class RemoveFacturyUserRequest : TokenRequest
    {
        /// <summary>
        /// Code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }
    }

    /// <summary>
    /// 晶奇系统注册 请求
    /// </summary>
    public class FacturyExamRegisterRequest : TokenRequest
    {
        /// <summary>
        /// 身份证号
        /// </summary>
        /// <value></value>
        public string Identity { get; set; }

        /// <summary>
        /// 姓名
        /// </summary>
        /// <value></value>
        public string PatientName { get; set; }
    }

    /// <summary>
    /// 晶奇系统注册 响应
    /// </summary>
    public class FacturyExamRegisterResult
    {
        /// <summary>
        /// 注册结果
        /// </summary>
        /// <value></value>
        public string Status { get; set; }
        /// <summary>
        /// 注册结果提示
        /// </summary>
        /// <value></value>
        public string ErroMsg { get; set; }

        /// <summary>
        /// 体检编号
        /// </summary>
        /// <value></value>
        public string PhyId { get; set; }
        /// <summary>
        /// 居民姓名
        /// </summary>
        /// <value></value>
        public string PatName { get; set; }
        /// <summary>
        /// 居民性别，男
        /// </summary>
        /// <value></value>
        public string Gender { get; set; }
        /// <summary>
        /// 居民年龄
        /// </summary>
        /// <value></value>
        public string PatAge { get; set; }
        /// <summary>
        /// 联系电话
        /// </summary>
        /// <value></value>
        public string Phone { get; set; }
        /// <summary>
        /// 所属社区
        /// </summary>
        /// <value></value>
        public string OrgName { get; set; }
        /// <summary>
        /// 居住地址
        /// </summary>
        /// <value></value>
        public string Address { get; set; }
        /// <summary>
        /// 人群分类 老年人,高血压
        /// </summary>
        /// <value></value>
        public string LisClu { get; set; }
        /// <summary>
        /// 登记日期 2024-05-30 10:48:29
        /// </summary>
        /// <value></value>
        public string PhyDate { get; set; }
        /// <summary>
        /// 个人档案ID
        /// </summary>
        /// <value></value>
        public string PatientID { get; set; }
        /// <summary>
        /// 个人档案编号
        /// </summary>
        /// <value></value>
        public string No { get; set; }
    }

    /// <summary>
    /// 晶奇系统删除注册 请求
    /// </summary>
    public class FacturyExamDeleteRequest : TokenRequest
    {
        /// <summary>
        /// 体检编号
        /// </summary>
        /// <value></value>
        public string PhyId { get; set; }
        
        /// <summary>
        /// 身份证号
        /// </summary>
        /// <value></value>
        public string Identity { get; set; }

        /// <summary>
        /// 姓名
        /// </summary>
        /// <value></value>
        public string PatientName { get; set; }
    }

    /// <summary>
    /// 晶奇系统删除注册 响应
    /// </summary>
    public class FacturyExamDeleteResult
    {
        /// <summary>
        /// 结果
        /// </summary>
        /// <value></value>
        public string Status { get; set; }
        /// <summary>
        /// 结果提示
        /// </summary>
        /// <value></value>
        public string ErroMsg { get; set; }
    }
}