using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum.VitalEnum;

namespace WingInterfaceLibrary.Request.Vital
{
    /// <summary>
    /// 创建随访数据请求
    /// </summary>
    public class CreateFollowUpRequest : TokenRequest
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
        /// <summary>
        /// 键
        /// </summary>
        /// <value></value>
        public string Key { get; set; }
        /// <summary>
        /// 居民代码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }
        /// <summary>
        /// 已签约医生
        /// </summary>
        /// <value></value>
        public string ContractedDoctor { get; set; }
        /// <summary>
        /// 跟进更新数据
        /// </summary>
        /// <value></value>
        public string FollowUpData { get; set; }
        /// <summary>
        /// 模版编码
        /// </summary>
        /// <value></value>
        public string TemplateCode { get; set; }
        /// <summary>
        /// 本次随访时间
        /// </summary>
        /// <value></value>
        public DateTime? FollowUpTime { get; set; }
        /// <summary>
        /// 下次随访时间
        /// </summary>
        /// <value></value>
        public DateTime? NextFollowUpTime { get; set; }
        /// <summary>
        /// 随访方式
        /// </summary>
        /// <value></value>
        public FollowUpModeEnum FollowUpMode { get; set; }
        /// <summary>
        /// 随访照片
        /// </summary>
        /// <value></value>
        public List<string> FollowUpPhotos { get; set; }

        /// <summary>
        /// 体检号(健康体检专用)
        /// </summary>
        /// <value></value>
        public string PhysicalExamNumber { get; set; }
    }

    /// <summary>
    /// 根据编码获取随访数据请求
    /// </summary>
    public class GetFollowUpRequest : TokenRequest
    {
        public string Key { get; set; }
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据编码获取随访数据请求
    /// </summary>
    public class GetFollowUpByPhysicalExamNumberRequest : TokenRequest
    {
        /// <summary>
        /// 体检号(健康体检专用)
        /// </summary>
        /// <value></value>
        public string PhysicalExamNumber { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取随访数据请求
    /// </summary>
    public class GetFollowUpByKeyRequest : TokenRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除随访数据请求
    /// </summary>
    public class RemoveFollowUpRequest : TokenRequest
    {
        public string Key { get; set; }
        public string Code { get; set; }
    }

    /// <summary>
    /// 获取随访数据列表请求
    /// </summary>
    public class GetFollowUpListRequest : TokenRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 更新随访数据请求
    /// </summary>
    public class UpdateFollowUpRequest : TokenRequest
    {
        public string Code { get; set; }
        /// <summary>
        /// 键
        /// </summary>
        /// <value></value>
        public string Key { get; set; } = "-1";
        /// <summary>
        /// 跟进更新数据
        /// </summary>
        /// <value></value>
        public string FollowUpData { get; set; } = "-1";
        /// <summary>
        /// 随访状态
        /// </summary>
        /// <value></value>
        public FollowUpStateEnum? FollowUpState { get; set; } = null;
        /// <summary>
        /// 本次随访时间
        /// </summary>
        /// <value></value>
        public DateTime? FollowUpTime { get; set; } = null;
        /// <summary>
        /// 下次随访时间
        /// </summary>
        /// <value></value>
        public DateTime? NextFollowUpTime { get; set; } = null;
        /// <summary>
        /// 随访方式
        /// </summary>
        /// <value></value>
        public FollowUpModeEnum? FollowUpMode { get; set; } = null;
        /// <summary>
        /// 随访照片
        /// </summary>
        /// <value></value>
        public List<string> FollowUpPhotos { get; set; } = null;
    }

    /// <summary>
    /// 根据字典键获取随访分页
    /// </summary>
    public class GetFollowUpPageByKeyRequest : PageRequest
    {

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;

        /// <summary>
        /// 字典键
        /// </summary>
        /// <value></value>
        public string Key { get; set; }

        /// <summary>
        /// 居民编码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }
    }

    /// <summary>
    /// 根据字典键获取随访居民分页
    /// </summary>
    public class GetFollowUpPatientPageByKeyRequest : PageRequest
    {

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;

        /// <summary>
        /// 字典键
        /// </summary>
        /// <value></value>
        public string Key { get; set; }

        /// <summary>
        /// 随访状态
        /// </summary>
        /// <value></value>
        public FollowUpStateEnum? FollowUpState { get; set; } = null;
    }

    /// <summary>
    /// 查询随访分页请求
    /// </summary>
    public class FollowUpPageRequest : PageRequest
    {

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;
    }

    /// <summary>
    /// 查询居民对应的随访记录信息
    /// </summary>
    public class GetFollowUpRecordListRequest : TokenRequest
    {
        /// <summary>
        /// 查询的随访项目Key
        /// </summary>
        /// <value></value>
        public List<string> Keys { get; set; }

        /// <summary>
        /// 居民编码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }
    }

    /// <summary>
    /// 查询居民对应的随访记录信息（按年）
    /// </summary>
    public class GetFollowUpRecordListByYearRequest : TokenRequest
    {
        /// <summary>
        /// 查询的随访项目Key
        /// </summary>
        /// <value></value>
        public List<string> Keys { get; set; }

        /// <summary>
        /// 居民编码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }

        /// <summary>
        /// 年份
        /// </summary>
        /// <value></value>
        public string Year { get; set; }
    }
}