using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Net.Http;
using System.Threading;
using System.Threading.Tasks;

namespace WingInterfaceLibrary.Request.Vital
{
    /// <summary>
    /// 创建标签数据请求
    /// </summary>
    public class CreateLabelRequest : TokenRequest
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
		/// <summary>
		/// 标签名称
		/// </summary>
		/// <value></value>
		public string LabelName { get; set; }
		/// <summary>
		/// 组织代码
		/// </summary>
		/// <value></value>
		public string OrganizationCode { get; set; }
		/// <summary>
		/// 标签类型键
		/// </summary>
		/// <value></value>
		public string LabelTypeKey { get; set; }


    }

    /// <summary>
    /// 根据编码获取标签数据请求
    /// </summary>
    public class GetLabelRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取标签数据请求
    /// </summary>
    public class GetLabelByKeyRequest : TokenRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除标签数据请求
    /// </summary>
    public class RemoveLabelRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 获取标签数据列表请求
    /// </summary>
    public class GetLabelListRequest : TokenRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 更新标签数据请求
    /// </summary>
    public class UpdateLabelRequest : TokenRequest
    {
        public string Code { get; set; }
		/// <summary>
		/// 标签名称
		/// </summary>
		/// <value></value>
		public string LabelName { get; set; }
		/// <summary>
		/// 组织代码
		/// </summary>
		/// <value></value>
		public string OrganizationCode { get; set; }
		/// <summary>
		/// 标签类型键
		/// </summary>
		/// <value></value>
		public string LabelTypeKey { get; set; }

    }

    /// <summary>
    /// 通过字典键获取动态类型列表
    /// </summary>
    public class GetLabelListByKeyRequest : TokenRequest
    {
        /// <summary>
        /// 字典键
        /// </summary>
        /// <value></value>
        public string Key { get; set; }
    }

    /// <summary>
    /// 获取人员分类集合请求
    /// </summary>
    public class GetCrowdLabelsRequest : TokenRequest
    {
    }

    
    /// <summary>
    /// 查询标签分页请求
    /// </summary>
    public class LabelPageRequest : PageRequest
    {

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;
    }
}