using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Net.Http;
using System.Threading;
using System.Threading.Tasks;
using WingInterfaceLibrary.Enum.NotificationEnum;

namespace WingInterfaceLibrary.Request.Vital
{
    /// <summary>
    /// 创建数据请求
    /// </summary>
    public class CreateNotificationRequest : TokenRequest
    {
		public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
		/// <summary>
		/// 版本
		/// </summary>
		/// <value></value>
		public string Version { get; set; }
		/// <summary>
		/// 适用设备
		/// </summary>
		/// <value></value>
		public List<string> ApplicableEquipment { get; set; }
		/// <summary>
		/// 内容
		/// </summary>
		/// <value></value>
		public string NotificationContent { get; set; }
		/// <summary>
		/// 类型
		/// </summary>
		/// <value></value>
		public NotificationTypeEnum NotificationType { get; set; }


    }

    /// <summary>
    /// 根据编码获取数据请求
    /// </summary>
    public class GetNotificationRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 查询分页请求
    /// </summary>
    public class NotificationPageRequest : PageRequest
    {

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;
		
		/// <summary>
		/// 最后一个接受到的通知的序号
		/// </summary>
		/// <value></value>
		public long LastNotificationNo { get; set; }
		/// <summary>
		/// 版本
		/// </summary>
		/// <value></value>
		public string Version { get; set; } = "0.0.0.0";
		/// <summary>
		/// 适用设备
		/// </summary>
		/// <value></value>
		public List<string> ApplicableEquipment { get; set; }
		/// <summary>
		/// 类型
		/// </summary>
		/// <value></value>
		public NotificationTypeEnum? NotificationType { get; set; }
    }
}