using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Net.Http;
using System.Threading;
using System.Threading.Tasks;

namespace WingInterfaceLibrary.Request.Vital
{
    /// <summary>
    /// 创建操作日志数据请求
    /// </summary>
    public class CreateOperationLogRequest : TokenRequest
    {
		/// <summary>
		/// 操作
		/// </summary>
		/// <value></value>
		public string Operation { get; set; }
		/// <summary>
		/// 操作时间
		/// </summary>
		/// <value></value>
		public DateTime OperationTime { get; set; }
		/// <summary>
		/// 操作类型
		/// </summary>
		/// <value></value>
		public int OperationType { get; set; }


    }

    /// <summary>
    /// 根据编码获取操作日志数据请求
    /// </summary>
    public class GetOperationLogRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取操作日志数据请求
    /// </summary>
    public class GetOperationLogByKeyRequest : TokenRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除操作日志数据请求
    /// </summary>
    public class RemoveOperationLogRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 获取操作日志数据列表请求
    /// </summary>
    public class GetOperationLogListRequest : TokenRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 更新操作日志数据请求
    /// </summary>
    public class UpdateOperationLogRequest : TokenRequest
    {
        public string Code { get; set; }
		/// <summary>
		/// 操作
		/// </summary>
		/// <value></value>
		public string Operation { get; set; }
		/// <summary>
		/// 操作时间
		/// </summary>
		/// <value></value>
		public DateTime OperationTime { get; set; }
		/// <summary>
		/// 操作类型
		/// </summary>
		/// <value></value>
		public int OperationType { get; set; }

    }

    /// <summary>
    /// 查询操作日志分页请求
    /// </summary>
    public class OperationLogPageRequest : PageRequest
    {

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;
    }
}