using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum.VitalEnum;

namespace WingInterfaceLibrary.Request.Vital
{
    /// <summary>
    /// 创建组织数据请求
    /// </summary>
    public class CreateOrganizationRequest : TokenRequest
	{
		public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
		/// <summary>
		/// 省份代码
		/// </summary>
		/// <value></value>
		public string ProvinceCode { get; set; }
		/// <summary>
		/// 城市代码
		/// </summary>
		/// <value></value>
		public string CityCode { get; set; }
		/// <summary>
		/// 区域代码
		/// </summary>
		/// <value></value>
		public string DistrictCode { get; set; }
		/// <summary>
		/// 乡镇代码
		/// </summary>
		/// <value></value>
		public string TownCode { get; set; }
		/// <summary>
		/// 村/小区代码
		/// </summary>
		/// <value></value>
		public string ResidenceCode { get; set; }
		/// <summary>
		/// 组织名称
		/// </summary>
		/// <value></value>
		public string OrganizationName { get; set; }
		/// <summary>
		/// 联系方式号码
		/// </summary>
		/// <value></value>
		public string ContactNumber { get; set; }
		/// <summary>
		/// logoURL
		/// </summary>
		/// <value></value>
		public string LogoUrl { get; set; }
		/// <summary>
		/// 地址
		/// </summary>
		/// <value></value>
		public string Address { get; set; }

		/// <summary>
		/// 父级机构
		/// </summary>
		/// <value></value>
		public string FatherCode { get; set; }

		/// <summary>
        /// 权限编码集合
        /// </summary>
        public List<string> FeatureCodes { get; set; }
		
		/// <summary>
		/// 顾客类型
		/// </summary>
		/// <value></value>
		public CustomTypeEnum CustomType { get; set; }

		/// <summary>
        /// 可使用的设备Key集合
        /// </summary>
        public List<string> PeripheralDeviceKeys { get; set; }

		/// <summary>
		/// 动态参数配置
		/// </summary>
		/// <value></value>
		public string DynamicParameter { get; set; }

        /// <summary>
        /// 体检地区码（3位）
        /// </summary>
        /// <value></value>
        public string OrganizationUniqueCode { get; set; }

        /// <summary>
        /// 体检项目集合
        /// </summary>
        /// <value></value>
        public List<string> ExamItemCodes { get; set; }

        /// <summary>
        /// 超声医师电子签名
        /// </summary>
        /// <value></value>
        public string UltrasonicSignature { get; set; }

        /// <summary>
        /// 尿常规检测医师电子签名
        /// </summary>
        /// <value></value>
        public string UrinalysisSignature { get; set; }
        
        /// <summary>
        /// 生化解析模板
        /// </summary>
        /// <value></value>
        public string BiochemicalTemplateKey { get; set; }
        
        /// <summary>
        /// 血常规解析模板
        /// </summary>
        /// <value></value>
        public string BloodRoutineTemplateKey { get; set; }
        
        /// <summary>
        /// 是否自动创建报告
        /// </summary>
        /// <value></value>
        public bool IsAutoCreateReport { get; set; }
	}

	/// <summary>
	/// 根据编码获取组织数据请求
	/// </summary>
	public class GetOrganizationRequest : TokenRequest
	{
		public string Code { get; set; }
	}

	/// <summary>
	/// 根据关键字段获取组织数据请求
	/// </summary>
	public class GetOrganizationByKeyRequest : TokenRequest
	{
		public string Key { get; set; }
		public string Value { get; set; }
	}

	/// <summary>
	/// 删除组织数据请求
	/// </summary>
	public class RemoveOrganizationRequest : TokenRequest
	{
		public string Code { get; set; }
	}

	/// <summary>
	/// 获取组织数据列表请求
	/// </summary>
	public class GetOrganizationListRequest : TokenRequest
	{
		public List<string> Codes { get; set; }
	}

	/// <summary>
	/// 更新组织数据请求
	/// </summary>
	public class UpdateOrganizationRequest : TokenRequest
	{
		public string Code { get; set; }
		/// <summary>
		/// 省份代码
		/// </summary>
		/// <value></value>
		public string ProvinceCode { get; set; }
		/// <summary>
		/// 城市代码
		/// </summary>
		/// <value></value>
		public string CityCode { get; set; }
		/// <summary>
		/// 区域代码
		/// </summary>
		/// <value></value>
		public string DistrictCode { get; set; }
		/// <summary>
		/// 乡镇代码
		/// </summary>
		/// <value></value>
		public string TownCode { get; set; }
		/// <summary>
		/// 村/小区代码
		/// </summary>
		/// <value></value>
		public string ResidenceCode { get; set; }
		/// <summary>
		/// 组织名称
		/// </summary>
		/// <value></value>
		public string OrganizationName { get; set; }
		/// <summary>
		/// 联系方式号码
		/// </summary>
		/// <value></value>
		public string ContactNumber { get; set; }
		/// <summary>
		/// logoURL
		/// </summary>
		/// <value></value>
		public string LogoUrl { get; set; }
		/// <summary>
		/// 地址
		/// </summary>
		/// <value></value>
		public string Address { get; set; }

		/// <summary>
		/// 父级机构
		/// </summary>
		/// <value></value>
		public string FatherCode { get; set; }

		/// <summary>
        /// 权限编码集合
        /// </summary>
        public List<string> FeatureCodes { get; set; }

		/// <summary>
		/// 顾客类型
		/// </summary>
		/// <value></value>
		public CustomTypeEnum CustomType { get; set; }

		/// <summary>
        /// 可使用的设备Key集合
        /// </summary>
        public List<string> PeripheralDeviceKeys { get; set; }

		/// <summary>
		/// 动态参数配置
		/// </summary>
		/// <value></value>
		public string DynamicParameter { get; set; }

        /// <summary>
        /// 体检地区码（3位）
        /// </summary>
        /// <value></value>
        public string OrganizationUniqueCode { get; set; }

        /// <summary>
        /// 体检项目集合
        /// </summary>
        /// <value></value>
        public List<string> ExamItemCodes { get; set; }

        /// <summary>
        /// 超声医师电子签名
        /// </summary>
        /// <value></value>
        public string UltrasonicSignature { get; set; }

        /// <summary>
        /// 尿常规检测医师电子签名
        /// </summary>
        /// <value></value>
        public string UrinalysisSignature { get; set; }
        
        /// <summary>
        /// 生化解析模板
        /// </summary>
        /// <value></value>
        public string BiochemicalTemplateKey { get; set; }
        
        /// <summary>
        /// 血常规解析模板
        /// </summary>
        /// <value></value>
        public string BloodRoutineTemplateKey { get; set; }
        
        /// <summary>
        /// 是否自动创建报告
        /// </summary>
        /// <value></value>
        public bool IsAutoCreateReport { get; set; }
	}

	/// <summary>
	/// 查询组织分页请求
	/// </summary>
	public class OrganizationPageRequest : PageRequest
	{

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;
	}

	public class GetOrganizationTreeRequest : TokenRequest
	{

	}

	public class GetEnableDeviceKeysRequest : TokenRequest
	{
		/// <summary>
		/// 组织代码
		/// </summary>
		/// <value></value>
		public string OrganizationCode { get; set; }
	}

	
	public class GetDynamicParameterRequest : TokenRequest
	{
		/// <summary>
		/// 组织代码
		/// </summary>
		/// <value></value>
		public string OrganizationCode { get; set; }
	}
}