using System;
using System.Collections.Generic;

namespace WingInterfaceLibrary.Request.Vital
{
    /// <summary>
    /// 创建居民扩展信息数据请求
    /// </summary>
    public class CreatePatientExtensionRequest : TokenRequest
    {
		/// <summary>
		/// 居民代码
		/// </summary>
		/// <value></value>
		public string PatientCode { get; set; }
		/// <summary>
		/// 键
		/// </summary>
		/// <value></value>
		public string Key { get; set; }
		/// <summary>
		/// 扩展数据
		/// </summary>
		/// <value></value>
		public string ExtensionData { get; set; }


    }

    /// <summary>
    /// 根据编码获取居民扩展信息数据请求
    /// </summary>
    public class GetPatientExtensionRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据编码和Key获取居民扩展信息数据请求
    /// </summary>
    public class GetPatientExtensionByCodeAndKeyRequest : TokenRequest
    {
        /// <summary>
        /// 字典值
        /// </summary>
        /// <value></value>
        public string Key { get; set; }

        /// <summary>
        /// 居民编码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }
    }

    /// <summary>
    /// 删除居民扩展信息数据请求
    /// </summary>
    public class RemovePatientExtensionRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 获取居民扩展信息数据列表请求
    /// </summary>
    public class GetPatientExtensionListRequest : TokenRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 更新居民扩展信息数据请求
    /// </summary>
    public class UpdatePatientExtensionRequest : TokenRequest
    {
        public string Code { get; set; }
		/// <summary>
		/// 居民代码
		/// </summary>
		/// <value></value>
		public string PatientCode { get; set; }
		/// <summary>
		/// 键
		/// </summary>
		/// <value></value>
		public string Key { get; set; }
		/// <summary>
		/// 扩展数据
		/// </summary>
		/// <value></value>
		public string ExtensionData { get; set; }

    }

    /// <summary>
    /// 查询居民扩展信息分页请求
    /// </summary>
    public class PatientExtensionPageRequest : PageRequest
    {

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;
    }
}