using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum.VitalEnum;

namespace WingInterfaceLibrary.Request.Vital
{
    /// <summary>
    /// 创建居民数据请求
    /// </summary>
    public class CreatePatientRequest : TokenRequest
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
        /// <summary>
        /// 居民名称
        /// </summary>
        /// <value></value>
        public string PatientName { get; set; }
        /// <summary>
        /// 电话
        /// </summary>
        /// <value></value>
        public string Phone { get; set; }

        /// <summary>
        /// 联系人姓名
        /// </summary>
        /// <value></value>
        public string EmergencyName { get; set; }

        /// <summary>
        /// 紧急联系人手机号
        /// </summary>
        public string EmergencyPhone { get; set; }
        /// <summary>
        /// 证件编号
        /// </summary>
        /// <value></value>
        public string CardNo { get; set; }
        /// <summary>
        /// 民族
        /// </summary>
        /// <value></value>
        public string Nationality { get; set; }
        /// <summary>
        /// 生日
        /// </summary>
        /// <value></value>
        public DateTime Birthday { get; set; }
        /// <summary>
        /// 人群标签
        /// </summary>
        /// <value></value>
        public List<string> CrowdLabels { get; set; }
        /// <summary>
        /// 卡片类型
        /// </summary>
        /// <value></value>
        public CardTypeEnum CardType { get; set; }
        /// <summary>
        /// 居民性别
        /// </summary>
        /// <value></value>
        public GenderEnum PatientGender { get; set; }
        /// <summary>
        /// 居民地址
        /// </summary>
        /// <value></value>
        public string PatientAddress { get; set; }
        /// <summary>
        /// 永久村/小区地址
        /// </summary>
        /// <value></value>
        public string PermanentResidenceAddress { get; set; }
        /// <summary>
        /// 团队区域代码
        /// </summary>
        /// <value></value>
        public string TeamRegionCode { get; set; }
        /// <summary>
        /// 已签约医生
        /// </summary>
        /// <value></value>
        public string ContractedDoctor { get; set; }
    }

    /// <summary>
    /// 根据编码获取居民数据请求
    /// </summary>
    public class GetPatientRequest : TokenRequest
    {
        public string Code { get; set; }

        /// <summary>
        /// 是否根据操作医生验证，默认是true
        /// </summary>
        /// <value></value>
        public bool IsValidOperationDoctor { get; set; } = true;
    }

    /// <summary>
    /// 根据关键字段获取居民数据请求
    /// </summary>
    public class GetPatientByKeyRequest : TokenRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除居民数据请求
    /// </summary>
    public class RemovePatientRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 获取居民数据列表请求
    /// </summary>
    public class GetPatientListRequest : TokenRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 更新居民数据请求
    /// </summary>
    public class UpdatePatientRequest : TokenRequest
    {
        public string Code { get; set; }
        /// <summary>
        /// 居民名称
        /// </summary>
        /// <value></value>
        public string PatientName { get; set; } = "-1";
        /// <summary>
        /// 电话
        /// </summary>
        /// <value></value>
        public string Phone { get; set; } = "-1";

        /// <summary>
        /// 联系人姓名
        /// </summary>
        /// <value></value>
        public string EmergencyName { get; set; } = "-1";

        /// <summary>
        /// 紧急联系人手机号
        /// </summary>
        public string EmergencyPhone { get; set; } = "-1";
        /// <summary>
        /// 证件编号
        /// </summary>
        /// <value></value>
        public string CardNo { get; set; } = "-1";
        /// <summary>
        /// 民族
        /// </summary>
        /// <value></value>
        public string Nationality { get; set; } = "-1";
        /// <summary>
        /// 生日
        /// </summary>
        /// <value></value>
        public DateTime? Birthday { get; set; } = null;
        /// <summary>
        /// 人群标签
        /// </summary>
        /// <value></value>
        public List<string> CrowdLabels { get; set; } = null;
        /// <summary>
        /// 卡片类型
        /// </summary>
        /// <value></value>
        public CardTypeEnum? CardType { get; set; } = null;
        /// <summary>
        /// 居民性别
        /// </summary>
        /// <value></value>
        public GenderEnum? PatientGender { get; set; } = null;
        /// <summary>
        /// 居民地址
        /// </summary>
        /// <value></value>
        public string PatientAddress { get; set; } = "-1";
        /// <summary>
        /// 永久村/小区地址
        /// </summary>
        /// <value></value>
        public string PermanentResidenceAddress { get; set; } = "-1";
        /// <summary>
        /// 团队区域代码
        /// </summary>
        /// <value></value>
        public string TeamRegionCode { get; set; } = "-1";
        /// <summary>
        /// 已签约医生
        /// </summary>
        /// <value></value>
        public string ContractedDoctor { get; set; } = "-1";
    }

    /// <summary>
    /// 设置人群请求
    /// </summary>
    public class SetCrowdLabelsRequest : TokenRequest
    {
        public string Code { get; set; }
        /// <summary>
        /// 人群标签
        /// </summary>
        /// <value></value>
        public List<string> CrowdLabels { get; set; } = null;
    }

    /// <summary>
    /// 查询居民分页请求
    /// </summary>
    public class PatientPageRequest : PageRequest
    {
        /// <summary>
        /// 人群标签
        /// </summary>
        /// <value></value>
        public List<string> CrowdLabels { get; set; }

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;

        /// <summary>
		/// 仅查询建档人是自己的
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public bool CreatedBySelf { get; set; }

        /// <summary>
        /// 签约状态
        /// </summary>
        /// <value></value>
        public ContractStateEnum? ContractState { get; set; }
    }

    /// <summary>
    /// 提交居民照片请求
    /// </summary>
    public class UpdatePatientPhotosRequest : TokenRequest
    {
        public string Code { get; set; }
        /// <summary>
        /// 照片
        /// </summary>
        /// <value></value>
        public List<string> Photos { get; set; } = null;
    }

    /// <summary>
    /// 根据身份证图片获取居民基本信息
    /// </summary>
    public class GetPatientBaseByImageRequest : TokenRequest
    {
        /// <summary>
        /// 图片
        /// </summary>
        /// <value></value>
        public string Image { get; set; }
    }

    /// <summary>
    /// 根据身份证图片获取居民基本信息
    /// </summary>
    public class GetPatientBaseByFaceImageRequest : TokenRequest
    {
        /// <summary>
        /// 图片
        /// </summary>
        /// <value></value>
        public string Image { get; set; }
    }

    /// <summary>
    /// 根据身份证图片获取居民基本信息
    /// </summary>
    public class SavePatientBaseByFaceImageRequest : TokenRequest
    {
        /// <summary>
        /// 证件号
        /// </summary>
        /// <value></value>
        public string CardNo { get; set; }

        /// <summary>
        /// 图片
        /// </summary>
        /// <value></value>
        public string Image { get; set; }
    }

    /// <summary>
    /// 根据身份证图片获取居民基本信息
    /// </summary>
    public class SavePatientBaseByFaceImageLocalRequest : TokenRequest
    {
        /// <summary>
        /// 证件号
        /// </summary>
        /// <value></value>
        public string PersonId { get; set; }

        /// <summary>
        /// 人脸特征数据
        /// </summary>
        /// <value></value>
        public string Data { get; set; }

        /// <summary>
        /// 人脸特征大小
        /// </summary>
        /// <value></value>
        public int Size { get; set; }

        /// <summary>
        /// 人脸特征模型版本
        /// </summary>
        /// <value></value>
        public string IdRegModelVersion { get; set; }

        /// <summary>
        /// 人脸图片
        /// </summary>
        /// <value></value>
        public string ImagePath { get; set; }
    }

    /// <summary>
    /// 删除人员信息并重新绑定请求
    /// </summary>
    public class UnbindAndCreateByFaceImageRequest : TokenRequest
    {
        /// <summary>
        /// 原绑定的身份证号
        /// </summary>
        /// <value></value>
        public string OldCardNo { get; set; }

        /// <summary>
        /// 新绑定的身份证号
        /// </summary>
        /// <value></value>
        public string NewCardNo { get; set; }

        /// <summary>
        /// 人脸图片
        /// </summary>
        /// <value></value>
        public string Image { get; set; }
    }

    /// <summary>
    /// 删除人员信息请求
    /// </summary>
    public class UnbindByCardNoRequest : TokenRequest
    {
        /// <summary>
        /// 绑定的身份证号
        /// </summary>
        /// <value></value>
        public string CardNo { get; set; }
    }

    /// <summary>
    /// 获取居民档案统计信息请求
    /// </summary>
    public class GetPatientStatisticRequest : TokenRequest
    {
        /// <summary>
        /// 人群标签
        /// </summary>
        /// <value></value>
        public List<string> CrowdLabels { get; set; }

        /// <summary>
		/// 仅查询建档人是自己的
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public bool CreatedBySelf { get; set; }

        /// <summary>
        /// 签约状态
        /// </summary>
        /// <value></value>
        public ContractStateEnum? ContractState { get; set; }
    }

    /// <summary>
    /// 获取人员信息列表请求
    /// </summary>
    public class GetPersonListRequest : TokenRequest
    {
        /// <summary>
        /// 返回数量
        /// </summary>
        /// <value></value>
        public int PageIndex { get; set; } = 1;

        /// <summary>
        /// 返回数量
        /// </summary>
        /// <value></value>
        public int PageSize { get; set; } = 100000;

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value></value>
        public DateTime StartTime { get; set; }
    }
}