using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Net.Http;
using System.Threading;
using System.Threading.Tasks;
using WingInterfaceLibrary.Enum.VitalEnum;
using WingInterfaceLibrary.Request.DBVitalRequest;

namespace WingInterfaceLibrary.Request.Vital
{
    /// <summary>
    /// 创建处方数据请求
    /// </summary>
    public class CreatePrescriptionRequest : TokenRequest
    {
		public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
		/// <summary>
		/// 键
		/// </summary>
		/// <value></value>
		public string Key { get; set; }
		/// <summary>
		/// 居民代码
		/// </summary>
		/// <value></value>
		public string PatientCode { get; set; }

        /// <summary>
        /// 体检号
        /// </summary>
        public string PhysicalExamNumber { get; set; }

        /// <summary>
        /// 随访编码
        /// </summary>
        public string FollowUpCode { get; set; }

        /// <summary>
        /// 处方信息
        /// </summary>
        /// <value></value>
        public string PrescriptionData { get; set; }
    }

    /// <summary>
    /// 根据编码获取处方数据请求
    /// </summary>
    public class GetPrescriptionRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据随访编码和居民编码获取处方数据请求
    /// </summary>
    public class GetPrescriptionDetailByFollowAnPatientRequest : TokenRequest
    {
        /// <summary>
        /// 随访编码
        /// </summary>
        /// <value></value>
        public string FollowUpCode { get; set; }

        /// <summary>
        /// 随访编码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取处方数据请求
    /// </summary>
    public class GetPrescriptionByKeyRequest : TokenRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除处方数据请求
    /// </summary>
    public class RemovePrescriptionRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 获取处方数据列表请求
    /// </summary>
    public class GetPrescriptionListRequest : TokenRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 更新处方数据请求
    /// </summary>
    public class UpdatePrescriptionRequest : TokenRequest
    {
        public string Code { get; set; }

		/// <summary>
		/// 键
		/// </summary>
		/// <value></value>
		public string Key { get; set; } = "-1";

		/// <summary>
		/// 居民代码
		/// </summary>
		/// <value></value>
		public string PatientCode { get; set; } = "-1";

		/// <summary>
		/// 处方数据
		/// </summary>
		/// <value></value>
		public string PrescriptionData { get; set; } = "-1";

        /// <summary>
        /// 体检号(健康体检专用)
        /// </summary>
        public string PhysicalExamNumber { get; set; }

        /// <summary>
        /// 随访编码
        /// </summary>
        public string FollowUpCode { get; set; }
    }

    /// <summary>
    /// 查询处方分页请求
    /// </summary>
    public class PrescriptionPageRequest : PageRequest
    {
		/// <summary>
		/// 居民代码
		/// </summary>
		/// <value></value>
		public string PatientCode { get; set; }

        /// <summary>
        /// 体检号
        /// </summary>
        public string PhysicalExamNumber { get; set; }

        /// <summary>
        /// 随访编码
        /// </summary>
        public string FollowUpCode { get; set; }

        /// <summary>
		/// 键
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Key { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;
    }

	/// <summary>
    /// 多条件获取处方数据请求
    /// </summary>
    public class GetPrescriptionConditionRequest
	{
		/// <summary>
        /// 检查项列表
        /// </summary>
		public List<string> ExamCodes { get; set; }

        /// <summary>
        /// 体检号(健康体检专用)
        /// </summary>
        public string PhysicalExamNumber { get; set; }

        /// <summary>
        /// 随访编码
        /// </summary>
        public string FollowUpCode { get; set; }

        /// <summary>
        /// Key
        /// </summary>
		public string Key { get; set; }
	}
}