using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Net.Http;
using System.Threading;
using System.Threading.Tasks;
using WingInterfaceLibrary.Enum.VitalEnum;
using WingInterfaceLibrary.Request.DBVitalRequest;

namespace WingInterfaceLibrary.Request.Vital
{
    /// <summary>
    /// 创建报告数据请求
    /// </summary>
    public class CreateReportRequest : TokenRequest
    {
		public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
		/// <summary>
		/// 键
		/// </summary>
		/// <value></value>
		public string Key { get; set; }
		/// <summary>
		/// 居民代码
		/// </summary>
		/// <value></value>
		public string PatientCode { get; set; }
		/// <summary>
		/// 已签约医生
		/// </summary>
		/// <value></value>
		public string ContractedDoctor { get; set; }
		/// <summary>
		/// 报告数据
		/// </summary>
		/// <value></value>
		public string ReportDataJson { get; set; }
		/// <summary>
		/// 报告状态
		/// </summary>
		/// <value></value>
		public ReportStateEnum ReportState { get; set; }
		/// <summary>
		/// 模板代码
		/// </summary>
		/// <value></value>
		public string TemplateCode { get; set; }

        /// <summary>
        /// 体检号(健康体检专用)
        /// </summary>
        public string PhysicalExamNumber { get; set; }

        /// <summary>
        /// 检查code
        /// </summary>
        public string ExamCode { get; set; }

        /// <summary>
        /// 报告信息列表
        /// </summary>
        /// <value></value>
        public IList<PreviewDTO> PreviewList { get; set; }    

        /// <summary>
        /// 体检信息
        /// </summary>
        /// <value></value>
        public Dictionary<string,string> ReportData { get; set; }
    }

    /// <summary>
    /// 根据编码获取报告数据请求
    /// </summary>
    public class GetReportRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取报告数据请求
    /// </summary>
    public class GetReportByKeyRequest : TokenRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除报告数据请求
    /// </summary>
    public class RemoveReportRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 获取报告数据列表请求
    /// </summary>
    public class GetReportListRequest : TokenRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 更新报告数据请求
    /// </summary>
    public class UpdateReportRequest : TokenRequest
    {
        public string Code { get; set; }
		/// <summary>
		/// 键
		/// </summary>
		/// <value></value>
		public string Key { get; set; } = "-1";
		/// <summary>
		/// 居民代码
		/// </summary>
		/// <value></value>
		public string PatientCode { get; set; } = "-1";
		/// <summary>
		/// 已签约医生
		/// </summary>
		/// <value></value>
		public string ContractedDoctor { get; set; } = "-1";
		/// <summary>
		/// 报告数据
		/// </summary>
		/// <value></value>
		public string ReportDataJson { get; set; } = "-1";
        /// <summary>
		/// 模板
		/// </summary>
		/// <value></value>
        public string ReportTemplateJson { get; set; } = "-1";
		/// <summary>
		/// 报告状态
		/// </summary>
		/// <value></value>
		public ReportStateEnum? ReportState { get; set; } = null;
		/// <summary>
		/// 模板代码
		/// </summary>
		/// <value></value>
		public string TemplateCode { get; set; } = "-1";

        /// <summary>
        /// 体检号(健康体检专用)
        /// </summary>
        public string PhysicalExamNumber { get; set; }

        /// <summary>
        /// 检查code
        /// </summary>
        public string ExamCode { get; set; }

        /// <summary>
        /// 报告信息列表
        /// </summary>
        /// <value></value>
        public IList<PreviewDTO> PreviewList { get; set; }    

        /// <summary>
        /// 体检信息
        /// </summary>
        /// <value></value>
        public Dictionary<string,string> ReportData { get; set; }
    }

    /// <summary>
    /// 查询报告分页请求
    /// </summary>
    public class ReportPageRequest : PageRequest
    {

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;
    }

	/// <summary>
    /// 多条件获取报告数据请求
    /// </summary>
    public class GetReportConditionRequest
	{
		/// <summary>
        /// 检查项列表
        /// </summary>
		public List<string> ExamCodes { get; set; }

        /// <summary>
        /// 体检号(健康体检专用)
        /// </summary>
        public string PhysicalExamNumber { get; set; }

        /// <summary>
        /// Key
        /// </summary>
		public string Key { get; set; }
	}
}