using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Net.Http;
using System.Threading;
using System.Threading.Tasks;

namespace WingInterfaceLibrary.Request.Vital
{
    /// <summary>
    /// 创建居住数据请求
    /// </summary>
    public class CreateResidenceRequest : TokenRequest
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
		/// <summary>
		/// 城镇代码
		/// </summary>
		/// <value></value>
		public string TownCode { get; set; }
		/// <summary>
		/// 名称
		/// </summary>
		/// <value></value>
		public string Name { get; set; }


    }

    /// <summary>
    /// 根据编码获取居住数据请求
    /// </summary>
    public class GetResidenceRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取居住数据请求
    /// </summary>
    public class GetResidenceByKeyRequest : TokenRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除居住数据请求
    /// </summary>
    public class RemoveResidenceRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 获取居住数据列表请求
    /// </summary>
    public class GetResidenceListRequest : TokenRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 更新居住数据请求
    /// </summary>
    public class UpdateResidenceRequest : TokenRequest
    {
        public string Code { get; set; }
		/// <summary>
		/// 城镇代码
		/// </summary>
		/// <value></value>
		public string TownCode { get; set; }
		/// <summary>
		/// 名称
		/// </summary>
		/// <value></value>
		public string Name { get; set; }

    }

    /// <summary>
    /// 根据乡镇编码获取存、小区列表
    /// </summary>
    public class GetResidencePageByTownRequest:PageRequest
    {

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;

        /// <summary>
        /// 乡镇编码
        /// </summary>
        /// <value></value>
        public string TownCode { get; set; }
    }

    /// <summary>
    /// 查询村/小区分页请求
    /// </summary>
    public class ResidencePageRequest : PageRequest
    {

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;
    }
}