using System;
using System.Collections.Generic;

namespace WingInterfaceLibrary.Request.Vital
{
    /// <summary>
    /// 创建角色数据请求
    /// </summary>
    public class CreateRoleRequest : TokenRequest
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
		/// <summary>
		/// 角色名称
		/// </summary>
		/// <value></value>
		public string RoleName { get; set; }
		/// <summary>
		/// 功能代码
		/// </summary>
		/// <value></value>
		public List<string> FeatureCodes { get; set; }
		/// <summary>
		/// 描述
		/// </summary>
		/// <value></value>
		public string Description { get; set; }


    }

    /// <summary>
    /// 根据编码获取角色数据请求
    /// </summary>
    public class GetRoleRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取角色数据请求
    /// </summary>
    public class GetRoleByKeyRequest : TokenRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除角色数据请求
    /// </summary>
    public class RemoveRoleRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 获取角色数据列表请求
    /// </summary>
    public class GetRoleListRequest : TokenRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 更新角色数据请求
    /// </summary>
    public class UpdateRoleRequest : TokenRequest
    {
        public string Code { get; set; }
		/// <summary>
		/// 角色名称
		/// </summary>
		/// <value></value>
		public string RoleName { get; set; }
		/// <summary>
		/// 功能代码
		/// </summary>
		/// <value></value>
		public List<string> FeatureCodes { get; set; }
		/// <summary>
		/// 描述
		/// </summary>
		/// <value></value>
		public string Description { get; set; }

    }

    /// <summary>
    /// 查询角色分页请求
    /// </summary>
    public class RolePageRequest : PageRequest
    {

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;
    }
}