using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Net.Http;
using System.Threading;
using System.Threading.Tasks;
using WingInterfaceLibrary.Enum.VitalEnum;

namespace WingInterfaceLibrary.Request.Vital
{
    /// <summary>
    /// 创建服务包请求
    /// </summary>
    public class CreateServicePackRequest : TokenRequest
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
        /// <summary>
        /// 服务包名称
        /// </summary>     
        /// <value>基础服务包</value>
        public string Name { get; set; }

        /// <summary>
        /// 服务包类型
        /// </summary>
        /// <value>0</value>
        public ServicePackTypeEnum ServicePackType { get; set; }

        /// <summary>
        /// 服务包内容
        /// </summary>
        /// <value>一年两次体检</value>
        public string Content { get; set; }

        /// <summary>
        /// 服务机构编码
        /// </summary>
        public string OrganizationCode { get; set; }

    }

    /// <summary>
    /// 获取服务包详细信息
    /// </summary>
    public class GetServicePackRequest : TokenRequest
    {
        /// <summary>
        /// 服务包编码
        /// </summary>
        /// <value>0001</value>
        public string Code { get; set; }
    }

    /// <summary>
    /// 删除服务包
    /// </summary>
    public class RemovetServicePackRequest : TokenRequest
    {
        /// <summary>
        /// 服务包编码
        /// </summary>
        /// <value>0001</value>
        public string Code { get; set; }
    }

    /// <summary>
    /// 更新服务包
    /// </summary>
    public class UpdateServicePackRequest : TokenRequest
    {
        /// <summary>
        /// 服务编码
        /// </summary>
        /// <value>0001</value>
        public string Code { get; set; }

        /// <summary>
        /// 服务包名称
        /// </summary>
        /// <value>基础服务包</value>
        public string Name { get; set; }

        /// <summary>
        /// 服务包类型
        /// </summary>
        /// <value>0</value>
        public ServicePackTypeEnum ServicePackType { get; set; }

        /// <summary>
        /// 服务包内容
        /// </summary>
        /// <value>一年三次体检</value>
        public string Content { get; set; }

        /// <summary>
        /// 服务机构编码
        /// </summary>
        public string OrganizationCode { get; set; }
    }

    /// <summary>
    /// 更新服务包内服务项
    /// </summary>
    public class UpdateServicePackForItemsRequest : TokenRequest
    {
        /// <summary>
        /// 服务包编码
        /// </summary>
        ///  <value>0001</value>
        public string Code { get; set; }

        /// <summary>
        /// 服务项Id集合
        /// </summary>
        /// <value>00001,000002</value>
        public List<string> Items { get; set; }
    }
    /// <summary>
    /// 创建服务项请求
    /// </summary>
    public class CreateServiceItemRequest : TokenRequest
    {

        /// <summary>
        /// 名称
        /// </summary>
        /// <value>高血压服务项</value>
        public string Name { get; set; }

        /// <summary>
        /// 服务项内容
        /// </summary>
        /// <value>高血压服务测量</value>
        public string Content { get; set; }

        /// <summary>
        /// 服务项类型
        /// </summary>
        /// <value>0</value>
        public ServiceItemTypeEnum ServiceItemType { get; set; }

        /// <summary>
        /// 服务次数
        /// </summary>
        /// <value>1</value>
        public string ServiceNumber { get; set; }
        /// <summary>
        /// 服务科室
        /// </summary>
        /// <value>卫生科室</value>
        public string Department { get; set; }

        /// <summary>
        /// 指导价格
        /// </summary>
        ///  <value>100</value>
        public string GuidancePrice { get; set; }

        /// <summary>
        /// 拟调价格
        /// </summary>
        ///  <value>100</value>
        public string AdjustedPrice { get; set; }

        /// <summary>
        /// 总价格
        /// </summary>
        ///  <value>100</value>
        public string TotalPrice { get; set; }

        /// <summary>
        /// 收费标准说明
        /// </summary>
        ///  <value>符合国家收费标准一年</value>
        public string PriceExplanation { get; set; }

        /// <summary>
        /// 服务机构编码
        /// </summary>
        public string OrganizationCode { get; set; }
    }

    /// <summary>
    /// 获取服务项详细信息请求
    /// </summary>
    public class GetServiceItemRequest : TokenRequest
    {
        /// <summary>
        /// 服务项编码
        /// </summary>
        /// <value>00001</value>
        public string Code { get; set; }
    }

    /// <summary>
    /// 获取服务项目分页查询请求
    /// </summary>
    public class GetServiceItemPageRequest : PageRequest
    {

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;
        
        /// <summary>
        /// 服务项编码
        /// </summary>
        /// <value>00001</value>
        public string Code { get; set; }
        
        /// <summary>
        /// 仅查询默认配置
        /// </summary>
        public bool FilterDefaultItems { get; set; }
        
        /// <summary>
        /// 机构编码
        /// </summary>
        /// <value>00001</value>
        public string OrganizationCode { get; set; }
    }

    /// <summary>
    /// 删除服务项请求
    /// </summary>
    public class RemovetServiceItemRequest : TokenRequest
    {
        /// <summary>
        /// 服务项编码
        /// </summary>
        /// <value>00001</value>
        public string Code { get; set; }
    }

    /// <summary>
    /// 更新服务项请求
    /// </summary>
    public class UpdateServiceItemRequest : TokenRequest
    {
        /// <summary>
        /// 服务项编码
        /// </summary>
        /// <value>00001</value>
        public string Code { get; set; }


        /// <summary>
        /// 名称
        /// </summary>
        /// <value>高血压服务项</value>
        public string Name { get; set; }

        /// <summary>
        /// 服务项内容
        /// </summary>
        /// <value>高血压服务测量</value>
        public string Content { get; set; }

        /// <summary>
        /// 服务项类型
        /// </summary>
        /// <value>0</value>
        public ServiceItemTypeEnum ServiceItemType { get; set; }

        /// <summary>
        /// 服务次数
        /// </summary>
        /// <value>1</value>
        public string ServiceNumber { get; set; }

        /// <summary>
        /// 服务科室
        /// </summary>
        /// <value>卫生科室</value>
        public string Department { get; set; }

        /// <summary>
        /// 指导价格
        /// </summary>
        ///  <value>100</value>
        public string GuidancePrice { get; set; }

        /// <summary>
        /// 拟调价格
        /// </summary>
        ///  <value>100</value>
        public string AdjustedPrice { get; set; }

        /// <summary>
        /// 总价格
        /// </summary>
        ///  <value>100</value>
        public string TotalPrice { get; set; }

        /// <summary>
        /// 收费标准说明
        /// </summary>
        ///  <value>符合国家收费标准一年</value>
        public string PriceExplanation { get; set; }

        /// <summary>
        /// 服务机构编码
        /// </summary>
        public string OrganizationCode { get; set; }
    }

    /// <summary>
    /// 更新服务包的标签
    /// </summary>
    public class UpdateServicePackForLabelsRequest : TokenRequest
    {
        /// <summary>
        /// 服务包编码
        /// </summary>
        /// <value>0001</value>
        public string Code { get; set; }

        /// <summary>
        /// 人群标签
        /// </summary>
        ///  <value>00001,00002</value>
        public List<string> Labels { get; set; }
    }


    /// <summary>
    /// 批量服务项请求
    /// </summary>
    public class GetServiceItemListRequest : TokenRequest
    {
        /// <summary>
        /// 服务项编码
        /// </summary>
        ///  <value>00001,00002</value>
        public List<string> Codes { get; set; }
    }
    
    /// <summary>
    /// 查询服务包分页请求
    /// </summary>
    public class ServicePackPageRequest : PageRequest
    {

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;

        /// <summary>
        /// 服务机构编码
        /// </summary>
        public string OrganizationCode { get; set; }

        /// <summary>
        /// 服务包类型
        /// </summary>
        /// <value>0</value>
        public ServicePackTypeEnum? ServicePackType { get; set; }
    }
}
