using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum.VitalEnum;

namespace WingInterfaceLibrary.Request.Vital
{
    /// <summary>
    /// 创建统计数据请求
    /// </summary>
    public class CreateStatisticRequest : TokenRequest
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
		/// <summary>
		/// 统计键
		/// </summary>
		/// <value></value>
		public string StatisticKey { get; set; }
		/// <summary>
		/// 统计类型
		/// </summary>
		/// <value></value>
		public StatisticTypeEnum StatisticType { get; set; }
		/// <summary>
		/// 时间
		/// </summary>
		/// <value></value>
		public string Time { get; set; }
		/// <summary>
		/// 统计数据
		/// </summary>
		/// <value></value>
		public string StatisticData { get; set; }


    }

    /// <summary>
    /// 根据编码获取统计数据请求
    /// </summary>
    public class GetStatisticRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取统计数据请求
    /// </summary>
    public class GetStatisticByKeyRequest : TokenRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除统计数据请求
    /// </summary>
    public class RemoveStatisticRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 获取统计数据列表请求
    /// </summary>
    public class GetStatisticListRequest : TokenRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 更新统计数据请求
    /// </summary>
    public class UpdateStatisticRequest : TokenRequest
    {
        public string Code { get; set; }
		/// <summary>
		/// 统计键
		/// </summary>
		/// <value></value>
		public string StatisticKey { get; set; }
		/// <summary>
		/// 统计类型
		/// </summary>
		/// <value></value>
		public StatisticTypeEnum StatisticType { get; set; }
		/// <summary>
		/// 时间
		/// </summary>
		/// <value></value>
		public string Time { get; set; }
		/// <summary>
		/// 统计数据
		/// </summary>
		/// <value></value>
		public string StatisticData { get; set; }

    }

    /// <summary>
    /// 查询统计分页请求
    /// </summary>
    public class StatisticPageRequest : PageRequest
    {

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;
    }

    /// <summary>
    /// 获取首页统计信息
    /// </summary>
    public class GetHomePageStatisticRequest : TokenRequest
    {

    }
}