using System;
using System.Collections.Generic;

namespace WingInterfaceLibrary.Request.Vital
{
    /// <summary>
    /// 创建系统设置数据请求
    /// </summary>
    public class CreateSystemSettingRequest : TokenRequest
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
		/// <summary>
		/// 设置键
		/// </summary>
		/// <value></value>
		public string SettingKey { get; set; }
		/// <summary>
		/// 设置内容
		/// </summary>
		/// <value></value>
		public string SettingContent { get; set; }


    }

    /// <summary>
    /// 根据编码获取系统设置数据请求
    /// </summary>
    public class GetSystemSettingRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取系统设置数据请求
    /// </summary>
    public class GetSystemSettingByKeyRequest : TokenRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除系统设置数据请求
    /// </summary>
    public class RemoveSystemSettingRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 获取系统设置数据列表请求
    /// </summary>
    public class GetSystemSettingListRequest : TokenRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 更新系统设置数据请求
    /// </summary>
    public class UpdateSystemSettingRequest : TokenRequest
    {
        public string Code { get; set; }
		/// <summary>
		/// 设置键
		/// </summary>
		/// <value></value>
		public string SettingKey { get; set; }
		/// <summary>
		/// 设置内容
		/// </summary>
		/// <value></value>
		public string SettingContent { get; set; }

    }

    /// <summary>
    /// 查询系统设置分页请求
    /// </summary>
    public class SystemSettingPageRequest : PageRequest
    {

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;
    }

    /// <summary>
    /// 需同步的配置
    /// </summary>
    public class SyncSettingRequest : TokenRequest
    {
    }
}