using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Net.Http;
using System.Threading;
using System.Threading.Tasks;

namespace WingInterfaceLibrary.Request.Vital
{
    /// <summary>
    /// 创建团队区域数据请求
    /// </summary>
    public class CreateTeamRegionRequest : TokenRequest
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
		/// <summary>
		/// 团队代码
		/// </summary>
		/// <value></value>
		public string TeamCode { get; set; }
		/// <summary>
		/// 完整名称
		/// </summary>
		/// <value></value>
		public string FullName { get; set; }
		/// <summary>
		/// 区域代码
		/// </summary>
		/// <value></value>
		public string RegionCode { get; set; }


    }

    /// <summary>
    /// 根据编码获取团队区域数据请求
    /// </summary>
    public class GetTeamRegionRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取团队区域数据请求
    /// </summary>
    public class GetTeamRegionByKeyRequest : TokenRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除团队区域数据请求
    /// </summary>
    public class RemoveTeamRegionRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 获取团队区域数据列表请求
    /// </summary>
    public class GetTeamRegionListRequest : TokenRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 更新团队区域数据请求
    /// </summary>
    public class UpdateTeamRegionRequest : TokenRequest
    {
        public string Code { get; set; }
		/// <summary>
		/// 团队代码
		/// </summary>
		/// <value></value>
		public string TeamCode { get; set; }
		/// <summary>
		/// 完整名称
		/// </summary>
		/// <value></value>
		public string FullName { get; set; }
		/// <summary>
		/// 区域代码
		/// </summary>
		/// <value></value>
		public string RegionCode { get; set; }

    }

    /// <summary>
    /// 查询团队区域分页请求
    /// </summary>
    public class TeamRegionPageRequest : PageRequest
    {

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;
    }
}