using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Net.Http;
using System.Threading;
using System.Threading.Tasks;

namespace WingInterfaceLibrary.Request.Vital
{
    /// <summary>
    /// 创建团队数据请求
    /// </summary>
    public class CreateTeamRequest : TokenRequest
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
		/// <summary>
		/// 团队名称
		/// </summary>
		/// <value></value>
		public string TeamName { get; set; }
		/// <summary>
		/// 描述
		/// </summary>
		/// <value></value>
		public string Description { get; set; }
		/// <summary>
		/// 组织代码
		/// </summary>
		/// <value></value>
		public string OrganizationCode { get; set; }
		/// <summary>
		/// 成员
		/// </summary>
		/// <value></value>
		public List<string> Members { get; set; }
        /// <summary>
        /// 负责人
        /// </summary>
        /// <value></value>
        public string Principal { get; set; }

    }

    /// <summary>
    /// 根据编码获取团队数据请求
    /// </summary>
    public class GetTeamRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取团队数据请求
    /// </summary>
    public class GetTeamByKeyRequest : TokenRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除团队数据请求
    /// </summary>
    public class RemoveTeamRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 获取团队数据列表请求
    /// </summary>
    public class GetTeamListRequest : TokenRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 更新团队数据请求
    /// </summary>
    public class UpdateTeamRequest : TokenRequest
    {
        public string Code { get; set; }
		/// <summary>
		/// 团队名称
		/// </summary>
		/// <value></value>
		public string TeamName { get; set; }
		/// <summary>
		/// 描述
		/// </summary>
		/// <value></value>
		public string Description { get; set; }
		/// <summary>
		/// 组织代码
		/// </summary>
		/// <value></value>
		public string OrganizationCode { get; set; }
		/// <summary>
		/// 成员
		/// </summary>
		/// <value></value>
		public List<string> Members { get; set; }
        /// <summary>
        /// 负责人
        /// </summary>
        /// <value></value>
        public string Principal { get; set; }
    }
    
    /// <summary>
    /// 加入团队请求
    /// </summary>
    public class JoinTeamRequest : TokenRequest
    {
        /// <summary>
        /// 用户编码
        /// </summary>
        /// <value></value>
        public List<string> UserCodes { get; set; }

        /// <summary>
        /// 团队编码
        /// </summary>
        /// <value></value>
        public string TeamCode { get; set; }
    }

    /// <summary>
    /// 退出团队请求
    /// </summary>
    public class QuitTeamRequest : TokenRequest
    {
        /// <summary>
        /// 用户编码
        /// </summary>
        /// <value></value>
        public List<string> UserCodes { get; set; }

        /// <summary>
        /// 团队编码
        /// </summary>
        /// <value></value>
        public string TeamCode { get; set; }
    }

    /// <summary>
    /// 根据机构编码获取团队列表
    /// </summary>
    public class GetTeamPageByOrganizationRequest:PageRequest
    {

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;

        /// <summary>
        /// 机构编码
        /// </summary>
        /// <value></value>
        public string OrganizationCode { get; set; }
    }

    /// <summary>
    /// 设置主治医师请求
    /// </summary>
    public class SetTeamPrincipalRequest : TokenRequest
    {
        /// <summary>
        /// 团队编码
        /// </summary>
        /// <value></value>
        public string TeamCode { get; set; }

        /// <summary>
        /// 主治医师
        /// </summary>
        /// <value></value>
        public string Principal { get; set; }
    }

    /// <summary>
    /// 查询团队分页请求
    /// </summary>
    public class TeamPageRequest : PageRequest
    {

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;
    }
}