using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Net.Http;
using System.Threading;
using System.Threading.Tasks;
using WingInterfaceLibrary.Enum.VitalEnum;

namespace WingInterfaceLibrary.Request.Vital
{
    /// <summary>
    /// 创建模板数据请求
    /// </summary>
    public class CreateTemplateRequest : TokenRequest
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
		/// <summary>
		/// 模板名称
		/// </summary>
		/// <value></value>
		public string TemplateName { get; set; }
		/// <summary>
		/// 模板类型
		/// </summary>
		/// <value></value>
		public TemplateTypeEnum TemplateType { get; set; }
		/// <summary>
		/// 键
		/// </summary>
		/// <value></value>
		public string Key { get; set; }
		/// <summary>
		/// 模板内容
		/// </summary>
		/// <value></value>
		public string TemplateContent { get; set; }


    }

    /// <summary>
    /// 根据编码获取模板数据请求
    /// </summary>
    public class GetTemplateRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取模板数据请求
    /// </summary>
    public class GetTemplateByKeyRequest : TokenRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除模板数据请求
    /// </summary>
    public class RemoveTemplateRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 获取模板数据列表请求
    /// </summary>
    public class GetTemplateListRequest : TokenRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 更新模板数据请求
    /// </summary>
    public class UpdateTemplateRequest : TokenRequest
    {
        public string Code { get; set; }
		/// <summary>
		/// 模板名称
		/// </summary>
		/// <value></value>
		public string TemplateName { get; set; }
		/// <summary>
		/// 模板类型
		/// </summary>
		/// <value></value>
		public TemplateTypeEnum TemplateType { get; set; }
		/// <summary>
		/// 键
		/// </summary>
		/// <value></value>
		public string Key { get; set; }
		/// <summary>
		/// 模板内容
		/// </summary>
		/// <value></value>
		public string TemplateContent { get; set; }

    }

    /// <summary>
    /// 根据Key获取最新模板数据请求
    /// </summary>
    public class GetLastOneTemplateByKeyRequest : TokenRequest
    {
        /// <summary>
        /// 字典键
        /// </summary>
        /// <value></value>
        public string Key { get; set; }
    }    

    /// <summary>
    /// 查询模板集合 请求
    /// </summary>
    public class GetTemplateInfosRequest : TokenRequest
    {
        /// <summary>
        /// TemplateCode
        /// </summary>
        /// <value></value>
        public string TemplateCode { get; set; }
        
        /// <summary>
        /// TemplateKey
        /// </summary>
        /// <value></value>
        public string TemplateKey { get; set; }
        
        /// <summary>
        /// TemplateType
        /// </summary>
        /// <value></value>
        public TemplateTypeEnum? TemplateType { get; set; }
    }

    /// <summary>
    /// 查询模板分页请求
    /// </summary>
    public class TemplatePageRequest : PageRequest
    {

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;
    }
}