using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Net.Http;
using System.Threading;
using System.Threading.Tasks;

namespace WingInterfaceLibrary.Request.Vital
{
    /// <summary>
    /// 创建城镇数据请求
    /// </summary>
    public class CreateTownRequest : TokenRequest
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
		/// <summary>
		/// 省份代码
		/// </summary>
		/// <value></value>
		public string ProvinceCode { get; set; }
		/// <summary>
		/// 城市代码
		/// </summary>
		/// <value></value>
		public string CityCode { get; set; }
		/// <summary>
		/// 区域代码
		/// </summary>
		/// <value></value>
		public string DistrictCode { get; set; }
		/// <summary>
		/// 名称
		/// </summary>
		/// <value></value>
		public string Name { get; set; }


    }

    /// <summary>
    /// 根据编码获取城镇数据请求
    /// </summary>
    public class GetTownRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取城镇数据请求
    /// </summary>
    public class GetTownByKeyRequest : TokenRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除城镇数据请求
    /// </summary>
    public class RemoveTownRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 获取城镇数据列表请求
    /// </summary>
    public class GetTownListRequest : TokenRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 更新城镇数据请求
    /// </summary>
    public class UpdateTownRequest : TokenRequest
    {
        public string Code { get; set; }
		/// <summary>
		/// 省份代码
		/// </summary>
		/// <value></value>
		public string ProvinceCode { get; set; }
		/// <summary>
		/// 城市代码
		/// </summary>
		/// <value></value>
		public string CityCode { get; set; }
		/// <summary>
		/// 区域代码
		/// </summary>
		/// <value></value>
		public string DistrictCode { get; set; }
		/// <summary>
		/// 名称
		/// </summary>
		/// <value></value>
		public string Name { get; set; }

    }

    /// <summary>
    /// 根据区Id获取乡镇列表
    /// </summary>
    public class GetTownPageByDistrictRequest:PageRequest
    {

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;

        /// <summary>
        /// 区Id
        /// </summary>
        /// <value></value>
        public string DistrictCode { get; set; }
    }

    /// <summary>
    /// 查询乡镇分页请求
    /// </summary>
    public class TownPageRequest : PageRequest
    {

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;
    }
}