using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Net.Http;
using System.Threading;
using System.Threading.Tasks;

namespace WingInterfaceLibrary.Request.Vital
{
    /// <summary>
    /// 创建更新数据请求
    /// </summary>
    public class CreateUpgradeRequest : TokenRequest
    {
		public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
		/// <summary>
		/// 版本
		/// </summary>
		/// <value></value>
		public string Version { get; set; }
		/// <summary>
		/// 更新备注
		/// </summary>
		/// <value></value>
		public string UpgradeNotes { get; set; }
		/// <summary>
		/// 更新文件URL
		/// </summary>
		/// <value></value>
		public string UpgradeFileUrl { get; set; }
		/// <summary>
		/// 适用设备
		/// </summary>
		/// <value></value>
		public List<string> ApplicableEquipment { get; set; }
		/// <summary>
		/// 是灰度发布
		/// </summary>
		/// <value></value>
		public bool IsGatedLaunch { get; set; }


    }

    /// <summary>
    /// 根据编码获取更新数据请求
    /// </summary>
    public class GetUpgradeRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 更新更新数据请求
    /// </summary>
    public class UpdateUpgradeRequest : TokenRequest
    {
        public string Code { get; set; }
		/// <summary>
		/// 版本
		/// </summary>
		/// <value></value>
		public string Version { get; set; }
		/// <summary>
		/// 更新备注
		/// </summary>
		/// <value></value>
		public string UpgradeNotes { get; set; }
		/// <summary>
		/// 更新文件URL
		/// </summary>
		/// <value></value>
		public string UpgradeFileUrl { get; set; }
		/// <summary>
		/// 适用设备
		/// </summary>
		/// <value></value>
		public List<string> ApplicableEquipment { get; set; }
		/// <summary>
		/// 是灰度发布
		/// </summary>
		/// <value></value>
		public bool IsGatedLaunch { get; set; }

    }

    /// <summary>
    /// 查询更新分页请求
    /// </summary>
    public class UpgradePageRequest : PageRequest
    {

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;
    }

	/// <summary>
	/// 查询最新的更新
	/// </summary>
	public class GetLastUpgradeRequest: TokenRequest
	{
		/// <summary>
		/// 客户端当前版本
		/// </summary>
		/// <value></value>
		public string ClientVersion { get; set; }

		/// <summary>
		/// 设备物理唯一码
		/// </summary>
		/// <value></value>
		public string DeviceSerialNumber { get; set; }
	}

	/// <summary>
	/// 查询系统资源文件内容请求
	/// </summary>
	public class GetResourceInfoByVersionRequest: TokenRequest
	{
		/// <summary>
		/// 资源文件当前版本号，示例：1.0
		/// </summary>
		/// <value></value>
		public string Version { get; set; }

		/// <summary>
		/// 资源文件名，示例：TCMDescription
		/// </summary>
		/// <value></value>
		public string ResourceKey { get; set; }
	}

	/// <summary>
	/// 查询系统资源文件内容请求
	/// </summary>
	public class GetResourceInfoByVersionResult
	{
		/// <summary>
		/// 资源文件名，示例：TCMDescription
		/// </summary>
        public string ResourceKey { get; set; }
		
		/// <summary>
		/// 资源文件当前版本号，示例：1.0
		/// </summary>
		/// <value></value>
        public string Version { get; set; }
		
		/// <summary>
		/// 文件内容
		/// </summary>
		/// <value></value>
        public string Content { get; set; }
	}
}