using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum.VitalEnum;

namespace WingInterfaceLibrary.Request.Vital
{
    /// <summary>
    /// 创建用户权限数据请求
    /// </summary>
    public class CreateUserFeatureRequest : TokenRequest
    {
        public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
        /// <summary>
        /// 功能名称
        /// </summary>
        /// <value></value>
        public string FeatureName { get; set; }
        /// <summary>
        /// 功能显示名称
        /// </summary>
        /// <value></value>
        public string FeatureShowName { get; set; }
        /// <summary>
        /// 描述
        /// </summary>
        /// <value></value>
        public string Description { get; set; }
        /// <summary>
        /// 父亲代码
        /// </summary>
        /// <value></value>
        public string FatherCode { get; set; }
        /// <summary>
        /// 排序
        /// </summary>
        /// <value></value>
        public int Sort { get; set; }
        /// <summary>
        /// 应用类型
        /// </summary>
        /// <value></value>
        public ApplicationTypeEnum AppType { get; set; }
        /// <summary>
        /// 权限类型
        /// </summary>
        /// <value></value>
        public FeatureTypeEnum FeatureType { get; set; }
    }

    /// <summary>
    /// 根据编码获取用户权限数据请求
    /// </summary>
    public class GetUserFeatureRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取用户权限数据请求
    /// </summary>
    public class GetUserFeatureByKeyRequest : TokenRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除用户权限数据请求
    /// </summary>
    public class RemoveUserFeatureRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 获取用户权限数据列表请求
    /// </summary>
    public class GetUserFeatureListRequest : TokenRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 更新用户权限数据请求
    /// </summary>
    public class UpdateUserFeatureRequest : TokenRequest
    {
        public string Code { get; set; }
        /// <summary>
        /// 功能名称
        /// </summary>
        /// <value></value>
        public string FeatureName { get; set; }
        /// <summary>
        /// 功能显示名称
        /// </summary>
        /// <value></value>
        public string FeatureShowName { get; set; }
        /// <summary>
        /// 描述
        /// </summary>
        /// <value></value>
        public string Description { get; set; }
        /// <summary>
        /// 父亲代码
        /// </summary>
        /// <value></value>
        public string FatherCode { get; set; }
        /// <summary>
        /// 排序
        /// </summary>
        /// <value></value>
        public int Sort { get; set; }
        /// <summary>
        /// 应用类型
        /// </summary>
        /// <value></value>
        public ApplicationTypeEnum AppType { get; set; }
        /// <summary>
        /// 权限类型
        /// </summary>
        /// <value></value>
        public FeatureTypeEnum FeatureType { get; set; }
    }

    /// <summary>
    /// 查询用户权限分页请求
    /// </summary>
    public class UserFeaturePageRequest : PageRequest
    {

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;
    }
}