using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Net.Http;
using System.Threading;
using System.Threading.Tasks;

namespace WingInterfaceLibrary.Request.Vital
{
    /// <summary>
    /// 创建用户密码数据请求
    /// </summary>
    public class CreateUserPasswordRequest : TokenRequest
    {
		/// <summary>
		/// 秘密密码
		/// </summary>
		/// <value></value>
		public string SecretPassword { get; set; }
    }

    /// <summary>
    /// 根据编码获取用户密码数据请求
    /// </summary>
    public class GetUserPasswordRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 根据关键字段获取用户密码数据请求
    /// </summary>
    public class GetUserPasswordByKeyRequest : TokenRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除用户密码数据请求
    /// </summary>
    public class RemoveUserPasswordRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 获取用户密码数据列表请求
    /// </summary>
    public class GetUserPasswordListRequest : TokenRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 更新用户密码数据请求
    /// </summary>
    public class UpdateUserPasswordRequest : TokenRequest
    {
        public string Code { get; set; }
		/// <summary>
		/// 秘密密码
		/// </summary>
		/// <value></value>
		public string SecretPassword { get; set; }

    }

    /// <summary>
    /// 查询用户密码分页请求
    /// </summary>
    public class UserPasswordPageRequest : PageRequest
    {

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;
    }
}