using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum.VitalEnum;

namespace WingInterfaceLibrary.Request.Vital
{
    /// <summary>
    /// 创建用户数据请求
    /// </summary>
    public class CreateUserRequest : TokenRequest
    {
		public string Code { get; set; } = Guid.NewGuid().ToString("N").ToUpper();
		/// <summary>
		/// 用户名称
		/// </summary>
		/// <value></value>
		public string UserName { get; set; }
		/// <summary>
		/// 电话
		/// </summary>
		/// <value></value>
		public string Phone { get; set; }
		/// <summary>
		/// 证件编号
		/// </summary>
		/// <value></value>
		public string CardNo { get; set; }
		/// <summary>
		/// 真实姓名名称
		/// </summary>
		/// <value></value>
		public string RealName { get; set; }
		/// <summary>
		/// 头像图片令牌
		/// </summary>
		/// <value></value>
		public string HeadImageToken { get; set; }
		/// <summary>
		/// 组织代码
		/// </summary>
		/// <value></value>
		public string OrganizationCode { get; set; }
		/// <summary>
		/// 团队代码
		/// </summary>
		/// <value></value>
		public string TeamCode { get; set; }
		/// <summary>
		/// 角色代码
		/// </summary>
		/// <value></value>
		public string RoleCode { get; set; }
		/// <summary>
		/// 密文密码
		/// </summary>
		/// <value></value>
		public string SecretPassword { get; set;}
		/// <summary>
        /// 职位职称
        /// </summary>
        /// <value></value>
        public string RankName { get; set; }

		/// <summary>
		/// 医生签名
		/// </summary>
		/// <value></value>
		public string Signature { get; set; } = "-1";
        
        /// <summary>
        /// 超声机编码，超声工作站使用
        /// </summary>
        /// <value></value>
        public string UltrasoundCode { get; set; }
        
        /// <summary>
        /// 心电编码，心电工作站使用
        /// </summary>
        /// <value></value>
        public string EcgCode { get; set; }
        
        /// <summary>
        /// FacturyUserCode
        /// </summary>
        /// <value></value>
        public string FacturyUserCode { get; set; }

    }

    /// <summary>
    /// 根据编码获取用户数据请求
    /// </summary>
    public class GetUserRequest : TokenRequest
    {
		public string Code { get; set; } = string.Empty;
    }

    /// <summary>
    /// 根据关键字段获取用户数据请求
    /// </summary>
    public class GetUserByKeyRequest : TokenRequest
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }

    /// <summary>
    /// 删除用户数据请求
    /// </summary>
    public class RemoveUserRequest : TokenRequest
    {
        public string Code { get; set; }
    }

    /// <summary>
    /// 获取用户数据列表请求
    /// </summary>
    public class GetUserListRequest : TokenRequest
    {
        public List<string> Codes { get; set; }
    }

    /// <summary>
    /// 更新用户数据请求
    /// </summary>
    public class UpdateUserRequest : TokenRequest
    {
		public string Code { get; set; } = string.Empty;
		/// <summary>
		/// 电话
		/// </summary>
		/// <value></value>
		public string Phone { get; set; } = "-1";
		/// <summary>
		/// 证件编号
		/// </summary>
		/// <value></value>
		public string CardNo { get; set; } = "-1";
		/// <summary>
		/// 真实姓名名称
		/// </summary>
		/// <value></value>
		public string RealName { get; set; } = "-1";
		/// <summary>
		/// 头像图片令牌
		/// </summary>
		/// <value></value>
		public string HeadImageToken { get; set; } = "-1";
		/// <summary>
		/// 组织代码
		/// </summary>
		/// <value></value>
		public string OrganizationCode { get; set; } = "-1";
		/// <summary>
		/// 团队代码
		/// </summary>
		/// <value></value>
		public string TeamCode { get; set; } = "-1";
		/// <summary>
		/// 角色代码
		/// </summary>
		/// <value></value>
		public string RoleCode { get; set; } = "-1";
        /// <summary>
        /// 职位职称
        /// </summary>
        /// <value></value>
        public string RankName { get; set; } = "-1";
		/// <summary>
		/// 医生签名
		/// </summary>
		/// <value></value>
		public string Signature { get; set; } = "-1";
        
        /// <summary>
        /// 超声机编码，超声工作站使用
        /// </summary>
        /// <value></value>
        public string UltrasoundCode { get; set; }
        
        /// <summary>
        /// 心电编码，心电工作站使用
        /// </summary>
        /// <value></value>
        public string EcgCode { get; set; }
        
        /// <summary>
        /// FacturyUserCode
        /// </summary>
        /// <value></value>
        public string FacturyUserCode { get; set; }
    }

	/// <summary>
	/// 重新设置用户名
	/// </summary>
    public class ResetUserNameRequest  : TokenRequest
    {
		public string Code { get; set; } = string.Empty;

		/// <summary>
		/// 用户名
		/// </summary>
		/// <value></value>
		public string UserName { get; set; }
	}

	/// <summary>
	/// 设备用户关联的超声机 请求
	/// </summary>
    public class BindUltrasoundCodeRequest  : TokenRequest
    {
		/// <summary>
		/// 用户编码
		/// </summary>
		/// <value></value>
		public string UserCode { get; set; }

		/// <summary>
		/// 超声机编码
		/// </summary>
		/// <value></value>
		public string UltrasoundCode { get; set; }
	}

	/// <summary>
	/// 设备用户关联的心电 请求
	/// </summary>
    public class BindEcgCodeRequest  : TokenRequest
    {
		/// <summary>
		/// 用户编码
		/// </summary>
		/// <value></value>
		public string UserCode { get; set; }

		/// <summary>
		/// 心电编码
		/// </summary>
		/// <value></value>
		public string EcgCode { get; set; }
	}

	/// <summary>
	/// 关联晶奇工号 请求
	/// </summary>
    public class SetJingQiUserRequest  : TokenRequest
    {
		/// <summary>
		/// 用户编码
		/// </summary>
		/// <value></value>
		public string UserCode { get; set; }

		/// <summary>
		/// 厂商信息编号
		/// </summary>
		/// <value></value>
		public string FacturyUserCode { get; set; }
	}

    /// <summary>
    /// 根据机构编码获取用户列表
    /// </summary>
	public class GetUserPageByOrganizationCodeRequest : PageRequest
	{

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;

		/// <summary>
		/// 机构编码
		/// </summary>
		/// <value></value>
		public string OrganizationCode { get; set; } = string.Empty;
	}

	/// <summary>
    /// 根据团队编码获取用户列表
    /// </summary>
	public class GetUserPageByTeamCodeRequest : PageRequest
	{

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;

		/// <summary>
		/// 团队编码
		/// </summary>
		/// <value></value>
		public string TeamCode { get; set; } = string.Empty;
	}

	/// <summary>
	/// 设置负责区域
	/// </summary>
	public class SetAreaOfResponsibilityRequest : TokenRequest
	{
		/// <summary>
		/// 用户编码
		/// </summary>
		/// <value></value>
        public string Code { get; set; }

		/// <summary>
		/// 村、小区编码
		/// </summary>
		/// <value></value>
		public List<string> ResidenceCodes { get; set; }
	}

	/// <summary>
	/// 设置签名
	/// </summary>
	public class SetSignatureRequest : TokenRequest
	{
		/// <summary>
		/// 用户编码
		/// </summary>
		/// <value></value>
        public string Code { get; set; }

		/// <summary>
		/// 签名
		/// </summary>
		/// <value></value>
		public string Signature { get; set; }
	}

	/// <summary>
	/// 设置负责区域
	/// </summary>
	public class GetAreaOfResponsibilityRequest : TokenRequest
	{
		/// <summary>
		/// 用户编码
		/// </summary>
		/// <value></value>
        public string Code { get; set; }
	}

	/// <summary>
    /// 查询用户分页请求
    /// </summary>
    public class UserPageRequest : PageRequest
    {

        /// <summary>
		/// 关键字
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string Keyword { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? StartTime { get; set; } = null;

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value>2023-09-01</value>
        /// <code>0</code>   
        public DateTime? EndTime { get; set; } = null;
		
        /// <summary>
		/// 机构编码
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string OrganizationCode { get; set; }
		
        /// <summary>
		/// 团队编码
		/// </summary>
		/// <value>张三</value>
        /// <code>0</code>      
		public string TeamCode { get; set; }
    }

	/// <summary>
	/// 获取菜单权限
	/// </summary>
	public class GetMenuPermissionRequest : TokenRequest
	{
		/// <summary>
		/// 应用类型
		/// </summary>
		/// <value></value>
		public ApplicationTypeEnum AppType { get; set; }
	}

	/// <summary>
	/// 获取操作权限
	/// </summary>
	public class GetOperationPermissionRequest : TokenRequest
	{
		/// <summary>
		/// 应用类型
		/// </summary>
		/// <value></value>
		public ApplicationTypeEnum AppType { get; set; }
	}
}