using System;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Vital;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.Request.Vital
{
    /// <summary>
    /// 分页获取健康检查预约数据 请求
    /// </summary>

    public class GetHealthExamBookingPageRequest : PageRequest
    {
        /// <summary>
        /// 关键字
        /// </summary>
        /// <value>nickName</value>
        /// <code>0</code>
        public string Keyword { get; set; }

        /// <summary>
        /// 机构集合
        /// </summary>
        /// <value></value>
        public List<string> OrgCodes { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value></value>
        public DateTime StartTime { get; set; }

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value></value>
        public DateTime EndTime { get; set; }

        /// <summary>
        /// 按照更新时间正序
        /// </summary>
        /// <value></value>
        public bool OrderByAscending { get; set; }
    }

    /// <summary>
    /// 解除预约请求
    /// </summary>
    public class CancelHealthExamBookingRequest : TokenRequest
    {
        /// <summary>
        /// 体检记录编码
        /// </summary>
        public string Code { get; set; }

        /// <summary>
        /// 预约证件号
        /// </summary>
        public string IdentityCard { get; set; }
    }

    /// <summary>
    /// 新增/修改体检信息-请求
    /// </summary>
    public class SaveHealthExamBookingRequest : TokenRequest
    {
        /// <summary>
        /// 体检记录编码
        /// </summary>
        public string Code { get; set; }

        /// <summary>
        /// 预约类型
        /// </summary>
        public BookingTypeEnum BookingType { get; set; }

        /// <summary>
        /// 体检名称
        /// </summary>
        public string Name { get; set; }

        /// <summary>
        /// 体检地点
        /// </summary>
        public string Location { get; set; }

        /// <summary>
        /// 体检开始日期
        /// </summary>
        /// <value></value>
        public DateTime StartDate { get; set; }

        /// <summary>
        /// 体检结束日期
        /// </summary>
        /// <value></value>
        public DateTime EndDate { get; set; }

        /// <summary>
        /// 体检对象
        /// </summary>
        /// <value></value>
        public string Subject { get; set; }

        /// <summary>
        /// 体检说明
        /// </summary>
        /// <value></value>
        public string Description { get; set; }

        /// <summary>
        /// 发起人编码
        /// </summary>
        /// <value></value>
        public string InitiatorCode { get; set; }

        /// <summary>
        /// 发起人机构编码
        /// </summary>
        /// <value></value>
        public string OrgCode { get; set; }

        /// <summary>
        /// 预约状态（待提交、已预约、已取消）
        /// </summary>
        /// <value></value>
        public BookingStatusEnum Status { get; set; }

        /// <summary>
        /// 体检人员集合
        /// </summary>
        /// <typeparam name="HealthExamPersonEntity"></typeparam>
        /// <returns></returns>
        public List<HealthExamPersonDTO> Persons { get; set; } = new List<HealthExamPersonDTO>();

        /// <summary>
        /// 检查项目
        /// </summary>
        /// <typeparam name="HealthExamPersonEntity"></typeparam>
        /// <returns></returns>
        public List<HealthExamItemDTO> ExamItems { get; set; } = new List<HealthExamItemDTO>();
    }

    /// <summary>
    /// 查询体检信息-请求
    /// </summary>
    public class GetHealthExamBookingRequest : TokenRequest
    {
        /// <summary>
        /// 预约编码
        /// </summary>
        /// <value></value>
        public string Code { get; set; }
    }

    /// <summary>
    /// 删除体检信息-请求
    /// </summary>
    public class DeleteHealthExamBookingRequest : TokenRequest
    {
        /// <summary>
        /// 预约编码
        /// </summary>
        /// <value></value>
        public string Code { get; set; }
    }

    /// <summary>
    /// 团队预约，报名-请求
    /// </summary>
    public class SignUpHealthExamBookingRequest : TokenRequest
    {
        /// <summary>
        /// 预约编码
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 姓名
        /// </summary>
        /// <value></value>
        public string Name { get; set; }

        /// <summary>
        /// 性别
        /// </summary>
        /// <value></value>
        public PatientGenderEnum Gender { get; set; }

        /// <summary>
        /// 证件号
        /// </summary>
        /// <value></value>
        public string IdentityCard { get; set; }

        /// <summary>
        /// 手机号
        /// </summary>
        /// <value></value>
        public string Phone { get; set; }
    }

    /// <summary>
    /// 根据身份证号查询预约信息
    /// </summary>
    public class GetExamBookingByIDCardRequest : TokenRequest
    {
        /// <summary>
        /// 身份证号
        /// </summary>
        /// <value></value>
        public string IDCardNo { get; set; }

        /// <summary>
        /// 操作人
        /// </summary>
        /// <value></value>
        public string OperatorCode { get; set; }
    }

    /// <summary>
    /// 新增登记信息
    /// </summary>
    public class AddRegiterInfoRequest : TokenRequest
    {
        /// <summary>
        /// 身份证号
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 身份证号
        /// </summary>
        /// <value></value>
        public string IDCardNo { get; set; }

        /// <summary>
        /// 姓名
        /// </summary>
        /// <value></value>
        public string Name { get; set; }

        /// <summary>
        /// 性别
        /// </summary>
        /// <value></value>
        public string Sex { get; set; }

        /// <summary>
        /// 年龄
        /// </summary>
        /// <value></value>
        public string Age { get; set; }

        /// <summary>
        /// 生日
        /// </summary>
        /// <value></value>
        public DateTime Birthday { get; set; }

        /// <summary>
        /// 手机号
        /// </summary>
        /// <value></value>
        public string Phone { get; set; }

        /// <summary>
        /// 地址
        /// </summary>
        /// <value></value>
        public string Adress { get; set; }

        /// <summary>
        /// 项目类型
        /// </summary>
        /// <value></value>
        public Enum.VitalEnum.VitalProjectTypeEnum ProjectType { get; set; } = Enum.VitalEnum.VitalProjectTypeEnum.VitalStation;

        /// <summary>
        /// 民族
        /// </summary>
        /// <value></value>
        public string Nationality { get; set; }

        /// <summary>
        /// 户籍地址
        /// </summary>
        /// <value></value>
        public string PermanentResidenceAddress { get; set; }
    }

    /// <summary>
    /// 新增登记信息响应
    /// </summary>
    public class AddRegiterInfoResult
    {
        /// <summary>
        /// 体检登记记录编码
        /// </summary>
        /// <value></value>
        public string RegisterPersonCode { get; set; }

        /// <summary>
        /// 是否首次建档
        /// </summary>
        /// <value></value>
        public bool IsNewPatient { get; set; }
    }

    /// <summary>
    /// 删除登记信息
    /// </summary>
    public class DeleteRegiterInfoRequest : TokenRequest
    {
        /// <summary>
        /// 体检登记记录编码
        /// </summary>
        /// <value></value>
        public string RegisterCode { get; set; }
    }

    /// <summary>
    /// 新增登记信息
    /// </summary>
    public class UpdateRegiterInfoRequest : AddRegiterInfoRequest
    {
        /// <summary>
        /// 预约信息code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

    }

    /// <summary>
    /// 更新结果和建议
    /// </summary>
    public class UpdateResultsAndSuggestionsRequest : TokenRequest
    {
        /// <summary>
        /// 预约信息code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 结果和建议
        /// </summary>
        /// <value></value>
        public string ResultsAndSuggestions { get; set; }

        /// <summary>
        /// 健康指导
        /// </summary>
        /// <value></value>
        public string HealthGuidance { get; set; }

        /// <summary>
        /// 更新检测结果数据
        /// </summary>
        /// <value></value>
        public List<DataItemDTO> DiagnosisExceptionResult { get; set; }
    }

    /// <summary>
    /// 查询登记信息列表
    /// </summary>
    public class GetRegiterInfoPageRequest : PageRequest
    {
        /// <summary>
        /// 关键字
        /// </summary>
        /// <value></value>
        public string Keyword { get; set; }

        /// <summary>
        /// 操作人
        /// </summary>
        /// <value></value>
        public string OperatorCode { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        /// <value></value>
        public DateTime StartTime { get; set; }

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value></value>
        public DateTime EndTime { get; set; }

        /// <summary>
        /// 身份证号
        /// </summary>
        /// <value></value>
        public string IDCardNo { get; set; }

        /// <summary>
        /// 项目类型
        /// </summary>
        /// <value></value>
        public Enum.VitalEnum.VitalProjectTypeEnum? ProjectType { get; set; }

    }

    /// <summary>
    /// 根据体检号查询机构体检项目请求
    /// </summary>
    public class GetExamItemsByExamNoRequest : TokenRequest
    {
        /// <summary>
        /// 体检编码
        /// </summary>
        /// <value></value>
        public string PhysicalExamNumber { get; set; }
    }

    /// <summary>
    /// 根据体检号查询机构体检标签请求
    /// </summary>
    public class GetExamLabelsByExamNoRequest : TokenRequest
    {
        /// <summary>
        /// 体检编码
        /// </summary>
        /// <value></value>
        public string PhysicalExamNumber { get; set; }
    }

    /// <summary>
    /// 根据体检号查询机构体检标签响应
    /// </summary>
    public class GetExamLabelsByExamNoResult
    {
        /// <summary>
        /// 体检号
        /// </summary>
        /// <value></value>
        public string RegisterPersonName { get; set; }

        /// <summary>
        /// 体检号
        /// </summary>
        /// <value></value>
        public string PhysicalExamNumber { get; set; }

        /// <summary>
        /// 性别
        /// </summary>
        /// <value></value>
        public string Sex { get; set; }

        /// <summary>
        /// 年龄
        /// </summary>
        /// <value></value>
        public string Age { get; set; }

        /// <summary>
        /// 体检标签
        /// </summary>
        /// <value></value>
        public List<HealthExamLabelDTO> EaxmLabels { get; set; }
    }

}