using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.Request.Vital
{

    /// <summary>
    /// 根据openid查询登录状态
    /// </summary>
    public class GetUserInfoByVitalOpenIdRequest
    {
        /// <summary>
        /// OpenId
        /// </summary>
        /// <value></value>
        public string OpenId { get; set; }
    }



    /// <summary>
    /// 根据人脸图像获取人脸信息请求
    /// </summary>
    public class GetPersonInfoByFaceImageRequest : TokenRequest
    {
        /// <summary>
        /// 图片
        /// </summary>
        /// <value></value>
        public string Image { get; set; }
    }

    /// <summary>
    /// 确认登记请求
    /// </summary>
    public class RegisterConfirmRequest : TokenRequest
    {
        /// <summary>
        /// 健康状态是否正常
        /// </summary>
        /// <value></value>
        public bool IsNormal { get; set; }

        /// <summary>
        /// 人员code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 机构
        /// </summary>
        /// <value></value>
        public string Organization { get; set; }

        /// <summary>
        /// 经纬度
        /// </summary>
        /// <value></value>
        public string Nautical { get; set; }

        /// <summary>
        /// 卫生机构
        /// </summary>
        /// <value></value>
        public string Government { get; set; }
    }

    /// <summary>
    /// 根据编码获取人员数据请求
    /// </summary>
    public class GetPersonRequest : TokenRequest
    {
        /// <summary>
        /// 人员code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }
    }

    /// <summary>
    /// 删除人员信息
    /// </summary>
    public class DeletePersonRequest : TokenRequest
    {
        public string Code { get; set; }
    }


    /// <summary>
    /// 扫脸录入查询接口
    /// </summary>
    public class EnterPersonFaceQueryRequest : TokenRequest
    {
        /// <summary>
        /// 图片
        /// </summary>
        /// <value></value>
        public string Image { get; set; }
    }



    /// <summary>
    /// 录入人员请求
    /// </summary>
    public class EnterPersonFaceRequest : TokenRequest
    {
        /// <summary>
        /// 姓名
        /// </summary>
        /// <value></value>
        public string Name { get; set; }

        /// <summary>
        /// 照片
        /// </summary>
        /// <value></value>
        public string HeadImg { get; set; }

        /// <summary>
        /// 性别
        /// </summary>
        /// <value></value>
        public PatientGenderEnum Sex { get; set; }

        /// <summary>
        /// 年龄
        /// </summary>
        /// <value></value>
        public string Age { get; set; }

        /// <summary>
        /// 身份证号
        /// </summary>
        /// <value></value>
        public string CardID { get; set; }

        /// <summary>
        /// 备注
        /// </summary>
        /// <value></value>
        public string Remarks { get; set; }

        /// <summary>
        /// 健康状态是否正常
        /// </summary>
        /// <value></value>
        public bool IsNormal { get; set; }

        /// <summary>
        /// 机构
        /// </summary>
        /// <value></value>
        public string Organization { get; set; }

        /// <summary>
        /// 经纬度
        /// </summary>
        /// <value></value>
        public string Nautical { get; set; }

        /// <summary>
        /// 卫生机构
        /// </summary>
        /// <value></value>
        public string Government { get; set; }
    }


    /// <summary>
    /// 查询人员录入状态
    /// </summary>

    public class EnterPersonFaceQueryResult
    {

        /// <summary>
        /// 是否识别成功
        /// </summary>
        /// <value></value>
        public FaceScanErrorTypeEnum FaceScanErrorType { get; set; }

        /// <summary>
        /// 错误信息
        /// </summary>
        /// <value></value>
        public string ErrorMessage { get; set; }

        /// <summary>
        /// 名称
        /// </summary>
        /// <value></value>
        public string Name { get; set; }

    }
}