using System.Collections.Generic;
using System.Threading.Tasks;
using WingInterfaceLibrary.DTO.Common;
using WingInterfaceLibrary.DTO.User;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Result.UserFeature;

namespace WingInterfaceLibrary.ResearchEdition
{
    /// <summary>
    /// 科研版接口
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>  
    /// <docSecondDirectory>科研版</docSecondDirectory>
    public interface IResearchEditionService
    {
        /// <summary>
        /// 设备端查询项目列表
        /// </summary>
        /// <returns>项目列表</returns>
        /// <value></value>
        /// <remarks>POST</remarks>
        /// <docFirstDirectory>设备端API</docFirstDirectory>
        /// <docSecondDirectory>科研版服务接口</docSecondDirectory>
        /// <errorCodes>PatientTypeIsEmpty,DeviceNotOrg</errorCodes>
        Task<IList<ResearchProjectBaseDTO>> GetDeviceResearchProjectListAsync(GetDeviceResearchProjectListRequest request);

        /// <summary>
        /// 查询项目列表
        /// </summary>
        /// <param name="request">查询项目列表请求实体</param>
        /// <returns></returns>
        /// <errorCodes></errorCodes>
        Task<IList<ResearchProjectBaseDTO>> GetResearchProjectListAsync(GetResearchProjectListRequest request);

        /// <summary>
        /// 查询项目详情
        /// </summary>
        /// <param name="request">查询项目详情请求实体</param>
        /// <returns></returns>
        /// <errorCodes></errorCodes>
        Task<ResearchProjectDTO> GetResearchProjectDetailAsync(GetResearchProjectDetailRequest request);

        /// <summary>
        /// 创建项目
        /// </summary>
        /// <param name="request">创建项目请求实体</param>
        /// <returns></returns>
        Task<string> CreateResearchProjectAsync(CreateResearchProjectRequest request);

        /// <summary>
        /// 修改项目
        /// </summary>
        /// <param name="request">修改项目请求实体</param>
        /// <returns></returns>
        Task<bool> UpdateResearchProjectAsync(UpdateResearchProjectRequest request);

        /// <summary>
        /// 删除项目
        /// </summary>
        /// <param name="request">修改项目请求实体</param>
        /// <returns></returns>
        Task<bool> DeleteResearchProjectAsync(DeleteResearchProjectRequest request);

        /// <summary>
        /// 删除样本
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeleteSampleAsync(DeletePatientSampleRequest request);

        /// <summary>
        /// 邀请成员
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> InviteResearchProjectMembersAsync(InviteResearchProjectMembersRequest request);

        /// <summary>
        /// 移除成员
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> RemoveResearchProjectMembersAsync(RemoveResearchProjectMembersRequest request);

        /// <summary>
        /// 创建任务
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> CreateResearchProjectTaskAsync(CreateResearchProjectTaskRequest request);

        /// <summary>
        /// 更新任务进度状态
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateResearchProjectTaskAsync(UpdateResearchProjectTaskRequest request);

        /// <summary>
        /// 取消主任务
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> CancelMainTaskAsync(BatchAnalysisTaskRequest request);

        /// <summary>
        /// 查询项目数据
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageCollection<ResearchProjectDataDTO>> GetResearchProjectDataPagesAsync(GetResearchProjectDatasRequest request);

        /// <summary>
        /// 查询样本数据
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<SampleDetail>> GetSampleDetailList(GetSampleDetailsRequest request);

        /// <summary>
        /// 查询样本图像数据
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<SampleRemedicalInfoDTO>> GetSampleImgList(GetSampleDetailsRequest request);

        /// <summary>
        /// 转入数据接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> TransferDataAsync(TransferDataRequest request);

        /// <summary>
        /// 获取URM关联图像集合
        /// </summary>
        /// <returns></returns>
        Task<List<SampleRemedicalInfoDTO>> GetUrmRemedicalInfosAsync(GetUrmRemedicalInfosRequest request);

        /// <summary>
        /// 查询任务列表
        /// </summary>
        /// <returns></returns>
        Task<IList<TaskBaseDTO>> GetTaskListAsync(GetTaskListRequest request);

        /// <summary>
        /// 查询主任务详情
        /// </summary>
        /// <returns></returns>
        Task<MainTaskDTO> GetMainTaskDetailAsync(GetMainTaskDetailRequest request);

        /// <summary>
        /// 查询子任务详情
        /// </summary>
        /// <returns></returns>
        Task<TaskDTO> GetTaskDetailAsync(GetTaskDetailRequest request);

        /// <summary>
        /// 根据项目查询时间轴
        /// </summary>
        /// <returns></returns>
        Task<IList<TimeAxisDetail>> GetTimeAxisByProjectAsync(GetTaskListByProjectRequest request);

        /// <summary>
        /// 查询所有用户集合（分页）
        /// </summary>
        /// <param name="request">查询机构专家集合请求实体</param>
        /// <returns></returns>
        /// <errorCodes></errorCodes>
        Task<PageCollection<UserBaseDTO>> GetUserBaseInfoPagesAsync(GetRRUserPagesRequest request);

        /// <summary>
        /// 批量分析
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> BatchAnalysisAsync(BatchAnalysisRequest request);

        /// <summary>
        /// 插队批量分析
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> BatchJumpQueueAnalysisAsync(BatchAnalysisRequest request);

        /// <summary>
        /// 暂停分析(子任务)
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>

        Task<bool> PauseAnalysisAsync(AnalysisTaskRequest request);

        /// <summary>
        /// 暂停批量分析
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> PauseBatchAnalysisAsync(BatchAnalysisTaskRequest request);

        /// <summary>
        /// 取消分析(子任务)
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> CancelAnalysisAsync(AnalysisTaskRequest request);

        /// <summary>
        /// 取消批量分析
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> CancelBatchAnalysisAsync(BatchAnalysisTaskRequest request);

        /// <summary>
        /// 继续分析(子任务)
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> ContinueAnalysisAsync(AnalysisTaskRequest request);

        /// <summary>
        /// 继续批量分析
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> ContinueBatchAnalysisAsync(BatchAnalysisTaskRequest request);

        /// <summary>
        /// 保存分析视频，队列实现
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> SaveAnalysisVideoByTaskAsync(SaveAnalysisVideoRequest request);

        /// <summary>
        /// 保存分析视频
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<SaveAnalysisVideoResult> SaveAnalysisVideoAsync(SaveAnalysisVideoRequest request);

        /// <summary>
        /// 验证并激活license
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<int> ActivationLicenseAsync(ActivationLicenseRequest request);

        /// <summary>
        /// 检查详情
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<BaseSampleDetail> GetSampleDetailAsync(GetSampleDetailRequest request);

        /// <summary>
        /// 修改检查
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> ModifySampleDetailAsync(ModifySampleDetailRequest request);

        /// <summary>
        /// 根据登录用户获取权限列表
        /// </summary>
        /// <param name="request">token</param>
        /// <returns>权限列表</returns>
        Task<List<UserFeatureInfoResult>> GetResearchProjectUserFeatureListAsync(TokenRequest request);

        /// <summary>
        /// 获取最新的license信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<LicenseInfoDTO> GetLicenseInfoAsync(TokenRequest request);

        /// <summary>
        /// 样本数据导出接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ProjectSampleDataExportResult> GetProjectSampleDataExportAsync(GetProjectSampleDataExportRequest request);

        /// <summary>
        /// 获取机器唯一码
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> GetMachaineIdAsync(TokenRequest request);

        /// <summary>
        /// 获取服务器host地址
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> GetServerHostUrlAsync(TokenRequest request);

        /// <summary>
        /// 保存用户URM配置信息
        /// </summary>
        /// <returns></returns>
        Task<SaveUserUrmConfigResult> SaveUserUrmConfigAsync(SaveUserUrmConfigRequest request);

        /// <summary>
        /// 删除用户URM配置信息
        /// </summary>
        /// <returns></returns>
        Task<bool> DeletePatientUrmConfigAsync(DeletePatientUrmConfigRequest request);

        /// <summary>
        /// 设置默认用户URM配置信息
        /// </summary>
        /// <returns></returns>
        Task<bool> SetDefaultPatientUrmConfigAsync(SetDefaultPatientUrmConfigRequest request);

        /// <summary>
        /// 查看用户URM配置集合
        /// </summary>
        /// <returns></returns>
        Task<List<UserUrmConfigDTO>> GetUserUrmConfigsAsync(GetUserUrmConfigsRequest request);

        /// <summary>
        /// 验证用户项目是否有项目权限或者项目是否存在
        /// </summary>
        /// <param name="request">查询项目详情请求实体</param>
        /// <returns></returns>
        /// <errorCodes>NotExistCurrentProjectAuthority,CurrentProjectNotExist</errorCodes>
        Task<bool> ValidateResearchProjectAuthAsync(GetResearchProjectDetailRequest request);
    }
}