using System;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO;
using WingInterfaceLibrary.DTO.Common;
using WingInterfaceLibrary.DTO.Record;
using WingInterfaceLibrary.DTO.User;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Request.Examine;

namespace WingInterfaceLibrary.ResearchEdition
{
    /// <summary>
    /// 科研项目
    /// </summary>
    public class ResearchProjectDTO : ResearchProjectBaseDTO
    {

        /// <summary>
        /// 项目成员
        /// </summary>
        /// <value></value>
        public List<UserBaseDTO> Users { get; set; }

        /// <summary>
        /// 项目数据
        /// </summary>
        /// <value></value>
        public List<ResearchProjectDataDTO> ResearchProjectDataList { get; set; }



    }

    /// <summary>
    /// 科研项目基础信息
    /// </summary>
    public class ResearchProjectBaseDTO
    {
        /// <summary>
        /// Code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 创建人code
        /// </summary>
        /// <value></value>
        public string CreatorCode { get; set; }

        /// <summary>
        /// 创建人名称
        /// </summary>
        /// <value></value>
        public string CreatorName { get; set; }

        /// <summary>
        /// 创建时间
        /// </summary>
        /// <value></value>
        public DateTime CreateTime { get; set; }

        /// <summary>
        /// 操作人code
        /// </summary>
        /// <value></value>
        public string OperatorCode { get; set; }

        /// <summary>
        /// 操作人名称
        /// </summary>
        /// <value></value>
        public string OperatorName { get; set; }

        /// <summary>
        /// 操作人时间
        /// </summary>
        /// <value></value>
        public DateTime OperateTime { get; set; }

        /// <summary>
        /// 项目名称
        /// </summary>
        /// <value></value>
        public string Name { get; set; }

        /// <summary>
        /// 归属人
        /// </summary>
        /// <value></value>
        public string BelongUserCode { get; set; }

        /// <summary>
        /// 服务对象：人用、兽用
        /// </summary>
        /// <value>0</value>
        public OrganizationPatientTypeEnum PatientType { get; set; }

        /// <summary>
        /// 介绍
        /// </summary>
        /// <value></value>
        public string Introduction { get; set; }

    }

    /// <summary>
    /// 病例样本扩展实体
    /// </summary>
    public class PatientSampleDataDTO : ResearchProjectDataDTO
    {
        /// <summary>
        /// 项目名称
        /// </summary>
        /// <value></value>
        public string ProjectName { get; set; }

        /// <summary>
        /// 项目Code
        /// </summary>
        /// <value></value>
        public string ProjectCode { get; set; }

        /// <summary>
        /// 创建人
        /// </summary>
        /// <value></value>
        public string CreatorName { get; set; }
    }

    /// <summary>
    /// 项目数据
    /// </summary>
    public class ResearchProjectDataDTO
    {
        /// <summary>
        /// 对应病人记录code
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }

        /// <summary>
        /// 病人名称
        /// </summary>
        /// <value></value>
        public string PatientName { get; set; }

        /// <summary>
        /// 设备病人id
        /// </summary>
        /// <value></value>
        public string DevicePatientId { get; set; }

        /// <summary>
        /// 文件大小
        /// </summary>
        /// <value></value>
        public string FileSize { get; set; }

        /// <summary>
        /// 创建时间
        /// </summary>
        /// <value></value>
        public DateTime CreateTime { get; set; }

        /// <summary>
        /// 是否URM
        /// </summary>
        public bool IsUrm { get; set; }

        /// <summary>
        /// 设备唯一码
        /// </summary>
        /// <value></value>
        public string DeviceShortCode { get; set; }
    }

    /// <summary>
    /// 样本检查基础数据
    /// </summary>
    public class BaseSampleDetail
    {

        /// <summary>
        /// RecordCode
        /// </summary>
        /// <value></value>
        public string RecordCode { get; set; }

        /// <summary>
        /// 时间
        /// </summary>
        /// <value></value>
        public DateTime RecordTime { get; set; }

        /// <summary>
        /// 病人信息
        /// </summary>
        /// <code>0</code>
        public List<DataItemDTO> PatientInfo { get; set; }

        /// <summary>
        /// 病人额外信息列表
        /// </summary>
        /// <value></value>
        public List<PatientInfoExt> PatientInfoExtList { get; set; }
    }

    /// <summary>
    /// 样本检查记录
    /// </summary>
    public class SampleDetail : BaseSampleDetail
    {
        /// <summary>
        /// 数量
        /// </summary>
        /// <value></value>
        public int DataCount { get; set; }

        /// <summary>
        /// 图像列表
        /// </summary>
        /// <value></value>
        public IList<SampleRemedicalInfoDTO> SampleRemedicalInfoList { get; set; }

    }

    /// <summary>
    /// 样本检查记录响应实体
    /// </summary>
    public class SampleDetailInfo : BaseSampleDetail
    {
        /// <summary>
        /// 扫查项数据列表
        /// </summary>
        /// <value></value>
        public IList<SampleRemedicalBasicInfo> SampleRemedicalBasicList { get; set; }

    }

    /// <summary>
    /// 样本扫查项数据响应实体
    /// </summary>
    public class SampleRemedicalBasicInfo
    {
        // /// <summary>
        // /// 扫查类型描述
        // /// </summary>
        // /// <value>腹部常规</value>
        // /// <code>0</code>
        // public string PatientScanTypeDesc { get; set; }

        // /// <summary>
        // /// ApplicationCategory
        // /// </summary>
        // /// <value>ABD</value>
        // public string ApplicationCategory { get; set; } = string.Empty;

        // /// <summary>
        // /// ApplicationName
        // /// </summary>
        // /// <value>Abd General</value>
        // public string Application { get; set; } = string.Empty;


        /// <summary>
        /// 检查Code
        /// </summary>
        /// <value>Abd General</value>
        public string RecordCode { get; set; } = string.Empty;

        /// <summary>
        /// 检查名称
        /// </summary>
        /// <value>Abd General</value>
        public string RemedicalName { get; set; } = string.Empty;

        /// <summary>
        /// 图像列表
        /// </summary>
        /// <value></value>
        public IList<SampleRemedicalInfoDTO> SampleRemedicalInfoList { get; set; }
    }

    /// <summary>
    /// 扫查数据响应实体
    /// </summary>
    public class SampleRemedicalInfoDTO : BaseDTO
    {
        /// <summary>
        /// 扫查数据编码
        /// </summary>
        /// <value>4914352a75f645279f6b4ad6764cc288</value>
        public string BusinessCode { get; set; }

        /// <summary>
        /// 是否有URM源数据
        /// </summary>
        /// <value></value>
        public bool IsURM { get; set; }

        /// <summary>
        /// ApplicationCategory
        /// </summary>
        /// <value>ABD</value>
        public string ApplicationCategory { get; set; }

        /// <summary>
        /// ApplicationName
        /// </summary>
        /// <value>Abd General</value>
        public string Application { get; set; }

        /// <summary>
        /// Preview url
        /// </summary>
        /// <value></value>
        public string PreviewUrl { get; set; }

        /// <summary>
        /// 封面图
        /// </summary>
        /// <value></value>
        public string CoverImgUrl { get; set; }

        /// <summary>
        /// CND高清图下载地址
        /// </summary>
        /// <value></value>
        public string ImageUrl { get; set; }

        /// <summary>
        /// 图像大小
        /// </summary>
        /// <value>1233445</value>
        public long ImageSize { get; set; }

        /// <summary>
        /// 文件数据类型
        /// </summary>
        /// <value>0</value>
        public SampleRemedicalFileDataTypeEnum FileDataType { get; set; }

        /// <summary>
        /// 科研上传图像集合
        /// </summary>
        /// <returns></returns>
        public List<ImgItem> ImgList { get; set; } = new List<ImgItem>();

        /// <summary>
        /// 是否分析结果
        /// </summary>
        /// <value></value>
        public bool IsAnalysisResult { get; set; } = false;

        /// <summary>
        /// 测量图像列表实体
        /// </summary>
        /// <returns></returns>
        public List<SampleRemedicalMeasuredInfoDTO> SampleRemedicalMeasuredList { get; set; }

        /// <summary>
        /// URM原图编码
        /// </summary>
        /// <value></value>
        public string UrmOriginalCode { get; set; }

        /// <summary>
        /// URM分析/测量图像编码
        /// </summary>
        /// <value></value>
        public string RemedicalOriginalCode { get; set; }

        /// <summary>
        /// URMSrcWidth
        /// </summary>
        /// <value></value>
        public int URMSrcWidth { get; set; }

        /// <summary>
        /// URMSrcHeight
        /// </summary>
        /// <value></value>
        public int URMSrcHeight { get; set; }

        /// <summary>
        /// URMRes
        /// </summary>
        /// <value></value>
        public double URMRes { get; set; }
    }

    /// <summary>
    /// 样本图像对应的测量图像响应实体
    /// </summary>
    public class SampleRemedicalMeasuredInfoDTO : BaseDTO
    {
        /// <summary>
        /// 客户端测量图像数据编码
        /// </summary>
        /// <value>4914352a75f645279f6b4ad6764cc288</value>
        public string RemedicalMeasuredInfoCode { get; set; } = string.Empty;

        /// <summary>
        /// 第几帧，默认0
        /// </summary>
        /// <value>0</value>
        public int FrameIndex { get; set; }

        /// <summary>
        /// 原图地址
        /// </summary>
        /// <value>4914352a75f645279f6b4ad6764cc288</value>
        public string MeasuredFileToken { get; set; } = string.Empty;

        /// <summary>
        /// 缩略图地址
        /// </summary>
        /// <value>4914352a75f645279f6b4ad6764cc288</value>
        public string PreviewFileToken { get; set; } = string.Empty;

        /// <summary>
        /// 测量图像数据详情
        /// </summary>
        /// <value></value>
        public string MeasuredData { get; set; } = string.Empty;

        /// <summary>
        /// 模式
        /// </summary>
        /// <value>Tissue</value>
        public string Model { get; set; } = string.Empty;

    }


    /// <summary>
    /// 项目样本数据导出结果实体
    /// </summary>
    public class ProjectSampleDataExportResult
    {
        /// <summary>
        /// 创建时间
        /// </summary>
        /// <value></value>
        public DateTime CreateTime { get; set; }

        /// <summary>
        /// 项目名称
        /// </summary>
        /// <value></value>
        public string Name { get; set; }

        /// <summary>
        /// 服务对象：人用、兽用
        /// </summary>
        /// <value>0</value>
        public OrganizationPatientTypeEnum PatientType { get; set; }

        /// <summary>
        /// 生成的excel的存储地址
        /// </summary>
        /// <value>0</value>
        public string ExportExcelUrl { get; set; }

        /// <summary>
        /// 样本数据列表
        /// </summary>
        /// <value>0</value>
        public IList<SampleDetailInfo> SampleDetailList { get; set; }
    }

}