using System.Collections.Generic;
using System.Security.Cryptography.X509Certificates;
using WingInterfaceLibrary.DTO.Common;
using WingInterfaceLibrary.DTO.Record;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.RemedicalAISelected;

namespace WingInterfaceLibrary.ResearchEdition
{
    /// <summary>
    /// 查询项目列表
    /// </summary>
    public class GetResearchProjectListRequest : TokenRequest
    {
        /// <summary>
        /// 查询类型  1-我创建的，2-我加入的,3-默认的
        /// </summary>
        /// <value></value>
        public ResearchProjectSearchTypeEnum SearchType { get; set; }

        /// <summary>
        /// 关键字
        /// </summary>
        /// <value></value>
        public string Keyword { get; set; }
    }

    /// <summary>
    /// 查询项目列表
    /// </summary>
    public class GetDeviceResearchProjectListRequest : TokenRequest
    {

        /// <summary>
        /// 关键字
        /// </summary>
        /// <value></value>
        public string Keyword { get; set; }
    }

    /// <summary>
    /// 查询项目详情
    /// </summary>
    public class GetResearchProjectDetailRequest : TokenRequest
    {
        /// <summary>
        /// Code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }
        /// <summary>
        /// 用户 Code
        /// </summary>
        /// <value></value>
        public string UserCode { get; set; }

    }

    /// <summary>
    /// 创建项目
    /// </summary>
    public class CreateResearchProjectRequest : TokenRequest

    {
        /// <summary>
        /// 项目名称
        /// </summary>
        /// <value></value>
        public string Name { get; set; }

        /// <summary>
        /// 服务对象：人用、兽用
        /// </summary>
        /// <value>0</value>
        public OrganizationPatientTypeEnum PatientType { get; set; }

        /// <summary>
        /// 介绍
        /// </summary>
        /// <value></value>
        public string Introduction { get; set; }

    }

    /// <summary>
    /// 修改项目
    /// </summary>
    public class UpdateResearchProjectRequest : TokenRequest
    {
        /// <summary>
        /// 修改项目
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 项目名称
        /// </summary>
        /// <value></value>
        public string Name { get; set; }

        /// <summary>
        /// 服务对象：人用、兽用
        /// </summary>
        /// <value>0</value>
        public OrganizationPatientTypeEnum PatientType { get; set; }

        /// <summary>
        /// 介绍
        /// </summary>
        /// <value></value>
        public string Introduction { get; set; }

    }

    /// <summary>
    /// 删除项目
    /// </summary>
    public class DeleteResearchProjectRequest : TokenRequest
    {
        /// <summary>
        /// 修改项目
        /// </summary>
        /// <value></value>
        public string Code { get; set; }
    }

    /// <summary>
    /// 邀请成员
    /// </summary>
    public class InviteResearchProjectMembersRequest : TokenRequest
    {
        /// <summary>
        /// 项目code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 成员code
        /// </summary>
        /// <value></value>
        public List<string> MemberCodes { get; set; }
    }

    /// <summary>
    /// 移除成员
    /// </summary>
    public class RemoveResearchProjectMembersRequest : TokenRequest
    {
        /// <summary>
        /// 项目code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 成员code
        /// </summary>
        /// <value></value>
        public List<string> MemberCodes { get; set; }
    }

    /// <summary>
    /// 导入数据
    /// </summary>
    public class ImportDataRequest
    {
        /// <summary>
        /// 项目code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 文件路径
        /// </summary>
        /// <value></value>
        public List<string> Samples { get; set; }
    }

    /// <summary>
    /// 创建任务
    /// </summary>
    public class CreateResearchProjectTaskRequest : TokenRequest
    {
        /// <summary>
        /// 业务code
        /// </summary>
        /// <value></value>
        public string BusinessCode { get; set; }

        /// <summary>
        /// 任务类型
        /// </summary>
        /// <value></value>
        public VTaskType TaskType { get; set; }

        /// <summary>
        /// 任务名称
        /// </summary>
        /// <value></value>
        public string Name { get; set; }

        /// <summary>
        /// 任务列表
        /// </summary>
        /// <value></value>
        public List<CreateTaskDetailInfo> TaskDetailList { get; set; }
    }

    /// <summary>
    /// 更新任务进度状态
    /// </summary>
    public class UpdateResearchProjectTaskRequest : TokenRequest
    {
        /// <summary>
        /// 任务Code
        /// </summary>
        /// <value></value>
        public string MainTaskCode { get; set; }

        /// <summary>
        /// 子任务Id
        /// </summary>
        /// <value></value>
        public string Id { get; set; }

        /// <summary>
        /// 结果 成功、失败
        /// </summary>
        /// <value></value>
        public bool Result { get; set; } = false;

        /// <summary>
        /// 任务状态
        /// </summary>
        /// <value></value>
        public VTaskStatus Status { get; set; }

        /// <summary>
        /// 进度 %
        /// </summary>
        /// <value></value>
        public double Rate { get; set; }
    }

    /// <summary>
    /// 查询项目样本列表
    /// </summary>
    public class GetResearchProjectDatasRequest : PageRequest
    {
        /// <summary>
        /// 关键字
        /// </summary>
        /// <value></value>
        public string KeyWord { get; set; }

        /// <summary>
        /// 排序  0-时间倒序，1-时间正序
        /// </summary>
        /// <value></value>
        public int Sort { get; set; }

        /// <summary>
        /// 项目code
        /// </summary>
        /// <value></value>
        public string ProjectCode { get; set; }
    }

    /// <summary>
    /// 转出数据请求实体
    /// </summary>
    public class TransferDataDBRequest
    {
        /// <summary>
        /// 转出样本codes
        /// </summary>
        /// <value></value>
        public List<string> PatientCodes { get; set; }
        /// <summary>
        /// 转入项目code
        /// </summary>
        /// <value></value>
        public string ProjectCode { get; set; }

        /// <summary>
        /// 操作人
        /// </summary>
        /// <value></value>
        public string UserName { get; set; }

        /// <summary>
        /// 操作人code
        /// </summary>
        /// <value></value>
        public string UserCode { get; set; }

    }

    /// <summary>
    /// 查询项目样本列表
    /// </summary>
    public class GetSampleDetailsRequest : TokenRequest
    {
        /// <summary>
        /// 样本Code
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }
    }

    /// <summary>
    /// 转入数据接口
    /// </summary>
    public class TransferDataRequest : TokenRequest
    {
        /// <summary>
        /// 转出样本codes
        /// </summary>
        /// <value></value>
        public List<string> PatientCodes { get; set; }
        /// <summary>
        /// 转入项目code
        /// </summary>
        /// <value></value>
        public string ProjectCode { get; set; }
    }

    /// <summary>
    /// 获取URM关联图像集合请求
    /// </summary>
    public class GetUrmRemedicalInfosRequest : TokenRequest
    {
        /// <summary>
        /// URM原图编码
        /// </summary>
        /// <value></value>
        public string UrmRemedicalCode { get; set; }
    }

    /// <summary>
    /// 查询项目样本检查详情
    /// </summary>
    public class GetSampleDetailRequest : TokenRequest
    {
        /// <summary>
        /// 检查Code
        /// </summary>
        /// <value></value>
        public string RecordCode { get; set; }
    }

    /// <summary>
    /// 修改样本检查请求实体
    /// </summary>
    public class ModifySampleDetailRequest : TokenRequest
    {
        /// <summary>
        /// RecordCode
        /// </summary>
        /// <value></value>
        public string RecordCode { get; set; }

        /// <summary>
        /// 病人信息
        /// </summary>
        /// <code>0</code>
        public List<DataItemDTO> PatientInfo { get; set; }

        /// <summary>
        /// 病人额外信息列表
        /// </summary>
        /// <value></value>
        public List<PatientInfoExt> PatientInfoExtList { get; set; }
    }


    /// <summary>
    /// 根据项目code查询任务列表
    /// </summary>
    public class GetTaskListByProjectRequest : TokenRequest
    {
        /// <summary>
        /// 项目code
        /// </summary>
        /// <value></value>
        public string ProjectCode { get; set; }
    }

    /// <summary>
    /// 查询个人查询任务列表
    /// </summary>
    public class GetTaskListRequest : TokenRequest
    {
        /// <summary>
        /// 关键字
        /// </summary>
        /// <value></value>
        public string KeyWord { get; set; }

        /// <summary>
        /// 任务状态   主任务只有进行中和已完成
        /// </summary>
        /// <value></value>
        public VTaskStatus Status { get; set; }


    }

    /// <summary>
    /// 查询任务详情
    /// </summary>
    public class GetTaskDetailRequest : TokenRequest
    {
        /// <summary>
        /// 任务Code
        /// </summary>
        /// <value></value>
        public string TaskCode { get; set; }
    }

    /// <summary>
    /// 查询任务详情
    /// </summary>
    public class GetMainTaskDetailRequest : TokenRequest
    {
        /// <summary>
        /// 任务Code
        /// </summary>
        /// <value></value>
        public string MainTaskCode { get; set; }
    }

    /// <summary>
    /// 查询用户分页
    /// </summary>
    public class GetRRUserPagesRequest : PageRequest
    {
        /// <summary>
        /// 关键字
        /// </summary>
        /// <value></value>
        public string KeyWord { get; set; }
    }

    /// <summary>
    /// 创建项目样本请求实体
    /// </summary>
    public class CreateProjectSampleRequest : TokenRequest
    {
        /// <summary>
        /// 类型
        /// </summary>
        /// <value>Person、Animals</value>
        /// <code>0</code>
        public string PatientType { get; set; }

        /// <summary>
        /// 病人信息
        /// </summary>
        /// <value></value>
        public List<DataItemDTO> PatientInfo { get; set; }

        /// <summary>
        /// 项目数据记录列表
        /// </summary>
        /// <value></value>
        public List<ProjectDataItem> ProjectDataRecordList { get; set; }

    }

    /// <summary>
    /// 项目数据
    /// </summary>
    public class ProjectDataItem
    {
        /// <summary>
        /// 病人检查信息列表
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public List<PatientInfoExt> PatientScanInfoList { get; set; }

        /// <summary>
        /// 图像列表
        /// </summary>
        /// <value></value>
        public List<UploadDataItem> UploadDataList { get; set; }
    }

    /// <summary>
    /// 图像详情
    /// </summary>
    public class UploadDataItem
    {
        /// <summary>
        /// VRDFileToken
        /// </summary>
        /// <value>filetoken</value>
        public string VRDFileToken { get; set; }

        /// <summary>
        /// VRD文件大小
        /// </summary>
        /// <value>5832772</value>
        public long VRDFileSize { get; set; }

        /// <summary>
        /// VIDFileToken
        /// </summary>
        /// <value>VIDFileToken</value>
        public string VIDFileToken { get; set; }

        /// <summary>
        /// VIDFileSize
        /// </summary>
        /// <value>5832772</value>
        public string VIDFileSize { get; set; }

        /// <summary>
        /// URMFileToken
        /// </summary>
        /// <value>filetoken</value>
        public string URMFileToken { get; set; }

        /// <summary>
        /// URMFileSize
        /// </summary>
        /// <value>5832772</value>
        public string URMFileSize { get; set; }
    }

    /// <summary>
    /// 开始分析请求实体
    /// </summary>
    public class StartAnalysisRequest : TokenRequest
    {
        /// <summary>
        /// X轴坐标
        /// </summary>
        /// <value></value>
        public double X { get; set; }

        /// <summary>
        /// Y轴坐标
        /// </summary>
        /// <value></value>
        public double Y { get; set; }

        /// <summary>
        /// 高度
        /// </summary>
        /// <value></value>
        public double Width { get; set; }

        /// <summary>
        /// 宽度
        /// </summary>
        /// <value></value>
        public double Height { get; set; }

        /// <summary>
        /// 图像code
        /// </summary>
        /// <value></value>
        public string RemedicalCode { get; set; }
    }

    /// <summary>
    /// 批量分析请求实体
    /// </summary>
    public class BatchAnalysisRequest : TokenRequest
    {
        /// <summary>
        /// 批量分析列表
        /// </summary>
        /// <value></value>
        public List<AnalysisItem> AnalysisList { get; set; }
    }

    /// <summary>
    /// 分析任务请求实体
    /// </summary>
    public class AnalysisTaskRequest : TokenRequest
    {
        /// <summary>
        /// 子任务Code
        /// </summary>
        /// <value></value>
        public string TaskCode { get; set; }
    }

    /// <summary>
    /// 激活码请求实体
    /// </summary>
    public class ActivationLicenseRequest : TokenRequest
    {
        /// <summary>
        /// 激活码
        /// </summary>
        /// <value></value>
        public string LicenseCode { get; set; }
    }

    /// <summary>
    /// 批量分析任务请求实体
    /// </summary>
    public class BatchAnalysisTaskRequest : TokenRequest
    {
        /// <summary>
        /// 主任务Code
        /// </summary>
        /// <value></value>
        public string MainTaskCode { get; set; }
    }


    public class AnalysisItem
    {
        /// <summary>
        /// X轴坐标
        /// </summary>
        /// <value></value>
        public double X { get; set; }

        /// <summary>
        /// Y轴坐标
        /// </summary>
        /// <value></value>
        public double Y { get; set; }

        /// <summary>
        /// 高度
        /// </summary>
        /// <value></value>
        public double Width { get; set; }

        /// <summary>
        /// 宽度
        /// </summary>
        /// <value></value>
        public double Height { get; set; }

        /// <summary>
        /// 图像code
        /// </summary>
        /// <value></value>
        public string RemedicalCode { get; set; }

        /// <summary>
        /// CustomizedStartFrame
        /// </summary>
        /// <value></value>
        public int? CustomizedStartFrame { get; set; }

        /// <summary>
        /// CustomizedEndFrame
        /// </summary>
        /// <value></value>
        public int? CustomizedEndFrame { get; set; }

        /// <summary>
        /// RoiXPercent
        /// </summary>
        /// <value></value>
        public double RoiXPercent { get; set; }

        /// <summary>
        /// RoiYPercent
        /// </summary>
        /// <value></value>
        public double RoiYPercent { get; set; }

        /// <summary>
        /// RoiWPercent
        /// </summary>
        /// <value></value>
        public double RoiWPercent { get; set; }

        /// <summary>
        /// RoiHPercent
        /// </summary>
        /// <value></value>
        public double RoiHPercent { get; set; }
    }

    /// <summary>
    /// 保存分析视频
    /// </summary>
    public class SaveAnalysisVideoRequest : URMVideoProcessRequest
    {
        /// <summary>
        /// 底图Base64
        /// </summary>
        /// <value></value>
        public string BackgroundImage { get; set; }

        /// <summary>
        /// RoiXPercent
        /// </summary>
        /// <value></value>
        public double RoiXPercent { get; set; }

        /// <summary>
        /// RoiYPercent
        /// </summary>
        /// <value></value>
        public double RoiYPercent { get; set; }

        /// <summary>
        /// RoiWPercent
        /// </summary>
        /// <value></value>
        public double RoiWPercent { get; set; }

        /// <summary>
        /// RoiHPercent
        /// </summary>
        /// <value></value>
        public double RoiHPercent { get; set; }

        /// <summary>
        /// 左侧图像左上角X坐标
        /// </summary>
        /// <value></value>
        public double LeftImgTopLeftCornerXPercent { get; set; }

        /// <summary>
        /// 左侧图像左上角Y坐标
        /// </summary>
        /// <value></value>
        public double LeftImgTopLeftCornerYPercent { get; set; }

        /// <summary>
        /// 右侧图像左上角X坐标
        /// </summary>
        /// <value></value>
        public double RightImgTopLeftCornerXPercent { get; set; }

        /// <summary>
        /// 右侧图像左上角Y坐标
        /// </summary>
        /// <value></value>
        public double RightImgTopLeftCornerYPercent { get; set; }

        /// <summary>
        /// colorbar X坐标
        /// </summary>
        /// <value></value>
        public double ColorBarXPercent { get; set; }

        /// <summary>
        /// colorbar Y坐标
        /// </summary>
        /// <value></value>
        public double ColorBarYPercent { get; set; }
    }

    /// <summary>
    /// 保存分析视频
    /// </summary>
    public class SaveAnalysisVideoResult
    {
        /// <summary>
        /// 视频地址
        /// </summary>
        /// <value></value>
        public string VideoUrl { get; set; }

        /// <summary>
        /// 视频大小
        /// </summary>
        /// <value></value>
        public long VideoSize { get; set; }

        /// <summary>
        /// 视频预览图
        /// </summary>
        /// <value></value>
        public string CoverImgUrl { get; set; }
    }

    /// <summary>
    /// 项目样本数据导出请求实体
    /// </summary>
    public class GetProjectSampleDataExportRequest : TokenRequest
    {
        /// <summary>
        /// 项目code
        /// </summary>
        /// <value></value>
        public string ProjectCode { get; set; }

        /// <summary>
        /// 样本code列表
        /// </summary>
        /// <value></value>
        public IList<string> PatientCodes { get; set; }
    }

    /// <summary>
    /// 删除样本数据请求实体
    /// </summary>
    public class DeletePatientSampleRequest : TokenRequest
    {
        /// <summary>
        /// 项目code
        /// </summary>
        /// <value></value>
        public string ProjectCode { get; set; }

        /// <summary>
        /// 样本code
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }

        public string UserName { get; set; }

        public string UserCode { get; set; }
    }

}