using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.ResearchEdition
{
    /// <summary>
    /// 队列任务dto
    /// </summary>
    public class TaskDTO : TaskBaseDTO
    {
        /// <summary>
        /// 结果 成功、失败
        /// </summary>
        /// <value></value>
        public bool Result { get; set; }

        /// <summary>
        /// 描述
        /// </summary>
        /// <value></value>
        public string Description { get; set; }


        /// <summary>
        /// 主任务Code
        /// </summary>
        /// <value></value>
        public string MainTaskCode { get; set; }

        /// <summary>
        /// 是否是插队任务
        /// </summary>
        /// <value></value>
        public bool IsJumpQueue { get; set; }

        /// <summary>
        /// 任务进度（百分比）
        /// </summary>
        /// <value></value>
        public double Rate { get; set; }

        /// <summary>
        /// 是否加入队列处理（如果是非加入队列处理的为false）
        /// </summary>
        /// <value></value>
        public bool IsJoinQueue { get; set; } = false;

        /// <summary>
        /// id(客户端任务标识)
        /// </summary>
        /// <value></value>
        public string BusinessId { get; set; }

        public DateTime UpdateTime { get; set; }

        /// <summary>
        /// 任务所需Json数据
        /// </summary>
        /// <value></value>
        public string JsonData { get; set; }

    }


    /// <summary>
    /// 任务
    /// </summary>
    public class MainTaskDTO : TaskBaseDTO
    {
        /// <summary>
        /// 任务明细
        /// </summary>
        /// <value></value>
        public List<TaskDetail> TaskDetailList { get; set; }
    }


    /// <summary>
    /// 任务
    /// </summary>
    public class TaskBaseDTO
    {
        /// <summary>
        /// Code
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 创建人code
        /// </summary>
        /// <value></value>
        public string CreatorCode { get; set; }

        /// <summary>
        /// 创建人名称
        /// </summary>
        /// <value></value>
        public string CreatorName { get; set; }

        /// <summary>
        /// 创建时间
        /// </summary>
        /// <value></value>
        public DateTime CreateTime { get; set; }

        /// <summary>
        /// 操作人code
        /// </summary>
        /// <value></value>
        public string OperatorCode { get; set; }

        /// <summary>
        /// 操作人名称
        /// </summary>
        /// <value></value>
        public string OperatorName { get; set; }

        /// <summary>
        /// 操作人时间
        /// </summary>
        /// <value></value>
        public DateTime OperateTime { get; set; }

        /// <summary>
        /// 结束时间
        /// </summary>
        /// <value></value>
        public DateTime EndTime { get; set; }

        // /// <summary>
        // /// 结果 成功、失败
        // /// </summary>
        // /// <value></value>
        // public bool Result { get; set; } = false;

        /// <summary>
        /// 任务状态   主任务只有进行中和已完成
        /// </summary>
        /// <value></value>
        public VTaskStatus Status { get; set; }

        /// <summary>
        /// 任务类型
        /// </summary>
        /// <value></value>
        public VTaskType TaskType { get; set; }

        /// <summary>
        /// 任务名称
        /// </summary>
        /// <value></value>
        public string TaskName { get; set; }

        /// <summary>
        /// 业务编码
        /// </summary>
        /// <value></value>
        public string BusinessCode { get; set; }

        /// <summary>
        /// 样本编码
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }

    }

    /// <summary>
    /// 任务详情
    /// </summary>
    public class TaskDetail
    {
        /// <summary>
        /// TaskCode
        /// </summary>
        /// <value></value>
        public string TaskCode { get; set; }

        /// <summary>
        /// guid
        /// </summary>
        /// <value></value>
        public string Id { get; set; }

        /// <summary>
        /// 名称
        /// </summary>
        /// <value></value>
        public string Name { get; set; }

        /// <summary>
        /// 描述
        /// </summary>
        /// <value></value>
        public string Description { get; set; }

        /// <summary>
        /// 结果 成功、失败
        /// </summary>
        /// <value></value>
        public bool Result { get; set; } = false;

        /// <summary>
        /// 任务状态
        /// </summary>
        /// <value></value>
        public VTaskStatus Status { get; set; }

        /// <summary>
        /// 进度 %
        /// </summary>
        /// <value></value>
        public double Rate { get; set; }

        /// <summary>
        /// 业务编码
        /// </summary>
        /// <value></value>
        public string BusinessCode { get; set; }
    }

    /// <summary>
    /// 任务详情
    /// </summary>
    public class CreateTaskDetailInfo
    {
        /// <summary>
        /// guid
        /// </summary>
        /// <value></value>
        public string Id { get; set; }

        /// <summary>
        /// 名称
        /// </summary>
        /// <value></value>
        public string Name { get; set; }

        /// <summary>
        /// 描述
        /// </summary>
        /// <value></value>
        public string Description { get; set; }


    }

    /// <summary>
    /// 时间轴详情
    /// </summary>
    public class TimeAxisDetail
    {

        /// <summary>
        /// 操作人名称
        /// </summary>
        /// <value></value>
        public string OperatorName { get; set; }

        /// <summary>
        /// 操作人时间
        /// </summary>
        /// <value></value>
        public DateTime OperateTime { get; set; }

        /// <summary>
        /// 类型
        /// </summary>
        /// <value></value>
        public TimeAxisDetailEnum TimeAxisType { get; set; }

        /// <summary>
        /// DataJson
        /// </summary>
        /// <value></value>
        public string DataJson { get; set; }


    }

    /// <summary>
    /// 设备上传
    /// </summary>
    public class DeviceUploadTimeAxisJson
    {
        /// <summary>
        /// 样本(病人)code
        /// </summary>
        /// <value></value>
        public string PatientCode { get; set; }

        /// <summary>
        /// 检查code
        /// </summary>
        /// <value></value>
        public string RecordCode { get; set; }

        /// <summary>
        /// 图像code
        /// </summary>
        /// <value></value>
        public string RemedicalCode { get; set; }

    }

    /// <summary>
    /// 用户邀请/用户移除
    /// </summary>
    public class InviteUserTimeAxisJson
    {
        /// <summary>
        /// 用户code
        /// </summary>
        /// <value></value>
        public string UserCode { get; set; }

        /// <summary>
        /// 用户名
        /// </summary>
        /// <value></value>
        public string Name { get; set; }

    }

}