using System.Collections.Generic;
using System.Security.Cryptography.X509Certificates;
using WingInterfaceLibrary.DTO.Common;
using WingInterfaceLibrary.DTO.Record;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.RemedicalAISelected;

namespace WingInterfaceLibrary.ResearchEdition
{
    /// <summary>
    /// 保存用户URM配置信息 请求
    /// </summary>
    public class SaveUserUrmConfigRequest : TokenRequest
    {
        /// <summary>
        /// 用户科研URM配置编码
        /// </summary>
        /// <value></value>
        public string Code { get; set; }

        /// <summary>
        /// 配置名称
        /// </summary>
        /// <value></value>
        public string ConfigName { get; set; }

        /// <summary>
        /// 是否默认
        /// </summary>
        /// <value></value>
        public bool IsDefault { get; set; }

        /// <summary>
        /// 配置类型，1：URM后处理配置
        /// </summary>
        /// <value></value>
        public int ConfigType { get; set; }

        /// <summary>
        /// 配置详情
        /// </summary>
        /// <value></value>
        public List<UrmProcessConfigDTO> ConfigInfo { get; set; }

    }

    /// <summary>
    /// 保存用户URM配置信息 响应
    /// </summary>
    public class SaveUserUrmConfigResult
    {
        /// <summary>
        /// 用户科研URM配置编码
        /// </summary>
        /// <value></value>
        public string Code { get; set; }
    }

    /// <summary>
    /// 删除用户URM配置信息 请求
    /// </summary>
    public class DeletePatientUrmConfigRequest : TokenRequest
    {
        /// <summary>
        /// 用户科研URM配置编码
        /// </summary>
        /// <value></value>
        public string Code { get; set; }
    }

    /// <summary>
    /// 设置默认用户URM配置信息 请求
    /// </summary>
    public class SetDefaultPatientUrmConfigRequest : TokenRequest
    {
        /// <summary>
        /// 用户科研URM配置编码
        /// </summary>
        /// <value></value>
        public string Code { get; set; }
    }

    /// <summary>
    /// 查看用户URM配置集合 请求
    /// </summary>
    public class GetUserUrmConfigsRequest : TokenRequest
    {
    }

}