using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.Result.AppletAPI
{
    /// <summary>
    /// 用户信息
    /// </summary>
    public class GetUserInfoByOpenIdResult
    {
        /// <summary>
        /// NickName
        /// </summary>
        /// <value></value>
        public string NickName { get; set; }

        /// <summary>
        /// 医院
        /// </summary>
        /// <value></value>
        public string Hospital { get; set; }

        /// <summary>
        /// 用户id
        /// </summary>
        /// <value></value>
        public string UserId { get; set; }

    }

    /// <summary>
    /// 远程诊断
    /// </summary>
    public class RemedicalRecordInfo
    {
        /// <summary>
        /// id
        /// </summary>
        /// <value></value>
        public string RemedicalRecordId { get; set; }

        /// <summary>
        /// 设备
        /// </summary>
        /// <value></value>
        public string TerminalDesc { get; set; }

        /// <summary>
        /// 医院
        /// </summary>
        /// <value></value>
        public string OrganizationDesc { get; set; }

        /// <summary>
        /// 创建时间
        /// </summary>
        /// <value></value>
        public DateTime CreateTime { get; set; }

        /// <summary>
        /// 病人id
        /// </summary>
        /// <value></value>
        public string PatientId { get; set; }

        /// <summary>
        /// 病人名称
        /// </summary>
        /// <value></value>
        public string PatientName { get; set; }
        /// <summary>
        /// 性别
        /// </summary>
        /// <value></value>
        public PatientGenderEnum PatientGender { get; set; }
        /// <summary>
        /// 病人年龄
        /// </summary>
        /// <value></value>
        public string PatientAge { get; set; }
        /// <summary>
        /// 检查医生
        /// </summary>
        /// <value></value>
        public string ExamDoctor { get; set; }
        /// <summary>
        /// 扫查医生
        /// </summary>
        /// <value></value>
        public string CustomDoctor { get; set; }

        /// <summary>
        /// 是否上传报告
        /// </summary>
        /// <value></value>
        public bool ReportUploadStatus { get; set; }

        /// <summary>
        ///  AIDiagnosis Status
        /// </summary>
        /// <value></value>
        public RemedicalAIDiagnosisStatusEnum AIDiagnosisStatus { get; set; }
    }

    /// <summary>
    /// 扫查图像
    /// </summary>
    public class ImageData
    {

        /// <summary>
        /// Id
        /// </summary>
        /// <value></value>
        public string Id { get; set; }

        /// <summary>
        /// 类型
        /// </summary>
        /// <value></value>
        public RemedicalFileDataTypeEnum DataType { get; set; }

        /// <summary>
        /// Application
        /// </summary>
        /// <value></value>
        public string Application { get; set; }

        /// <summary>
        /// 预览图
        /// </summary>
        /// <value></value>
        public string PreviewFileToken { get; set; }

        /// <summary>
        /// 创建时间
        /// </summary>
        /// <value></value>
        public DateTime CreateTime { get; set; }

        /// <summary>
        /// 图像
        /// </summary>
        /// <value></value>
        public ImageFile File { get; set; }

    }

    /// <summary>
    /// 图像
    /// </summary>
    public class ImageFile
    {
        /// <summary>
        /// Id
        /// </summary>
        /// <value></value>
        public string Id { get; set; }
        /// <summary>
        /// 文件地址
        /// </summary>
        /// <value></value>
        public string FileUrl { get; set; }
        /// <summary>
        /// 创建时间
        /// </summary>
        /// <value></value>
        public DateTime CreateTime { get; set; }

    }

    /// <summary>
    /// 报告
    /// </summary>
    public class ReportInfo
    {
        /// <summary>
        /// 报告id
        /// </summary>
        /// <value></value>
        public string Id { get; set; }
        /// <summary>
        /// 报告
        /// </summary>
        /// <value></value>
        public IList<ReportImageInfo> PreviewImages { get; set; }
        /// <summary>
        /// 报告预览图
        /// </summary>
        /// <value></value>
        public string ReportPreviewJpg { get; set; }
    }

    /// <summary>
    /// 报告
    /// </summary>
    public class ReportImageInfo
    {
        /// <summary>
        /// ExamDataId
        /// </summary>
        /// <value></value>
        public string ExamDataId { get; set; }
        /// <summary>
        /// FileUrl
        /// </summary>
        /// <value></value>
        public string FileUrl { get; set; }
        /// <summary>
        /// Type
        /// </summary>
        /// <value></value>
        public AppletAPIImageType Type { get; set; }

    }

    /// <summary>
    /// 预约记录
    /// </summary>
    public class ConsultationInfo
    {
        /// <summary>
        /// 会诊记录id
        /// </summary>
        /// <value></value>

        public string ConsultationId { get; set; }

        /// <summary>
        /// 会诊单状态
        /// </summary>
        /// <value></value>
        public ConsultationState State { get; set; }

        /// <summary>
        /// 病人名称
        /// </summary>
        /// <value></value>
        public string PatientName { get; set; }

        /// <summary>
        /// 病人性别
        /// </summary>
        /// <value></value>
        public PatientGenderEnum PatientSex { get; set; }

        /// <summary>
        /// 病人年龄
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public string PatientAge { get; set; }

        /// <summary>
        /// 出生年月
        /// </summary>
        /// <value></value>
        public DateTime? Birthday { get; set; }

        /// <summary>
        /// 联系方式
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public string ContactInfo { get; set; }

        /// <summary>
        /// 病人ID
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public string PatientID { get; set; }

        /// <summary>
        /// 既往病史
        /// </summary>
        /// <value></value>
        public string History { get; set; }

        /// <summary>
        /// 初步诊断
        /// </summary>
        /// <value></value>
        public string PrimaryDiagnosis { get; set; }

        /// <summary>
        /// 预约医院
        /// </summary>
        /// <value></value>
        public string HospitalId { get; set; }

        /// <summary>
        /// 预约医院
        /// </summary>
        /// <value></value>
        public string HospitalName { get; set; }

        /// <summary>
        /// 申请医院
        /// </summary>
        /// <value></value>
        public string ApplyHospitalId { get; set; }

        /// <summary>
        /// 申请医院
        /// </summary>
        /// <value></value>
        public string ApplyHospitalName { get; set; }

        /// <summary>
        /// 预约专家
        /// </summary>
        /// <value></value>
        public string ExpertId { get; set; }

        /// <summary>
        /// 预约专家
        /// </summary>
        /// <value></value>
        public string ExpertName { get; set; }

        /// <summary>
        /// 预约日期
        /// </summary>
        /// <value></value>
        public DateTime ConsultationDate { get; set; }

        /// <summary>
        /// 检查部位
        /// </summary>
        /// <value></value>
        public string InspectionItems { get; set; }

        /// <summary>
        /// 扫查医生
        /// </summary>
        /// <value></value>
        public string ScanDoctorName { get; set; }

        /// <summary>
        /// 设备编号
        /// </summary>
        /// <value></value>
        public string DeviceModel { get; set; }

        /// <summary>
        /// 设备id
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public string TerminalId { get; set; }

        /// <summary>
        /// 图像列表
        /// </summary>
        /// <value></value>
        public IList<ImageTokenInfo> ImageTokens { get; set; }

        /// <summary>
        /// 视频列表
        /// </summary>
        /// <value></value>
        public IList<VideoTokenInfo> VideoInfos { get; set; }

        /// <summary>
        /// 报告列表
        /// </summary>
        /// <value></value>
        public IList<ReportPreviewPdf> ReportPreviewPdfs { get; set; }
    }

    /// <summary>
    /// ImageTokenInfo
    /// </summary>
    public class ImageTokenInfo
    {
        /// <summary>
        /// ImageToken
        /// </summary>
        /// <value></value>
        public string ImageToken { get; set; }

        /// <summary>
        /// 预览token
        /// </summary>
        /// <value></value>
        public string PreviewToken { get; set; }
    }

    /// <summary>
    /// VideoTokenInfo
    /// </summary>
    public class VideoTokenInfo
    {
        /// <summary>
        /// VideoToken
        /// </summary>
        /// <value></value>
        public string VideoToken { get; set; }

        /// <summary>
        /// 预览token
        /// </summary>
        /// <value></value>
        public string PreviewToken { get; set; }
    }

    /// <summary>
    /// ReportPreviewPdf
    /// </summary>
    public class ReportPreviewPdf
    {
        /// <summary>
        /// 报告id
        /// </summary>
        /// <value></value>
        public string ReportId { get; set; }

        /// <summary>
        /// 操作时间
        /// </summary>
        /// <value></value>
        public DateTime UpdateTime { get; set; }

        /// <summary>
        /// 报告url
        /// </summary>
        /// <value></value>
        public string PreviewPdfUrl { get; set; }
    }

    /// <summary>
    /// 设备信息
    /// </summary>
    public class TerminalInfo
    {
        public string Id { get; set; }
        /// <summary>
        /// Terminal belongs to the Organization
        /// </summary>
        public string OrganizationId { get; set; }
        /// <summary>
        /// Terminal belongs to the Organization description
        /// </summary>
        public string OrganizationDecription { get; set; }

        /// <summary>
        /// Terminal belongs to the Organization name
        /// </summary>
        public string OrganizationName { get; set; }

        /// <summary>
        /// Terminal Name
        /// </summary>
        public string Name { get; set; }

        /// <summary>
        /// Terminal Mode
        /// </summary>
        public string Model { get; set; }

        /// <summary>
        /// Terminal Description
        /// </summary>
        public string Description { get; set; }

        /// <summary>
        /// UniqueId
        /// </summary>
        /// <value></value>
        public string UniqueId { get; set; }




    }


    /// <summary>
    /// 医院基本信息
    /// </summary>
    public class OrganBaseInfo
    {
        /// <summary>
        /// 医院id
        /// </summary>
        /// <value></value>
        public string OrganizationId { get; set; }

        /// <summary>
        /// 医院名称
        /// </summary>
        /// <value></value>
        public string Name { get; set; }

    }

    /// <summary>
    /// 医生基本信息
    /// </summary>
    public class DoctorInfo
    {

        /// <summary>
        /// id
        /// </summary>
        /// <value></value>
        public string Id { get; set; }

        /// <summary>
        /// 对外显示名称
        /// </summary>
        /// <value></value>
        public string DisplayName { get; set; }
        /// <summary>
        /// 姓名
        /// </summary>
        /// <value></value>
        public string FullName { get; set; }

        /// <summary>
        /// 电子签名
        /// </summary>
        /// <value></value>
        public string ElectronSignUrl { get; set; }
    }

    /// <summary>
    /// 开始会诊响应结果
    /// </summary>
    public class StartConsultationResult
    {
        /// <summary>
        /// roomId
        /// </summary>
        /// <value></value>
        public string RoomId { get; set; }

        /// <summary>
        /// State
        /// </summary>
        public LiveStates State { get; set; }

        /// <summary>
        /// Integer room from server for TRTC
        /// </summary>
        public int IntegerRoomId { get; set; }

        /// <summary>
        /// Gets or sets the app id
        /// </summary>      
        public int AppId { get; set; }

        public List<LiveTerminalInfo> TerminalInfos { get; set; }


        public List<MeetingMemberInfo> MeetingMemberInfos { get; set; }
    }

    /// <summary>
    /// 设备
    /// </summary>
    public class LiveTerminalInfo
    {

        public bool TerminalLiveEnabled { get; set; }

        public bool CameraLiveEnabled { get; set; }

        /// <summary>
        /// Is merge living channel
        /// </summary>
        public bool IsMergeChannel { get; set; }
        /// <summary>
        /// Terminal screen width
        /// </summary>
        public int TerminalWidth { get; set; }
        /// <summary>
        /// Terminal screen height
        /// </summary>
        public int TerminalHeight { get; set; }

        public string CameraId { get; set; }

        public bool IsMultiChannels { get; set; }

        /// <summary>
        /// Camera width
        /// </summary>
        public int CameraWidth { get; set; }

        /// <summary>
        /// Camera height
        /// </summary>
        public int CameraHeight { get; set; }


        public int IntegerRoomId { get; set; }

        public int TerminalIntegerRoomId { get; set; }

        public LiveStates State { get; set; }

        public string Id { get; set; }


    }

    /// <summary>
    /// 会议成员信息
    /// </summary>
    public class MeetingMemberInfo
    {

        public LiveStates State { get; set; }
        public string Id { get; set; }
        public string Name { get; set; }
        public string DisplayName { get; set; }
        public string Avatar { get; set; }
        public string UserSign { get; set; }

    }

    /// <summary>
    /// 取消开始会诊响应结果
    /// </summary>
    public class CancelStartConsultationResult
    {
        /// <summary>
        /// LiveStates
        /// </summary>
        /// <value></value>
        public LiveStates LiveStates { get; set; }
    }

    /// <summary>
    /// 退出会诊响应结果
    /// </summary>
    public class ExitConsultationResult
    {
        /// <summary>
        /// LiveStates
        /// </summary>
        /// <value></value>
        public LiveStates LiveStates { get; set; }
    }

    /// <summary>
    /// 下载文件响应结果
    /// </summary>
    public class AppletAPIDownloadFileResult
    {
        /// <summary>
        /// 文件Base64String
        /// </summary>
        /// <value></value>
        public string FileString { get; set; }
    }

    /// <summary>
    /// 系统默认模板信息
    /// </summary>
    public class VinnoTemplateInfo
    {
        public string TemplateName { get; set; }
        public string TemplateUrl { get; set; }
    }

    public class ReportResultInfo
    {
        /// <summary>
        /// 报告id
        /// </summary>
        /// <value></value>
        public string Id { get; set; }

        /// <summary>
        /// 报告
        /// </summary>
        /// <value></value>
        public IList<ReportImageInfo> PreviewImages { get; set; }

        public string Template { get; set; }

        public IReadOnlyList<ReportElementMessage> ReportElementValues { get; set; }

        public IReadOnlyList<ReportMeasureElementMessage> ReportMeasureElementValues { get; set; }

        public IReadOnlyList<string> TagCodeList { get; set; }

        public DiagnosisOrganEnum Organ { get; set; }


        /// <summary>
        /// 质控状态
        /// </summary>
        public QualifiedState QualifiedState { get; set; }

        /// <summary>
        /// 质控类型
        /// </summary>
        public QualityType QualityType { get; set; }

    }

}