using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Courses;
using WingInterfaceLibrary.DTO.LiveRoom;
using WingInterfaceLibrary.DTO.RTC;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Enum.CourseEnum;
using WingInterfaceLibrary.LiveConsultation;

namespace WingInterfaceLibrary.Result.Education
{
    /// <summary>
    /// 开始直播课程响应实体
    /// </summary>
    public class InitiateLiveCourseResult: LiveCourseBaseResult
    {
        /// <summary>
        /// 发起人编码
        /// </summary>
        /// <value>UserDO_123456789</value>
        public string InitiatorCode { get; set; } = string.Empty;

        /// <summary>
        /// Room No. 
        /// </summary>
        /// <value></value>
        public int RoomNo { get; set; }

        /// <summary>
        /// 直播协议：TRTC、VRTC、Embedded
        /// </summary>
        /// <value>TRTC</value>
        public TransactionStatusEnum LiveProtocol { get; set; }

        /// <summary>
        /// Sdk app id
        /// </summary>
        /// <value></value>
        public int AppId { get; set; }

        /// <summary>
        /// User sign for rtc
        /// </summary>
        /// <value>123456</value>
        public string UserSign { get; set; } = string.Empty;

        /// <summary>
        /// 课程直播心跳间隔
        /// </summary>
        /// <value>10</value>
        public int HeartRateInterval { get; set; }

        /// <summary>
        /// 直播课成员列表
        /// </summary>
        /// <value>123456</value>
        public IList<LiveCourseMember> MemberLiveDatas { get; set; } = new List<LiveCourseMember>();        

        /// <summary>
        /// 课程分享直播信息
        /// </summary>
        /// <value></value>
        public LiveDataDTO CourseChannel { get; set; }

        /// <summary>
        /// 其他互动人员共享屏幕直播信息
        /// </summary>
        /// <value></value>
        public LiveDataDTO OthersScreenSharingChannel { get; set; }

        /// <summary>
        /// 桌面共享RTC信息
        /// </summary>
        /// <value></value>
        public ScreenSharingChannelDTO RtcScreenSharingChannel { get; set; }
    }

    /// <summary>
    /// 课程课程成员信息
    /// </summary>
    public class LiveCourseMember
    {
        /// <summary>
        ///用户编码
        /// </summary>
        /// <value>4914352a75f645279f6b4ad6764cc288</value>
        public string Id { get; set; }

        /// <summary>
        /// 用户或者设备名称
        /// </summary>
        /// <value>TestName</value>
        public string Name { get; set; }
        
        /// <summary>
        /// 成员类型
        /// </summary>
        /// <value>1</value>
        public LiveMemberEnum MemberType { get; set; }

        /// <summary>
        /// 头像
        /// </summary>
        /// <value></value>
        public string HeadImageToken { get; set; }

        /// <summary>
        /// 人员状态
        /// </summary>
        /// <value></value>
        public UserStatusEnum UserStatusType { get; set; }

        /// <summary>
        /// 是否静音
        /// </summary>
        /// <value>false</value>
        public bool Mute { get; set; }

        /// <summary>
        /// 是否开启视频
        /// </summary>
        /// <value>true</value>
        public bool VideoOpend { get; set; } = true;

        /// <summary>
        /// 是否直播老师
        /// </summary>
        /// <value>true</value>
        public bool IsTeacher { get; set; }

        /// <summary>
        /// 是否参与人
        /// </summary>
        /// <value>true</value>
        public bool IsExpertUser { get; set; }

        /// <summary>
        /// 是否助教
        /// </summary>
        /// <value>true</value>
        public bool IsAssistantUser { get; set; }

        /// <summary>
        /// 成员课程状态
        /// </summary>
        /// <value>1</value>
        public LiveMemberStatus Status { get; set; }

        /// <summary>
        /// 登录服务器地址
        /// </summary>
        /// <value></value>
        public string LoginServerUrl { get; set; }

        /// <summary>
        /// 登录源
        /// </summary>
        /// <value></value>
        public LoginSource LoginSource { get; set; }

        /// <summary>
        ///视频数据流信息
        /// </summary>
        /// <value></value>
        public LiveDataDTO LiveData { get; set; }
        
        /// <summary>
        /// 多路画面时，设备输出信息
        /// </summary>
        /// <value></value>
        public IList<VideoDeviceOutputInfo> VideoDeviceInfos { get; set; } = new List<VideoDeviceOutputInfo>();

        /// <summary>
        /// 是否调参中
        /// </summary>
        /// <value>false</value>
        public bool IsControllingParameter{ get; set; }

        /// <summary>
        /// 是否把多路视屏合流
        /// </summary>
        /// <value>true</value>
        public bool MergedChannel { get; set; }
        /// <summary>
        /// 合流的画面宽度
        /// </summary>
        /// <value>1920</value>
        public int MergedVideoOutputWidth { get; set; }

        /// <summary>
        /// 合流的画面高度
        /// </summary>
        /// <value>1080</value>
        public int MergedVideoOutputHeight { get; set; }

        /// <summary>
        /// 直播协议
        /// </summary>
        /// <value>rtmp</value>
        public TransactionStatusEnum LiveProtocol { get; set; }

       
        /// <summary>
        /// 是否后台管理角色-用于只加入房间 自己无摄像头画面无语音，用于课程助教或者会诊管理员角色
        /// </summary>
        /// <value></value>
        public bool  BackgroundRole  { get; set; }
    }
}
