using System.Collections.Generic;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.Result.Languge
{
    /// <summary>
    /// 服务器配置返回实体
    /// /// </summary>
    public class ServerSettingResult
    {
        /// <summary>
        /// server支持语言
        /// </summary>
        /// <value></value>
        public List<ServerLangugeClass> ServerLangugeList { get; set; } = new List<ServerLangugeClass>();

        /// <summary>
        /// server配置信息
        /// </summary>
        /// <typeparam name="string">HeartRateSeconds</typeparam>
        /// <typeparam name="string">300</typeparam>
        /// <returns></returns>
        public Dictionary<string, string> ServerConfigList { get; set; } = new Dictionary<string, string>();

        /// <summary>
        /// 心跳间隔秒数
        /// </summary>
        /// <value>300</value>
        public int HeartRateSeconds { get; set; }

        /// <summary>
        /// 会诊列表默认查询间隔天数
        /// </summary>
        /// <value>30</value>
        public int LiveConsultationDefaultQueryDays { get; set; }

        /// <summary>
        /// 通知URL地址
        /// </summary>
        /// <value>ws://127.0.0.1:9301?token=</value>
        public string NotificationUrl { get; set; }

        /// <summary>
        /// 会诊心跳间隔秒数
        /// </summary>  
        /// <value>10</value>
        public int LiveConsultationRateSeconds { get; set; }

        /// <summary>
        /// CMSUrl地址
        /// </summary>
        /// <value>http://127.0.0.1:9302/cmsTemplatePreview?token=</value>
        public string CMSUrl { get; set; }

        /// <summary>
        /// 我的课程 CourseUrl地址
        /// </summary>
        /// <value>http://192.168.6.117:8080/open/school/#/my_course/</value>
        public string CourseUrl { get; set; }

        /// <summary>
        /// 课程首页 CourseUrl地址
        /// </summary>
        /// <value>http://192.168.6.117:8080/open/school/#/course/</value>
        public string CourseHomeUrl { get; set; }

        /// <summary>
        /// 课程接口API地址 
        /// </summary>
        /// <value>http://127.0.0.1:8303</value>
        public string CourseAPIUrl { get; set; }

        /// <summary>
        /// 是否自研rtc 是：自研 否：腾讯
        /// </summary>
        /// <value></value>
        public bool IsSelfRtcService { get; set; }

        /// <summary>
        /// 直播协议：TRTC、VRTC、Embedded
        /// </summary>
        /// <value></value>
        public string LiveProtocol { get; set; }

        /// <summary>
        /// 直播协议
        /// </summary>
        /// <value></value>
        public TransactionStatusEnum LiveProtocolType { get; set; }

        /// <summary>
        /// 是否开启短信服务
        /// </summary>
        /// <value></value>
        public bool IsSMSOn { get; set; } = true;

        /// <summary>
        /// 是否开启语音识别服务
        /// </summary>
        /// <value></value>
        public bool IsASROn { get; set; } = true;

        /// <summary>
        /// web域名
        /// </summary>
        /// <value></value>
        public string WebServerUrl { get; set; } = "";

        /// <summary>
        /// 会诊超时次数
        /// </summary>
        /// <value>10</value>
        public int ConsultationTimeoutTimes { get; set; }

        /// <summary>
        /// 质控总开关
        /// </summary>
        /// <value>false</value>
        public bool QualityControlSwitch { get; set; } = false;

        /// <summary>
        /// 是否SP60截图版
        /// </summary>
        /// <value>false</value>
        public bool IsScreenshot { get; set; } = false;

        /// <summary>
        /// ManageUrl地址
        /// </summary>
        /// <value>http://127.0.0.1:9302/login?token=&dongleId=</value>
        public string ManageUrl { get; set; }

    }

    /// <summary>
    /// server支持语言明细
    /// </summary>
    public class ServerLangugeClass
    {
        /// <summary>
        /// 语言key
        /// </summary>
        /// <value></value>
        public string LangugeKey { get; set; }

        /// <summary>
        /// 语言配置模块
        /// </summary>
        /// <value></value>
        public List<string> LangugeModules { get; set; } = new List<string>();
    }

    /// <summary>
    /// 语言配置列表返回实体
    /// </summary>
    public class LangugeDataResult
    {
        /// <summary>
        /// 版本
        /// </summary>
        /// <value></value>
        public string Version { get; set; }

        /// <summary>
        /// 内容
        /// </summary>
        /// <value></value>
        public string Content { get; set; }

        /// <summary>
        /// 语言配置模块
        /// </summary>
        /// <value></value>
        public string LangugeModule { get; set; }
    }
}