using System;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Common;
using WingInterfaceLibrary.DTO.Record;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.Result.Record
{
    /// <summary>
    /// 导出诊断数据
    /// </summary>
    public class ExportRemedicalDataResult
    {

        /// <summary>
        /// 检查记录列表
        /// </summary>
        /// <value></value>
        public List<RecordData> RecordList { get; set; } = new List<RecordData>();

        /// <summary>
        /// 报告列表
        /// </summary>
        /// <value></value>
        public List<ReportData> ReportList { get; set; } = new List<ReportData>();

        /// <summary>
        /// 扫查图像列表
        /// </summary>
        /// <value></value>
        public List<RemedicalData> RemedicalList { get; set; } = new List<RemedicalData>();

    }

    /// <summary>
    /// 检查数据
    /// </summary>
    public class RecordData
    {
        /// <summary>
        /// 病人名字
        /// </summary>
        /// <value>张三</value>
        public string PatientName { get; set; }

        /// <summary>
        /// 病人编号
        /// </summary>
        /// <value>xxx</value>
        public string PatientCode { get; set; }

        /// <summary>
        /// 检查列表
        /// </summary>
        /// <value></value>
        public List<RecordInfoDTO> RecordItemList { get; set; } = new List<RecordInfoDTO>();
    }

    /// <summary>
    /// 报告数据
    /// </summary>
    public class ReportData
    {
        /// <summary>
        /// 病人名字
        /// </summary>
        /// <value>张三</value>
        public string PatientName { get; set; }

        /// <summary>
        /// 病人编号
        /// </summary>
        /// <value>xxx</value>
        public string PatientCode { get; set; }

        /// <summary>
        /// 报告列表
        /// </summary>
        /// <value></value>
        public List<ReportItem> ReportItemList { get; set; } = new List<ReportItem>();


    }

    /// <summary>
    /// 报告明细
    /// </summary>
    public class ReportItem
    {
        /// <summary>
        /// 对应检查
        /// </summary>
        /// <value></value>
        public string RecordCode { get; set; }

        /// <summary>
        /// 报告code
        /// </summary>
        /// <value></value>
        public string ReportCode { get; set; }

        /// <summary>
        /// 报告fileToken
        /// </summary>
        /// <value></value>
        public string FileToken { get; set; }

        /// <summary>
        /// 创建时间
        /// </summary>
        /// <value></value>
        public DateTime CreateTime { get; set; }

        /// <summary>
        /// 报告时间
        /// </summary>
        /// <value></value>
        public DateTime ReportTime { get; set; }
    }

    /// <summary>
    /// 扫查图像
    /// </summary>
    public class RemedicalData
    {
        public string PatientName { get; set; }

        public string PatientCode { get; set; }

        /// <summary>
        /// 图像列表
        /// </summary>
        /// <value></value>
        public List<RemedicalItem> RemedicalItemList { get; set; } = new List<RemedicalItem>();

    }

    /// <summary>
    /// 扫查图像明细
    /// </summary>
    public class RemedicalItem
    {
        /// <summary>
        /// 对应检查
        /// </summary>
        /// <value></value>
        public string RecordCode { get; set; }

        /// <summary>
        /// 扫查图像fileToken
        /// </summary>
        /// <value></value>
        public string FileToken { get; set; }

        /// <summary>
        /// 文件数据类型
        /// </summary>
        /// <value>0</value>
        public RemedicalFileDataTypeEnum FileDataType { get; set; }
    }
}