using System;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Record;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.DTO.Common;

namespace WingInterfaceLibrary.Result.Record
{
    /// <summary>
    /// 查询检查响应实体
    /// </summary>
    public class QueryRecordResult
    {
        /// <summary>
        /// 时间
        /// </summary>
        /// <value>2021-11-16  11:30</value>
        public DateTime CreateTime { get; set; }
        /// <summary>
        /// 部门
        /// </summary>
        /// <value>门诊部</value>
        public string DeptName { get; set; }
        /// <summary>
        /// 病人姓名
        /// </summary>
        /// <value>张三</value>
        public string PatientName { get; set; }
        /// <summary>
        /// 病人年龄
        /// </summary>
        /// <value>27</value>
        /// <code>0</code>
        public string PatientAge { get; set; }

        /// <summary>
        /// 病人年龄信息
        /// </summary>
        /// <value></value>
        public List<DataItemDTO> PatientAgeInfo { get; set; }

        /// <summary>
        /// 病人种类信息
        /// </summary>
        /// <value></value>
        public DataItemDTO PatientSpeciesInfo { get; set; }

        /// <summary>
        /// 病人性别
        /// </summary>
        /// <value>0</value>
        public int PatientSex { get; set; }
        /// <summary>
        /// 检查医生
        /// </summary>
        /// <value>绩笑</value>
        public string CreatorName { get; set; }
        /// <summary>
        /// 下发设备
        /// </summary>
        /// <value>演示超声机2号</value>
        public string DeviceName { get; set; }

        /// <summary>
        /// 设备展示名称
        /// </summary>
        /// <value></value>
        public string DisplayName { get; set; }

        /// <summary>
        /// 检查状态
        /// </summary>
        public RecordStatusEnum RecordStatus { get; set; }
        /// <summary>
        /// 病人额外信息列表
        /// </summary>
        /// <value></value>
        public List<PatientInfoExt> PatientInfoExtList { get; set; }

        /// <summary>
        /// AI诊断状态
        /// </summary>
        /// <value>2</value>
        public DiagnosisStatusEnum DiagnosisStatus { get; set; }

        /// <summary>
        /// AI诊断结果
        /// </summary>
        /// <value></value>
        public List<DiagnosisInfoDTO> DiagnosisInfos { get; set; } = new List<DiagnosisInfoDTO>();

        /// <summary>
        /// 是否采图中
        /// </summary>
        /// <value></value>
        public bool IsCollecting { get; set; }

        /// <summary>
        /// 开始采图时间
        /// </summary>
        /// <value></value>
        public DateTime StartCollectingTime { get; set; }

        /// <summary>
        /// 国家脑卒中项目，掌超上传医生
        /// </summary>
        /// <value></value>
        public string CustomDoctor { get; set; }

        /// <summary>
        /// 国家脑卒中项目，掌超上传医院
        /// </summary>
        /// <value></value>
        public string CustomOrganzation { get; set; }

        /// <summary>
        /// 国家脑卒中项目，掌超上传设备SN
        /// </summary>
        /// <value></value>
        public string EquipmentSN { get; set; }

        /// <summary>
        /// 设备医院名称
        /// </summary>
        /// <value></value>
        public string DeviceOrganzationName { get; set; }

        /// <summary>
        /// 是否转出
        /// </summary>
        /// <value></value>
        public bool IsReferral { get; set; }

        /// <summary>
        //  转诊状态 0-普通，1-转出，2-转入
        /// </summary>
        /// <value></value>
        public ReferralTypeEnum ReferralType { get; set; }

        /// <summary>
        /// 病人编码
        /// </summary>
        public string PatientCode { get; set; }

        /// <summary>
        /// 是否可以创建报告
        /// </summary>
        /// <value></value>
        public bool CanCreateReport { get; set; }

        /// <summary>
        /// 检查时间
        /// </summary>
        /// <value></value>
        public DateTime? ExamTime { get; set; }

        /// <summary>
        /// 是否已质控（有一个即算）
        /// </summary>
        /// <value></value>
        public bool IsQualityControlled { get; set; }


        /// <summary>
        /// 质控总分
        /// </summary>
        /// <value></value>
        public double Score { get; set; }


    }
}